diff -pruN 1.3.1+dfsg-1/base/abstractarray.jl 1.4.0+dfsg-1/base/abstractarray.jl
--- 1.3.1+dfsg-1/base/abstractarray.jl	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/base/abstractarray.jl	2020-03-21 16:36:32.000000000 +0000
@@ -212,7 +212,7 @@ eachindex(itrs...) = keys(itrs...)
 eachindex(A::AbstractVector) = (@_inline_meta(); axes1(A))
 
 @noinline function throw_eachindex_mismatch(::IndexLinear, A...)
-    throw(DimensionMismatch("all inputs to eachindex must have the same indices, got $(join(LinearIndices.(A), ", ", " and "))"))
+    throw(DimensionMismatch("all inputs to eachindex must have the same indices, got $(join(eachindex.(A), ", ", " and "))"))
 end
 @noinline function throw_eachindex_mismatch(::IndexCartesian, A...)
     throw(DimensionMismatch("all inputs to eachindex must have the same axes, got $(join(axes.(A), ", ", " and "))"))
@@ -232,9 +232,8 @@ If you supply more than one `AbstractArr
 iterable object that is fast for all arguments (a [`UnitRange`](@ref)
 if all inputs have fast linear indexing, a [`CartesianIndices`](@ref)
 otherwise).
-If the arrays have different sizes and/or dimensionalities, `eachindex` will return an
-iterable that spans the largest range along each dimension.
-
+If the arrays have different sizes and/or dimensionalities, a DimensionMismatch exception
+will be thrown.
 # Examples
 ```jldoctest
 julia> A = [1 2; 3 4];
diff -pruN 1.3.1+dfsg-1/base/abstractarraymath.jl 1.4.0+dfsg-1/base/abstractarraymath.jl
--- 1.3.1+dfsg-1/base/abstractarraymath.jl	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/base/abstractarraymath.jl	2020-03-21 16:36:32.000000000 +0000
@@ -69,7 +69,7 @@ julia> dropdims(a; dims=3)
 """
 dropdims(A; dims) = _dropdims(A, dims)
 function _dropdims(A::AbstractArray, dims::Dims)
-    for i in 1:length(dims)
+    for i in eachindex(dims)
         1 <= dims[i] <= ndims(A) || throw(ArgumentError("dropped dims must be in range 1:ndims(A)"))
         length(axes(A, dims[i])) == 1 || throw(ArgumentError("dropped dims must all be size 1"))
         for j = 1:i-1
@@ -119,7 +119,7 @@ julia> selectdim(A, 2, 3)
  7
 ```
 """
-@inline selectdim(A::AbstractArray, d::Integer, i) = _selectdim(A, d, i, setindex(map(Slice, axes(A)), i, d))
+@inline selectdim(A::AbstractArray, d::Integer, i) = _selectdim(A, d, i, _setindex(i, d, map(Slice, axes(A))...))
 @noinline function _selectdim(A, d, i, idxs)
     d >= 1 || throw(ArgumentError("dimension must be ≥ 1, got $d"))
     nd = ndims(A)
@@ -375,7 +375,7 @@ _reperr(s, n, N) = throw(ArgumentError("
     end
 
     # fill the first inner block
-    if all(x -> x == 1, inner)
+    if all(isequal(1), inner)
         idxs = (axes(A)..., ntuple(n->OneTo(1), ndims(R)-ndims(A))...) # keep dimension consistent
         R[idxs...] = A
     else
@@ -390,12 +390,12 @@ _reperr(s, n, N) = throw(ArgumentError("
     end
 
     # fill the outer blocks along each dimension
-    if all(x -> x == 1, outer)
+    if all(isequal(1), outer)
         return R
     end
     src_indices  = [1:n for n in inner_shape]
     dest_indices = copy(src_indices)
-    for i in 1:length(outer)
+    for i in eachindex(outer)
         B = view(R, src_indices...)
         for j in 2:outer[i]
             dest_indices[i] = dest_indices[i] .+ inner_shape[i]
@@ -452,6 +452,7 @@ See also [`eachrow`](@ref), [`eachcol`](
     length(dims) == 1 || throw(ArgumentError("only single dimensions are supported"))
     dim = first(dims)
     dim <= ndims(A) || throw(DimensionMismatch("A doesn't have $dim dimensions"))
-    idx1, idx2 = ntuple(d->(:), dim-1), ntuple(d->(:), ndims(A)-dim)
-    return (view(A, idx1..., i, idx2...) for i in axes(A, dim))
+    inds_before = ntuple(d->(:), dim-1)
+    inds_after = ntuple(d->(:), ndims(A)-dim)
+    return (view(A, inds_before..., i, inds_after...) for i in axes(A, dim))
 end
diff -pruN 1.3.1+dfsg-1/base/abstractdict.jl 1.4.0+dfsg-1/base/abstractdict.jl
--- 1.3.1+dfsg-1/base/abstractdict.jl	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/base/abstractdict.jl	2020-03-21 16:36:32.000000000 +0000
@@ -77,7 +77,8 @@ function keys end
 
 Return an iterator over all keys in a dictionary.
 `collect(keys(a))` returns an array of keys.
-Since the keys are stored internally in a hash table,
+When the keys are stored internally in a hash table,
+as is the case for `Dict`,
 the order in which they are returned may vary.
 But `keys(a)` and `values(a)` both iterate `a` and
 return the elements in the same order.
@@ -102,7 +103,8 @@ keys(a::AbstractDict) = KeySet(a)
 
 Return an iterator over all values in a collection.
 `collect(values(a))` returns an array of values.
-Since the values are stored internally in a hash table,
+When the values are stored internally in a hash table,
+as is the case for `Dict`,
 the order in which they are returned may vary.
 But `keys(a)` and `values(a)` both iterate `a` and
 return the elements in the same order.
@@ -708,8 +710,8 @@ end
     map!(f, values(dict::AbstractDict))
 
 Modifies `dict` by transforming each value from `val` to `f(val)`.
-Note that the type of `dict` cannot be changed: if `f(val)` is not an instance of the key type
-of `dict` then it will be converted to the key type if possible and otherwise raise an error.
+Note that the type of `dict` cannot be changed: if `f(val)` is not an instance of the value type
+of `dict` then it will be converted to the value type if possible and otherwise raise an error.
 
 # Examples
 ```jldoctest
@@ -719,10 +721,10 @@ Dict{Symbol,Int64} with 2 entries:
   :b => 2
 
 julia> map!(v -> v-1, values(d))
-Dict{Symbol,Int64} with 2 entries:
-  :a => 0
-  :b => 1
- ```
+Base.ValueIterator for a Dict{Symbol,Int64} with 2 entries. Values:
+  0
+  1
+```
 """
 function map!(f, iter::ValueIterator)
     # This is the naive fallback which requires hash evaluations
diff -pruN 1.3.1+dfsg-1/base/abstractset.jl 1.4.0+dfsg-1/base/abstractset.jl
--- 1.3.1+dfsg-1/base/abstractset.jl	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/base/abstractset.jl	2020-03-21 16:36:32.000000000 +0000
@@ -35,7 +35,10 @@ julia> union([4, 2], 1:2)
  1
 
 julia> union(Set([1, 2]), 2:3)
-Set([2, 3, 1])
+Set{Int64} with 3 elements:
+  2
+  3
+  1
 ```
 """
 function union end
@@ -60,7 +63,12 @@ julia> a = Set([1, 3, 4, 5]);
 julia> union!(a, 1:2:8);
 
 julia> a
-Set([7, 4, 3, 5, 1])
+Set{Int64} with 5 elements:
+  7
+  4
+  3
+  5
+  1
 ```
 """
 function union!(s::AbstractSet, sets...)
@@ -105,7 +113,8 @@ julia> intersect([1, 4, 4, 5, 6], [4, 6,
  6
 
 julia> intersect(Set([1, 2]), BitSet([2, 3]))
-Set([2])
+Set{Int64} with 1 element:
+  2
 ```
 """
 intersect(s::AbstractSet, itr, itrs...) = intersect!(intersect(s, itr), itrs...)
@@ -160,7 +169,8 @@ julia> a = Set([1, 3, 4, 5]);
 julia> setdiff!(a, 1:2:6);
 
 julia> a
-Set([4])
+Set{Int64} with 1 element:
+  4
 ```
 """
 function setdiff!(s::AbstractSet, itrs...)
@@ -251,16 +261,15 @@ true
 issubset, ⊆, ⊇
 
 function issubset(l, r)
-    if haslength(r)
-        rlen = length(r)
-        if isa(l, AbstractSet)
-            # check l for too many unique elements
-            length(l) > rlen && return false
+    if haslength(r) && (isa(l, AbstractSet) || !hasfastin(r))
+        rlen = length(r) # conditions above make this length computed only when needed
+        # check l for too many unique elements
+        if isa(l, AbstractSet) && length(l) > rlen
+            return false
         end
-        # if r is big enough, convert it to a Set
-        # threshold empirically determined by repeatedly
-        # sampling using these two methods (see #26198)
-        if rlen > 70 && !isa(r, AbstractSet)
+        # when `in` would be too slow and r is big enough, convert it to a Set
+        # this threshold was empirically determined (cf. #26198)
+        if !hasfastin(r) && rlen > 70
             return issubset(l, Set(r))
         end
     end
@@ -270,6 +279,19 @@ function issubset(l, r)
     return true
 end
 
+"""
+    hasfastin(T)
+
+Determine whether the computation `x ∈ collection` where `collection::T` can be considered
+as a "fast" operation (typically constant or logarithmic complexity).
+The definition `hasfastin(x) = hasfastin(typeof(x))` is provided for convenience so that instances
+can be passed instead of types.
+However the form that accepts a type argument should be defined for new types.
+"""
+hasfastin(::Type) = false
+hasfastin(::Union{Type{<:AbstractSet},Type{<:AbstractDict},Type{<:AbstractRange}}) = true
+hasfastin(x) = hasfastin(typeof(x))
+
 ⊇(l, r) = r ⊆ l
 
 ## strict subset comparison
diff -pruN 1.3.1+dfsg-1/base/array.jl 1.4.0+dfsg-1/base/array.jl
--- 1.3.1+dfsg-1/base/array.jl	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/base/array.jl	2020-03-21 16:36:32.000000000 +0000
@@ -158,7 +158,7 @@ size(a::Array{<:Any,N}) where {N} = (@_i
 
 asize_from(a::Array, n) = n > ndims(a) ? () : (arraysize(a,n), asize_from(a, n+1)...)
 
-allocatedinline(::Type{T}) where {T} = (@_pure_meta; ccall(:jl_array_store_unboxed, Cint, (Any,), T) != Cint(0))
+allocatedinline(::Type{T}) where {T} = (@_pure_meta; ccall(:jl_stored_inline, Cint, (Any,), T) != Cint(0))
 
 """
     Base.isbitsunion(::Type{T})
@@ -174,19 +174,24 @@ julia> Base.isbitsunion(Union{Float64, S
 false
 ```
 """
-isbitsunion(u::Union) = (@_pure_meta; ccall(:jl_array_store_unboxed, Cint, (Any,), u) != Cint(0))
+isbitsunion(u::Union) = allocatedinline(u)
 isbitsunion(x) = false
 
-isptrelement(t::Type) = (@_pure_meta; ccall(:jl_array_store_unboxed, Cint, (Any,), t) == Cint(0))
-
 function _unsetindex!(A::Array{T}, i::Int) where {T}
+    @_inline_meta
     @boundscheck checkbounds(A, i)
-    if isptrelement(T)
-        t = @_gc_preserve_begin A
-        p = Ptr{Ptr{Cvoid}}(pointer(A))
-        unsafe_store!(p, C_NULL, i)
-        @_gc_preserve_end t
+    t = @_gc_preserve_begin A
+    p = Ptr{Ptr{Cvoid}}(pointer(A, i))
+    if !allocatedinline(T)
+        unsafe_store!(p, C_NULL)
+    elseif T isa DataType
+        if !datatype_pointerfree(T)
+            for j = 1:(Core.sizeof(T) ÷ Core.sizeof(Ptr{Cvoid}))
+                unsafe_store!(p, C_NULL, j)
+            end
+        end
     end
+    @_gc_preserve_end t
     return A
 end
 
@@ -239,7 +244,7 @@ segfault your program, in the same manne
 function unsafe_copyto!(dest::Ptr{T}, src::Ptr{T}, n) where T
     # Do not use this to copy data between pointer arrays.
     # It can't be made safe no matter how carefully you checked.
-    ccall(:memmove, Ptr{Cvoid}, (Ptr{Cvoid}, Ptr{Cvoid}, UInt),
+    ccall(:memmove, Ptr{Cvoid}, (Ptr{Cvoid}, Ptr{Cvoid}, Csize_t),
           dest, src, n * aligned_sizeof(T))
     return dest
 end
@@ -257,19 +262,41 @@ the same manner as C.
 function unsafe_copyto!(dest::Array{T}, doffs, src::Array{T}, soffs, n) where T
     t1 = @_gc_preserve_begin dest
     t2 = @_gc_preserve_begin src
-    if isbitstype(T)
-        unsafe_copyto!(pointer(dest, doffs), pointer(src, soffs), n)
+    destp = pointer(dest, doffs)
+    srcp = pointer(src, soffs)
+    if !allocatedinline(T)
+        ccall(:jl_array_ptr_copy, Cvoid, (Any, Ptr{Cvoid}, Any, Ptr{Cvoid}, Int),
+              dest, destp, src, srcp, n)
+    elseif isbitstype(T)
+        ccall(:memmove, Ptr{Cvoid}, (Ptr{Cvoid}, Ptr{Cvoid}, Csize_t),
+              destp, srcp, n * aligned_sizeof(T))
     elseif isbitsunion(T)
-        ccall(:memmove, Ptr{Cvoid}, (Ptr{Cvoid}, Ptr{Cvoid}, UInt),
-              pointer(dest, doffs), pointer(src, soffs), n * aligned_sizeof(T))
+        ccall(:memmove, Ptr{Cvoid}, (Ptr{Cvoid}, Ptr{Cvoid}, Csize_t),
+              destp, srcp, n * aligned_sizeof(T))
         # copy selector bytes
-        ccall(:memmove, Ptr{Cvoid}, (Ptr{Cvoid}, Ptr{Cvoid}, UInt),
+        ccall(:memmove, Ptr{Cvoid}, (Ptr{Cvoid}, Ptr{Cvoid}, Csize_t),
               ccall(:jl_array_typetagdata, Ptr{UInt8}, (Any,), dest) + doffs - 1,
               ccall(:jl_array_typetagdata, Ptr{UInt8}, (Any,), src) + soffs - 1,
               n)
     else
-        ccall(:jl_array_ptr_copy, Cvoid, (Any, Ptr{Cvoid}, Any, Ptr{Cvoid}, Int),
-              dest, pointer(dest, doffs), src, pointer(src, soffs), n)
+        # handle base-case: everything else above was just optimizations
+        @inbounds if destp < srcp || destp > srcp + n
+            for i = 1:n
+                if isassigned(src, soffs + i - 1)
+                    dest[doffs + i - 1] = src[soffs + i - 1]
+                else
+                    _unsetindex!(dest, doffs + i - 1)
+                end
+            end
+        else
+            for i = n:-1:1
+                if isassigned(src, soffs + i - 1)
+                    dest[doffs + i - 1] = src[soffs + i - 1]
+                else
+                    _unsetindex!(dest, doffs + i - 1)
+                end
+            end
+        end
     end
     @_gc_preserve_end t2
     @_gc_preserve_end t1
@@ -387,11 +414,15 @@ to_dim(d::Integer) = d
 to_dim(d::OneTo) = last(d)
 
 """
-    fill(x, dims)
+    fill(x, dims::Tuple)
+    fill(x, dims...)
 
 Create an array filled with the value `x`. For example, `fill(1.0, (5,5))` returns a 5×5
 array of floats, with each element initialized to `1.0`.
 
+`dims` may be specified as either a tuple or a sequence of arguments. For example,
+the common idiom `fill(x)` creates a zero-dimensional array containing the single value `x`.
+
 # Examples
 ```jldoctest
 julia> fill(1.0, (5,5))
@@ -401,17 +432,28 @@ julia> fill(1.0, (5,5))
  1.0  1.0  1.0  1.0  1.0
  1.0  1.0  1.0  1.0  1.0
  1.0  1.0  1.0  1.0  1.0
+
+julia> fill(0.5, 1, 2)
+1×2 Array{Float64,2}:
+ 0.5  0.5
+
+julia> fill(42)
+0-dimensional Array{Int64,0}:
+42
 ```
 
 If `x` is an object reference, all elements will refer to the same object. `fill(Foo(),
 dims)` will return an array filled with the result of evaluating `Foo()` once.
 """
+function fill end
+
 fill(v, dims::DimOrInd...) = fill(v, dims)
 fill(v, dims::NTuple{N, Union{Integer, OneTo}}) where {N} = fill(v, map(to_dim, dims))
 fill(v, dims::NTuple{N, Integer}) where {N} = (a=Array{typeof(v),N}(undef, dims); fill!(a, v); a)
 fill(v, dims::Tuple{}) = (a=Array{typeof(v),0}(undef, dims); fill!(a, v); a)
 
 """
+    zeros([T=Float64,] dims::Tuple)
     zeros([T=Float64,] dims...)
 
 Create an `Array`, with element type `T`, of all zeros with size specified by `dims`.
@@ -432,6 +474,7 @@ julia> zeros(Int8, 2, 3)
 function zeros end
 
 """
+    ones([T=Float64,] dims::Tuple)
     ones([T=Float64,] dims...)
 
 Create an `Array`, with element type `T`, of all ones with size specified by `dims`.
@@ -843,7 +886,8 @@ _deleteat!(a::Vector, i::Integer, delta:
 """
     push!(collection, items...) -> collection
 
-Insert one or more `items` at the end of `collection`.
+Insert one or more `items` in `collection`. If `collection` is an ordered container,
+the items are inserted at the end (in the given order).
 
 # Examples
 ```jldoctest
@@ -857,9 +901,9 @@ julia> push!([1, 2, 3], 4, 5, 6)
  6
 ```
 
-Use [`append!`](@ref) to add all the elements of another collection to
-`collection`. The result of the preceding example is equivalent to `append!([1, 2, 3], [4,
-5, 6])`.
+If `collection` is ordered, use [`append!`](@ref) to add all the elements of another
+collection to it. The result of the preceding example is equivalent to `append!([1, 2, 3], [4,
+5, 6])`. For `AbstractSet` objects, [`union!`](@ref) can be used instead.
 """
 function push! end
 
@@ -880,7 +924,7 @@ end
 """
     append!(collection, collection2) -> collection.
 
-Add the elements of `collection2` to the end of `collection`.
+For an ordered container `collection`, add the elements of `collection2` to the end of it.
 
 # Examples
 ```jldoctest
@@ -1061,13 +1105,16 @@ julia> A
  2
 
 julia> S = Set([1, 2])
-Set([2, 1])
+Set{Int64} with 2 elements:
+  2
+  1
 
 julia> pop!(S)
 2
 
 julia> S
-Set([1])
+Set{Int64} with 1 element:
+  1
 
 julia> pop!(Dict(1=>2))
 1 => 2
@@ -1548,32 +1595,13 @@ function vcat(arrays::Vector{T}...) wher
         n += length(a)
     end
     arr = Vector{T}(undef, n)
-    ptr = pointer(arr)
-    if isbitsunion(T)
-        selptr = ccall(:jl_array_typetagdata, Ptr{UInt8}, (Any,), arr)
-    end
-    elsz = aligned_sizeof(T)
-    t = @_gc_preserve_begin arr
+    nd = 1
     for a in arrays
         na = length(a)
-        nba = na * elsz
-        if isbitstype(T)
-            ccall(:memcpy, Ptr{Cvoid}, (Ptr{Cvoid}, Ptr{Cvoid}, UInt),
-                  ptr, a, nba)
-        elseif isbitsunion(T)
-            ccall(:memcpy, Ptr{Cvoid}, (Ptr{Cvoid}, Ptr{Cvoid}, UInt),
-                  ptr, a, nba)
-            # copy selector bytes
-            ccall(:memcpy, Ptr{Cvoid}, (Ptr{Cvoid}, Ptr{Cvoid}, UInt),
-                  selptr, ccall(:jl_array_typetagdata, Ptr{UInt8}, (Any,), a), na)
-            selptr += na
-        else
-            ccall(:jl_array_ptr_copy, Cvoid, (Any, Ptr{Cvoid}, Any, Ptr{Cvoid}, Int),
-                  arr, ptr, a, pointer(a), na)
-        end
-        ptr += nba
+        @assert nd + na <= 1 + length(arr) # Concurrent modification of arrays?
+        unsafe_copyto!(arr, nd, a, 1, na)
+        nd += na
     end
-    @_gc_preserve_end t
     return arr
 end
 
diff -pruN 1.3.1+dfsg-1/base/arraymath.jl 1.4.0+dfsg-1/base/arraymath.jl
--- 1.3.1+dfsg-1/base/arraymath.jl	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/base/arraymath.jl	2020-03-21 16:36:32.000000000 +0000
@@ -94,7 +94,7 @@ function reverse(A::Array{T}; dims::Inte
             end
         end
     else
-        if isbitstype(T) && M>200
+        if allocatedinline(T) && M>200
             for i = 1:sd
                 ri = sd+1-i
                 for j=0:stride:(N-stride)
diff -pruN 1.3.1+dfsg-1/base/arrayshow.jl 1.4.0+dfsg-1/base/arrayshow.jl
--- 1.3.1+dfsg-1/base/arrayshow.jl	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/base/arrayshow.jl	2020-03-21 16:36:32.000000000 +0000
@@ -107,7 +107,7 @@ function print_matrix_row(io::IO,
             sx = undef_ref_str
         end
         l = repeat(" ", A[k][1]-a[1]) # pad on left and right as needed
-        r = repeat(" ", A[k][2]-a[2])
+        r = j == axes(X, 2)[end] ? "" : repeat(" ", A[k][2]-a[2])
         prettysx = replace_in_print_matrix(X,i,j,sx)
         print(io, l, prettysx, r)
         if k < length(A); print(io, sep); end
@@ -121,15 +121,18 @@ of a bunch of rows for long matrices. No
 but it also repeated every M elements if desired.
 """
 function print_matrix_vdots(io::IO, vdots::AbstractString,
-        A::Vector, sep::AbstractString, M::Integer, m::Integer)
+                            A::Vector, sep::AbstractString, M::Integer, m::Integer,
+                            pad_right::Bool = true)
     for k = 1:length(A)
         w = A[k][1] + A[k][2]
         if k % M == m
             l = repeat(" ", max(0, A[k][1]-length(vdots)))
-            r = repeat(" ", max(0, w-length(vdots)-length(l)))
+            r = k == length(A) && !pad_right ?
+                "" :
+                repeat(" ", max(0, w-length(vdots)-length(l)))
             print(io, l, vdots, r)
         else
-            print(io, repeat(" ", w))
+            (k != length(A) || pad_right) && print(io, repeat(" ", w))
         end
         if k < length(A); print(io, sep); end
     end
@@ -216,7 +219,7 @@ function print_matrix(io::IO, X::Abstrac
                 if i != rowsA[end] || i == rowsA[halfheight]; println(io); end
                 if i == rowsA[halfheight]
                     print(io, i == first(rowsA) ? pre : presp)
-                    print_matrix_vdots(io, vdots,A,sep,vmod,1)
+                    print_matrix_vdots(io, vdots, A, sep, vmod, 1, false)
                     print(io, i == last(rowsA) ? post : postsp * '\n')
                 end
             end
@@ -235,9 +238,9 @@ function print_matrix(io::IO, X::Abstrac
                 if i != rowsA[end] || i == rowsA[halfheight]; println(io); end
                 if i == rowsA[halfheight]
                     print(io, i == first(rowsA) ? pre : presp)
-                    print_matrix_vdots(io, vdots,Lalign,sep,vmod,1)
+                    print_matrix_vdots(io, vdots, Lalign, sep, vmod, 1, true)
                     print(io, ddots)
-                    print_matrix_vdots(io, vdots,Ralign,sep,vmod,r)
+                    print_matrix_vdots(io, vdots, Ralign, sep, vmod, r, false)
                     print(io, i == last(rowsA) ? post : postsp * '\n')
                 end
             end
@@ -299,14 +302,12 @@ end
 
 # print_array: main helper functions for show(io, text/plain, array)
 # typeinfo agnostic
-
-# 0-dimensional arrays
-print_array(io::IO, X::AbstractArray{T,0} where T) =
-    isassigned(X) ? show(io, X[]) :
-                    print(io, undef_ref_str)
-
+# Note that this is for showing the content inside the array, and for `MIME"text/plain".
+# There are `show(::IO, ::A) where A<:AbstractArray` methods that don't use this
+# e.g. show_vector, show_zero_dim
+print_array(io::IO, X::AbstractArray{<:Any, 0}) =
+    isassigned(X) ? show(io, X[]) : print(io, undef_ref_str)
 print_array(io::IO, X::AbstractVecOrMat) = print_matrix(io, X)
-
 print_array(io::IO, X::AbstractArray) = show_nd(io, X, print_matrix, true)
 
 # typeinfo aware
@@ -415,6 +416,7 @@ _show_empty(io, X) = nothing # by defaul
 
 # typeinfo aware (necessarily)
 function show(io::IO, X::AbstractArray)
+    ndims(X) == 0 && return show_zero_dim(io, X)
     ndims(X) == 1 && return show_vector(io, X)
     prefix = typeinfo_prefix(io, X)
     io = IOContext(io, :typeinfo => eltype(X))
@@ -423,6 +425,19 @@ function show(io::IO, X::AbstractArray)
         _show_nonempty(io, X, prefix)
 end
 
+### 0-dimensional arrays (#31481)
+show_zero_dim(io::IO, X::BitArray{0}) = print(io, "BitArray(", Int(X[]), ")")
+function show_zero_dim(io::IO, X::AbstractArray{T, 0}) where T
+    if isassigned(X)
+        print(io, "fill(")
+        show(io, X[])
+    else
+        print(io, "Array{$T,0}(")
+        show(io, undef)
+    end
+    print(io, ")")
+end
+
 ### Vector arrays
 
 # typeinfo aware
@@ -457,6 +472,17 @@ typeinfo_eltype(typeinfo::Type{<:Abstrac
 typeinfo_eltype(typeinfo::Type{<:AbstractDict{K,V}}) where {K,V} = eltype(typeinfo)
 typeinfo_eltype(typeinfo::Type{<:AbstractSet{T}}) where {T} = eltype(typeinfo)
 
+# types that can be parsed back accurately from their un-decorated representations
+function typeinfo_implicit(@nospecialize(T))
+    if T === Float64 || T === Int || T === Char || T === String || T === Symbol ||
+        issingletontype(T)
+        return true
+    end
+    return isconcretetype(T) &&
+        ((T <: Array && typeinfo_implicit(eltype(T))) ||
+         ((T <: Tuple || T <: Pair) && all(typeinfo_implicit, fieldtypes(T))) ||
+         (T <: AbstractDict && typeinfo_implicit(keytype(T)) && typeinfo_implicit(valtype(T))))
+end
 
 # X not constrained, can be any iterable (cf. show_vector)
 function typeinfo_prefix(io::IO, X)
@@ -470,14 +496,14 @@ function typeinfo_prefix(io::IO, X)
     eltype_X = eltype(X)
 
     if X isa AbstractDict
-        if eltype_X == eltype_ctx || !isempty(X) && isconcretetype(keytype(X)) && isconcretetype(valtype(X))
+        if eltype_X == eltype_ctx || (!isempty(X) && typeinfo_implicit(keytype(X)) && typeinfo_implicit(valtype(X)))
             string(typeof(X).name)
         else
             string(typeof(X))
         end
     else
         # Types hard-coded here are those which are created by default for a given syntax
-        if eltype_X == eltype_ctx || !isempty(X) && eltype_X in (Float64, Int, Char, String)
+        if eltype_X == eltype_ctx || (!isempty(X) && typeinfo_implicit(eltype_X))
             ""
         elseif print_without_params(eltype_X)
             string(unwrap_unionall(eltype_X).name) # Print "Array" rather than "Array{T,N}"
diff -pruN 1.3.1+dfsg-1/base/Base.jl 1.4.0+dfsg-1/base/Base.jl
--- 1.3.1+dfsg-1/base/Base.jl	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/base/Base.jl	2020-03-21 16:36:32.000000000 +0000
@@ -4,6 +4,19 @@ baremodule Base
 
 using Core.Intrinsics, Core.IR
 
+# to start, we're going to use a very simple definition of `include`
+# that doesn't require any function (except what we can get from the `Core` top-module)
+const _included_files = Array{Tuple{Module,String},1}()
+function include(mod::Module, path::String)
+    ccall(:jl_array_grow_end, Cvoid, (Any, UInt), _included_files, UInt(1))
+    Core.arrayset(true, _included_files, (mod, ccall(:jl_prepend_cwd, Any, (Any,), path)), arraylen(_included_files))
+    Core.println(path)
+    ccall(:jl_uv_flush, Nothing, (Ptr{Nothing},), Core.io_pointer(Core.stdout))
+    Core.include(mod, path)
+end
+include(path::String) = include(Base, path)
+
+# from now on, this is now a top-module for resolving syntax
 const is_primary_base_module = ccall(:jl_module_parent, Ref{Module}, (Any,), Base) === Core.Main
 ccall(:jl_set_istopmod, Cvoid, (Any, Bool), Base, is_primary_base_module)
 
@@ -20,50 +33,6 @@ setproperty!(x::Tuple, f::Int, v) = setf
 getproperty(x, f::Symbol) = getfield(x, f)
 setproperty!(x, f::Symbol, v) = setfield!(x, f, convert(fieldtype(typeof(x), f), v))
 
-function include_relative end
-function include(mod::Module, path::AbstractString)
-    local result
-    if INCLUDE_STATE === 1
-        result = _include1(mod, path)
-    elseif INCLUDE_STATE === 2
-        result = _include(mod, path)
-    elseif INCLUDE_STATE === 3
-        result = include_relative(mod, path)
-    end
-    result
-end
-function include(path::AbstractString)
-    local result
-    if INCLUDE_STATE === 1
-        result = _include1(Base, path)
-    elseif INCLUDE_STATE === 2
-        result = _include(Base, path)
-    else
-        # to help users avoid error (accidentally evaluating into Base), this is not allowed
-        error("Base.include(string) is discontinued, use `include(fname)` or `Base.include(@__MODULE__, fname)` instead.")
-    end
-    result
-end
-const _included_files = Array{Tuple{Module,String},1}()
-function _include1(mod::Module, path)
-    Core.Compiler.push!(_included_files, (mod, ccall(:jl_prepend_cwd, Any, (Any,), path)))
-    Core.include(mod, path)
-end
-let SOURCE_PATH = ""
-    # simple, race-y TLS, relative include
-    global _include
-    function _include(mod::Module, path)
-        prev = SOURCE_PATH
-        path = normpath(joinpath(dirname(prev), path))
-        push!(_included_files, (mod, abspath(path)))
-        SOURCE_PATH = path
-        result = Core.include(mod, path)
-        SOURCE_PATH = prev
-        result
-    end
-end
-INCLUDE_STATE = 1 # include = Core.include
-
 include("coreio.jl")
 
 eval(x) = Core.eval(Base, x)
@@ -138,7 +107,7 @@ include("ntuple.jl")
 include("abstractdict.jl")
 
 include("iterators.jl")
-using .Iterators: zip, enumerate
+using .Iterators: zip, enumerate, only
 using .Iterators: Flatten, Filter, product  # for generators
 
 include("namedtuple.jl")
@@ -147,6 +116,7 @@ include("namedtuple.jl")
 include("hashing.jl")
 include("rounding.jl")
 using .Rounding
+include("div.jl")
 include("float.jl")
 include("twiceprecision.jl")
 include("complex.jl")
@@ -279,7 +249,21 @@ using .Math
 const (√)=sqrt
 const (∛)=cbrt
 
-INCLUDE_STATE = 2 # include = _include (from lines above)
+# now switch to a simple, race-y TLS, relative include for the rest of Base
+delete_method(which(include, (Module, String)))
+let SOURCE_PATH = ""
+    global function include(mod::Module, path::String)
+        prev = SOURCE_PATH
+        path = normpath(joinpath(dirname(prev), path))
+        Core.println(path)
+        ccall(:jl_uv_flush, Nothing, (Ptr{Nothing},), Core.io_pointer(Core.stdout))
+        push!(_included_files, (mod, abspath(path)))
+        SOURCE_PATH = path
+        result = Core.include(mod, path)
+        SOURCE_PATH = prev
+        return result
+    end
+end
 
 # reduction along dims
 include("reducedim.jl")  # macros in this file relies on string.jl
@@ -303,10 +287,15 @@ function deepcopy_internal end
 include("Enums.jl")
 using .Enums
 
-# BigInts and BigFloats
+# BigInts
 include("gmp.jl")
 using .GMP
 
+# float printing: requires BigInt
+include("ryu/Ryu.jl")
+using .Ryu
+
+# BigFloats
 include("mpfr.jl")
 using .MPFR
 
@@ -320,10 +309,6 @@ include("irrationals.jl")
 include("mathconstants.jl")
 using .MathConstants: ℯ, π, pi
 
-# (s)printf macros
-include("printf.jl")
-# import .Printf
-
 # metaprogramming
 include("meta.jl")
 
@@ -372,6 +357,34 @@ if isdefined(Core, :Compiler) && is_prim
     Docs.loaddocs(Core.Compiler.CoreDocs.DOCS)
 end
 
+# finally, now make `include` point to the full version
+for m in methods(include)
+    delete_method(m)
+end
+# These functions are duplicated in client.jl/include(::String) for
+# nicer stacktraces. Modifications here have to be backported there
+include(mod::Module, path::AbstractString) = include(mod, convert(String, path))
+function include(mod::Module, _path::String)
+    path, prev = _include_dependency(mod, _path)
+    for callback in include_callbacks # to preserve order, must come before Core.include
+        invokelatest(callback, mod, path)
+    end
+    tls = task_local_storage()
+    tls[:SOURCE_PATH] = path
+    local result
+    try
+        # result = Core.include(mod, path)
+        result = ccall(:jl_load_, Any, (Any, Any), mod, path)
+    finally
+        if prev === nothing
+            delete!(tls, :SOURCE_PATH)
+        else
+            tls[:SOURCE_PATH] = prev
+        end
+    end
+    return result
+end
+
 end_base_include = time_ns()
 
 if is_primary_base_module
@@ -400,7 +413,7 @@ function __init__()
     nothing
 end
 
-INCLUDE_STATE = 3 # include = include_relative
+
 end
 
 const tot_time_stdlib = RefValue(0.0)
diff -pruN 1.3.1+dfsg-1/base/bitarray.jl 1.4.0+dfsg-1/base/bitarray.jl
--- 1.3.1+dfsg-1/base/bitarray.jl	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/base/bitarray.jl	2020-03-21 16:36:32.000000000 +0000
@@ -51,14 +51,14 @@ Behaves identically to the [`Array`](@re
 ```julia-repl
 julia> BitArray(undef, 2, 2)
 2×2 BitArray{2}:
- false  false
- false  true
+ 0  0
+ 0  0
 
 julia> BitArray(undef, (3, 1))
 3×1 BitArray{2}:
- false
- true
- false
+ 0
+ 0
+ 0
 ```
 """
 BitArray(::UndefInitializer, dims::Integer...) = BitArray(undef, map(Int,dims))
@@ -71,6 +71,28 @@ const BitMatrix = BitArray{2}
 
 BitVector() = BitArray{1}(undef, 0)
 
+"""
+    BitVector(nt::Tuple{Vararg{Bool}})
+
+Construct a `BitVector` from a tuple of `Bool`.
+# Examples
+```julia-repl
+julia> nt = (true, false, true, false)
+(true, false, true, false)
+
+julia> BitVector(nt)
+4-element BitArray{1}:
+ 1
+ 0
+ 1
+ 0
+```
+"""
+function BitVector(nt::Tuple{Vararg{Bool}})
+    bv = BitVector(undef, length(nt))
+    bv .= nt
+end
+
 ## utility functions ##
 
 length(B::BitArray) = B.len
diff -pruN 1.3.1+dfsg-1/base/bitset.jl 1.4.0+dfsg-1/base/bitset.jl
--- 1.3.1+dfsg-1/base/bitset.jl	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/base/bitset.jl	2020-03-21 16:36:32.000000000 +0000
@@ -340,10 +340,13 @@ filter!(f, s::BitSet) = unsafe_filter!(f
 @inline in(n::Int, s::BitSet) = _bits_getindex(s.bits, n, s.offset)
 @inline in(n::Integer, s::BitSet) = _is_convertible_Int(n) ? in(Int(n), s) : false
 
-function iterate(s::BitSet, idx=0)
-   idx = _bits_findnext(s.bits, idx)
-   idx == -1 && return nothing
-   (idx + intoffset(s), idx+1)
+function iterate(s::BitSet, (word, idx) = (CHK0, 0))
+    while word == 0
+        idx == length(s.bits) && return nothing
+        idx += 1
+        word = @inbounds s.bits[idx]
+    end
+    trailing_zeros(word) + (idx - 1 + s.offset) << 6, (_blsr(word), idx)
 end
 
 @noinline _throw_bitset_notempty_error() =
diff -pruN 1.3.1+dfsg-1/base/bool.jl 1.4.0+dfsg-1/base/bool.jl
--- 1.3.1+dfsg-1/base/bool.jl	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/base/bool.jl	2020-03-21 16:36:32.000000000 +0000
@@ -112,7 +112,5 @@ end
 *(y::AbstractFloat, x::Bool) = x * y
 
 div(x::Bool, y::Bool) = y ? x : throw(DivideError())
-fld(x::Bool, y::Bool) = div(x,y)
-cld(x::Bool, y::Bool) = div(x,y)
 rem(x::Bool, y::Bool) = y ? false : throw(DivideError())
 mod(x::Bool, y::Bool) = rem(x,y)
diff -pruN 1.3.1+dfsg-1/base/boot.jl 1.4.0+dfsg-1/base/boot.jl
--- 1.3.1+dfsg-1/base/boot.jl	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/base/boot.jl	2020-03-21 16:36:32.000000000 +0000
@@ -210,6 +210,7 @@ else
     const UInt = UInt32
 end
 
+function iterate end
 function Typeof end
 ccall(:jl_toplevel_eval_in, Any, (Any, Any),
       Core, quote
@@ -431,11 +432,12 @@ Array{T}(A::AbstractArray{S,N}) where {T
 AbstractArray{T}(A::AbstractArray{S,N}) where {T,S,N} = AbstractArray{T,N}(A)
 
 # primitive Symbol constructors
-function Symbol(s::String)
+eval(Core, :(function Symbol(s::String)
+    $(Expr(:meta, :pure))
     return ccall(:jl_symbol_n, Ref{Symbol}, (Ptr{UInt8}, Int),
                  ccall(:jl_string_ptr, Ptr{UInt8}, (Any,), s),
                  sizeof(s))
-end
+end))
 function Symbol(a::Array{UInt8,1})
     return ccall(:jl_symbol_n, Ref{Symbol}, (Ptr{UInt8}, Int),
                  ccall(:jl_array_ptr, Ptr{UInt8}, (Any,), a),
@@ -541,11 +543,6 @@ end
 
 NamedTuple() = NamedTuple{(),Tuple{}}(())
 
-"""
-    NamedTuple{names}(args::Tuple)
-
-Construct a named tuple with the given `names` (a tuple of Symbols) from a tuple of values.
-"""
 NamedTuple{names}(args::Tuple) where {names} = NamedTuple{names,typeof(args)}(args)
 
 using .Intrinsics: sle_int, add_int
@@ -569,9 +566,9 @@ function is_top_bit_set(x::Union{Int8,UI
     eq_int(lshr_int(x, 7), trunc_int(typeof(x), 1))
 end
 
-function check_top_bit(x)
+function check_top_bit(::Type{To}, x) where {To}
     @_inline_meta
-    is_top_bit_set(x) && throw_inexacterror(:check_top_bit, typeof(x), x)
+    is_top_bit_set(x) && throw_inexacterror(:check_top_bit, To, x)
     x
 end
 
@@ -596,11 +593,11 @@ toInt8(x::Int16)      = checked_trunc_si
 toInt8(x::Int32)      = checked_trunc_sint(Int8, x)
 toInt8(x::Int64)      = checked_trunc_sint(Int8, x)
 toInt8(x::Int128)     = checked_trunc_sint(Int8, x)
-toInt8(x::UInt8)      = bitcast(Int8, check_top_bit(x))
-toInt8(x::UInt16)     = checked_trunc_sint(Int8, check_top_bit(x))
-toInt8(x::UInt32)     = checked_trunc_sint(Int8, check_top_bit(x))
-toInt8(x::UInt64)     = checked_trunc_sint(Int8, check_top_bit(x))
-toInt8(x::UInt128)    = checked_trunc_sint(Int8, check_top_bit(x))
+toInt8(x::UInt8)      = bitcast(Int8, check_top_bit(Int8, x))
+toInt8(x::UInt16)     = checked_trunc_sint(Int8, check_top_bit(Int8, x))
+toInt8(x::UInt32)     = checked_trunc_sint(Int8, check_top_bit(Int8, x))
+toInt8(x::UInt64)     = checked_trunc_sint(Int8, check_top_bit(Int8, x))
+toInt8(x::UInt128)    = checked_trunc_sint(Int8, check_top_bit(Int8, x))
 toInt8(x::Bool)       = and_int(bitcast(Int8, x), Int8(1))
 toInt16(x::Int8)      = sext_int(Int16, x)
 toInt16(x::Int16)     = x
@@ -608,10 +605,10 @@ toInt16(x::Int32)     = checked_trunc_si
 toInt16(x::Int64)     = checked_trunc_sint(Int16, x)
 toInt16(x::Int128)    = checked_trunc_sint(Int16, x)
 toInt16(x::UInt8)     = zext_int(Int16, x)
-toInt16(x::UInt16)    = bitcast(Int16, check_top_bit(x))
-toInt16(x::UInt32)    = checked_trunc_sint(Int16, check_top_bit(x))
-toInt16(x::UInt64)    = checked_trunc_sint(Int16, check_top_bit(x))
-toInt16(x::UInt128)   = checked_trunc_sint(Int16, check_top_bit(x))
+toInt16(x::UInt16)    = bitcast(Int16, check_top_bit(Int16, x))
+toInt16(x::UInt32)    = checked_trunc_sint(Int16, check_top_bit(Int16, x))
+toInt16(x::UInt64)    = checked_trunc_sint(Int16, check_top_bit(Int16, x))
+toInt16(x::UInt128)   = checked_trunc_sint(Int16, check_top_bit(Int16, x))
 toInt16(x::Bool)      = and_int(zext_int(Int16, x), Int16(1))
 toInt32(x::Int8)      = sext_int(Int32, x)
 toInt32(x::Int16)     = sext_int(Int32, x)
@@ -620,9 +617,9 @@ toInt32(x::Int64)     = checked_trunc_si
 toInt32(x::Int128)    = checked_trunc_sint(Int32, x)
 toInt32(x::UInt8)     = zext_int(Int32, x)
 toInt32(x::UInt16)    = zext_int(Int32, x)
-toInt32(x::UInt32)    = bitcast(Int32, check_top_bit(x))
-toInt32(x::UInt64)    = checked_trunc_sint(Int32, check_top_bit(x))
-toInt32(x::UInt128)   = checked_trunc_sint(Int32, check_top_bit(x))
+toInt32(x::UInt32)    = bitcast(Int32, check_top_bit(Int32, x))
+toInt32(x::UInt64)    = checked_trunc_sint(Int32, check_top_bit(Int32, x))
+toInt32(x::UInt128)   = checked_trunc_sint(Int32, check_top_bit(Int32, x))
 toInt32(x::Bool)      = and_int(zext_int(Int32, x), Int32(1))
 toInt64(x::Int8)      = sext_int(Int64, x)
 toInt64(x::Int16)     = sext_int(Int64, x)
@@ -632,8 +629,8 @@ toInt64(x::Int128)    = checked_trunc_si
 toInt64(x::UInt8)     = zext_int(Int64, x)
 toInt64(x::UInt16)    = zext_int(Int64, x)
 toInt64(x::UInt32)    = zext_int(Int64, x)
-toInt64(x::UInt64)    = bitcast(Int64, check_top_bit(x))
-toInt64(x::UInt128)   = checked_trunc_sint(Int64, check_top_bit(x))
+toInt64(x::UInt64)    = bitcast(Int64, check_top_bit(Int64, x))
+toInt64(x::UInt128)   = checked_trunc_sint(Int64, check_top_bit(Int64, x))
 toInt64(x::Bool)      = and_int(zext_int(Int64, x), Int64(1))
 toInt128(x::Int8)     = sext_int(Int128, x)
 toInt128(x::Int16)    = sext_int(Int128, x)
@@ -644,9 +641,9 @@ toInt128(x::UInt8)    = zext_int(Int128,
 toInt128(x::UInt16)   = zext_int(Int128, x)
 toInt128(x::UInt32)   = zext_int(Int128, x)
 toInt128(x::UInt64)   = zext_int(Int128, x)
-toInt128(x::UInt128)  = bitcast(Int128, check_top_bit(x))
+toInt128(x::UInt128)  = bitcast(Int128, check_top_bit(Int128, x))
 toInt128(x::Bool)     = and_int(zext_int(Int128, x), Int128(1))
-toUInt8(x::Int8)      = bitcast(UInt8, check_top_bit(x))
+toUInt8(x::Int8)      = bitcast(UInt8, check_top_bit(UInt8, x))
 toUInt8(x::Int16)     = checked_trunc_uint(UInt8, x)
 toUInt8(x::Int32)     = checked_trunc_uint(UInt8, x)
 toUInt8(x::Int64)     = checked_trunc_uint(UInt8, x)
@@ -657,8 +654,8 @@ toUInt8(x::UInt32)    = checked_trunc_ui
 toUInt8(x::UInt64)    = checked_trunc_uint(UInt8, x)
 toUInt8(x::UInt128)   = checked_trunc_uint(UInt8, x)
 toUInt8(x::Bool)      = and_int(bitcast(UInt8, x), UInt8(1))
-toUInt16(x::Int8)     = sext_int(UInt16, check_top_bit(x))
-toUInt16(x::Int16)    = bitcast(UInt16, check_top_bit(x))
+toUInt16(x::Int8)     = sext_int(UInt16, check_top_bit(UInt16, x))
+toUInt16(x::Int16)    = bitcast(UInt16, check_top_bit(UInt16, x))
 toUInt16(x::Int32)    = checked_trunc_uint(UInt16, x)
 toUInt16(x::Int64)    = checked_trunc_uint(UInt16, x)
 toUInt16(x::Int128)   = checked_trunc_uint(UInt16, x)
@@ -668,9 +665,9 @@ toUInt16(x::UInt32)   = checked_trunc_ui
 toUInt16(x::UInt64)   = checked_trunc_uint(UInt16, x)
 toUInt16(x::UInt128)  = checked_trunc_uint(UInt16, x)
 toUInt16(x::Bool)     = and_int(zext_int(UInt16, x), UInt16(1))
-toUInt32(x::Int8)     = sext_int(UInt32, check_top_bit(x))
-toUInt32(x::Int16)    = sext_int(UInt32, check_top_bit(x))
-toUInt32(x::Int32)    = bitcast(UInt32, check_top_bit(x))
+toUInt32(x::Int8)     = sext_int(UInt32, check_top_bit(UInt32, x))
+toUInt32(x::Int16)    = sext_int(UInt32, check_top_bit(UInt32, x))
+toUInt32(x::Int32)    = bitcast(UInt32, check_top_bit(UInt32, x))
 toUInt32(x::Int64)    = checked_trunc_uint(UInt32, x)
 toUInt32(x::Int128)   = checked_trunc_uint(UInt32, x)
 toUInt32(x::UInt8)    = zext_int(UInt32, x)
@@ -679,10 +676,10 @@ toUInt32(x::UInt32)   = x
 toUInt32(x::UInt64)   = checked_trunc_uint(UInt32, x)
 toUInt32(x::UInt128)  = checked_trunc_uint(UInt32, x)
 toUInt32(x::Bool)     = and_int(zext_int(UInt32, x), UInt32(1))
-toUInt64(x::Int8)     = sext_int(UInt64, check_top_bit(x))
-toUInt64(x::Int16)    = sext_int(UInt64, check_top_bit(x))
-toUInt64(x::Int32)    = sext_int(UInt64, check_top_bit(x))
-toUInt64(x::Int64)    = bitcast(UInt64, check_top_bit(x))
+toUInt64(x::Int8)     = sext_int(UInt64, check_top_bit(UInt64, x))
+toUInt64(x::Int16)    = sext_int(UInt64, check_top_bit(UInt64, x))
+toUInt64(x::Int32)    = sext_int(UInt64, check_top_bit(UInt64, x))
+toUInt64(x::Int64)    = bitcast(UInt64, check_top_bit(UInt64, x))
 toUInt64(x::Int128)   = checked_trunc_uint(UInt64, x)
 toUInt64(x::UInt8)    = zext_int(UInt64, x)
 toUInt64(x::UInt16)   = zext_int(UInt64, x)
@@ -690,11 +687,11 @@ toUInt64(x::UInt32)   = zext_int(UInt64,
 toUInt64(x::UInt64)   = x
 toUInt64(x::UInt128)  = checked_trunc_uint(UInt64, x)
 toUInt64(x::Bool)     = and_int(zext_int(UInt64, x), UInt64(1))
-toUInt128(x::Int8)    = sext_int(UInt128, check_top_bit(x))
-toUInt128(x::Int16)   = sext_int(UInt128, check_top_bit(x))
-toUInt128(x::Int32)   = sext_int(UInt128, check_top_bit(x))
-toUInt128(x::Int64)   = sext_int(UInt128, check_top_bit(x))
-toUInt128(x::Int128)  = bitcast(UInt128, check_top_bit(x))
+toUInt128(x::Int8)    = sext_int(UInt128, check_top_bit(UInt128, x))
+toUInt128(x::Int16)   = sext_int(UInt128, check_top_bit(UInt128, x))
+toUInt128(x::Int32)   = sext_int(UInt128, check_top_bit(UInt128, x))
+toUInt128(x::Int64)   = sext_int(UInt128, check_top_bit(UInt128, x))
+toUInt128(x::Int128)  = bitcast(UInt128, check_top_bit(UInt128, x))
 toUInt128(x::UInt8)   = zext_int(UInt128, x)
 toUInt128(x::UInt16)  = zext_int(UInt128, x)
 toUInt128(x::UInt32)  = zext_int(UInt128, x)
diff -pruN 1.3.1+dfsg-1/base/broadcast.jl 1.4.0+dfsg-1/base/broadcast.jl
--- 1.3.1+dfsg-1/base/broadcast.jl	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/base/broadcast.jl	2020-03-21 16:36:32.000000000 +0000
@@ -496,6 +496,7 @@ _bcsm(a::Number, b::Number) = a == b ||
 # (We may not want to define general promotion rules between, say, OneTo and Slice, but if
 #  we get here we know the axes are at least consistent for the purposes of broadcasting)
 axistype(a::T, b::T) where T = a
+axistype(a::OneTo, b::OneTo) = OneTo{Int}(a)
 axistype(a, b) = UnitRange{Int}(a)
 
 ## Check that all arguments are broadcast compatible with shape
@@ -916,22 +917,22 @@ end
 @inline function copyto!(dest::BitArray, bc::Broadcasted{Nothing})
     axes(dest) == axes(bc) || throwdm(axes(dest), axes(bc))
     ischunkedbroadcast(dest, bc) && return chunkedcopyto!(dest, bc)
+    length(dest) < 256 && return invoke(copyto!, Tuple{AbstractArray, Broadcasted{Nothing}}, dest, bc)
     tmp = Vector{Bool}(undef, bitcache_size)
     destc = dest.chunks
-    ind = cind = 1
+    cind = 1
     bc′ = preprocess(dest, bc)
-    @simd for I in eachindex(bc′)
-        @inbounds tmp[ind] = bc′[I]
-        ind += 1
-        if ind > bitcache_size
-            dumpbitcache(destc, cind, tmp)
-            cind += bitcache_chunks
-            ind = 1
+    for P in Iterators.partition(eachindex(bc′), bitcache_size)
+        ind = 1
+        @simd for I in P
+            @inbounds tmp[ind] = bc′[I]
+            ind += 1
+        end
+        @simd for i in ind:bitcache_size
+            @inbounds tmp[i] = false
         end
-    end
-    if ind > 1
-        @inbounds tmp[ind:bitcache_size] .= false
         dumpbitcache(destc, cind, tmp)
+        cind += bitcache_chunks
     end
     return dest
 end
diff -pruN 1.3.1+dfsg-1/base/channels.jl 1.4.0+dfsg-1/base/channels.jl
--- 1.3.1+dfsg-1/base/channels.jl	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/base/channels.jl	2020-03-21 16:36:32.000000000 +0000
@@ -242,10 +242,8 @@ Stacktrace:
 ```
 """
 function bind(c::Channel, task::Task)
-    # TODO: implement "schedulewait" and deprecate taskdone_hook
-    #T = Task(() -> close_chnl_on_taskdone(task, c))
-    #schedulewait(task, T)
-    register_taskdone_hook(task, tsk -> close_chnl_on_taskdone(tsk, c))
+    T = Task(() -> close_chnl_on_taskdone(task, c))
+    _wait2(task, T)
     return c
 end
 
@@ -277,28 +275,19 @@ end
 
 function close_chnl_on_taskdone(t::Task, c::Channel)
     isopen(c) || return
-    cleanup = () -> try
-            isopen(c) || return
-            if istaskfailed(t)
-                excp = task_result(t)
-                if excp isa Exception
-                    close(c, excp)
-                    return
-                end
+    lock(c)
+    try
+        isopen(c) || return
+        if istaskfailed(t)
+            excp = task_result(t)
+            if excp isa Exception
+                close(c, excp)
+                return
             end
-            close(c)
-            return
-        finally
-            unlock(c)
         end
-    if trylock(c)
-        # can't use `lock`, since attempts to task-switch to wait for it
-        # will just silently fail and leave us with broken state
-        cleanup()
-    else
-        # so schedule this to happen once we are finished destroying our task
-        # (on a new Task)
-        @async (lock(c); cleanup())
+        close(c)
+    finally
+        unlock(c)
     end
     nothing
 end
diff -pruN 1.3.1+dfsg-1/base/char.jl 1.4.0+dfsg-1/base/char.jl
--- 1.3.1+dfsg-1/base/char.jl	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/base/char.jl	2020-03-21 16:36:32.000000000 +0000
@@ -218,10 +218,10 @@ isless(x::AbstractChar, y::AbstractChar)
 hash(x::AbstractChar, h::UInt) = hash(Char(x), h)
 widen(::Type{T}) where {T<:AbstractChar} = T
 
--(x::AbstractChar, y::AbstractChar) = Int(x) - Int(y)
--(x::T, y::Integer) where {T<:AbstractChar} = T(Int32(x) - Int32(y))
-+(x::T, y::Integer) where {T<:AbstractChar} = T(Int32(x) + Int32(y))
-+(x::Integer, y::AbstractChar) = y + x
+@inline -(x::AbstractChar, y::AbstractChar) = Int(x) - Int(y)
+@inline -(x::T, y::Integer) where {T<:AbstractChar} = T(Int32(x) - Int32(y))
+@inline +(x::T, y::Integer) where {T<:AbstractChar} = T(Int32(x) + Int32(y))
+@inline +(x::Integer, y::AbstractChar) = y + x
 
 # `print` should output UTF-8 by default for all AbstractChar types.
 # (Packages may implement other IO subtypes to specify different encodings.)
@@ -304,7 +304,7 @@ function show(io::IO, ::MIME"text/plain"
         else
             u = codepoint(c)
         end
-        h = string(u, base = 16, pad = u ≤ 0xffff ? 4 : 6)
+        h = uppercase(string(u, base = 16, pad = 4))
         print(io, (isascii(c) ? "ASCII/" : ""), "Unicode U+", h)
     else
         print(io, ": Malformed UTF-8")
diff -pruN 1.3.1+dfsg-1/base/c.jl 1.4.0+dfsg-1/base/c.jl
--- 1.3.1+dfsg-1/base/c.jl	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/base/c.jl	2020-03-21 16:36:32.000000000 +0000
@@ -26,7 +26,7 @@ and will be converted automatically at t
 
 See [`@cfunction`](@ref).
 """
-struct CFunction <: Ref{Cvoid}
+mutable struct CFunction <: Ref{Cvoid}
     ptr::Ptr{Cvoid}
     f::Any
     _1::Ptr{Cvoid}
@@ -47,7 +47,7 @@ Note that the argument type tuple must b
 (although it can include a splat expression). And that these arguments will be evaluated in global scope
 during compile-time (not deferred until runtime).
 Adding a '\\\$' in front of the function argument changes this to instead create a runtime closure
-over the local variable `callable`.
+over the local variable `callable` (this is not supported on all architectures).
 
 See [manual section on ccall and cfunction usage](@ref Calling-C-and-Fortran-Code).
 
@@ -61,12 +61,12 @@ julia> @cfunction(foo, Int, (Int, Int))
 Ptr{Cvoid} @0x000000001b82fcd0
 ```
 """
-macro cfunction(f, at, rt)
-    if !(isa(rt, Expr) && rt.head === :tuple)
+macro cfunction(f, rt, at)
+    if !(isa(at, Expr) && at.head === :tuple)
         throw(ArgumentError("@cfunction argument types must be a literal tuple"))
     end
-    rt.head = :call
-    pushfirst!(rt.args, GlobalRef(Core, :svec))
+    at.head = :call
+    pushfirst!(at.args, GlobalRef(Core, :svec))
     if isa(f, Expr) && f.head === :$
         fptr = f.args[1]
         typ = CFunction
@@ -74,7 +74,7 @@ macro cfunction(f, at, rt)
         fptr = QuoteNode(f)
         typ = Ptr{Cvoid}
     end
-    cfun = Expr(:cfunction, typ, fptr, at, rt, QuoteNode(:ccall))
+    cfun = Expr(:cfunction, typ, fptr, rt, at, QuoteNode(:ccall))
     return esc(cfun)
 end
 
diff -pruN 1.3.1+dfsg-1/base/client.jl 1.4.0+dfsg-1/base/client.jl
--- 1.3.1+dfsg-1/base/client.jl	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/base/client.jl	2020-03-21 16:36:32.000000000 +0000
@@ -71,6 +71,7 @@ function repl_cmd(cmd, out)
     nothing
 end
 
+# deprecated function--preserved for DocTests.jl
 function ip_matches_func(ip, func::Symbol)
     for fr in StackTraces.lookup(ip)
         if fr === StackTraces.UNKNOWN || fr.from_c
@@ -82,28 +83,28 @@ function ip_matches_func(ip, func::Symbo
 end
 
 function scrub_repl_backtrace(bt)
-    if bt !== nothing
+    if bt !== nothing && !(bt isa Vector{Any}) # ignore our sentinel value types
+        bt = stacktrace(bt)
         # remove REPL-related frames from interactive printing
-        eval_ind = findlast(addr->ip_matches_func(addr, :eval), bt)
-        if eval_ind !== nothing
-            return bt[1:eval_ind-1]
-        end
+        eval_ind = findlast(frame -> !frame.from_c && frame.func === :eval, bt)
+        eval_ind === nothing || deleteat!(bt, eval_ind:length(bt))
     end
     return bt
 end
 
 function display_error(io::IO, er, bt)
     printstyled(io, "ERROR: "; bold=true, color=Base.error_color())
-    showerror(IOContext(io, :limit => true), er, scrub_repl_backtrace(bt))
+    bt = scrub_repl_backtrace(bt)
+    showerror(IOContext(io, :limit => true), er, bt, backtrace = bt!==nothing)
     println(io)
 end
 function display_error(io::IO, stack::Vector)
     printstyled(io, "ERROR: "; bold=true, color=Base.error_color())
-    show_exception_stack(IOContext(io, :limit => true), Any[ (x[1], scrub_repl_backtrace(x[2])) for x in stack ])
+    bt = Any[ (x[1], scrub_repl_backtrace(x[2])) for x in stack ]
+    show_exception_stack(IOContext(io, :limit => true), bt)
 end
 display_error(stack::Vector) = display_error(stderr, stack)
-display_error(er, bt) = display_error(stderr, er, bt)
-display_error(er) = display_error(er, [])
+display_error(er, bt=nothing) = display_error(stderr, er, bt)
 
 function eval_user_input(errio, @nospecialize(ast), show_value::Bool)
     errcount = 0
@@ -421,7 +422,30 @@ end
 
 # MainInclude exists to hide Main.include and eval from `names(Main)`.
 baremodule MainInclude
-include(fname::AbstractString) = Main.Base.include(Main, fname)
+using ..Base
+# We inline the definition of include from loading.jl/include_relative to get one-frame stacktraces.
+# include(fname::AbstractString) = Main.Base.include(Main, fname)
+function include(fname::AbstractString)
+    mod = Main
+    isa(fname, String) || (fname = Base.convert(String, fname)::String)
+    path, prev = Base._include_dependency(mod, fname)
+    for callback in Base.include_callbacks # to preserve order, must come before Core.include
+        Base.invokelatest(callback, mod, path)
+    end
+    tls = Base.task_local_storage()
+    tls[:SOURCE_PATH] = path
+    local result
+    try
+        result = ccall(:jl_load_, Any, (Any, Any), mod, path)
+    finally
+        if prev === nothing
+            Base.delete!(tls, :SOURCE_PATH)
+        else
+            tls[:SOURCE_PATH] = prev
+        end
+    end
+    return result
+end
 eval(x) = Core.eval(Main, x)
 end
 
diff -pruN 1.3.1+dfsg-1/base/cmd.jl 1.4.0+dfsg-1/base/cmd.jl
--- 1.3.1+dfsg-1/base/cmd.jl	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/base/cmd.jl	2020-03-21 16:36:32.000000000 +0000
@@ -102,6 +102,8 @@ shell_escape(cmd::Cmd; special::Abstract
     shell_escape(cmd.exec..., special=special)
 shell_escape_posixly(cmd::Cmd) =
     shell_escape_posixly(cmd.exec...)
+shell_escape_winsomely(cmd::Cmd) =
+    shell_escape_winsomely(cmd.exec...)
 
 function show(io::IO, cmd::Cmd)
     print_env = cmd.env !== nothing
diff -pruN 1.3.1+dfsg-1/base/compiler/abstractinterpretation.jl 1.4.0+dfsg-1/base/compiler/abstractinterpretation.jl
--- 1.3.1+dfsg-1/base/compiler/abstractinterpretation.jl	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/base/compiler/abstractinterpretation.jl	2020-03-21 16:36:32.000000000 +0000
@@ -64,6 +64,14 @@ function abstract_call_gf_by_type(@nospe
     seen = 0    # number of signatures actually inferred
     istoplevel = sv.linfo.def isa Module
     multiple_matches = napplicable > 1
+
+    if f !== nothing && napplicable == 1 && is_method_pure(applicable[1][3], applicable[1][1], applicable[1][2])
+        val = pure_eval_call(f, argtypes)
+        if val !== false
+            return val
+        end
+    end
+
     for i in 1:napplicable
         match = applicable[i]::SimpleVector
         method = match[3]::Method
@@ -427,7 +435,7 @@ end
 # refine its type to an array of element types.
 # Union of Tuples of the same length is converted to Tuple of Unions.
 # returns an array of types
-function precise_container_type(@nospecialize(typ), vtypes::VarTable, sv::InferenceState)
+function precise_container_type(@nospecialize(itft), @nospecialize(typ), vtypes::VarTable, sv::InferenceState)
     if isa(typ, PartialStruct) && typ.typ.name === Tuple.name
         return typ.fields
     end
@@ -489,17 +497,24 @@ function precise_container_type(@nospeci
     elseif tti0 <: Array
         return Any[Vararg{eltype(tti0)}]
     else
-        return abstract_iteration(typ, vtypes, sv)
+        return abstract_iteration(itft, typ, vtypes, sv)
     end
 end
 
 # simulate iteration protocol on container type up to fixpoint
-function abstract_iteration(@nospecialize(itertype), vtypes::VarTable, sv::InferenceState)
+function abstract_iteration(@nospecialize(itft), @nospecialize(itertype), vtypes::VarTable, sv::InferenceState)
     if !isdefined(Main, :Base) || !isdefined(Main.Base, :iterate) || !isconst(Main.Base, :iterate)
         return Any[Vararg{Any}]
     end
-    iteratef = getfield(Main.Base, :iterate)
-    stateordonet = abstract_call(iteratef, nothing, Any[Const(iteratef), itertype], vtypes, sv)
+    if itft === nothing
+        iteratef = getfield(Main.Base, :iterate)
+        itft = Const(iteratef)
+    elseif isa(itft, Const)
+        iteratef = itft.val
+    else
+        return Any[Vararg{Any}]
+    end
+    stateordonet = abstract_call_known(iteratef, nothing, Any[itft, itertype], vtypes, sv)
     # Return Bottom if this is not an iterator.
     # WARNING: Changes to the iteration protocol must be reflected here,
     # this is not just an optimization.
@@ -518,7 +533,7 @@ function abstract_iteration(@nospecializ
         valtype = stateordonet.parameters[1]
         statetype = stateordonet.parameters[2]
         push!(ret, valtype)
-        stateordonet = abstract_call(iteratef, nothing, Any[Const(iteratef), itertype, statetype], vtypes, sv)
+        stateordonet = abstract_call_known(iteratef, nothing, Any[Const(iteratef), itertype, statetype], vtypes, sv)
         stateordonet = widenconst(stateordonet)
     end
     if stateordonet === Nothing
@@ -535,7 +550,7 @@ function abstract_iteration(@nospecializ
         end
         valtype = tmerge(valtype, nounion.parameters[1])
         statetype = tmerge(statetype, nounion.parameters[2])
-        stateordonet = abstract_call(iteratef, nothing, Any[Const(iteratef), itertype, statetype], vtypes, sv)
+        stateordonet = abstract_call_known(iteratef, nothing, Any[Const(iteratef), itertype, statetype], vtypes, sv)
         stateordonet = widenconst(stateordonet)
     end
     push!(ret, Vararg{valtype})
@@ -543,7 +558,7 @@ function abstract_iteration(@nospecializ
 end
 
 # do apply(af, fargs...), where af is a function value
-function abstract_apply(@nospecialize(aft), aargtypes::Vector{Any}, vtypes::VarTable, sv::InferenceState,
+function abstract_apply(@nospecialize(itft), @nospecialize(aft), aargtypes::Vector{Any}, vtypes::VarTable, sv::InferenceState,
                         max_methods = sv.params.MAX_METHODS)
     aftw = widenconst(aft)
     if !isa(aft, Const) && (!isType(aftw) || has_free_typevars(aftw))
@@ -561,7 +576,7 @@ function abstract_apply(@nospecialize(af
     for i = 1:nargs
         ctypes´ = []
         for ti in (splitunions ? uniontypes(aargtypes[i]) : Any[aargtypes[i]])
-            cti = precise_container_type(ti, vtypes, sv)
+            cti = precise_container_type(itft, ti, vtypes, sv)
             if _any(t -> t === Bottom, cti)
                 continue
             end
@@ -577,14 +592,16 @@ function abstract_apply(@nospecialize(af
         ctypes = ctypes´
     end
     for ct in ctypes
-        if isa(aft, Const)
-            rt = abstract_call(aft.val, nothing, ct, vtypes, sv, max_methods)
-        elseif isconstType(aft)
-            rt = abstract_call(aft.parameters[1], nothing, ct, vtypes, sv, max_methods)
-        else
-            astype = argtypes_to_type(ct)
-            rt = abstract_call_gf_by_type(nothing, ct, astype, sv, max_methods)
+        lct = length(ct)
+        # truncate argument list at the first Vararg
+        for i = 1:lct-1
+            if isvarargtype(ct[i])
+                ct[i] = tuple_tail_elem(ct[i], ct[(i+1):lct])
+                resize!(ct, i)
+                break
+            end
         end
+        rt = abstract_call(nothing, ct, vtypes, sv, max_methods)
         res = tmerge(res, rt)
         if res === Any
             break
@@ -593,33 +610,24 @@ function abstract_apply(@nospecialize(af
     return res
 end
 
-function pure_eval_call(@nospecialize(f), argtypes::Vector{Any}, @nospecialize(atype), sv::InferenceState)
-    for i = 2:length(argtypes)
-        a = widenconditional(argtypes[i])
-        if !(isa(a, Const) || isconstType(a))
-            return false
-        end
-    end
-
-    min_valid = UInt[typemin(UInt)]
-    max_valid = UInt[typemax(UInt)]
-    meth = _methods_by_ftype(atype, 1, sv.params.world, min_valid, max_valid)
-    if meth === false || length(meth) != 1
-        return false
-    end
-    meth = meth[1]::SimpleVector
-    sig = meth[1]::DataType
-    sparams = meth[2]::SimpleVector
-    method = meth[3]::Method
-
+function is_method_pure(method::Method, @nospecialize(sig), sparams::SimpleVector)
     if isdefined(method, :generator)
         method.generator.expand_early || return false
         mi = specialize_method(method, sig, sparams, false)
         isa(mi, MethodInstance) || return false
         staged = get_staged(mi)
         (staged isa CodeInfo && (staged::CodeInfo).pure) || return false
-    elseif !method.pure
-        return false
+        return true
+    end
+    return method.pure
+end
+
+function pure_eval_call(@nospecialize(f), argtypes::Vector{Any})
+    for i = 2:length(argtypes)
+        a = widenconditional(argtypes[i])
+        if !(isa(a, Const) || isconstType(a))
+            return false
+        end
     end
 
     args = Any[ (a = widenconditional(argtypes[i]); isa(a, Const) ? a.val : a.parameters[1]) for i in 2:length(argtypes) ]
@@ -632,20 +640,38 @@ function pure_eval_call(@nospecialize(f)
     end
 end
 
-function abstract_call(@nospecialize(f), fargs::Union{Nothing,Vector{Any}}, argtypes::Vector{Any}, vtypes::VarTable, sv::InferenceState, max_methods = sv.params.MAX_METHODS)
-    if f === _apply
-        return abstract_apply(argtypes[2], argtypes[3:end], vtypes, sv, max_methods)
+function argtype_by_index(argtypes::Vector{Any}, i::Int)
+    n = length(argtypes)
+    if isvarargtype(argtypes[n])
+        return i >= n ? unwrapva(argtypes[n]) : argtypes[i]
+    else
+        return i > n ? Bottom : argtypes[i]
     end
+end
 
-    la = length(argtypes)
-    for i = 2:(la - 1)
-        if isvarargtype(argtypes[i])
-            return Any
-        end
+function argtype_tail(argtypes::Vector{Any}, i::Int)
+    n = length(argtypes)
+    if isvarargtype(argtypes[n]) && i > n
+        i = n
     end
+    return argtypes[i:n]
+end
+
+# call where the function is known exactly
+function abstract_call_known(@nospecialize(f), fargs::Union{Nothing,Vector{Any}}, argtypes::Vector{Any}, vtypes::VarTable, sv::InferenceState, max_methods = sv.params.MAX_METHODS)
+    la = length(argtypes)
 
-    if isa(f, Builtin) || isa(f, IntrinsicFunction)
-        if f === ifelse && fargs isa Vector{Any} && length(argtypes) == 4 && argtypes[2] isa Conditional
+    if isa(f, Builtin)
+        if f === _apply
+            ft = argtype_by_index(argtypes, 2)
+            ft === Bottom && return Bottom
+            return abstract_apply(nothing, ft, argtype_tail(argtypes, 3), vtypes, sv, max_methods)
+        elseif f === _apply_iterate
+            itft = argtype_by_index(argtypes, 2)
+            ft = argtype_by_index(argtypes, 3)
+            (itft === Bottom || ft === Bottom) && return Bottom
+            return abstract_apply(itft, ft, argtype_tail(argtypes, 4), vtypes, sv, max_methods)
+        elseif f === ifelse && fargs isa Vector{Any} && la == 4 && argtypes[2] isa Conditional
             # try to simulate this as a real conditional (`cnd ? x : y`), so that the penalty for using `ifelse` instead isn't too high
             cnd = argtypes[2]::Conditional
             tx = argtypes[3]
@@ -661,8 +687,8 @@ function abstract_call(@nospecialize(f),
             return tmerge(tx, ty)
         end
         rt = builtin_tfunction(f, argtypes[2:end], sv)
-        if f === getfield && isa(fargs, Vector{Any}) && length(argtypes) == 3 && isa(argtypes[3], Const) && isa(argtypes[3].val, Int) && argtypes[2] ⊑ Tuple
-            cti = precise_container_type(argtypes[2], vtypes, sv)
+        if f === getfield && isa(fargs, Vector{Any}) && la == 3 && isa(argtypes[3], Const) && isa(argtypes[3].val, Int) && argtypes[2] ⊑ Tuple
+            cti = precise_container_type(nothing, argtypes[2], vtypes, sv)
             idx = argtypes[3].val
             if 1 <= idx <= length(cti)
                 rt = unwrapva(cti[idx])
@@ -736,7 +762,7 @@ function abstract_call(@nospecialize(f),
         end
         return isa(rt, TypeVar) ? rt.ub : rt
     elseif f === Core.kwfunc
-        if length(argtypes) == 2
+        if la == 2
             ft = widenconst(argtypes[2])
             if isa(ft, DataType) && isdefined(ft.name, :mt) && isdefined(ft.name.mt, :kwsorter)
                 return Const(ft.name.mt.kwsorter)
@@ -746,19 +772,19 @@ function abstract_call(@nospecialize(f),
     elseif f === TypeVar
         # Manually look through the definition of TypeVar to
         # make sure to be able to get `PartialTypeVar`s out.
-        (length(argtypes) < 2 || length(argtypes) > 4) && return Union{}
+        (la < 2 || la > 4) && return Union{}
         n = argtypes[2]
         ub_var = Const(Any)
         lb_var = Const(Union{})
-        if length(argtypes) == 4
+        if la == 4
             ub_var = argtypes[4]
             lb_var = argtypes[3]
-        elseif length(argtypes) == 3
+        elseif la == 3
             ub_var = argtypes[3]
         end
         return typevar_tfunc(n, lb_var, ub_var)
     elseif f === UnionAll
-        if length(argtypes) == 3
+        if la == 3
             canconst = true
             if isa(argtypes[3], Const)
                 body = argtypes[3].val
@@ -795,23 +821,24 @@ function abstract_call(@nospecialize(f),
         if rt_rt !== nothing
             return rt_rt
         end
-    elseif length(argtypes) == 2 && istopfunction(f, :!)
+        return Type
+    elseif la == 2 && istopfunction(f, :!)
         # handle Conditional propagation through !Bool
         aty = argtypes[2]
         if isa(aty, Conditional)
             abstract_call_gf_by_type(f, Any[Const(f), Bool], Tuple{typeof(f), Bool}, sv) # make sure we've inferred `!(::Bool)`
             return Conditional(aty.var, aty.elsetype, aty.vtype)
         end
-    elseif length(argtypes) == 3 && istopfunction(f, :!==)
+    elseif la == 3 && istopfunction(f, :!==)
         # mark !== as exactly a negated call to ===
-        rty = abstract_call((===), fargs, argtypes, vtypes, sv)
+        rty = abstract_call_known((===), fargs, argtypes, vtypes, sv)
         if isa(rty, Conditional)
             return Conditional(rty.var, rty.elsetype, rty.vtype) # swap if-else
         elseif isa(rty, Const)
             return Const(rty.val === false)
         end
         return rty
-    elseif length(argtypes) == 3 && istopfunction(f, :(>:))
+    elseif la == 3 && istopfunction(f, :(>:))
         # mark issupertype as a exact alias for issubtype
         # swap T1 and T2 arguments and call <:
         if length(fargs) == 3
@@ -820,12 +847,12 @@ function abstract_call(@nospecialize(f),
             fargs = nothing
         end
         argtypes = Any[typeof(<:), argtypes[3], argtypes[2]]
-        rty = abstract_call(<:, fargs, argtypes, vtypes, sv)
+        rty = abstract_call_known(<:, fargs, argtypes, vtypes, sv)
         return rty
-    elseif length(argtypes) == 2 && isa(argtypes[2], Const) && isa(argtypes[2].val, SimpleVector) && istopfunction(f, :length)
+    elseif la == 2 && isa(argtypes[2], Const) && isa(argtypes[2].val, SimpleVector) && istopfunction(f, :length)
         # mark length(::SimpleVector) as @pure
         return Const(length(argtypes[2].val))
-    elseif length(argtypes) == 3 && isa(argtypes[2], Const) && isa(argtypes[3], Const) &&
+    elseif la == 3 && isa(argtypes[2], Const) && isa(argtypes[3], Const) &&
             isa(argtypes[2].val, SimpleVector) && isa(argtypes[3].val, Int) && istopfunction(f, :getindex)
         # mark getindex(::SimpleVector, i::Int) as @pure
         svecval = argtypes[2].val::SimpleVector
@@ -833,29 +860,23 @@ function abstract_call(@nospecialize(f),
         if 1 <= idx <= length(svecval) && isassigned(svecval, idx)
             return Const(getindex(svecval, idx))
         end
-    elseif length(argtypes) == 2 && istopfunction(f, :typename)
+    elseif la == 2 && istopfunction(f, :typename)
         return typename_static(argtypes[2])
     elseif max_methods > 1 && istopfunction(f, :copyto!)
         max_methods = 1
+    elseif la == 3 && istopfunction(f, :typejoin)
+        val = pure_eval_call(f, argtypes)
+        return val === false ? Type : val
     end
 
     atype = argtypes_to_type(argtypes)
-    t = pure_eval_call(f, argtypes, atype, sv)
-    t !== false && return t
-
-    if istopfunction(f, :typejoin) || is_return_type(f)
-        return Type # don't try to infer these function edges directly -- it won't actually come up with anything useful
-    end
-
     return abstract_call_gf_by_type(f, argtypes, atype, sv, max_methods)
 end
 
-# wrapper around `abstract_call` for first computing if `f` is available
-function abstract_eval_call(fargs::Union{Nothing,Vector{Any}}, argtypes::Vector{Any}, vtypes::VarTable, sv::InferenceState)
+# call where the function is any lattice element
+function abstract_call(fargs::Union{Nothing,Vector{Any}}, argtypes::Vector{Any}, vtypes::VarTable, sv::InferenceState,
+                       max_methods = sv.params.MAX_METHODS)
     #print("call ", e.args[1], argtypes, "\n\n")
-    for x in argtypes
-        x === Bottom && return Bottom
-    end
     ft = argtypes[1]
     if isa(ft, Const)
         f = ft.val
@@ -864,19 +885,14 @@ function abstract_eval_call(fargs::Union
     elseif isa(ft, DataType) && isdefined(ft, :instance)
         f = ft.instance
     else
-        for i = 2:(length(argtypes) - 1)
-            if isvarargtype(argtypes[i])
-                return Any
-            end
-        end
         # non-constant function, but the number of arguments is known
         # and the ft is not a Builtin or IntrinsicFunction
         if typeintersect(widenconst(ft), Builtin) != Union{}
             return Any
         end
-        return abstract_call_gf_by_type(nothing, argtypes, argtypes_to_type(argtypes), sv)
+        return abstract_call_gf_by_type(nothing, argtypes, argtypes_to_type(argtypes), sv, max_methods)
     end
-    return abstract_call(f, fargs, argtypes, vtypes, sv)
+    return abstract_call_known(f, fargs, argtypes, vtypes, sv, max_methods)
 end
 
 function sp_type_rewrap(@nospecialize(T), linfo::MethodInstance, isreturn::Bool)
@@ -925,7 +941,7 @@ function abstract_eval_cfunction(e::Expr
     # this may be the wrong world for the call,
     # but some of the result is likely to be valid anyways
     # and that may help generate better codegen
-    abstract_eval_call(nothing, at, vtypes, sv)
+    abstract_call(nothing, at, vtypes, sv)
     nothing
 end
 
@@ -945,8 +961,17 @@ function abstract_eval(@nospecialize(e),
     end
     e = e::Expr
     if e.head === :call
-        argtypes = Any[ abstract_eval(a, vtypes, sv) for a in e.args ]
-        t = abstract_eval_call(e.args, argtypes, vtypes, sv)
+        ea = e.args
+        n = length(ea)
+        argtypes = Vector{Any}(undef, n)
+        @inbounds for i = 1:n
+            ai = abstract_eval(ea[i], vtypes, sv)
+            if ai === Bottom
+                return Bottom
+            end
+            argtypes[i] = ai
+        end
+        t = abstract_call(ea, argtypes, vtypes, sv)
     elseif e.head === :new
         t = instanceof_tfunc(abstract_eval(e.args[1], vtypes, sv))[1]
         if isconcretetype(t) && !t.mutable
@@ -1072,12 +1097,6 @@ function abstract_eval_ssavalue(s::SSAVa
     return typ
 end
 
-# determine whether `ex` abstractly evals to constant `c`
-function abstract_evals_to_constant(@nospecialize(ex), @nospecialize(c), vtypes::VarTable, sv::InferenceState)
-    av = abstract_eval(ex, vtypes, sv)
-    return isa(av, Const) && av.val === c
-end
-
 # make as much progress on `frame` as possible (without handling cycles)
 function typeinf_local(frame::InferenceState)
     @assert !frame.inferred
diff -pruN 1.3.1+dfsg-1/base/compiler/compiler.jl 1.4.0+dfsg-1/base/compiler/compiler.jl
--- 1.3.1+dfsg-1/base/compiler/compiler.jl	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/base/compiler/compiler.jl	2020-03-21 16:36:32.000000000 +0000
@@ -5,7 +5,7 @@ getfield(getfield(Main, :Core), :eval)(g
 using Core.Intrinsics, Core.IR
 
 import Core: print, println, show, write, unsafe_write, stdout, stderr,
-             _apply, svec, apply_type, Builtin, IntrinsicFunction, MethodInstance, CodeInstance
+             _apply, _apply_iterate, svec, apply_type, Builtin, IntrinsicFunction, MethodInstance, CodeInstance
 
 const getproperty = getfield
 const setproperty! = setfield!
diff -pruN 1.3.1+dfsg-1/base/compiler/inferenceresult.jl 1.4.0+dfsg-1/base/compiler/inferenceresult.jl
--- 1.3.1+dfsg-1/base/compiler/inferenceresult.jl	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/base/compiler/inferenceresult.jl	2020-03-21 16:36:32.000000000 +0000
@@ -35,9 +35,13 @@ function matching_cache_argtypes(linfo::
     if linfo.def.isva
         isva_given_argtypes = Vector{Any}(undef, nargs)
         for i = 1:(nargs - 1)
-            isva_given_argtypes[i] = given_argtypes[i]
+            isva_given_argtypes[i] = argtype_by_index(given_argtypes, i)
+        end
+        if length(given_argtypes) >= nargs || !isvarargtype(given_argtypes[end])
+            isva_given_argtypes[nargs] = tuple_tfunc(given_argtypes[nargs:end])
+        else
+            isva_given_argtypes[nargs] = tuple_tfunc(given_argtypes[end:end])
         end
-        isva_given_argtypes[nargs] = tuple_tfunc(given_argtypes[nargs:end])
         given_argtypes = isva_given_argtypes
     end
     cache_argtypes, overridden_by_const = matching_cache_argtypes(linfo, nothing)
diff -pruN 1.3.1+dfsg-1/base/compiler/optimize.jl 1.4.0+dfsg-1/base/compiler/optimize.jl
--- 1.3.1+dfsg-1/base/compiler/optimize.jl	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/base/compiler/optimize.jl	2020-03-21 16:36:32.000000000 +0000
@@ -262,6 +262,7 @@ function is_pure_intrinsic_infer(f::Intr
              f === Intrinsics.llvmcall ||   # this one is never effect-free
              f === Intrinsics.arraylen ||   # this one is volatile
              f === Intrinsics.sqrt_llvm ||  # this one may differ at runtime (by a few ulps)
+             f === Intrinsics.sqrt_llvm_fast ||  # this one may differ at runtime (by a few ulps)
              f === Intrinsics.cglobal)  # cglobal lookup answer changes at runtime
 end
 
diff -pruN 1.3.1+dfsg-1/base/compiler/ssair/inlining.jl 1.4.0+dfsg-1/base/compiler/ssair/inlining.jl
--- 1.3.1+dfsg-1/base/compiler/ssair/inlining.jl	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/base/compiler/ssair/inlining.jl	2020-03-21 16:36:32.000000000 +0000
@@ -592,11 +592,11 @@ function spec_lambda(@nospecialize(atype
 end
 
 # This assumes the caller has verified that all arguments to the _apply call are Tuples.
-function rewrite_apply_exprargs!(ir::IRCode, idx::Int, argexprs::Vector{Any}, atypes::Vector{Any})
-    new_argexprs = Any[argexprs[2]]
-    new_atypes = Any[atypes[2]]
+function rewrite_apply_exprargs!(ir::IRCode, idx::Int, argexprs::Vector{Any}, atypes::Vector{Any}, arg_start::Int)
+    new_argexprs = Any[argexprs[arg_start]]
+    new_atypes = Any[atypes[arg_start]]
     # loop over original arguments and flatten any known iterators
-    for i in 3:length(argexprs)
+    for i in (arg_start+1):length(argexprs)
         def = argexprs[i]
         def_type = atypes[i]
         if def_type isa PartialStruct
@@ -882,11 +882,15 @@ end
 
 function inline_apply!(ir::IRCode, idx::Int, sig::Signature, params::Params)
     stmt = ir.stmts[idx]
-    while sig.f === Core._apply
+    while sig.f === Core._apply || sig.f === Core._apply_iterate
+        arg_start = sig.f === Core._apply ? 2 : 3
         atypes = sig.atypes
+        if arg_start > length(atypes)
+            return nothing
+        end
         # Try to figure out the signature of the function being called
         # and if rewrite_apply_exprargs can deal with this form
-        for i = 3:length(atypes)
+        for i = (arg_start + 1):length(atypes)
             # TODO: We could basically run the iteration protocol here
             if !is_valid_type_for_apply_rewrite(atypes[i], params)
                 return nothing
@@ -894,13 +898,13 @@ function inline_apply!(ir::IRCode, idx::
         end
         # Independent of whether we can inline, the above analysis allows us to rewrite
         # this apply call to a regular call
-        ft = atypes[2]
-        if length(atypes) == 3 && ft isa Const && ft.val === Core.tuple && atypes[3] ⊑ Tuple
+        ft = atypes[arg_start]
+        if length(atypes) == arg_start+1 && ft isa Const && ft.val === Core.tuple && atypes[arg_start+1] ⊑ Tuple
             # rewrite `((t::Tuple)...,)` to `t`
-            ir.stmts[idx] = stmt.args[3]
+            ir.stmts[idx] = stmt.args[arg_start+1]
             return nothing
         end
-        stmt.args, atypes = rewrite_apply_exprargs!(ir, idx, stmt.args, atypes)
+        stmt.args, atypes = rewrite_apply_exprargs!(ir, idx, stmt.args, atypes, arg_start)
         has_free_typevars(ft) && return nothing
         f = singleton_type(ft)
         sig = Signature(f, ft, atypes)
diff -pruN 1.3.1+dfsg-1/base/compiler/ssair/passes.jl 1.4.0+dfsg-1/base/compiler/ssair/passes.jl
--- 1.3.1+dfsg-1/base/compiler/ssair/passes.jl	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/base/compiler/ssair/passes.jl	2020-03-21 16:36:32.000000000 +0000
@@ -370,6 +370,13 @@ function lift_leaves(compact::Incrementa
             end
         elseif isa(leaf, QuoteNode)
             leaf = leaf.value
+        elseif isa(leaf, GlobalRef)
+            mod, name = leaf.mod, leaf.name
+            if isdefined(mod, name) && isconst(mod, name)
+                leaf = getfield(mod, name)
+            else
+                return nothing
+            end
         elseif isa(leaf, Union{Argument, Expr})
             return nothing
         end
diff -pruN 1.3.1+dfsg-1/base/compiler/ssair/verify.jl 1.4.0+dfsg-1/base/compiler/ssair/verify.jl
--- 1.3.1+dfsg-1/base/compiler/ssair/verify.jl	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/base/compiler/ssair/verify.jl	2020-03-21 16:36:32.000000000 +0000
@@ -29,6 +29,7 @@ function check_op(ir::IRCode, domtree::D
             end
         else
             if !dominates(domtree, def_bb, use_bb) && !(bb_unreachable(domtree, def_bb) && bb_unreachable(domtree, use_bb))
+                # At the moment, we allow GC preserve tokens outside the standard domination notion
                 #@Base.show ir
                 @verify_error "Basic Block $def_bb does not dominate block $use_bb (tried to use value $(op.id))"
                 error()
@@ -189,10 +190,17 @@ function verify_ir(ir::IRCode)
                     end
                 end
             end
-            if isa(stmt, Expr) && stmt.head === :(=)
-                if stmt.args[1] isa SSAValue
-                    @verify_error "SSAValue as assignment LHS"
-                    error()
+            if isa(stmt, Expr)
+                if stmt.head === :(=)
+                    if stmt.args[1] isa SSAValue
+                        @verify_error "SSAValue as assignment LHS"
+                        error()
+                    end
+                elseif stmt.head === :gc_preserve_end
+                    # We allow gc_preserve_end tokens to span across try/catch
+                    # blocks, which isn't allowed for regular SSA values, so
+                    # we skip the validation below.
+                    continue
                 end
             end
             for op in userefs(stmt)
diff -pruN 1.3.1+dfsg-1/base/compiler/tfuncs.jl 1.4.0+dfsg-1/base/compiler/tfuncs.jl
--- 1.3.1+dfsg-1/base/compiler/tfuncs.jl	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/base/compiler/tfuncs.jl	2020-03-21 16:36:32.000000000 +0000
@@ -164,6 +164,7 @@ add_tfunc(floor_llvm, 1, 1, math_tfunc,
 add_tfunc(trunc_llvm, 1, 1, math_tfunc, 10)
 add_tfunc(rint_llvm, 1, 1, math_tfunc, 10)
 add_tfunc(sqrt_llvm, 1, 1, math_tfunc, 20)
+add_tfunc(sqrt_llvm_fast, 1, 1, math_tfunc, 20)
     ## same-type comparisons ##
 cmp_tfunc(@nospecialize(x), @nospecialize(y)) = Bool
 add_tfunc(eq_int, 2, 2, cmp_tfunc, 1)
@@ -997,7 +998,7 @@ function apply_type_nothrow(argtypes::Ar
     for i = 2:length(argtypes)
         isa(u, UnionAll) || return false
         ai = widenconditional(argtypes[i])
-        if ai === TypeVar
+        if ai ⊑ TypeVar
             # We don't know anything about the bounds of this typevar, but as
             # long as the UnionAll is not constrained, that's ok.
             if !(u.var.lb === Union{} && u.var.ub === Any)
@@ -1440,14 +1441,7 @@ function return_type_tfunc(argtypes::Vec
                     if contains_is(argtypes_vec, Union{})
                         return Const(Union{})
                     end
-                    astype = argtypes_to_type(argtypes_vec)
-                    if isa(aft, Const)
-                        rt = abstract_call(aft.val, nothing, argtypes_vec, vtypes, sv, -1)
-                    elseif isconstType(aft)
-                        rt = abstract_call(aft.parameters[1], nothing, argtypes_vec, vtypes, sv, -1)
-                    else
-                        rt = abstract_call_gf_by_type(nothing, argtypes_vec, astype, sv, -1)
-                    end
+                    rt = abstract_call(nothing, argtypes_vec, vtypes, sv, -1)
                     if isa(rt, Const)
                         # output was computed to be constant
                         return Const(typeof(rt.val))
diff -pruN 1.3.1+dfsg-1/base/compiler/typelattice.jl 1.4.0+dfsg-1/base/compiler/typelattice.jl
--- 1.3.1+dfsg-1/base/compiler/typelattice.jl	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/base/compiler/typelattice.jl	2020-03-21 16:36:32.000000000 +0000
@@ -168,6 +168,8 @@ function ⊑(@nospecialize(a), @nospecia
             return a.instance === b.val
         end
         return false
+    elseif isa(a, PartialTypeVar) && b === TypeVar
+        return true
     elseif !(isa(a, Type) || isa(a, TypeVar)) ||
            !(isa(b, Type) || isa(b, TypeVar))
         return a === b
diff -pruN 1.3.1+dfsg-1/base/compiler/typelimits.jl 1.4.0+dfsg-1/base/compiler/typelimits.jl
--- 1.3.1+dfsg-1/base/compiler/typelimits.jl	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/base/compiler/typelimits.jl	2020-03-21 16:36:32.000000000 +0000
@@ -57,21 +57,6 @@ function is_derived_type(@nospecialize(t
         for p in cP
             is_derived_type(t, p, mindepth) && return true
         end
-        if isconcretetype(c) && isbitstype(c)
-            # see if it was extracted from a fieldtype
-            # however, only look through types that can be inlined
-            # to ensure monotonicity of derivation
-            # since we know that for immutable, concrete, bits types,
-            # the field types must have been constructed prior to the type,
-            # it cannot have a reference cycle in the type graph
-            cF = c.types
-            for f in cF
-                # often a parameter is also a field type; avoid searching twice
-                if !contains_is(c.parameters, f)
-                    is_derived_type(t, f, mindepth) && return true
-                end
-            end
-        end
     end
     return false
 end
diff -pruN 1.3.1+dfsg-1/base/compiler/typeutils.jl 1.4.0+dfsg-1/base/compiler/typeutils.jl
--- 1.3.1+dfsg-1/base/compiler/typeutils.jl	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/base/compiler/typeutils.jl	2020-03-21 16:36:32.000000000 +0000
@@ -95,11 +95,10 @@ _typename(union::UnionAll) = _typename(u
 _typename(a::DataType) = Const(a.name)
 
 function tuple_tail_elem(@nospecialize(init), ct::Vector{Any})
-    # FIXME: this is broken: it violates subtyping relations and creates invalid types with free typevars
-    tmerge_maybe_vararg(@nospecialize(a), @nospecialize(b)) = tmerge(a, tvar_extent(unwrapva(b)))
     t = init
     for x in ct
-        t = tmerge_maybe_vararg(t, x)
+        # FIXME: this is broken: it violates subtyping relations and creates invalid types with free typevars
+        t = tmerge(t, tvar_extent(unwrapva(x)))
     end
     return Vararg{widenconst(t)}
 end
diff -pruN 1.3.1+dfsg-1/base/compiler/utilities.jl 1.4.0+dfsg-1/base/compiler/utilities.jl
--- 1.3.1+dfsg-1/base/compiler/utilities.jl	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/base/compiler/utilities.jl	2020-03-21 16:36:32.000000000 +0000
@@ -73,7 +73,9 @@ function quoted(@nospecialize(x))
 end
 
 function is_inlineable_constant(@nospecialize(x))
-    x isa Type && return true
+    if x isa Type || x isa Symbol
+        return true
+    end
     return isbits(x) && Core.sizeof(x) <= MAX_INLINE_CONST_SIZE
 end
 
diff -pruN 1.3.1+dfsg-1/base/complex.jl 1.4.0+dfsg-1/base/complex.jl
--- 1.3.1+dfsg-1/base/complex.jl	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/base/complex.jl	2020-03-21 16:36:32.000000000 +0000
@@ -108,7 +108,7 @@ Float64
 """
 real(T::Type) = typeof(real(zero(T)))
 real(::Type{T}) where {T<:Real} = T
-real(::Type{Complex{T}}) where {T<:Real} = T
+real(C::Type{<:Complex}) = fieldtype(C, 1)
 
 """
     isreal(x) -> Bool
@@ -184,12 +184,16 @@ function show(io::IO, z::Complex)
     compact = get(io, :compact, false)
     show(io, r)
     if signbit(i) && !isnan(i)
-        i = -i
         print(io, compact ? "-" : " - ")
+        if isa(i,Signed) && !isa(i,BigInt) && i == typemin(typeof(i))
+            show(io, -widen(i))
+        else
+            show(io, -i)
+        end
     else
         print(io, compact ? "+" : " + ")
+        show(io, i)
     end
-    show(io, i)
     if !(isa(i,Integer) && !isa(i,Bool) || isa(i,AbstractFloat) && isfinite(i))
         print(io, "*")
     end
diff -pruN 1.3.1+dfsg-1/base/condition.jl 1.4.0+dfsg-1/base/condition.jl
--- 1.3.1+dfsg-1/base/condition.jl	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/base/condition.jl	2020-03-21 16:36:32.000000000 +0000
@@ -161,3 +161,8 @@ this, and can be used for level-triggere
 This object is NOT thread-safe. See [`Threads.Condition`](@ref) for a thread-safe version.
 """
 const Condition = GenericCondition{AlwaysLockedST}
+
+lock(c::GenericCondition{AlwaysLockedST}) =
+    throw(ArgumentError("`Condition` is not thread-safe. Please use `Threads.Condition` instead for multi-threaded code."))
+unlock(c::GenericCondition{AlwaysLockedST}) =
+    throw(ArgumentError("`Condition` is not thread-safe. Please use `Threads.Condition` instead for multi-threaded code."))
diff -pruN 1.3.1+dfsg-1/base/deepcopy.jl 1.4.0+dfsg-1/base/deepcopy.jl
--- 1.3.1+dfsg-1/base/deepcopy.jl	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/base/deepcopy.jl	2020-03-21 16:36:32.000000000 +0000
@@ -56,19 +56,35 @@ end
 
 function deepcopy_internal(@nospecialize(x), stackdict::IdDict)
     T = typeof(x)::DataType
-    isbitstype(T) && return x
-    if haskey(stackdict, x)
-        return stackdict[x]
-    end
-    y = ccall(:jl_new_struct_uninit, Any, (Any,), T)
+    nf = nfields(x)
     if T.mutable
+        if haskey(stackdict, x)
+            return stackdict[x]
+        end
+        y = ccall(:jl_new_struct_uninit, Any, (Any,), T)
         stackdict[x] = y
-    end
-    for i in 1:nfields(x)
-        if isdefined(x,i)
-            ccall(:jl_set_nth_field, Cvoid, (Any, Csize_t, Any), y, i-1,
-                  deepcopy_internal(getfield(x,i), stackdict))
+        for i in 1:nf
+            if isdefined(x, i)
+                xi = getfield(x, i)
+                xi = deepcopy_internal(xi, stackdict)::typeof(xi)
+                ccall(:jl_set_nth_field, Cvoid, (Any, Csize_t, Any), y, i-1, xi)
+            end
+        end
+    elseif nf == 0 || isbitstype(T)
+        y = x
+    else
+        flds = Vector{Any}(undef, nf)
+        for i in 1:nf
+            if isdefined(x, i)
+                xi = getfield(x, i)
+                xi = deepcopy_internal(xi, stackdict)::typeof(xi)
+                flds[i] = xi
+            else
+                nf = i - 1 # rest of tail must be undefined values
+                break
+            end
         end
+        y = ccall(:jl_new_structv, Any, (Any, Ptr{Any}, UInt32), T, flds, nf)
     end
     return y::T
 end
@@ -90,7 +106,7 @@ function _deepcopy_array_t(@nospecialize
         if ccall(:jl_array_isassigned, Cint, (Any, Csize_t), x, i-1) != 0
             xi = ccall(:jl_arrayref, Any, (Any, Csize_t), x, i-1)
             if !isbits(xi)
-                xi = deepcopy_internal(xi, stackdict)
+                xi = deepcopy_internal(xi, stackdict)::typeof(xi)
             end
             ccall(:jl_arrayset, Cvoid, (Any, Any, Csize_t), dest, xi, i-1)
         end
diff -pruN 1.3.1+dfsg-1/base/deprecated.jl 1.4.0+dfsg-1/base/deprecated.jl
--- 1.3.1+dfsg-1/base/deprecated.jl	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/base/deprecated.jl	2020-03-21 16:36:32.000000000 +0000
@@ -101,33 +101,28 @@ firstcaller(bt::Vector, funcsym::Symbol)
 function firstcaller(bt::Vector, funcsyms)
     # Identify the calling line
     found = false
-    lkup = StackTraces.UNKNOWN
-    found_frame = Ptr{Cvoid}(0)
-    for frame in bt
-        lkups = StackTraces.lookup(frame)
-        for outer lkup in lkups
+    for ip in bt
+        lkups = StackTraces.lookup(ip)
+        for lkup in lkups
             if lkup == StackTraces.UNKNOWN || lkup.from_c
                 continue
             end
             if found
-                found_frame = frame
-                @goto found
+                return ip, lkup
             end
             found = lkup.func in funcsyms
             # look for constructor type name
             if !found && lkup.linfo isa Core.MethodInstance
                 li = lkup.linfo
                 ft = ccall(:jl_first_argument_datatype, Any, (Any,), li.def.sig)
-                if isa(ft,DataType) && ft.name === Type.body.name
+                if isa(ft, DataType) && ft.name === Type.body.name
                     ft = unwrap_unionall(ft.parameters[1])
-                    found = (isa(ft,DataType) && ft.name.name in funcsyms)
+                    found = (isa(ft, DataType) && ft.name.name in funcsyms)
                 end
             end
         end
     end
-    return found_frame, StackTraces.UNKNOWN
-    @label found
-    return found_frame, lkup
+    return C_NULL, StackTraces.UNKNOWN
 end
 
 deprecate(m::Module, s::Symbol, flag=1) = ccall(:jl_deprecate_binding, Cvoid, (Any, Any, Cint), m, s, flag)
diff -pruN 1.3.1+dfsg-1/base/dict.jl 1.4.0+dfsg-1/base/dict.jl
--- 1.3.1+dfsg-1/base/dict.jl	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/base/dict.jl	2020-03-21 16:36:32.000000000 +0000
@@ -631,7 +631,7 @@ end
 """
     delete!(collection, key)
 
-Delete the mapping for the given key in a collection, and return the collection.
+Delete the mapping for the given key in a collection, if any, and return the collection.
 
 # Examples
 ```jldoctest
@@ -643,6 +643,10 @@ Dict{String,Int64} with 2 entries:
 julia> delete!(d, "b")
 Dict{String,Int64} with 1 entry:
   "a" => 1
+
+julia> delete!(d, "b") # d is left unchanged
+Dict{String,Int64} with 1 entry:
+  "a" => 1
 ```
 """
 delete!(collection, key)
diff -pruN 1.3.1+dfsg-1/base/div.jl 1.4.0+dfsg-1/base/div.jl
--- 1.3.1+dfsg-1/base/div.jl	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/base/div.jl	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1,278 @@
+# This file is a part of Julia. License is MIT: https://julialang.org/license
+
+# Div is truncating by default
+
+"""
+    div(x, y, r::RoundingMode=RoundToZero)
+
+The quotient from Euclidean division. Computes x/y, rounded to an integer according
+to the rounding mode `r`. In other words, the quantity
+
+    round(x/y,r)
+
+without any intermediate rounding.
+
+See also: [`fld`](@ref), [`cld`](@ref) which are special cases of this function
+
+# Examples:
+```jldoctest
+julia> div(4, 3, RoundDown) # Matches fld(4, 3)
+1
+julia> div(4, 3, RoundUp) # Matches cld(4, 3)
+2
+julia> div(5, 2, RoundNearest)
+2
+julia> div(5, 2, RoundNearestTiesAway)
+3
+julia> div(-5, 2, RoundNearest)
+-2
+julia> div(-5, 2, RoundNearestTiesAway)
+-3
+julia> div(-5, 2, RoundNearestTiesUp)
+-2
+```
+"""
+div(x, y, r::RoundingMode)
+
+div(a, b) = div(a, b, RoundToZero)
+
+"""
+    rem(x, y, r::RoundingMode=RoundToZero)
+
+Compute the remainder of `x` after integer division by `y`, with the quotient rounded
+according to the rounding mode `r`. In other words, the quantity
+
+    x - y*round(x/y,r)
+
+without any intermediate rounding.
+
+- if `r == RoundNearest`, then the result is exact, and in the interval
+  ``[-|y|/2, |y|/2]``. See also [`RoundNearest`](@ref).
+
+- if `r == RoundToZero` (default), then the result is exact, and in the interval
+  ``[0, |y|)`` if `x` is positive, or ``(-|y|, 0]`` otherwise. See also [`RoundToZero`](@ref).
+
+- if `r == RoundDown`, then the result is in the interval ``[0, y)`` if `y` is positive, or
+  ``(y, 0]`` otherwise. The result may not be exact if `x` and `y` have different signs, and
+  `abs(x) < abs(y)`. See also [`RoundDown`](@ref).
+
+- if `r == RoundUp`, then the result is in the interval `(-y,0]` if `y` is positive, or
+  `[0,-y)` otherwise. The result may not be exact if `x` and `y` have the same sign, and
+  `abs(x) < abs(y)`. See also [`RoundUp`](@ref).
+
+"""
+rem(x, y, r::RoundingMode)
+
+# TODO: Make these primitive and have the two-argument version call these
+rem(x, y, ::RoundingMode{:ToZero}) = rem(x,y)
+rem(x, y, ::RoundingMode{:Down}) = mod(x,y)
+rem(x, y, ::RoundingMode{:Up}) = mod(x,-y)
+
+"""
+    fld(x, y)
+
+Largest integer less than or equal to `x/y`. Equivalent to `div(x, y, RoundDown)`.
+
+See also: [`div`](@ref)
+
+# Examples
+```jldoctest
+julia> fld(7.3,5.5)
+1.0
+```
+"""
+fld(a, b) = div(a, b, RoundDown)
+
+"""
+    cld(x, y)
+
+Smallest integer larger than or equal to `x/y`. Equivalent to `div(x, y, RoundUp)`.
+
+See also: [`div`](@ref)
+
+# Examples
+```jldoctest
+julia> cld(5.5,2.2)
+3.0
+```
+"""
+cld(a, b) = div(a, b, RoundUp)
+
+# divrem
+"""
+    divrem(x, y, r::RoundingMode=RoundToZero)
+
+The quotient and remainder from Euclidean division.
+Equivalent to `(div(x,y,r), rem(x,y,r))`. Equivalently, with the the default
+value of `r`, this call is equivalent to `(x÷y, x%y)`.
+
+# Examples
+```jldoctest
+julia> divrem(3,7)
+(0, 3)
+
+julia> divrem(7,3)
+(2, 1)
+```
+"""
+divrem(x, y) = divrem(x, y, RoundToZero)
+function divrem(a, b, r::RoundingMode)
+    if r == RoundToZero
+        # For compat. Remove in 2.0.
+        (div(a, b), rem(a, b))
+    elseif r === RoundDown
+        # For compat. Remove in 2.0.
+        (fld(a, b), mod(a, b))
+    else
+        (div(a, b, r), rem(a, b, r))
+    end
+end
+function divrem(x::Integer, y::Integer, rnd::typeof(RoundNearest))
+    (q, r) = divrem(x, y)
+    if x >= 0
+        if y >= 0
+            r >=        (y÷2) + (isodd(y) | iseven(q)) ? (q+true, r-y) : (q, r)
+        else
+            r >=       -(y÷2) + (isodd(y) | iseven(q)) ? (q-true, r+y) : (q, r)
+        end
+    else
+        if y >= 0
+            r <= -signed(y÷2) - (isodd(y) | iseven(q)) ? (q-true, r+y) : (q, r)
+        else
+            r <=        (y÷2) - (isodd(y) | iseven(q)) ? (q+true, r-y) : (q, r)
+        end
+    end
+end
+function divrem(x::Integer, y::Integer, rnd:: typeof(RoundNearestTiesAway))
+    (q, r) = divrem(x, y)
+    if x >= 0
+        if y >= 0
+            r >=        (y÷2) + isodd(y) ? (q+true, r-y) : (q, r)
+        else
+            r >=       -(y÷2) + isodd(y) ? (q-true, r+y) : (q, r)
+        end
+    else
+        if y >= 0
+            r <= -signed(y÷2) - isodd(y) ? (q-true, r+y) : (q, r)
+        else
+            r <=        (y÷2) - isodd(y) ? (q+true, r-y) : (q, r)
+        end
+    end
+end
+function divrem(x::Integer, y::Integer, rnd::typeof(RoundNearestTiesUp))
+    (q, r) = divrem(x, y)
+    if x >= 0
+        if y >= 0
+            r >=        (y÷2) + isodd(y) ? (q+true, r-y) : (q, r)
+        else
+            r >=       -(y÷2) + true     ? (q-true, r+y) : (q, r)
+        end
+    else
+        if y >= 0
+            r <= -signed(y÷2) - true     ? (q-true, r+y) : (q, r)
+        else
+            r <=        (y÷2) - isodd(y) ? (q+true, r-y) : (q, r)
+        end
+    end
+end
+
+"""
+    fldmod(x, y)
+
+The floored quotient and modulus after division. A convenience wrapper for
+`divrem(x, y, RoundDown)`. Equivalent to `(fld(x,y), mod(x,y))`.
+"""
+fldmod(x,y) = divrem(x, y, RoundDown)
+
+# We definite generic rounding methods for other rounding modes in terms of
+# RoundToZero.
+function div(x::Signed, y::Unsigned, ::typeof(RoundDown))
+    (q, r) = divrem(x, y)
+    q - (signbit(x) & (r != 0))
+end
+function div(x::Unsigned, y::Signed, ::typeof(RoundDown))
+    (q, r) = divrem(x, y)
+    q - (signbit(y) & (r != 0))
+end
+
+function div(x::Signed, y::Unsigned, ::typeof(RoundUp))
+    (q, r) = divrem(x, y)
+    q + (!signbit(x) & (r != 0))
+end
+function div(x::Unsigned, y::Signed, ::typeof(RoundUp))
+    (q, r) = divrem(x, y)
+    q + (!signbit(y) & (r != 0))
+end
+
+function div(x::Integer, y::Integer, rnd::Union{typeof(RoundNearest),
+                                              typeof(RoundNearestTiesAway),
+                                              typeof(RoundNearestTiesUp)})
+    divrem(x,y,rnd)[1]
+end
+
+# For bootstrapping purposes, we define div for integers directly. Provide the
+# generic signature also
+div(a::T, b::T, ::typeof(RoundToZero)) where {T<:Union{BitSigned, BitUnsigned64}} = div(a, b)
+div(a::Bool, b::Bool, r::RoundingMode) = div(a, b)
+# Prevent ambiguities
+for rm in (RoundUp, RoundDown, RoundToZero)
+    @eval div(a::Bool, b::Bool, r::$(typeof(rm))) = div(a, b)
+end
+function div(x::Bool, y::Bool, rnd::Union{typeof(RoundNearest),
+                                        typeof(RoundNearestTiesAway),
+                                        typeof(RoundNearestTiesUp)})
+    div(x, y)
+end
+fld(a::T, b::T) where {T<:Union{Integer,AbstractFloat}} = div(a, b, RoundDown)
+cld(a::T, b::T) where {T<:Union{Integer,AbstractFloat}} = div(a, b, RoundUp)
+div(a::Int128, b::Int128, ::typeof(RoundToZero)) = div(a, b)
+div(a::UInt128, b::UInt128, ::typeof(RoundToZero)) = div(a, b)
+rem(a::Int128, b::Int128, ::typeof(RoundToZero)) = rem(a, b)
+rem(a::UInt128, b::UInt128, ::typeof(RoundToZero)) = rem(a, b)
+
+# These are kept for compatibility with external packages overriding fld/cld.
+# In 2.0, packages should extend div(a,b,r) instead, in which case, these can
+# be removed.
+fld(x::Real, y::Real) = div(promote(x,y)..., RoundDown)
+cld(x::Real, y::Real) = div(promote(x,y)..., RoundUp)
+fld(x::Signed, y::Unsigned) = div(x, y, RoundDown)
+fld(x::Unsigned, y::Signed) = div(x, y, RoundDown)
+cld(x::Signed, y::Unsigned) = div(x, y, RoundUp)
+cld(x::Unsigned, y::Signed) = div(x, y, RoundUp)
+fld(x::T, y::T) where {T<:Real} = throw(MethodError(div, (x, y, RoundDown)))
+cld(x::T, y::T) where {T<:Real} = throw(MethodError(div, (x, y, RoundUp)))
+
+# Promotion
+function div(x::Real, y::Real, r::RoundingMode)
+    typeof(x) === typeof(y) && throw(MethodError(div, (x, y, r)))
+    if r == RoundToZero
+        # For compat. Remove in 2.0.
+        div(promote(x, y)...)
+    else
+        div(promote(x, y)..., r)
+    end
+end
+
+# Integers
+# fld(x,y) == div(x,y) - ((x>=0) != (y>=0) && rem(x,y) != 0 ? 1 : 0)
+div(x::T, y::T, ::typeof(RoundDown)) where {T<:Unsigned} = div(x,y)
+function div(x::T, y::T, ::typeof(RoundDown)) where T<:Integer
+    d = div(x, y, RoundToZero)
+    return d - (signbit(x ⊻ y) & (d * y != x))
+end
+
+# cld(x,y) = div(x,y) + ((x>0) == (y>0) && rem(x,y) != 0 ? 1 : 0)
+function div(x::T, y::T, ::typeof(RoundUp)) where T<:Unsigned
+    d = div(x, y, RoundToZero)
+    return d + (d * y != x)
+end
+function div(x::T, y::T, ::typeof(RoundUp)) where T<:Integer
+    d = div(x, y, RoundToZero)
+    return d + (((x > 0) == (y > 0)) & (d * y != x))
+end
+
+# Real
+# NOTE: C89 fmod() and x87 FPREM implicitly provide truncating float division,
+# so it is used here as the basis of float div().
+div(x::T, y::T, r::RoundingMode) where {T<:AbstractFloat} = convert(T,round((x-rem(x,y,r))/y))
+rem(x::T, y::T, ::typeof(RoundUp)) where {T<:AbstractFloat} = convert(T,x-y*ceil(x/y))
diff -pruN 1.3.1+dfsg-1/base/docs/basedocs.jl 1.4.0+dfsg-1/base/docs/basedocs.jl
--- 1.3.1+dfsg-1/base/docs/basedocs.jl	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/base/docs/basedocs.jl	2020-03-21 16:36:32.000000000 +0000
@@ -349,6 +349,57 @@ For other purposes, `:( ... )` and `quot
 kw"quote"
 
 """
+    {}
+
+Curly braces are used to specify [type parameters](@ref man-parametric-types).
+
+Type parameters allow a single type declaration to introduce a whole family of
+new types — one for each possible combination of parameter values. For example,
+the [`Set`](@ref) type describes many possible types of sets; it uses one type
+parameter to describe the type of the elements it contains. The specific _parameterized_
+types `Set{Float64}` and `Set{Int64}` describe two _concrete_ types: both are
+subtypes ([`<:`](@ref)) of `Set`, but the former has `Float64` elements and the latter
+has `Int64` elements.
+"""
+kw"{", kw"{}", kw"}"
+
+"""
+    []
+
+Square braces are used for [indexing](@ref man-array-indexing), [indexed assignment](@ref man-indexed-assignment),
+[array literals](@ref man-array-literals), and [array comprehensions](@ref man-comprehensions).
+"""
+kw"[", kw"[]", kw"]"
+
+"""
+    ()
+
+Parentheses are used to group expressions, call functions, and construct [tuples](@ref Tuple) and [named tuples](@ref NamedTuple).
+"""
+kw"(", kw"()", kw")"
+
+"""
+    #
+
+The number sign (or hash) character is used to begin a single-line comment.
+"""
+kw"#"
+
+"""
+    #= =#
+
+A multi-line comment begins with `#=` and ends with `=#`, and may be nested.
+"""
+kw"#=", kw"=#"
+
+"""
+    ;
+
+Semicolons are used as statement separators and mark the beginning of keyword arguments in function declarations or calls.
+"""
+kw";"
+
+"""
     Expr(head::Symbol, args...)
 
 A type representing compound expressions in parsed julia code (ASTs).
@@ -397,6 +448,23 @@ julia> A'
 kw"'"
 
 """
+    \$
+
+Interpolation operator for interpolating into e.g. [strings](@ref string-interpolation)
+and [expressions](@ref man-expression-interpolation).
+
+# Examples
+```jldoctest
+julia> name = "Joe"
+"Joe"
+
+julia> "My name is \$name."
+"My name is Joe."
+```
+"""
+kw"$"
+
+"""
     const
 
 `const` is used to declare global variables whose values will not change. In almost all code
@@ -856,10 +924,10 @@ end
 Fields can have type restrictions, which may be parameterized:
 
 ```julia
-    struct Point{X}
-        x::X
-        y::Float64
-    end
+struct Point{X}
+    x::X
+    y::Float64
+end
 ```
 
 A struct can also declare an abstract super type via `<:` syntax:
@@ -894,7 +962,8 @@ kw"mutable struct"
 
 Special function available to inner constructors which created a new object
 of the type.
-See the manual section on [Inner Constructor Methods](@ref) for more information.
+See the manual section on [Inner Constructor Methods](@ref man-inner-constructor-methods)
+for more information.
 """
 kw"new"
 
@@ -1432,6 +1501,24 @@ Unsigned
     Bool <: Integer
 
 Boolean type, containing the values `true` and `false`.
+
+`Bool` is a kind of number: `false` is numerically
+equal to `0` and `true` is numerically equal to `1`.
+Moreover, `false` acts as a multiplicative "strong zero":
+
+```jldoctest
+julia> false == 0
+true
+
+julia> true == 1
+true
+
+julia> 0 * NaN
+NaN
+
+julia> false * NaN
+0.0
+```
 """
 Bool
 
@@ -1526,9 +1613,10 @@ tuple
 
 """
     getfield(value, name::Symbol)
+    getfield(value, i::Int)
 
-Extract a named field from a `value` of composite type.
-See also [`getproperty`](@ref Base.getproperty).
+Extract a field from a composite `value` by name or position.
+See also [`getproperty`](@ref Base.getproperty) and [`fieldnames`](@ref).
 
 # Examples
 ```jldoctest
@@ -1540,6 +1628,9 @@ julia> getfield(a, :num)
 
 julia> a.num
 1
+
+julia> getfield(a, 1)
+1
 ```
 """
 getfield
@@ -2111,6 +2202,29 @@ See the manual section on [Tuple Types](
 Tuple
 
 """
+    NamedTuple{names}(args::Tuple)
+
+Construct a named tuple with the given `names` (a tuple of Symbols) from a tuple of values.
+"""
+NamedTuple{names}(args::Tuple)
+
+"""
+    NamedTuple{names,T}(args::Tuple)
+
+Construct a named tuple with the given `names` (a tuple of Symbols) and field types `T`
+(a `Tuple` type) from a tuple of values.
+"""
+NamedTuple{names,T}(args::Tuple)
+
+"""
+    NamedTuple{names}(nt::NamedTuple)
+
+Construct a named tuple by selecting fields in `names` (a tuple of Symbols) from
+another named tuple.
+"""
+NamedTuple{names}(nt::NamedTuple)
+
+"""
     typeassert(x, type)
 
 Throw a [`TypeError`](@ref) unless `x isa type`.
diff -pruN 1.3.1+dfsg-1/base/docs/bindings.jl 1.4.0+dfsg-1/base/docs/bindings.jl
--- 1.3.1+dfsg-1/base/docs/bindings.jl	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/base/docs/bindings.jl	2020-03-21 16:36:32.000000000 +0000
@@ -25,6 +25,7 @@ function splitexpr(x::Expr)
     error("Invalid @var syntax `$x`.")
 end
 splitexpr(s::Symbol) = Expr(:macrocall, getfield(Base, Symbol("@__MODULE__")), nothing), quot(s)
+splitexpr(r::GlobalRef) = r.mod, quot(r.name)
 splitexpr(other)     = error("Invalid @var syntax `$other`.")
 
 macro var(x)
diff -pruN 1.3.1+dfsg-1/base/docs/Docs.jl 1.4.0+dfsg-1/base/docs/Docs.jl
--- 1.3.1+dfsg-1/base/docs/Docs.jl	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/base/docs/Docs.jl	2020-03-21 16:36:32.000000000 +0000
@@ -120,6 +120,12 @@ signature(@nospecialize other) = signatu
 function argtype(expr::Expr)
     isexpr(expr, :(::))  && return expr.args[end]
     isexpr(expr, :(...)) && return :(Vararg{$(argtype(expr.args[1]))})
+    if isexpr(expr, :meta) && length(expr.args) == 2
+        a1 = expr.args[1]
+        if a1 === :nospecialize || a1 === :specialize
+            return argtype(expr.args[2])
+        end
+    end
     return argtype(expr.args[1])
 end
 argtype(@nospecialize other) = :Any
@@ -366,13 +372,15 @@ end
 
 function calldoc(__source__, __module__, str, def::Expr)
     @nospecialize str
-    args = def.args[2:end]
+    args = callargs(def)
     if isempty(args) || all(validcall, args)
         objectdoc(__source__, __module__, str, nothing, def, signature(def))
     else
         docerror(def)
     end
 end
+callargs(ex::Expr) = isexpr(ex, :where) ? callargs(ex.args[1]) :
+    isexpr(ex, :call) ? ex.args[2:end] : error("Invalid expression to callargs: $ex")
 validcall(x) = isa(x, Symbol) || isexpr(x, (:(::), :..., :kw, :parameters))
 
 function moduledoc(__source__, __module__, meta, def, def′::Expr)
@@ -502,6 +510,12 @@ function docm(source::LineNumberNode, mo
     end
 end
 
+# iscallexpr checks if an expression is a :call expression. The call expression may be
+# also part of a :where expression, so it unwraps the :where layers until it reaches the
+# "actual" expression
+iscallexpr(ex::Expr) = isexpr(ex, :where) ? iscallexpr(ex.args[1]) : isexpr(ex, :call)
+iscallexpr(ex) = false
+
 function docm(source::LineNumberNode, mod::Module, meta, ex, define::Bool = true)
     @nospecialize meta ex
     # Some documented expressions may be decorated with macro calls which obscure the actual
@@ -530,9 +544,14 @@ function docm(source::LineNumberNode, mo
     #   function f end
     #   f(...)
     #
-    isexpr(x, FUNC_HEADS) && is_signature(x.args[1])   ? objectdoc(source, mod, meta, def, x, signature(x)) :
+    # Including if the "call" expression is wrapped in "where" expression(s) (#32960), i.e.
+    #
+    #   f(::T) where T
+    #   f(::T, ::U) where T where U
+    #
+    isexpr(x, FUNC_HEADS) && is_signature(x.args[1]) ? objectdoc(source, mod, meta, def, x, signature(x)) :
     isexpr(x, [:function, :macro])  && !isexpr(x.args[1], :call) ? objectdoc(source, mod, meta, def, x) :
-    isexpr(x, :call)                                   ? calldoc(source, mod, meta, x) :
+    iscallexpr(x) ? calldoc(source, mod, meta, x) :
 
     # Type definitions.
     #
diff -pruN 1.3.1+dfsg-1/base/download.jl 1.4.0+dfsg-1/base/download.jl
--- 1.3.1+dfsg-1/base/download.jl	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/base/download.jl	2020-03-21 16:36:32.000000000 +0000
@@ -48,7 +48,7 @@ end
 
 const DOWNLOAD_HOOKS = Callable[]
 
-function download_url(url::String)
+function download_url(url::AbstractString)
     for hook in DOWNLOAD_HOOKS
         url = String(hook(url)::AbstractString)
     end
diff -pruN 1.3.1+dfsg-1/base/Enums.jl 1.4.0+dfsg-1/base/Enums.jl
--- 1.3.1+dfsg-1/base/Enums.jl	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/base/Enums.jl	2020-03-21 16:36:32.000000000 +0000
@@ -189,7 +189,7 @@ macro enum(T, syms...)
         Enums.namemap(::Type{$(esc(typename))}) = $(esc(namemap))
         Base.typemin(x::Type{$(esc(typename))}) = $(esc(typename))($lo)
         Base.typemax(x::Type{$(esc(typename))}) = $(esc(typename))($hi)
-        let insts = ntuple(i->$(esc(typename))($values[i]), $(length(values)))
+        let insts = (Any[ $(esc(typename))(v) for v in $values ]...,)
             Base.instances(::Type{$(esc(typename))}) = insts
         end
     end
diff -pruN 1.3.1+dfsg-1/base/error.jl 1.4.0+dfsg-1/base/error.jl
--- 1.3.1+dfsg-1/base/error.jl	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/base/error.jl	2020-03-21 16:36:32.000000000 +0000
@@ -43,10 +43,18 @@ function error(s::Vararg{Any,N}) where {
 end
 
 """
-    rethrow([e])
+    rethrow()
 
-Throw an object without changing the current exception backtrace. The default argument is
-the current exception (if called within a `catch` block).
+Rethrow the current exception from within a `catch` block. The rethrown
+exception will continue propagation as if it had not been caught.
+
+!!! note
+    The alternative form `rethrow(e)` allows you to associate an alternative
+    exception object `e` with the current backtrace. However this misrepresents
+    the program state at the time of the error so you're encouraged to instead
+    throw a new exception using `throw(e)`. In Julia 1.1 and above, using
+    `throw(e)` will preserve the root cause exception on the stack, as
+    described in [`catch_stack`](@ref).
 """
 rethrow() = ccall(:jl_rethrow, Bottom, ())
 rethrow(e) = ccall(:jl_rethrow_other, Bottom, (Any,), e)
@@ -54,30 +62,56 @@ rethrow(e) = ccall(:jl_rethrow_other, Bo
 struct InterpreterIP
     code::Union{CodeInfo,Core.MethodInstance,Nothing}
     stmt::Csize_t
+    mod::Union{Module,Nothing}
 end
 
-# convert dual arrays (ips, interpreter_frames) to a single array of locations
+# convert dual arrays (raw bt buffer, array of GC managed values) to a single
+# array of locations
 function _reformat_bt(bt, bt2)
     ret = Vector{Union{InterpreterIP,Ptr{Cvoid}}}()
     i, j = 1, 1
     while i <= length(bt)
         ip = bt[i]::Ptr{Cvoid}
-        if UInt(ip) == (-1 % UInt)
-            # The next one is really a CodeInfo
-            push!(ret, InterpreterIP(
-                bt2[j],
-                bt[i+2]))
-            j += 1
-            i += 3
-        else
-            push!(ret, Ptr{Cvoid}(ip))
+        if UInt(ip) != (-1 % UInt) # See also jl_bt_is_native
+            # native frame
+            push!(ret, ip)
             i += 1
+            continue
         end
+        # Extended backtrace entry
+        entry_metadata = reinterpret(UInt, bt[i+1])
+        njlvalues =  entry_metadata & 0x7
+        nuintvals = (entry_metadata >> 3) & 0x7
+        tag       = (entry_metadata >> 6) & 0xf
+        header    =  entry_metadata >> 10
+        if tag == 1 # JL_BT_INTERP_FRAME_TAG
+            code = bt2[j]
+            mod = njlvalues == 2 ? bt2[j+1] : nothing
+            push!(ret, InterpreterIP(code, header, mod))
+        else
+            # Tags we don't know about are an error
+            throw(ArgumentError("Unexpected extended backtrace entry tag $tag at bt[$i]"))
+        end
+        # See jl_bt_entry_size
+        j += njlvalues
+        i += Int(2 + njlvalues + nuintvals)
     end
     ret
 end
 
-function backtrace end
+"""
+    backtrace()
+
+Get a backtrace object for the current program point.
+"""
+function backtrace()
+    @_noinline_meta
+    # skip frame for backtrace(). Note that for this to work properly,
+    # backtrace() itself must not be interpreted nor inlined.
+    skip = 1
+    bt1, bt2 = ccall(:jl_backtrace_from_here, Ref{SimpleVector}, (Cint, Cint), false, skip)
+    return _reformat_bt(bt1::Vector{Ptr{Cvoid}}, bt2::Vector{Any})
+end
 
 """
     catch_backtrace()
@@ -85,10 +119,8 @@ function backtrace end
 Get the backtrace of the current exception, for use within `catch` blocks.
 """
 function catch_backtrace()
-    bt = Ref{Any}(nothing)
-    bt2 = Ref{Any}(nothing)
-    ccall(:jl_get_backtrace, Cvoid, (Ref{Any}, Ref{Any}), bt, bt2)
-    return _reformat_bt(bt[], bt2[])
+    bt, bt2 = ccall(:jl_get_backtrace, Ref{SimpleVector}, ())
+    return _reformat_bt(bt::Vector{Ptr{Cvoid}}, bt2::Vector{Any})
 end
 
 """
@@ -127,12 +159,13 @@ end
 
 ## system error handling ##
 """
-    systemerror(sysfunc, iftrue)
+    systemerror(sysfunc[, errno::Cint=Libc.errno()])
+    systemerror(sysfunc, iftrue::Bool)
 
 Raises a `SystemError` for `errno` with the descriptive string `sysfunc` if `iftrue` is `true`
 """
-systemerror(p, b::Bool; extrainfo=nothing) = b ? throw(Main.Base.SystemError(string(p), Libc.errno(), extrainfo)) : nothing
-
+systemerror(p, b::Bool; extrainfo=nothing) = b ? systemerror(p, extrainfo=extrainfo) : nothing
+systemerror(p, errno::Cint=Libc.errno(); extrainfo=nothing) = throw(Main.Base.SystemError(string(p), errno, extrainfo))
 
 ## system errors from Windows API functions
 struct WindowsErrorInfo
@@ -140,12 +173,14 @@ struct WindowsErrorInfo
     extrainfo
 end
 """
-    windowserror(sysfunc, iftrue)
+    windowserror(sysfunc[, code::UInt32=Libc.GetLastError()])
+    windowserror(sysfunc, iftrue::Bool)
 
-Like [`systemerror`](@ref), but for Windows API functions that use [`GetLastError`](@ref) instead
-of setting [`errno`](@ref).
+Like [`systemerror`](@ref), but for Windows API functions that use [`GetLastError`](@ref Base.Libc.GetLastError) to
+return an error code instead of setting [`errno`](@ref Base.Libc.errno).
 """
-windowserror(p, b::Bool; extrainfo=nothing) = b ? throw(Main.Base.SystemError(string(p), Libc.errno(), WindowsErrorInfo(Libc.GetLastError(), extrainfo))) : nothing
+windowserror(p, b::Bool; extrainfo=nothing) = b ? windowserror(p, extrainfo=extrainfo) : nothing
+windowserror(p, code::UInt32=Libc.GetLastError(); extrainfo=nothing) = throw(Main.Base.SystemError(string(p), 0, WindowsErrorInfo(code, extrainfo)))
 
 
 ## assertion macro ##
diff -pruN 1.3.1+dfsg-1/base/errorshow.jl 1.4.0+dfsg-1/base/errorshow.jl
--- 1.3.1+dfsg-1/base/errorshow.jl	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/base/errorshow.jl	2020-03-21 16:36:32.000000000 +0000
@@ -165,6 +165,49 @@ end
 
 typesof(args...) = Tuple{Any[ Core.Typeof(a) for a in args ]...}
 
+function print_with_compare(io::IO, @nospecialize(a::DataType), @nospecialize(b::DataType), color::Symbol)
+    if a.name === b.name
+        Base.show_type_name(io, a.name)
+        n = length(a.parameters)
+        print(io, '{')
+        for i = 1:n
+            if i > length(b.parameters)
+                printstyled(io, a.parameters[i], color=color)
+            else
+                print_with_compare(io::IO, a.parameters[i], b.parameters[i], color)
+            end
+            i < n && print(io, ',')
+        end
+        print(io, '}')
+    else
+        printstyled(io, a; color=color)
+    end
+end
+
+function print_with_compare(io::IO, @nospecialize(a), @nospecialize(b), color::Symbol)
+    if a === b
+        print(io, a)
+    else
+        printstyled(io, a; color=color)
+    end
+end
+
+function show_convert_error(io::IO, ex::MethodError, @nospecialize(arg_types_param))
+    # See #13033
+    T = striptype(ex.args[1])
+    if T === nothing
+        print(io, "First argument to `convert` must be a Type, got ", ex.args[1])
+    else
+        print_one_line = isa(T, DataType) && isa(arg_types_param[2], DataType) && T.name != arg_types_param[2].name
+        printstyled(io, "Cannot `convert` an object of type ")
+        print_one_line || printstyled(io, "\n  ")
+        print_with_compare(io, arg_types_param[2], T, :light_green)
+        printstyled(io, " to an object of type ")
+        print_one_line || printstyled(io, "\n  ")
+        print_with_compare(io, T, arg_types_param[2], :light_red)
+    end
+end
+
 function showerror(io::IO, ex::MethodError)
     # ex.args is a tuple type if it was thrown from `invoke` and is
     # a tuple of the arguments otherwise.
@@ -181,7 +224,7 @@ function showerror(io::IO, ex::MethodErr
     name = ft.name.mt.name
     f_is_function = false
     kwargs = ()
-    if startswith(string(ft.name.name), "#kw#")
+    if endswith(string(ft.name.name), "##kw")
         f = ex.args[2]
         ft = typeof(f)
         name = ft.name.mt.name
@@ -191,13 +234,7 @@ function showerror(io::IO, ex::MethodErr
     end
     if f == Base.convert && length(arg_types_param) == 2 && !is_arg_types
         f_is_function = true
-        # See #13033
-        T = striptype(ex.args[1])
-        if T === nothing
-            print(io, "First argument to `convert` must be a Type, got ", ex.args[1])
-        else
-            print(io, "Cannot `convert` an object of type ", arg_types_param[2], " to an object of type ", T)
-        end
+        show_convert_error(io, ex, arg_types_param)
     elseif isempty(methods(f)) && isa(f, DataType) && f.abstract
         print(io, "no constructors have been defined for ", f)
     elseif isempty(methods(f)) && !isa(f, Function) && !isa(f, Type)
@@ -235,15 +272,14 @@ function showerror(io::IO, ex::MethodErr
     if f_is_function && isdefined(Base, name)
         basef = getfield(Base, name)
         if basef !== ex.f && hasmethod(basef, arg_types)
-            println(io)
-            print(io, "You may have intended to import Base.", name)
+            print(io, "\nYou may have intended to import ")
+            show_unquoted(io, Expr(:., :Base, QuoteNode(name)))
         end
     end
     if (ex.world != typemax(UInt) && hasmethod(ex.f, arg_types) &&
         !hasmethod(ex.f, arg_types, world = ex.world))
         curworld = get_world_counter()
-        println(io)
-        print(io, "The applicable method may be too new: running in world age $(ex.world), while current world is $(curworld).")
+        print(io, "\nThe applicable method may be too new: running in world age $(ex.world), while current world is $(curworld).")
     end
     if !is_arg_types
         # Check for row vectors used where a column vector is intended.
@@ -284,8 +320,14 @@ function showerror_ambiguous(io::IO, met
         sigfix = typeintersect(m.sig, sigfix)
     end
     if isa(unwrap_unionall(sigfix), DataType) && sigfix <: Tuple
-        print(io, "\nPossible fix, define\n  ")
-        Base.show_tuple_as_call(io, :function,  sigfix)
+        if all(m->morespecific(sigfix, m.sig), meth)
+            print(io, "\nPossible fix, define\n  ")
+            Base.show_tuple_as_call(io, :function,  sigfix)
+        else
+            println(io)
+            print(io, "To resolve the ambiguity, try making one of the methods more specific, or ")
+            print(io, "adding a new method more specific than any of the existing applicable methods.")
+        end
     end
     nothing
 end
@@ -417,11 +459,10 @@ function show_method_candidates(io::IO,
                         end
                     end
                 end
-                kwords = Symbol[]
-                if isdefined(ft.name.mt, :kwsorter)
-                    kwsorter_t = typeof(ft.name.mt.kwsorter)
-                    kwords = kwarg_decl(method, kwsorter_t)
-                    length(kwords) > 0 && print(iob, "; ", join(kwords, ", "))
+                kwords = kwarg_decl(method)
+                if !isempty(kwords)
+                    print(iob, "; ")
+                    join(iob, kwords, ", ")
                 end
                 print(iob, ")")
                 show_method_params(iob0, tv)
@@ -455,8 +496,7 @@ function show_method_candidates(io::IO,
 
     if !isempty(lines) # Display up to three closest candidates
         Base.with_output_color(:normal, io) do io
-            println(io)
-            print(io, "Closest candidates are:")
+            print(io, "\nClosest candidates are:")
             sort!(lines, by = x -> -x[2])
             i = 0
             for line in lines
@@ -524,7 +564,8 @@ function show_reduced_backtrace(io::IO,
             i = frame_counter
             j = p
             while i < length(t) && t[i] == t[j]
-                i+=1 ; j+=1
+                i += 1
+                j += 1
             end
             if j >= frame_counter-1
                 #= At least one cycle repeated =#
@@ -592,6 +633,7 @@ function show_backtrace(io::IO, t::Vecto
 end
 
 function show_backtrace(io::IO, t::Vector{Any})
+    # t is a pre-processed backtrace (ref #12856)
     if length(t) < BIG_STACKTRACE_SIZE
         try invokelatest(update_stackframes_callback[], t) catch end
         for entry in t
@@ -602,26 +644,39 @@ function show_backtrace(io::IO, t::Vecto
     end
 end
 
+function is_kw_sorter_name(name::Symbol)
+    sn = string(name)
+    return !startswith(sn, '#') && endswith(sn, "##kw")
+end
+
 function process_backtrace(t::Vector, limit::Int=typemax(Int); skipC = true)
     n = 0
     last_frame = StackTraces.UNKNOWN
     count = 0
     ret = Any[]
-    for i = eachindex(t)
-        lkups = StackTraces.lookup(t[i])
+    for i in eachindex(t)
+        lkups = t[i]
+        if lkups isa StackFrame
+            lkups = [lkups]
+        else
+            lkups = StackTraces.lookup(lkups)
+        end
         for lkup in lkups
             if lkup === StackTraces.UNKNOWN
                 continue
             end
 
-            if lkup.from_c && skipC; continue; end
-            if i == 1 && lkup.func === :error; continue; end
+            if (lkup.from_c && skipC) || is_kw_sorter_name(lkup.func)
+                continue
+            end
             count += 1
-            if count > limit; break; end
+            if count > limit
+                break
+            end
 
             if lkup.file != last_frame.file || lkup.line != last_frame.line || lkup.func != last_frame.func || lkup.linfo !== lkup.linfo
                 if n > 0
-                    push!(ret, (last_frame,n))
+                    push!(ret, (last_frame, n))
                 end
                 n = 1
                 last_frame = lkup
@@ -629,9 +684,10 @@ function process_backtrace(t::Vector, li
                 n += 1
             end
         end
+        count > limit && break
     end
     if n > 0
-        push!(ret, (last_frame,n))
+        push!(ret, (last_frame, n))
     end
     return ret
 end
@@ -650,3 +706,14 @@ function show_exception_stack(io::IO, st
         println(io)
     end
 end
+
+# Defined here rather than error.jl for bootstrap ordering
+function show(io::IO, ip::InterpreterIP)
+    print(io, typeof(ip))
+    if ip.code isa Core.CodeInfo
+        print(io, " in top-level CodeInfo for $(ip.mod) at statement $(Int(ip.stmt))")
+    else
+        print(io, " in $(ip.code) at statement $(Int(ip.stmt))")
+    end
+end
+
diff -pruN 1.3.1+dfsg-1/base/essentials.jl 1.4.0+dfsg-1/base/essentials.jl
--- 1.3.1+dfsg-1/base/essentials.jl	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/base/essentials.jl	2020-03-21 16:36:32.000000000 +0000
@@ -19,6 +19,7 @@ abstract type AbstractSet{T} end
 
 Supertype for dictionary-like types with keys of type `K` and values of type `V`.
 [`Dict`](@ref), [`IdDict`](@ref) and other types are subtypes of this.
+An `AbstractDict{K, V}` should be an iterator of `Pair{K, V}`.
 """
 abstract type AbstractDict{K,V} end
 
@@ -113,6 +114,8 @@ macro _propagate_inbounds_meta()
     return Expr(:meta, :inline, :propagate_inbounds)
 end
 
+function iterate end
+
 """
     convert(T, x)
 
@@ -407,7 +410,7 @@ julia> reinterpret(Float32, UInt32(7))
 
 julia> reinterpret(Float32, UInt32[1 2 3 4 5])
 1×5 reinterpret(Float32, ::Array{UInt32,2}):
- 1.4013e-45  2.8026e-45  4.2039e-45  5.60519e-45  7.00649e-45
+ 1.0f-45  3.0f-45  4.0f-45  6.0f-45  7.0f-45
 ```
 """
 reinterpret(::Type{T}, x) where {T} = bitcast(T, x)
diff -pruN 1.3.1+dfsg-1/base/exports.jl 1.4.0+dfsg-1/base/exports.jl
--- 1.3.1+dfsg-1/base/exports.jl	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/base/exports.jl	2020-03-21 16:36:32.000000000 +0000
@@ -196,6 +196,7 @@ export
 
 # scalar math
     @evalpoly,
+    evalpoly,
     abs,
     abs2,
     acos,
@@ -628,6 +629,7 @@ export
 
     enumerate,  # re-exported from Iterators
     zip,
+    only,
 
 # object identity and equality
     copy,
@@ -743,6 +745,7 @@ export
     nameof,
     parentmodule,
     pathof,
+    pkgdir,
     names,
     which,
     @isdefined,
diff -pruN 1.3.1+dfsg-1/base/expr.jl 1.4.0+dfsg-1/base/expr.jl
--- 1.3.1+dfsg-1/base/expr.jl	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/base/expr.jl	2020-03-21 16:36:32.000000000 +0000
@@ -67,8 +67,9 @@ function copy(c::CodeInfo)
     cnew.slotflags = copy(cnew.slotflags)
     cnew.codelocs  = copy(cnew.codelocs)
     cnew.linetable = copy(cnew.linetable)
-    cnew.ssaflags = copy(cnew.ssaflags)
-    ssavaluetypes = cnew.ssavaluetypes
+    cnew.ssaflags  = copy(cnew.ssaflags)
+    cnew.edges     = cnew.edges === nothing ? nothing : copy(cnew.edges)
+    ssavaluetypes  = cnew.ssavaluetypes
     ssavaluetypes isa Vector{Any} && (cnew.ssavaluetypes = copy(ssavaluetypes))
     return cnew
 end
@@ -196,7 +197,7 @@ end
 """
     @noinline
 
-Prevents the compiler from inlining a function.
+Give a hint to the compiler that it should not inline a function.
 
 Small functions are typically inlined automatically.
 By using `@noinline` on small functions, auto-inlining can be
@@ -208,6 +209,8 @@ prevented. This is shown in the followin
         Function Definition
     =#
 end
+
+If the function is trivial (for example returning a constant) it might get inlined anyway.
 ```
 """
 macro noinline(ex)
@@ -227,6 +230,7 @@ generic functions. Calls to generic func
 mutable global state.
 Use with caution, incorrect `@pure` annotation of a function may introduce
 hard to identify bugs. Double check for calls to generic functions.
+This macro is intended for internal compiler use and may be subject to changes.
 """
 macro pure(ex)
     esc(isa(ex, Expr) ? pushmeta!(ex, :pure) : ex)
@@ -241,10 +245,8 @@ macro propagate_inbounds(ex)
     if isa(ex, Expr)
         pushmeta!(ex, :inline)
         pushmeta!(ex, :propagate_inbounds)
-        esc(ex)
-    else
-        esc(ex)
     end
+    esc(ex)
 end
 
 """
diff -pruN 1.3.1+dfsg-1/base/fastmath.jl 1.4.0+dfsg-1/base/fastmath.jl
--- 1.3.1+dfsg-1/base/fastmath.jl	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/base/fastmath.jl	2020-03-21 16:36:32.000000000 +0000
@@ -24,7 +24,7 @@ module FastMath
 
 export @fastmath
 
-import Core.Intrinsics: sqrt_llvm, neg_float_fast,
+import Core.Intrinsics: sqrt_llvm_fast, neg_float_fast,
     add_float_fast, sub_float_fast, mul_float_fast, div_float_fast, rem_float_fast,
     eq_float_fast, ne_float_fast, lt_float_fast, le_float_fast
 
@@ -277,7 +277,7 @@ pow_fast(x::Float64, y::Integer) = ccall
 pow_fast(x::FloatTypes, ::Val{p}) where {p} = pow_fast(x, p) # inlines already via llvm.powi
 @inline pow_fast(x, v::Val) = Base.literal_pow(^, x, v)
 
-sqrt_fast(x::FloatTypes) = sqrt_llvm(x)
+sqrt_fast(x::FloatTypes) = sqrt_llvm_fast(x)
 
 # libm
 
diff -pruN 1.3.1+dfsg-1/base/file.jl 1.4.0+dfsg-1/base/file.jl
--- 1.3.1+dfsg-1/base/file.jl	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/base/file.jl	2020-03-21 16:36:32.000000000 +0000
@@ -167,13 +167,20 @@ julia> pwd()
 ```
 """
 function mkdir(path::AbstractString; mode::Integer = 0o777)
-    @static if Sys.iswindows()
-        ret = ccall(:_wmkdir, Int32, (Cwstring,), path)
-    else
-        ret = ccall(:mkdir, Int32, (Cstring, UInt32), path, checkmode(mode))
+    req = Libc.malloc(_sizeof_uv_fs)
+    try
+        ret = ccall(:uv_fs_mkdir, Cint,
+                    (Ptr{Cvoid}, Ptr{Cvoid}, Cstring, Cint, Ptr{Cvoid}),
+                    C_NULL, req, path, checkmode(mode), C_NULL)
+        if ret < 0
+            ccall(:uv_fs_req_cleanup, Cvoid, (Ptr{Cvoid},), req)
+            uv_error("mkdir", ret)
+        end
+        ccall(:uv_fs_req_cleanup, Cvoid, (Ptr{Cvoid},), req)
+        return path
+    finally
+        Libc.free(req)
     end
-    systemerror(:mkdir, ret != 0; extrainfo=path)
-    path
 end
 
 """
@@ -391,6 +398,9 @@ end
     touch(path::AbstractString)
 
 Update the last-modified timestamp on a file to the current time.
+
+If the file does not exist a new file is created.
+
 Return `path`.
 
 # Examples
@@ -455,7 +465,10 @@ const TEMP_CLEANUP_LOCK = ReentrantLock(
 
 function temp_cleanup_later(path::AbstractString; asap::Bool=false)
     lock(TEMP_CLEANUP_LOCK)
-    TEMP_CLEANUP[path] = asap
+    # each path should only be inserted here once, but if there
+    # is a collision, let !asap win over asap: if any user might
+    # still be using the path, don't delete it until process exit
+    TEMP_CLEANUP[path] = get(TEMP_CLEANUP, path, true) & asap
     if length(TEMP_CLEANUP) > TEMP_CLEANUP_MAX[]
         temp_cleanup_purge(false)
         TEMP_CLEANUP_MAX[] = max(TEMP_CLEANUP_MIN[], 2*length(TEMP_CLEANUP))
@@ -467,12 +480,16 @@ end
 function temp_cleanup_purge(all::Bool=true)
     need_gc = Sys.iswindows()
     for (path, asap) in TEMP_CLEANUP
-        if (all || asap) && ispath(path)
-            need_gc && GC.gc(true)
-            need_gc = false
-            rm(path, recursive=true, force=true)
+        try
+            if (all || asap) && ispath(path)
+                need_gc && GC.gc(true)
+                need_gc = false
+                rm(path, recursive=true, force=true)
+            end
+            !ispath(path) && delete!(TEMP_CLEANUP, path)
+        catch ex
+            @warn "temp cleanup" _group=:file exception=(ex, catch_backtrace())
         end
-        !ispath(path) && delete!(TEMP_CLEANUP, path)
     end
 end
 
@@ -500,29 +517,41 @@ function mktemp(parent::AbstractString=t
     return (filename, Base.open(filename, "r+"))
 end
 
-function tempname()
-    parent = tempdir()
-    seed::UInt32 = rand(UInt32)
-    while true
-        if (seed & typemax(UInt16)) == 0
-            seed += 1
-        end
-        filename = _win_tempname(parent, seed)
-        if !ispath(filename)
-            return filename
-        end
-        seed += 1
-    end
+# generate a random string from random bytes
+function _rand_string()
+    nchars = 10
+    A = Vector{UInt8}(undef, nchars)
+    windowserror("SystemFunction036 (RtlGenRandom)", 0 == ccall(
+        (:SystemFunction036, :Advapi32), stdcall, UInt8, (Ptr{Cvoid}, UInt32),
+            A, sizeof(A)))
+
+    slug = Base.StringVector(10)
+    chars = "0123456789abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ"
+    for i = 1:nchars
+        slug[i] = chars[(A[i] % length(chars)) + 1]
+    end
+    return name = String(slug)
+end
+
+function tempname(parent::AbstractString=tempdir(); cleanup::Bool=true)
+    isdir(parent) || throw(ArgumentError("$(repr(parent)) is not a directory"))
+    name = _rand_string()
+    filename = joinpath(parent, temp_prefix * name)
+    @assert !ispath(filename)
+    cleanup && temp_cleanup_later(filename)
+    return filename
 end
 
 else # !windows
+
 # Obtain a temporary filename.
-function tempname()
-    d = tempdir() # tempnam ignores TMPDIR on darwin
-    p = ccall(:tempnam, Cstring, (Cstring, Cstring), d, temp_prefix)
+function tempname(parent::AbstractString=tempdir(); cleanup::Bool=true)
+    isdir(parent) || throw(ArgumentError("$(repr(parent)) is not a directory"))
+    p = ccall(:tempnam, Cstring, (Cstring, Cstring), parent, temp_prefix)
     systemerror(:tempnam, p == C_NULL)
     s = unsafe_string(p)
     Libc.free(p)
+    cleanup && temp_cleanup_later(s)
     return s
 end
 
@@ -540,16 +569,35 @@ end # os-test
 
 
 """
-    tempname()
+    tempname(parent=tempdir(); cleanup=true) -> String
 
 Generate a temporary file path. This function only returns a path; no file is
-created. The path is likely to be unique, but this cannot be guaranteed.
+created. The path is likely to be unique, but this cannot be guaranteed due to
+the very remote posibility of two simultaneous calls to `tempname` generating
+the same file name. The name is guaranteed to differ from all files already
+existing at the time of the call to `tempname`.
+
+When called with no arguments, the temporary name will be an absolute path to a
+temporary name in the system temporary directory as given by `tempdir()`. If a
+`parent` directory argument is given, the temporary path will be in that
+directory instead.
+
+The `cleanup` option controls whether the process attempts to delete the
+returned path automatically when the process exits. Note that the `tempname`
+function does not create any file or directory at the returned location, so
+there is nothing to cleanup unless you create a file or directory there. If
+you do and `clean` is `true` it will be deleted upon process termination.
+
+!!! compat "Julia 1.4"
+    The `parent` and `cleanup` arguments were added in 1.4. Prior to Julia 1.4
+    the path `tempname` would never be cleaned up at process termination.
 
 !!! warning
 
     This can lead to security holes if another process obtains the same
     file name and creates the file before you are able to. Open the file with
-    `JL_O_EXCL` if this is a concern. Using [`mktemp()`](@ref) is also recommended instead.
+    `JL_O_EXCL` if this is a concern. Using [`mktemp()`](@ref) is also
+    recommended instead.
 """
 tempname()
 
@@ -612,7 +660,7 @@ function mktemp(fn::Function, parent::Ab
     finally
         try
             close(tmp_io)
-            rm(tmp_path)
+            ispath(tmp_path) && rm(tmp_path)
         catch ex
             @error "mktemp cleanup" _group=:file exception=(ex, catch_backtrace())
             # might be possible to remove later
@@ -634,7 +682,7 @@ function mktempdir(fn::Function, parent:
         fn(tmpdir)
     finally
         try
-            rm(tmpdir, recursive=true)
+            ispath(tmpdir) && rm(tmpdir, recursive=true)
         catch ex
             @error "mktempdir cleanup" _group=:file exception=(ex, catch_backtrace())
             # might be possible to remove later
@@ -649,50 +697,106 @@ struct uv_dirent_t
 end
 
 """
-    readdir(dir::AbstractString=".") -> Vector{String}
+    readdir(dir::AbstractString=pwd();
+        join::Bool = false,
+        sort::Bool = true,
+    ) -> Vector{String}
+
+Return the names in the directory `dir` or the current working directory if not
+given. When `join` is false, `readdir` returns just the names in the directory
+as is; when `join` is true, it returns `joinpath(dir, name)` for each `name` so
+that the returned strings are full paths. If you want to get absolute paths
+back, call `readdir` with an absolute directory path and `join` set to true.
+
+By default, `readdir` sorts the list of names it returns. If you want to skip
+sorting the names and get them in the order that the file system lists them,
+you can use `readir(dir, sort=false)` to opt out of sorting.
 
-Return the files and directories in the directory `dir` (or the current working directory if not given).
+!!! compat "Julia 1.4"
+    The `join` and `sort` keyword arguments require at least Julia 1.4.
 
 # Examples
 ```julia-repl
-julia> readdir("/home/JuliaUser/Projects/julia")
-34-element Array{String,1}:
- ".circleci"
- ".freebsdci.sh"
+julia> cd("/home/JuliaUser/dev/julia")
+
+julia> readdir()
+30-element Array{String,1}:
+ ".appveyor.yml"
  ".git"
  ".gitattributes"
- ".github"
  ⋮
- "test"
  "ui"
  "usr"
  "usr-staging"
+
+julia> readdir(join=true)
+30-element Array{String,1}:
+ "/home/JuliaUser/dev/julia/.appveyor.yml"
+ "/home/JuliaUser/dev/julia/.git"
+ "/home/JuliaUser/dev/julia/.gitattributes"
+ ⋮
+ "/home/JuliaUser/dev/julia/ui"
+ "/home/JuliaUser/dev/julia/usr"
+ "/home/JuliaUser/dev/julia/usr-staging"
+
+julia> readdir("base")
+145-element Array{String,1}:
+ ".gitignore"
+ "Base.jl"
+ "Enums.jl"
+ ⋮
+ "version_git.sh"
+ "views.jl"
+ "weakkeydict.jl"
+
+julia> readdir("base", join=true)
+145-element Array{String,1}:
+ "base/.gitignore"
+ "base/Base.jl"
+ "base/Enums.jl"
+ ⋮
+ "base/version_git.sh"
+ "base/views.jl"
+ "base/weakkeydict.jl"```
+
+julia> readdir(abspath("base"), join=true)
+145-element Array{String,1}:
+ "/home/JuliaUser/dev/julia/base/.gitignore"
+ "/home/JuliaUser/dev/julia/base/Base.jl"
+ "/home/JuliaUser/dev/julia/base/Enums.jl"
+ ⋮
+ "/home/JuliaUser/dev/julia/base/version_git.sh"
+ "/home/JuliaUser/dev/julia/base/views.jl"
+ "/home/JuliaUser/dev/julia/base/weakkeydict.jl"
 ```
 """
-function readdir(path::AbstractString)
+function readdir(dir::AbstractString; join::Bool=false, sort::Bool=true)
     # Allocate space for uv_fs_t struct
     uv_readdir_req = zeros(UInt8, ccall(:jl_sizeof_uv_fs_t, Int32, ()))
 
     # defined in sys.c, to call uv_fs_readdir, which sets errno on error.
     err = ccall(:uv_fs_scandir, Int32, (Ptr{Cvoid}, Ptr{UInt8}, Cstring, Cint, Ptr{Cvoid}),
-                C_NULL, uv_readdir_req, path, 0, C_NULL)
-    err < 0 && throw(SystemError("unable to read directory $path", -err))
-    #uv_error("unable to read directory $path", err)
+                C_NULL, uv_readdir_req, dir, 0, C_NULL)
+    err < 0 && throw(SystemError("unable to read directory $dir", -err))
 
     # iterate the listing into entries
     entries = String[]
     ent = Ref{uv_dirent_t}()
     while Base.UV_EOF != ccall(:uv_fs_scandir_next, Cint, (Ptr{Cvoid}, Ptr{uv_dirent_t}), uv_readdir_req, ent)
-        push!(entries, unsafe_string(ent[].name))
+        name = unsafe_string(ent[].name)
+        push!(entries, join ? joinpath(dir, name) : name)
     end
 
     # Clean up the request string
     ccall(:uv_fs_req_cleanup, Cvoid, (Ptr{UInt8},), uv_readdir_req)
 
+    # sort entries unless opted out
+    sort && sort!(entries)
+
     return entries
 end
-
-readdir() = readdir(".")
+readdir(; join::Bool=false, sort::Bool=true) =
+    readdir(join ? pwd() : ".", join=join, sort=sort)
 
 """
     walkdir(dir; topdown=true, follow_symlinks=false, onerror=throw)
diff -pruN 1.3.1+dfsg-1/base/float.jl 1.4.0+dfsg-1/base/float.jl
--- 1.3.1+dfsg-1/base/float.jl	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/base/float.jl	2020-03-21 16:36:32.000000000 +0000
@@ -530,7 +530,8 @@ abs(x::Float64) = abs_float(x)
 """
     isnan(f) -> Bool
 
-Test whether a floating point number is not a number (NaN).
+Test whether a number value is a NaN, an indeterminate value which is neither an infinity
+nor a finite number ("not a number").
 """
 isnan(x::AbstractFloat) = x != x
 isnan(x::Float16) = reinterpret(UInt16,x)&0x7fff > 0x7c00
@@ -876,6 +877,11 @@ significand_mask(::Type{Float16}) = 0x03
 for T in (Float16, Float32, Float64)
     @eval significand_bits(::Type{$T}) = $(trailing_ones(significand_mask(T)))
     @eval exponent_bits(::Type{$T}) = $(sizeof(T)*8 - significand_bits(T) - 1)
+    @eval exponent_bias(::Type{$T}) = $(Int(exponent_one(T) >> significand_bits(T)))
+    # maximum float exponent
+    @eval exponent_max(::Type{$T}) = $(Int(exponent_mask(T) >> significand_bits(T)) - exponent_bias(T))
+    # maximum float exponent without bias
+    @eval exponent_raw_max(::Type{$T}) = $(Int(exponent_mask(T) >> significand_bits(T)))
 end
 
 # integer size of float
diff -pruN 1.3.1+dfsg-1/base/gcutils.jl 1.4.0+dfsg-1/base/gcutils.jl
--- 1.3.1+dfsg-1/base/gcutils.jl	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/base/gcutils.jl	2020-03-21 16:36:32.000000000 +0000
@@ -12,7 +12,7 @@ Register a function `f(x)` to be called
 this function is unpredictable.
 
 `f` must not cause a task switch, which excludes most I/O operations such as `println`.
-`@schedule println("message")` or `ccall(:jl_, Void, (Any,), "message")` may be helpful for
+`@schedule println("message")` or `ccall(:jl_, Cvoid, (Any,), "message")` may be helpful for
 debugging purposes.
 """
 function finalizer(@nospecialize(f), @nospecialize(o))
@@ -49,15 +49,24 @@ Module with garbage collection utilities
 """
 module GC
 
-"""
-    GC.gc()
+# mirrored from julia.h
+const GC_AUTO = 0
+const GC_FULL = 1
+const GC_INCREMENTAL = 2
 
-Perform garbage collection.
+"""
+    GC.gc([full=true])
+
+Perform garbage collection. The argument `full` determines the kind of
+collection: A full collection (default) sweeps all objects, which makes the
+next GC scan much slower, while an incremental collection may only sweep
+so-called young objects.
 
 !!! warning
     Excessive use will likely lead to poor performance.
 """
-gc(full::Bool=true) = ccall(:jl_gc_collect, Cvoid, (Int32,), full)
+gc(full::Bool=true) =
+    ccall(:jl_gc_collect, Cvoid, (Cint,), full ? GC_FULL : GC_INCREMENTAL)
 
 """
     GC.enable(on::Bool)
@@ -85,13 +94,22 @@ macro preserve(args...)
     for x in syms
         isa(x, Symbol) || error("Preserved variable must be a symbol")
     end
-    s, r = gensym(), gensym()
-    esc(quote
-        $s = $(Expr(:gc_preserve_begin, syms...))
-        $r = $(args[end])
-        $(Expr(:gc_preserve_end, s))
-        $r
-    end)
+    esc(Expr(:gc_preserve, args[end], syms...))
 end
 
+"""
+    GC.safepoint()
+
+Inserts a point in the program where garbage collection may run.
+This can be useful in rare cases in multi-threaded programs where some threads
+are allocating memory (and hence may need to run GC) but other threads are doing
+only simple operations (no allocation, task switches, or I/O).
+Calling this function periodically in non-allocating threads allows garbage
+collection to run.
+
+!!! compat "Julia 1.4"
+    This function is available as of Julia 1.4.
+"""
+safepoint() = ccall(:jl_gc_safepoint, Cvoid, ())
+
 end # module GC
diff -pruN 1.3.1+dfsg-1/base/gmp.jl 1.4.0+dfsg-1/base/gmp.jl
--- 1.3.1+dfsg-1/base/gmp.jl	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/base/gmp.jl	2020-03-21 16:36:32.000000000 +0000
@@ -5,7 +5,7 @@ module GMP
 export BigInt
 
 import .Base: *, +, -, /, <, <<, >>, >>>, <=, ==, >, >=, ^, (~), (&), (|), xor,
-             binomial, cmp, convert, div, divrem, factorial, fld, gcd, gcdx, lcm, mod,
+             binomial, cmp, convert, div, divrem, factorial, cld, fld, gcd, gcdx, lcm, mod,
              ndigits, promote_rule, rem, show, isqrt, string, powermod,
              sum, trailing_zeros, trailing_ones, count_ones, tryparse_internal,
              bin, oct, dec, hex, isequal, invmod, _prevpow2, _nextpow2, ndigits0zpb,
@@ -146,7 +146,8 @@ sizeinbase(a::BigInt, b) = Int(ccall((:_
 
 for (op, nbits) in (:add => :(BITS_PER_LIMB*(1 + max(abs(a.size), abs(b.size)))),
                     :sub => :(BITS_PER_LIMB*(1 + max(abs(a.size), abs(b.size)))),
-                    :mul => 0, :fdiv_q => 0, :tdiv_q => 0, :fdiv_r => 0, :tdiv_r => 0,
+                    :mul => 0, :fdiv_q => 0, :tdiv_q => 0, :cdiv_q => 0,
+                    :fdiv_r => 0, :tdiv_r => 0, :cdiv_r => 0,
                     :gcd => 0, :lcm => 0, :and => 0, :ior => 0, :xor => 0)
     op! = Symbol(op, :!)
     @eval begin
@@ -465,7 +466,7 @@ big(n::Integer) = convert(BigInt, n)
 
 # Binary ops
 for (fJ, fC) in ((:+, :add), (:-,:sub), (:*, :mul),
-                 (:fld, :fdiv_q), (:div, :tdiv_q), (:mod, :fdiv_r), (:rem, :tdiv_r),
+                 (:mod, :fdiv_r), (:rem, :tdiv_r),
                  (:gcd, :gcd), (:lcm, :lcm),
                  (:&, :and), (:|, :ior), (:xor, :xor))
     @eval begin
@@ -473,6 +474,17 @@ for (fJ, fC) in ((:+, :add), (:-,:sub),
     end
 end
 
+for (r, f) in ((RoundToZero, :tdiv_q),
+               (RoundDown, :fdiv_q),
+               (RoundUp, :cdiv_q))
+    @eval div(x::BigInt, y::BigInt, ::typeof($r)) = MPZ.$f(x, y)
+end
+
+# For compat only. Remove in 2.0.
+div(x::BigInt, y::BigInt) = div(x, y, RoundToZero)
+fld(x::BigInt, y::BigInt) = div(x, y, RoundDown)
+cld(x::BigInt, y::BigInt) = div(x, y, RoundUp)
+
 /(x::BigInt, y::BigInt) = float(x)/float(y)
 
 function invmod(x::BigInt, y::BigInt)
diff -pruN 1.3.1+dfsg-1/base/grisu/grisu.jl 1.4.0+dfsg-1/base/grisu/grisu.jl
--- 1.3.1+dfsg-1/base/grisu/grisu.jl	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/base/grisu/grisu.jl	2020-03-21 16:36:32.000000000 +0000
@@ -154,31 +154,6 @@ function _show(io::IO, x::AbstractFloat,
     nothing
 end
 
-function Base.show(io::IO, x::Union{Float64,Float32})
-    if get(io, :compact, false)
-        _show(io, x, PRECISION, 6, x isa Float64, true)
-    else
-        _show(io, x, SHORTEST, 0, get(io, :typeinfo, Any) !== typeof(x), false)
-    end
-end
-
-function Base.show(io::IO, x::Float16)
-    hastypeinfo = Float16 === get(io, :typeinfo, Any)
-    # if hastypeinfo, the printing would be more compact using `SHORTEST`
-    # while still retaining all the information
-    # BUT: we want to print all digits in `show`, not in display, so we rely
-    # on the :compact property to make the decision
-    # (cf. https://github.com/JuliaLang/julia/pull/24651#issuecomment-345535687)
-    if get(io, :compact, false) && !hastypeinfo
-        _show(io, x, PRECISION, 5, false, true)
-    else
-        _show(io, x, SHORTEST, 0, !hastypeinfo, false)
-    end
-end
-
-Base.print(io::IO, x::Float32) = _show(io, x, SHORTEST, 0, false, false)
-Base.print(io::IO, x::Float16) = _show(io, x, SHORTEST, 0, false, false)
-
 # normal:
 #   0 < pt < len        ####.####           len+1
 #   pt <= 0             0.000########       len-pt+1
diff -pruN 1.3.1+dfsg-1/base/indices.jl 1.4.0+dfsg-1/base/indices.jl
--- 1.3.1+dfsg-1/base/indices.jl	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/base/indices.jl	2020-03-21 16:36:32.000000000 +0000
@@ -19,25 +19,49 @@ abstract type IndexStyle end
 Subtype of [`IndexStyle`](@ref) used to describe arrays which
 are optimally indexed by one linear index.
 
-A linear indexing style uses one integer to describe the position in the array
+A linear indexing style uses one integer index to describe the position in the array
 (even if it's a multidimensional array) and column-major
-ordering is used to access the elements. For example,
-if `A` were a `(2, 3)` custom matrix type with linear indexing,
-and we referenced `A[5]` (using linear style), this would
-be equivalent to referencing `A[1, 3]` (since `2*1 + 3 = 5`).
+ordering is used to efficiently access the elements. This means that
+requesting [`eachindex`](@ref) from an array that is `IndexLinear` will return
+a simple one-dimensional range, even if it is multidimensional.
+
+A custom array that reports its `IndexStyle` as `IndexLinear` only needs
+to implement indexing (and indexed assignment) with a single `Int` index;
+all other indexing expressions — including multidimensional accesses — will
+be recomputed to the linear index.  For example, if `A` were a `2×3` custom
+matrix with linear indexing, and we referenced `A[1, 3]`, this would be
+recomputed to the equivalent linear index and call `A[5]` since `2*1 + 3 = 5`.
+
 See also [`IndexCartesian`](@ref).
 """
 struct IndexLinear <: IndexStyle end
+
 """
     IndexCartesian()
 
 Subtype of [`IndexStyle`](@ref) used to describe arrays which
-are optimally indexed by a Cartesian index.
+are optimally indexed by a Cartesian index. This is the default
+for new custom [`AbstractArray`](@ref) subtypes.
+
+A Cartesian indexing style uses multiple integer indices to describe the position in
+a multidimensional array, with exactly one index per dimension. This means that
+requesting [`eachindex`](@ref) from an array that is `IndexCartesian` will return
+a range of [`CartesianIndices`](@ref).
+
+A `N`-dimensional custom array that reports its `IndexStyle` as `IndexCartesian` needs
+to implement indexing (and indexed assignment) with exactly `N` `Int` indices;
+all other indexing expressions — including linear indexing — will
+be recomputed to the equivalent Cartesian location.  For example, if `A` were a `2×3` custom
+matrix with cartesian indexing, and we referenced `A[5]`, this would be
+recomputed to the equivalent Cartesian index and call `A[1, 3]` since `5 = 2*1 + 3`.
+
+It is significantly more expensive to compute Cartesian indices from a linear index than it is
+to go the other way.  The former operation requires division — a very costly operation — whereas
+the latter only uses multiplication and addition and is essentially free. This asymmetry means it
+is far more costly to use linear indexing with an `IndexCartesian` array than it is to use
+Cartesian indexing with an `IndexLinear` array.
 
-A cartesian indexing style uses multiple integers/indices to describe the position in the array.
-For example, if `A` were a `(2, 3, 4)` custom matrix type with cartesian indexing,
-we could reference `A[2, 1, 3]` and Julia would automatically convert this into the
-correct location in the underlying memory. See also [`IndexLinear`](@ref).
+See also [`IndexLinear`](@ref).
 """
 struct IndexCartesian <: IndexStyle end
 
@@ -48,7 +72,7 @@ struct IndexCartesian <: IndexStyle end
 `IndexStyle` specifies the "native indexing style" for array `A`. When
 you define a new [`AbstractArray`](@ref) type, you can choose to implement
 either linear indexing (with [`IndexLinear`](@ref)) or cartesian indexing.
-If you decide to implement linear indexing, then you must set this trait for your array
+If you decide to only implement linear indexing, then you must set this trait for your array
 type:
 
     Base.IndexStyle(::Type{<:MyArray}) = IndexLinear()
@@ -56,7 +80,7 @@ type:
 The default is [`IndexCartesian()`](@ref).
 
 Julia's internal indexing machinery will automatically (and invisibly)
-convert all indexing operations into the preferred style. This allows users
+recompute all indexing operations into the preferred style. This allows users
 to access elements of your array using any indexing style, even when explicit
 methods have not been provided.
 
@@ -84,14 +108,14 @@ promote_shape(::Tuple{}, ::Tuple{}) = ()
 
 function promote_shape(a::Tuple{Int,}, b::Tuple{Int,})
     if a[1] != b[1]
-        throw(DimensionMismatch("dimensions must match"))
+        throw(DimensionMismatch("dimensions must match: a has dims $a, b has dims $b"))
     end
     return a
 end
 
 function promote_shape(a::Tuple{Int,Int}, b::Tuple{Int,})
     if a[1] != b[1] || a[2] != 1
-        throw(DimensionMismatch("dimensions must match"))
+        throw(DimensionMismatch("dimensions must match: a has dims $a, b has dims $b"))
     end
     return a
 end
@@ -100,7 +124,7 @@ promote_shape(a::Tuple{Int,}, b::Tuple{I
 
 function promote_shape(a::Tuple{Int, Int}, b::Tuple{Int, Int})
     if a[1] != b[1] || a[2] != b[2]
-        throw(DimensionMismatch("dimensions must match"))
+        throw(DimensionMismatch("dimensions must match: a has dims $a, b has dims $b"))
     end
     return a
 end
@@ -130,12 +154,12 @@ function promote_shape(a::Dims, b::Dims)
     end
     for i=1:length(b)
         if a[i] != b[i]
-            throw(DimensionMismatch("dimensions must match"))
+            throw(DimensionMismatch("dimensions must match: a has dims $a, b has dims $b, mismatch at $i"))
         end
     end
     for i=length(b)+1:length(a)
         if a[i] != 1
-            throw(DimensionMismatch("dimensions must match"))
+            throw(DimensionMismatch("dimensions must match: a has dims $a, must have singleton at dim $i"))
         end
     end
     return a
@@ -151,12 +175,12 @@ function promote_shape(a::Indices, b::In
     end
     for i=1:length(b)
         if a[i] != b[i]
-            throw(DimensionMismatch("dimensions must match"))
+            throw(DimensionMismatch("dimensions must match: a has dims $a, b has dims $b, mismatch at $i"))
         end
     end
     for i=length(b)+1:length(a)
         if a[i] != 1:1
-            throw(DimensionMismatch("dimensions must match"))
+            throw(DimensionMismatch("dimensions must match: a has dims $a, must have singleton at dim $i"))
         end
     end
     return a
diff -pruN 1.3.1+dfsg-1/base/initdefs.jl 1.4.0+dfsg-1/base/initdefs.jl
--- 1.3.1+dfsg-1/base/initdefs.jl	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/base/initdefs.jl	2020-03-21 16:36:32.000000000 +0000
@@ -300,15 +300,23 @@ const atexit_hooks = Callable[Filesystem
 
 Register a zero-argument function `f()` to be called at process exit. `atexit()` hooks are
 called in last in first out (LIFO) order and run before object finalizers.
+
+Exit hooks are allowed to call `exit(n)`, in which case Julia will exit with
+exit code `n` (instead of the original exit code). If more than one exit hook
+calls `exit(n)`, then Julia will exit with the exit code corresponding to the
+last called exit hook that calls `exit(n)`. (Because exit hooks are called in
+LIFO order, "last called" is equivalent to "first registered".)
 """
 atexit(f::Function) = (pushfirst!(atexit_hooks, f); nothing)
 
 function _atexit()
-    for f in atexit_hooks
+    while !isempty(atexit_hooks)
+        f = popfirst!(atexit_hooks)
         try
             f()
-        catch err
-            show(stderr, err)
+        catch ex
+            showerror(stderr, ex)
+            Base.show_backtrace(stderr, catch_backtrace())
             println(stderr)
         end
     end
diff -pruN 1.3.1+dfsg-1/base/intfuncs.jl 1.4.0+dfsg-1/base/intfuncs.jl
--- 1.3.1+dfsg-1/base/intfuncs.jl	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/base/intfuncs.jl	2020-03-21 16:36:32.000000000 +0000
@@ -6,6 +6,10 @@
     gcd(x,y)
 
 Greatest common (positive) divisor (or zero if `x` and `y` are both zero).
+The arguments may be integer and rational numbers.
+
+!!! compat "Julia 1.4"
+    Rational arguments require Julia 1.4 or later.
 
 # Examples
 ```jldoctest
@@ -53,6 +57,10 @@ end
     lcm(x,y)
 
 Least common (non-negative) multiple.
+The arguments may be integer and rational numbers.
+
+!!! compat "Julia 1.4"
+    Rational arguments require Julia 1.4 or later.
 
 # Examples
 ```jldoctest
@@ -72,14 +80,17 @@ function lcm(a::T, b::T) where T<:Intege
     end
 end
 
-gcd(a::Integer) = a
-lcm(a::Integer) = a
-gcd(a::Integer, b::Integer) = gcd(promote(a,b)...)
-lcm(a::Integer, b::Integer) = lcm(promote(a,b)...)
-gcd(a::Integer, b::Integer...) = gcd(a, gcd(b...))
-lcm(a::Integer, b::Integer...) = lcm(a, lcm(b...))
+gcd(a::Union{Integer,Rational}) = a
+lcm(a::Union{Integer,Rational}) = a
+gcd(a::Real, b::Real) = gcd(promote(a,b)...)
+lcm(a::Real, b::Real) = lcm(promote(a,b)...)
+gcd(a::Real, b::Real, c::Real...) = gcd(a, gcd(b, c...))
+lcm(a::Real, b::Real, c::Real...) = lcm(a, lcm(b, c...))
+gcd(a::T, b::T) where T<:Real = throw(MethodError(gcd, (a,b)))
+lcm(a::T, b::T) where T<:Real = throw(MethodError(lcm, (a,b)))
 
-lcm(abc::AbstractArray{<:Integer}) = reduce(lcm, abc; init=one(eltype(abc)))
+gcd(abc::AbstractArray{<:Real}) = reduce(gcd, abc; init=zero(eltype(abc)))
+lcm(abc::AbstractArray{<:Real}) = reduce(lcm, abc; init=one(eltype(abc)))
 
 function gcd(abc::AbstractArray{<:Integer})
     a = zero(eltype(abc))
@@ -100,6 +111,11 @@ Computes the greatest common (positive)
 coefficients, i.e. the integer coefficients `u` and `v` that satisfy
 ``ux+vy = d = gcd(x,y)``. ``gcdx(x,y)`` returns ``(d,u,v)``.
 
+The arguments may be integer and rational numbers.
+
+!!! compat "Julia 1.4"
+    Rational arguments require Julia 1.4 or later.
+
 # Examples
 ```jldoctest
 julia> gcdx(12, 42)
@@ -133,7 +149,8 @@ function gcdx(a::T, b::T) where T<:Integ
     end
     a < 0 ? (-a, -s0, -t0) : (a, s0, t0)
 end
-gcdx(a::Integer, b::Integer) = gcdx(promote(a,b)...)
+gcdx(a::Real, b::Real) = gcdx(promote(a,b)...)
+gcdx(a::T, b::T) where T<:Real = throw(MethodError(gcdx, (a,b)))
 
 # multiplicative inverse of n mod m, error if none
 
diff -pruN 1.3.1+dfsg-1/base/int.jl 1.4.0+dfsg-1/base/int.jl
--- 1.3.1+dfsg-1/base/int.jl	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/base/int.jl	2020-03-21 16:36:32.000000000 +0000
@@ -137,9 +137,6 @@ abs(x::Signed) = flipsign(x,x)
 
 ~(n::Integer) = -n-1
 
-unsigned(x::BitSigned) = reinterpret(typeof(convert(Unsigned, zero(x))), x)
-unsigned(x::Bool) = convert(Unsigned, x)
-
 """
     unsigned(x) -> Unsigned
 
@@ -158,8 +155,8 @@ julia> signed(unsigned(-2))
 -2
 ```
 """
-unsigned(x) = convert(Unsigned, x)
-signed(x::Unsigned) = reinterpret(typeof(convert(Signed, zero(x))), x)
+unsigned(x) = x % typeof(convert(Unsigned, zero(x)))
+unsigned(x::BitSigned) = reinterpret(typeof(convert(Unsigned, zero(x))), x)
 
 """
     signed(x)
@@ -167,7 +164,8 @@ signed(x::Unsigned) = reinterpret(typeof
 Convert a number to a signed integer. If the argument is unsigned, it is reinterpreted as
 signed without checking for overflow.
 """
-signed(x) = convert(Signed, x)
+signed(x) = x % typeof(convert(Signed, zero(x)))
+signed(x::BitUnsigned) = reinterpret(typeof(convert(Signed, zero(x))), x)
 
 div(x::BitSigned, y::Unsigned) = flipsign(signed(div(unsigned(abs(x)), y)), x)
 div(x::Unsigned, y::BitSigned) = unsigned(flipsign(signed(div(x, unsigned(abs(y)))), y))
@@ -175,8 +173,15 @@ div(x::Unsigned, y::BitSigned) = unsigne
 rem(x::BitSigned, y::Unsigned) = flipsign(signed(rem(unsigned(abs(x)), y)), x)
 rem(x::Unsigned, y::BitSigned) = rem(x, unsigned(abs(y)))
 
-fld(x::Signed, y::Unsigned) = div(x, y) - (signbit(x) & (rem(x, y) != 0))
-fld(x::Unsigned, y::Signed) = div(x, y) - (signbit(y) & (rem(x, y) != 0))
+function divrem(x::BitSigned, y::Unsigned)
+    q, r = divrem(unsigned(abs(x)), y)
+    flipsign(signed(q), x), flipsign(signed(r), x)
+end
+
+function divrem(x::Unsigned, y::BitSigned)
+    q, r = divrem(x, unsigned(abs(y)))
+    unsigned(flipsign(signed(q), y)), r
+end
 
 
 """
@@ -220,9 +225,6 @@ mod(x::BitSigned, y::Unsigned) = rem(y +
 mod(x::Unsigned, y::Signed) = rem(y + signed(rem(x, y)), y)
 mod(x::T, y::T) where {T<:Unsigned} = rem(x, y)
 
-cld(x::Signed, y::Unsigned) = div(x, y) + (!signbit(x) & (rem(x, y) != 0))
-cld(x::Unsigned, y::Signed) = div(x, y) + (!signbit(y) & (rem(x, y) != 0))
-
 # Don't promote integers for div/rem/mod since there is no danger of overflow,
 # while there is a substantial performance penalty to 64-bit promotion.
 div(x::T, y::T) where {T<:BitSigned64} = checked_sdiv_int(x, y)
@@ -230,24 +232,6 @@ rem(x::T, y::T) where {T<:BitSigned64} =
 div(x::T, y::T) where {T<:BitUnsigned64} = checked_udiv_int(x, y)
 rem(x::T, y::T) where {T<:BitUnsigned64} = checked_urem_int(x, y)
 
-
-# fld(x,y) == div(x,y) - ((x>=0) != (y>=0) && rem(x,y) != 0 ? 1 : 0)
-fld(x::T, y::T) where {T<:Unsigned} = div(x,y)
-function fld(x::T, y::T) where T<:Integer
-    d = div(x, y)
-    return d - (signbit(x ⊻ y) & (d * y != x))
-end
-
-# cld(x,y) = div(x,y) + ((x>0) == (y>0) && rem(x,y) != 0 ? 1 : 0)
-function cld(x::T, y::T) where T<:Unsigned
-    d = div(x, y)
-    return d + (d * y != x)
-end
-function cld(x::T, y::T) where T<:Integer
-    d = div(x, y)
-    return d + (((x > 0) == (y > 0)) & (d * y != x))
-end
-
 ## integer bitwise operations ##
 
 """
@@ -321,6 +305,8 @@ xor(x::T, y::T) where {T<:BitInteger} =
 
 Reverse the byte order of `n`.
 
+(See also [`ntoh`](@ref) and [`hton`](@ref) to convert between the current native byte order and big-endian order.)
+
 # Examples
 ```jldoctest
 julia> a = bswap(0x10203040)
diff -pruN 1.3.1+dfsg-1/base/io.jl 1.4.0+dfsg-1/base/io.jl
--- 1.3.1+dfsg-1/base/io.jl	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/base/io.jl	2020-03-21 16:36:32.000000000 +0000
@@ -135,7 +135,7 @@ Read the entirety of `io`, as a `String`
 julia> io = IOBuffer("JuliaLang is a GitHub organization");
 
 julia> read(io, Char)
-'J': ASCII/Unicode U+004a (category Lu: Letter, uppercase)
+'J': ASCII/Unicode U+004A (category Lu: Letter, uppercase)
 
 julia> io = IOBuffer("JuliaLang is a GitHub organization");
 
@@ -381,8 +381,8 @@ read(filename::AbstractString, args...)
 read(filename::AbstractString, ::Type{T}) where {T} = open(io->read(io, T), filename)
 
 """
-    read!(stream::IO, array::Union{Array, BitArray})
-    read!(filename::AbstractString, array::Union{Array, BitArray})
+    read!(stream::IO, array::AbstractArray)
+    read!(filename::AbstractString, array::AbstractArray)
 
 Read binary data from an I/O stream or file, filling in `array`.
 """
@@ -682,8 +682,8 @@ function read!(s::IO, a::Array{UInt8})
     return a
 end
 
-function read!(s::IO, a::Array{T}) where T
-    if isbitstype(T)
+function read!(s::IO, a::AbstractArray{T}) where T
+    if isbitstype(T) && (a isa Array || a isa FastContiguousSubArray{T,<:Any,<:Array{T}})
         GC.@preserve a unsafe_read(s, pointer(a), sizeof(a))
     else
         for i in eachindex(a)
diff -pruN 1.3.1+dfsg-1/base/iostream.jl 1.4.0+dfsg-1/base/iostream.jl
--- 1.3.1+dfsg-1/base/iostream.jl	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/base/iostream.jl	2020-03-21 16:36:32.000000000 +0000
@@ -100,7 +100,7 @@ julia> io = IOBuffer("JuliaLang is a Git
 julia> seek(io, 5);
 
 julia> read(io, Char)
-'L': ASCII/Unicode U+004c (category Lu: Letter, uppercase)
+'L': ASCII/Unicode U+004C (category Lu: Letter, uppercase)
 ```
 """
 function seek(s::IOStream, n::Integer)
@@ -122,12 +122,12 @@ julia> io = IOBuffer("JuliaLang is a Git
 julia> seek(io, 5);
 
 julia> read(io, Char)
-'L': ASCII/Unicode U+004c (category Lu: Letter, uppercase)
+'L': ASCII/Unicode U+004C (category Lu: Letter, uppercase)
 
 julia> seekstart(io);
 
 julia> read(io, Char)
-'J': ASCII/Unicode U+004a (category Lu: Letter, uppercase)
+'J': ASCII/Unicode U+004A (category Lu: Letter, uppercase)
 ```
 """
 seekstart(s::IO) = seek(s,0)
diff -pruN 1.3.1+dfsg-1/base/iterators.jl 1.4.0+dfsg-1/base/iterators.jl
--- 1.3.1+dfsg-1/base/iterators.jl	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/base/iterators.jl	2020-03-21 16:36:32.000000000 +0000
@@ -12,7 +12,7 @@ using .Base:
     @inline, Pair, AbstractDict, IndexLinear, IndexCartesian, IndexStyle, AbstractVector, Vector,
     tail, tuple_type_head, tuple_type_tail, tuple_type_cons, SizeUnknown, HasLength, HasShape,
     IsInfinite, EltypeUnknown, HasEltype, OneTo, @propagate_inbounds, Generator, AbstractRange,
-    LinearIndices, (:), |, +, -, !==, !, <=, <, missing, map, any
+    LinearIndices, (:), |, +, -, !==, !, <=, <, missing, map, any, @boundscheck, @inbounds
 
 import .Base:
     first, last,
@@ -22,7 +22,7 @@ import .Base:
     getindex, setindex!, get, iterate,
     popfirst!, isdone, peek
 
-export enumerate, zip, rest, countfrom, take, drop, cycle, repeated, product, flatten, partition
+export enumerate, zip, rest, countfrom, take, drop, takewhile, dropwhile, cycle, repeated, product, flatten, partition
 
 tail_if_any(::Tuple{}) = ()
 tail_if_any(x::Tuple) = tail(x)
@@ -270,8 +270,9 @@ end
 Run multiple iterators at the same time, until any of them is exhausted. The value type of
 the `zip` iterator is a tuple of values of its subiterators.
 
-Note: `zip` orders the calls to its subiterators in such a way that stateful iterators will
-not advance when another iterator finishes in the current iteration.
+!!! note
+    `zip` orders the calls to its subiterators in such a way that stateful iterators will
+    not advance when another iterator finishes in the current iteration.
 
 # Examples
 ```jldoctest
@@ -440,6 +441,59 @@ IteratorSize(::Type{<:Filter}) = SizeUnk
 
 reverse(f::Filter) = Filter(f.flt, reverse(f.itr))
 
+# Accumulate -- partial reductions of a function over an iterator
+
+struct Accumulate{F,I}
+    f::F
+    itr::I
+end
+
+"""
+    Iterators.accumulate(f, itr)
+
+Given a 2-argument function `f` and an iterator `itr`, return a new
+iterator that successively applies `f` to the previous value and the
+next element of `itr`.
+
+This is effectively a lazy version of [`Base.accumulate`](@ref).
+
+# Examples
+```jldoctest
+julia> f = Iterators.accumulate(+, [1,2,3,4])
+Base.Iterators.Accumulate{typeof(+),Array{Int64,1}}(+, [1, 2, 3, 4])
+
+julia> foreach(println, f)
+1
+3
+6
+10
+```
+"""
+accumulate(f, itr) = Accumulate(f, itr)
+
+function iterate(itr::Accumulate)
+    state = iterate(itr.itr)
+    if state === nothing
+        return nothing
+    end
+    return (state[1], state)
+end
+
+function iterate(itr::Accumulate, state)
+    nxt = iterate(itr.itr, state[2])
+    if nxt === nothing
+        return nothing
+    end
+    val = itr.f(state[1], nxt[1])
+    return (val, (val, nxt[2]))
+end
+
+length(itr::Accumulate) = length(itr.itr)
+size(itr::Accumulate) = size(itr.itr)
+
+IteratorSize(::Type{Accumulate{F,I}}) where {F,I} = IteratorSize(I)
+IteratorEltype(::Type{<:Accumulate}) = EltypeUnknown()
+
 # Rest -- iterate starting at the given state
 
 struct Rest{I,S}
@@ -648,6 +702,105 @@ end
 iterate(it::Drop, state) = iterate(it.xs, state)
 isdone(it::Drop, state) = isdone(it.xs, state)
 
+
+# takewhile
+
+struct TakeWhile{I,P<:Function}
+    pred::P
+    xs::I
+end
+
+"""
+    takewhile(pred, iter)
+
+An iterator that generates element from `iter` as long as predicate `pred` is true,
+afterwards, drops every element.
+
+!!! compat "Julia 1.4"
+    This function requires at least Julia 1.4.
+
+# Examples
+
+```jldoctest
+julia> s = collect(1:5)
+5-element Array{Int64,1}:
+ 1
+ 2
+ 3
+ 4
+ 5
+
+julia> collect(Iterators.takewhile(<(3),s))
+2-element Array{Int64,1}:
+ 1
+ 2
+```
+"""
+takewhile(pred,xs) = TakeWhile(pred,xs)
+
+function iterate(ibl::TakeWhile, itr...)
+    y = iterate(ibl.xs,itr...)
+    y === nothing && return nothing
+    ibl.pred(y[1]) || return nothing
+    y
+end
+
+IteratorSize(::Type{<:TakeWhile}) = SizeUnknown()
+eltype(::Type{TakeWhile{I,P}}) where {I,P} = eltype(I)
+IteratorEltype(::Type{TakeWhile{I,P}}) where {I,P} = IteratorEltype(I)
+
+
+# dropwhile
+
+struct DropWhile{I,P<:Function}
+    pred::P
+    xs::I
+end
+
+"""
+    dropwhile(pred, iter)
+
+An iterator that drops element from `iter` as long as predicate `pred` is true,
+afterwards, returns every element.
+
+!!! compat "Julia 1.4"
+    This function requires at least Julia 1.4.
+
+# Examples
+
+```jldoctest
+julia> s = collect(1:5)
+5-element Array{Int64,1}:
+ 1
+ 2
+ 3
+ 4
+ 5
+
+julia> collect(Iterators.dropwhile(<(3),s))
+3-element Array{Int64,1}:
+ 3
+ 4
+ 5
+```
+"""
+dropwhile(pred,itr) = DropWhile(pred,itr)
+
+iterate(ibl::DropWhile,itr) = iterate(ibl.xs, itr)
+function iterate(ibl::DropWhile)
+    y = iterate(ibl.xs)
+    while y !== nothing
+        ibl.pred(y[1]) || break
+        y = iterate(ibl.xs,y[2])
+    end
+    y
+end
+
+IteratorSize(::Type{<:DropWhile}) = SizeUnknown()
+eltype(::Type{DropWhile{I,P}}) where {I,P} = eltype(I)
+IteratorEltype(::Type{DropWhile{I,P}}) where {I,P} = IteratorEltype(I)
+
+
 # Cycle an iterator forever
 
 struct Cycle{I}
@@ -921,38 +1074,56 @@ Iterate over a collection `n` elements a
 # Examples
 ```jldoctest
 julia> collect(Iterators.partition([1,2,3,4,5], 2))
-3-element Array{Array{Int64,1},1}:
+3-element Array{SubArray{Int64,1,Array{Int64,1},Tuple{UnitRange{Int64}},true},1}:
  [1, 2]
  [3, 4]
  [5]
 ```
 """
-partition(c::T, n::Integer) where {T} = PartitionIterator{T}(c, Int(n))
-
+function partition(c, n::Integer)
+    n < 1 && throw(ArgumentError("cannot create partitions of length $n"))
+    return PartitionIterator(c, Int(n))
+end
 
 struct PartitionIterator{T}
     c::T
     n::Int
 end
+# Partitions are explicitly a linear indexing operation, so reshape to 1-d immediately
+PartitionIterator(A::AbstractArray, n::Int) = PartitionIterator(vec(A), n)
+PartitionIterator(v::AbstractVector, n::Int) = PartitionIterator{typeof(v)}(v, n)
 
 eltype(::Type{PartitionIterator{T}}) where {T} = Vector{eltype(T)}
+# Arrays use a generic `view`-of-a-`vec`, so we cannot exactly predict what we'll get back
+eltype(::Type{PartitionIterator{T}}) where {T<:AbstractArray} = AbstractVector{eltype(T)}
+# But for some common implementations in Base we know the answer exactly
+eltype(::Type{PartitionIterator{T}}) where {T<:Vector} = SubArray{eltype(T), 1, T, Tuple{UnitRange{Int}}, true}
+
+IteratorEltype(::Type{<:PartitionIterator{T}}) where {T} = IteratorEltype(T)
+IteratorEltype(::Type{<:PartitionIterator{T}}) where {T<:AbstractArray} = EltypeUnknown()
+IteratorEltype(::Type{<:PartitionIterator{T}}) where {T<:Vector} = IteratorEltype(T)
+
 partition_iteratorsize(::HasShape) = HasLength()
 partition_iteratorsize(isz) = isz
 function IteratorSize(::Type{PartitionIterator{T}}) where {T}
     partition_iteratorsize(IteratorSize(T))
 end
 
-IteratorEltype(::Type{<:PartitionIterator{T}}) where {T} = IteratorEltype(T)
-
 function length(itr::PartitionIterator)
     l = length(itr.c)
     return div(l, itr.n) + ((mod(l, itr.n) > 0) ? 1 : 0)
 end
 
-function iterate(itr::PartitionIterator{<:Vector}, state=1)
+function iterate(itr::PartitionIterator{<:AbstractRange}, state=1)
+    state > length(itr.c) && return nothing
+    r = min(state + itr.n - 1, length(itr.c))
+    return @inbounds itr.c[state:r], r + 1
+end
+
+function iterate(itr::PartitionIterator{<:AbstractArray}, state=1)
     state > length(itr.c) && return nothing
     r = min(state + itr.n - 1, length(itr.c))
-    return view(itr.c, state:r), r + 1
+    return @inbounds view(itr.c, state:r), r + 1
 end
 
 struct IterationCutShort; end
@@ -990,7 +1161,7 @@ There are several different ways to thin
    whenever an item is produced.
 
 `Stateful` provides the regular iterator interface. Like other mutable iterators
-(e.g. [`Channel`](@ref)), if iteration is stopped early (e.g. by a `break` in a `for` loop),
+(e.g. [`Channel`](@ref)), if iteration is stopped early (e.g. by a [`break`](@ref) in a [`for`](@ref) loop),
 iteration can be resumed from the same spot by continuing to iterate over the
 same iterator object (in contrast, an immutable iterator would restart from the
 beginning).
@@ -1095,4 +1266,41 @@ eltype(::Type{Stateful{T, VS}} where VS)
 IteratorEltype(::Type{Stateful{T,VS}}) where {T,VS} = IteratorEltype(T)
 length(s::Stateful) = length(s.itr) - s.taken
 
+"""
+    only(x)
+
+Returns the one and only element of collection `x`, and throws an `ArgumentError` if the
+collection has zero or multiple elements.
+
+See also: [`first`](@ref), [`last`](@ref).
+
+!!! compat "Julia 1.4"
+    This method requires at least Julia 1.4.
+"""
+@propagate_inbounds function only(x)
+    i = iterate(x)
+    @boundscheck if i === nothing
+        throw(ArgumentError("Collection is empty, must contain exactly 1 element"))
+    end
+    (ret, state) = i
+    @boundscheck if iterate(x, state) !== nothing
+        throw(ArgumentError("Collection has multiple elements, must contain exactly 1 element"))
+    end
+    return ret
+end
+
+# Collections of known size
+only(x::Ref) = x[]
+only(x::Number) = x
+only(x::Char) = x
+only(x::Tuple{Any}) = x[1]
+only(x::Tuple) = throw(
+    ArgumentError("Tuple contains $(length(x)) elements, must contain exactly 1 element")
+)
+only(a::AbstractArray{<:Any, 0}) = @inbounds return a[]
+only(x::NamedTuple{<:Any, <:Tuple{Any}}) = first(x)
+only(x::NamedTuple) = throw(
+    ArgumentError("NamedTuple contains $(length(x)) elements, must contain exactly 1 element")
+)
+
 end
diff -pruN 1.3.1+dfsg-1/base/libc.jl 1.4.0+dfsg-1/base/libc.jl
--- 1.3.1+dfsg-1/base/libc.jl	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/base/libc.jl	2020-03-21 16:36:32.000000000 +0000
@@ -313,14 +313,15 @@ function FormatMessage end
 if Sys.iswindows()
     GetLastError() = ccall(:GetLastError, stdcall, UInt32, ())
 
-    function FormatMessage(e=GetLastError())
+    FormatMessage(e) = FormatMessage(UInt32(e))
+    function FormatMessage(e::UInt32=GetLastError())
         FORMAT_MESSAGE_ALLOCATE_BUFFER = UInt32(0x100)
         FORMAT_MESSAGE_FROM_SYSTEM = UInt32(0x1000)
         FORMAT_MESSAGE_IGNORE_INSERTS = UInt32(0x200)
         FORMAT_MESSAGE_MAX_WIDTH_MASK = UInt32(0xFF)
         lpMsgBuf = Ref{Ptr{UInt16}}()
         lpMsgBuf[] = 0
-        len = ccall(:FormatMessageW, stdcall, UInt32, (Cint, Ptr{Cvoid}, Cint, Cint, Ptr{Ptr{UInt16}}, Cint, Ptr{Cvoid}),
+        len = ccall(:FormatMessageW, stdcall, UInt32, (UInt32, Ptr{Cvoid}, UInt32, UInt32, Ptr{Ptr{UInt16}}, UInt32, Ptr{Cvoid}),
                     FORMAT_MESSAGE_ALLOCATE_BUFFER | FORMAT_MESSAGE_FROM_SYSTEM | FORMAT_MESSAGE_IGNORE_INSERTS | FORMAT_MESSAGE_MAX_WIDTH_MASK,
                     C_NULL, e, 0, lpMsgBuf, 0, C_NULL)
         p = lpMsgBuf[]
@@ -382,15 +383,21 @@ Interface to the C `rand()` function. If
 by composing two calls to `rand()`. `T` can be `UInt32` or `Float64`.
 """
 rand() = ccall(:rand, Cint, ())
-# RAND_MAX at least 2^15-1 in theory, but we assume 2^16-1 (in practice, it's 2^31-1)
-rand(::Type{UInt32}) = ((rand() % UInt32) << 16) ⊻ (rand() % UInt32)
-rand(::Type{Float64}) = rand(UInt32) / 2^32
+@static if Sys.iswindows()
+    # Windows RAND_MAX is 2^15-1
+    rand(::Type{UInt32}) = ((rand() % UInt32) << 17) ⊻ ((rand() % UInt32) << 8) ⊻ (rand() % UInt32)
+else
+    # RAND_MAX is at least 2^15-1 in theory, but we assume 2^16-1
+    # on non-Windows systems (in practice, it's 2^31-1)
+    rand(::Type{UInt32}) = ((rand() % UInt32) << 16) ⊻ (rand() % UInt32)
+end
+rand(::Type{Float64}) = rand(UInt32) * 2.0^-32
 
 """
     srand([seed])
 
 Interface to the C `srand(seed)` function.
 """
-srand(seed=floor(time())) = ccall(:srand, Cvoid, (Cuint,), seed)
+srand(seed=floor(Int, time()) % Cuint) = ccall(:srand, Cvoid, (Cuint,), seed)
 
 end # module
diff -pruN 1.3.1+dfsg-1/base/libuv.jl 1.4.0+dfsg-1/base/libuv.jl
--- 1.3.1+dfsg-1/base/libuv.jl	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/base/libuv.jl	2020-03-21 16:36:32.000000000 +0000
@@ -98,10 +98,10 @@ uv_error(prefix::AbstractString, c::Inte
 
 ## event loop ##
 
-eventloop() = uv_eventloop::Ptr{Cvoid}
+eventloop() = ccall(:jl_global_event_loop, Ptr{Cvoid}, ())
 
 function process_events()
-    return ccall(:jl_process_events, Int32, (Ptr{Cvoid},), eventloop())
+    return ccall(:jl_process_events, Int32, ())
 end
 
 function uv_alloc_buf end
@@ -119,7 +119,6 @@ function reinit_stdio()
     global uv_jl_asynccb       = @cfunction(uv_asynccb, Cvoid, (Ptr{Cvoid},))
     global uv_jl_timercb       = @cfunction(uv_timercb, Cvoid, (Ptr{Cvoid},))
 
-    global uv_eventloop = ccall(:jl_global_event_loop, Ptr{Cvoid}, ())
     global stdin = init_stdio(ccall(:jl_stdin_stream, Ptr{Cvoid}, ()))
     global stdout = init_stdio(ccall(:jl_stdout_stream, Ptr{Cvoid}, ()))
     global stderr = init_stdio(ccall(:jl_stderr_stream, Ptr{Cvoid}, ()))
diff -pruN 1.3.1+dfsg-1/base/loading.jl 1.4.0+dfsg-1/base/loading.jl
--- 1.3.1+dfsg-1/base/loading.jl	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/base/loading.jl	2020-03-21 16:36:32.000000000 +0000
@@ -117,7 +117,14 @@ end
 
 const ns_dummy_uuid = UUID("fe0723d6-3a44-4c41-8065-ee0f42c8ceab")
 
-dummy_uuid(project_file::String) = uuid5(ns_dummy_uuid, realpath(project_file))
+function dummy_uuid(project_file::String)
+    project_path = try
+        realpath(project_file)
+    catch
+        project_file
+    end
+    return uuid5(ns_dummy_uuid, project_path)
+end
 
 ## package path slugs: turning UUID + SHA1 into a pair of 4-byte "slugs" ##
 
@@ -265,7 +272,7 @@ end
 """
     pathof(m::Module)
 
-Return the path of `m.jl` file that was used to `import` module `m`,
+Return the path of the `m.jl` file that was used to `import` module `m`,
 or `nothing` if `m` was not imported from a package.
 
 Use [`dirname`](@ref) to get the directory part and [`basename`](@ref)
@@ -277,6 +284,19 @@ function pathof(m::Module)
     return Base.locate_package(pkgid)
 end
 
+"""
+    pkgdir(m::Module)
+
+ Return the root directory of the package that imported module `m`,
+ or `nothing` if `m` was not imported from a package.
+ """
+function pkgdir(m::Module)
+    rootmodule = Base.moduleroot(m)
+    path = pathof(rootmodule)
+    path === nothing && return nothing
+    return dirname(dirname(path))
+end
+
 ## generic project & manifest API ##
 
 const project_names = ("JuliaProject.toml", "Project.toml")
@@ -466,21 +486,6 @@ function entry_path(path::String, name::
     return nothing # source not found
 end
 
-# given a project path (project directory or entry point)
-# return the project file
-function package_path_to_project_file(path::String)::Union{Nothing,String}
-    if !isdir(path)
-        dir = dirname(path)
-        basename(dir) == "src" || return nothing
-        path = dirname(dir)
-    end
-    for proj in project_names
-        project_file = joinpath(path, proj)
-        isfile_casesensitive(project_file) && return project_file
-    end
-    return nothing
-end
-
 ## explicit project & manifest API ##
 
 # find project file root or deps `name => uuid` mapping
@@ -1050,7 +1055,7 @@ function _require(pkg::PkgId)
             ccall(:jl_set_module_uuid, Cvoid, (Any, NTuple{2, UInt64}), __toplevel__, uuid)
         end
         try
-            include_relative(__toplevel__, path)
+            include(__toplevel__, path)
             return
         finally
             if uuid !== old_uuid
@@ -1081,8 +1086,8 @@ include_string(m::Module, txt::AbstractS
 
 function source_path(default::Union{AbstractString,Nothing}="")
     s = current_task().storage
-    if s !== nothing && haskey(s, :SOURCE_PATH)
-        return s[:SOURCE_PATH]
+    if s !== nothing && haskey(s::IdDict{Any,Any}, :SOURCE_PATH)
+        return s[:SOURCE_PATH]::Union{Nothing,String}
     end
     return default
 end
@@ -1092,27 +1097,6 @@ function source_dir()
     return p === nothing ? pwd() : dirname(p)
 end
 
-include_relative(mod::Module, path::AbstractString) = include_relative(mod, String(path))
-function include_relative(mod::Module, _path::String)
-    path, prev = _include_dependency(mod, _path)
-    for callback in include_callbacks # to preserve order, must come before Core.include
-        invokelatest(callback, mod, path)
-    end
-    tls = task_local_storage()
-    tls[:SOURCE_PATH] = path
-    local result
-    try
-        result = Core.include(mod, path)
-    finally
-        if prev === nothing
-            delete!(tls, :SOURCE_PATH)
-        else
-            tls[:SOURCE_PATH] = prev
-        end
-    end
-    return result
-end
-
 """
     Base.include([m::Module,] path::AbstractString)
 
@@ -1227,7 +1211,10 @@ function compilecache_path(pkg::PkgId)::
     if pkg.uuid === nothing
         abspath(cachepath, entryfile) * ".ji"
     else
-        project_precompile_slug = slug(_crc32c(something(Base.active_project(), "")), 5)
+        crc = _crc32c(something(Base.active_project(), ""))
+        crc = _crc32c(unsafe_string(JLOptions().image_file), crc)
+        crc = _crc32c(unsafe_string(JLOptions().julia_bin), crc)
+        project_precompile_slug = slug(crc, 5)
         abspath(cachepath, string(entryfile, "_", project_precompile_slug, ".ji"))
     end
 end
@@ -1277,6 +1264,8 @@ function compilecache(pkg::PkgId, path::
         open(cachefile, "a+") do f
             write(f, _crc32c(seekstart(f)))
         end
+        # inherit permission from the source file
+        chmod(cachefile, filemode(path) & 0o777)
     elseif p.exitcode == 125
         return PrecompilableError()
     else
@@ -1498,7 +1487,7 @@ Alternatively see [`PROGRAM_FILE`](@ref)
 """
 macro __FILE__()
     __source__.file === nothing && return nothing
-    return String(__source__.file)
+    return String(__source__.file::Symbol)
 end
 
 """
@@ -1510,6 +1499,6 @@ Return the current working directory if
 """
 macro __DIR__()
     __source__.file === nothing && return nothing
-    _dirname = dirname(String(__source__.file))
+    _dirname = dirname(String(__source__.file::Symbol))
     return isempty(_dirname) ? pwd() : abspath(_dirname)
 end
diff -pruN 1.3.1+dfsg-1/base/lock.jl 1.4.0+dfsg-1/base/lock.jl
--- 1.3.1+dfsg-1/base/lock.jl	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/base/lock.jl	2020-03-21 16:36:32.000000000 +0000
@@ -145,6 +145,16 @@ function relockall(rl::ReentrantLock, n:
     return
 end
 
+"""
+    lock(f::Function, lock)
+
+Acquire the `lock`, execute `f` with the `lock` held, and release the `lock` when `f`
+returns. If the lock is already locked by a different task/thread, wait for it to become
+available.
+
+When this function returns, the `lock` has been released, so the caller should
+not attempt to `unlock` it.
+"""
 function lock(f, l::AbstractLock)
     lock(l)
     try
diff -pruN 1.3.1+dfsg-1/base/locks-mt.jl 1.4.0+dfsg-1/base/locks-mt.jl
--- 1.3.1+dfsg-1/base/locks-mt.jl	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/base/locks-mt.jl	2020-03-21 16:36:32.000000000 +0000
@@ -11,33 +11,57 @@ export SpinLock
 # Atomic Locks
 ##########################################
 
-# Test-and-test-and-set spin locks are quickest up to about 30ish
-# contending threads. If you have more contention than that, perhaps
-# a lock is the wrong way to synchronize.
 """
     SpinLock()
 
-Create a non-reentrant lock.
+Create a non-reentrant, test-and-test-and-set spin lock.
 Recursive use will result in a deadlock.
+This kind of lock should only be used around code that takes little time
+to execute and does not block (e.g. perform I/O).
+In general, [`ReentrantLock`](@ref) should be used instead.
+
 Each [`lock`](@ref) must be matched with an [`unlock`](@ref).
 
 Test-and-test-and-set spin locks are quickest up to about 30ish
-contending threads. If you have more contention than that, perhaps
-a lock is the wrong way to synchronize.
+contending threads. If you have more contention than that, different
+synchronization approaches should be considered.
 """
-struct SpinLock <: AbstractLock
-    handle::Atomic{Int}
-    SpinLock() = new(Atomic{Int}(0))
+mutable struct SpinLock <: AbstractLock
+    handle::Int
+    SpinLock() = new(0)
 end
 
+import Base.Sys.WORD_SIZE
+
+@eval _xchg!(x::SpinLock, v::Int) =
+    llvmcall($"""
+             %ptr = inttoptr i$WORD_SIZE %0 to i$WORD_SIZE*
+             %rv = atomicrmw xchg i$WORD_SIZE* %ptr, i$WORD_SIZE %1 acq_rel
+             ret i$WORD_SIZE %rv
+             """, Int, Tuple{Ptr{Int}, Int}, unsafe_convert(Ptr{Int}, pointer_from_objref(x)), v)
+
+@eval _get(x::SpinLock) =
+    llvmcall($"""
+             %ptr = inttoptr i$WORD_SIZE %0 to i$WORD_SIZE*
+             %rv = load atomic i$WORD_SIZE, i$WORD_SIZE* %ptr acquire, align $(gc_alignment(Int))
+             ret i$WORD_SIZE %rv
+             """, Int, Tuple{Ptr{Int}}, unsafe_convert(Ptr{Int}, pointer_from_objref(x)))
+
+@eval _set!(x::SpinLock, v::Int) =
+    llvmcall($"""
+             %ptr = inttoptr i$WORD_SIZE %0 to i$WORD_SIZE*
+             store atomic i$WORD_SIZE %1, i$WORD_SIZE* %ptr release, align $(gc_alignment(Int))
+             ret void
+             """, Cvoid, Tuple{Ptr{Int}, Int}, unsafe_convert(Ptr{Int}, pointer_from_objref(x)), v)
+
 # Note: this cannot assert that the lock is held by the correct thread, because we do not
 # track which thread locked it. Users beware.
-Base.assert_havelock(l::SpinLock) = islocked(l) ? nothing : concurrency_violation()
+Base.assert_havelock(l::SpinLock) = islocked(l) ? nothing : Base.concurrency_violation()
 
 function lock(l::SpinLock)
     while true
-        if l.handle[] == 0
-            p = atomic_xchg!(l.handle, 1)
+        if _get(l) == 0
+            p = _xchg!(l, 1)
             if p == 0
                 return
             end
@@ -49,18 +73,18 @@ function lock(l::SpinLock)
 end
 
 function trylock(l::SpinLock)
-    if l.handle[] == 0
-        return atomic_xchg!(l.handle, 1) == 0
+    if _get(l) == 0
+        return _xchg!(l, 1) == 0
     end
     return false
 end
 
 function unlock(l::SpinLock)
-    l.handle[] = 0
+    _set!(l, 0)
     ccall(:jl_cpu_wake, Cvoid, ())
     return
 end
 
 function islocked(l::SpinLock)
-    return l.handle[] != 0
+    return _get(l) != 0
 end
diff -pruN 1.3.1+dfsg-1/base/logging.jl 1.4.0+dfsg-1/base/logging.jl
--- 1.3.1+dfsg-1/base/logging.jl	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/base/logging.jl	2020-03-21 16:36:32.000000000 +0000
@@ -33,8 +33,9 @@ abstract type AbstractLogger ; end
 
 Log a message to `logger` at `level`.  The logical location at which the
 message was generated is given by module `_module` and `group`; the source
-location by `file` and `line`. `id` is an arbitrary unique [`Symbol`](@ref) to be used
-as a key to identify the log statement when filtering.
+location by `file` and `line`. `id` is an arbitrary unique value (typically a
+[`Symbol`](@ref)) to be used as a key to identify the log statement when
+filtering.
 """
 function handle_message end
 
@@ -203,7 +204,7 @@ end
 macro _sourceinfo()
     esc(quote
         (__module__,
-         __source__.file === nothing ? "?" : String(__source__.file),
+         __source__.file === nothing ? "?" : String(__source__.file::Symbol),
          __source__.line)
     end)
 end
@@ -247,6 +248,8 @@ function log_record_id(_module, level, m
     end
 end
 
+default_group(file) = Symbol(splitext(basename(file))[1])
+
 # Generate code for logging macros
 function logmsg_code(_module, file, line, level, message, exs...)
     id = Expr(:quote, log_record_id(_module, level, message, exs))
@@ -292,12 +295,12 @@ function logmsg_code(_module, file, line
     if group === nothing
         group = if isdefined(Base, :basename) && isa(file, String)
             # precompute if we can
-            QuoteNode(splitext(basename(file))[1])
+            QuoteNode(default_group(file))
         else
             # memoized run-time execution
             ref = Ref{Symbol}()
             :(isassigned($ref) ? $ref[]
-                               : $ref[] = Symbol(splitext(basename(something($file, "")))[1]))
+                               : $ref[] = default_group(something($file, "")))
         end
     end
 
@@ -413,38 +416,49 @@ function disable_logging(level::LogLevel
     _min_enabled_level[] = level + 1
 end
 
-let _debug_groups = Symbol[],
+let _debug_groups_include::Vector{Symbol} = Symbol[],
+    _debug_groups_exclude::Vector{Symbol} = Symbol[],
     _debug_str::String = ""
 global function env_override_minlevel(group, _module)
     debug = get(ENV, "JULIA_DEBUG", "")
     if !(debug === _debug_str)
         _debug_str = debug
-        empty!(_debug_groups)
+        empty!(_debug_groups_include)
+        empty!(_debug_groups_exclude)
         for g in split(debug, ',')
-            isempty(g) && continue
-            if g == "all"
-                empty!(_debug_groups)
-                push!(_debug_groups, :all)
-                break
+            if !isempty(g)
+                if startswith(g, "!")
+                    if !isempty(g[2:end])
+                        push!(_debug_groups_exclude, Symbol(g[2:end]))
+                    end
+                else
+                    push!(_debug_groups_include, Symbol(g))
+                end
             end
-            push!(_debug_groups, Symbol(g))
         end
+        unique!(_debug_groups_include)
+        unique!(_debug_groups_exclude)
     end
-    if isempty(_debug_groups)
-        return false
-    end
-    if _debug_groups[1] === :all
-        return true
-    end
-    if isa(group, Symbol) && group in _debug_groups
-        return true
-    end
-    if isa(_module, Module)
-        if nameof(_module) in _debug_groups
+
+    if !(:all in _debug_groups_exclude) && (:all in _debug_groups_include || !isempty(_debug_groups_exclude))
+        if isempty(_debug_groups_exclude)
+            return true
+        elseif isa(group, Symbol) && group in _debug_groups_exclude
+            return false
+        elseif isa(_module, Module) && (nameof(_module) in _debug_groups_exclude || nameof(Base.moduleroot(_module)) in _debug_groups_exclude)
+            return false
+        else
             return true
         end
-        if nameof(Base.moduleroot(_module)) in _debug_groups
+    else
+        if isempty(_debug_groups_include)
+            return false
+        elseif isa(group, Symbol) && group in _debug_groups_include
             return true
+        elseif isa(_module, Module) && (nameof(_module) in _debug_groups_include || nameof(Base.moduleroot(_module)) in _debug_groups_include)
+            return true
+        else
+            return false
         end
     end
     return false
diff -pruN 1.3.1+dfsg-1/base/math.jl 1.4.0+dfsg-1/base/math.jl
--- 1.3.1+dfsg-1/base/math.jl	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/base/math.jl	2020-03-21 16:36:32.000000000 +0000
@@ -13,7 +13,7 @@ export sin, cos, sincos, tan, sinh, cosh
        cbrt, sqrt, significand,
        hypot, max, min, minmax, ldexp, frexp,
        clamp, clamp!, modf, ^, mod2pi, rem2pi,
-       @evalpoly
+       @evalpoly, evalpoly
 
 import .Base: log, exp, sin, cos, tan, sinh, cosh, tanh, asin,
              acos, atan, asinh, acosh, atanh, sqrt, log2, log10,
@@ -22,7 +22,8 @@ import .Base: log, exp, sin, cos, tan, s
 
 using .Base: sign_mask, exponent_mask, exponent_one,
             exponent_half, uinttype, significand_mask,
-            significand_bits, exponent_bits
+            significand_bits, exponent_bits, exponent_bias,
+            exponent_max, exponent_raw_max
 
 using Core.Intrinsics: sqrt_llvm
 
@@ -38,14 +39,6 @@ end
                                 "Complex(x)^y, or similar.")))
 end
 
-for T in (Float16, Float32, Float64)
-    @eval exponent_bias(::Type{$T}) = $(Int(exponent_one(T) >> significand_bits(T)))
-    # maximum float exponent
-    @eval exponent_max(::Type{$T}) = $(Int(exponent_mask(T) >> significand_bits(T)) - exponent_bias(T))
-    # maximum float exponent without bias
-    @eval exponent_raw_max(::Type{$T}) = $(Int(exponent_mask(T) >> significand_bits(T)))
-end
-
 # non-type specific math functions
 
 """
@@ -88,17 +81,109 @@ function clamp!(x::AbstractArray, lo, hi
     x
 end
 
+
+"""
+    evalpoly(x, p)
+
+Evaluate the polynomial ``\\sum_k p[k] x^{k-1}`` for the coefficients `p[1]`, `p[2]`, ...;
+that is, the coefficients are given in ascending order by power of `x`.
+Loops are unrolled at compile time if the number of coefficients is statically known, i.e.
+when `p` is a `Tuple`.
+This function generates efficient code using Horner's method if `x` is real, or using
+a Goertzel-like [^DK62] algorithm if `x` is complex.
+
+[^DK62]: Donald Knuth, Art of Computer Programming, Volume 2: Seminumerical Algorithms, Sec. 4.6.4.
+
+!!! compat "Julia 1.4"
+    This function requires Julia 1.4 or later.
+
+# Example
+```jldoctest
+julia> evalpoly(2, (1, 2, 3))
+17
+```
+"""
+function evalpoly(x, p::Tuple)
+    if @generated
+        N = length(p.parameters)
+        ex = :(p[end])
+        for i in N-1:-1:1
+            ex = :(muladd(x, $ex, p[$i]))
+        end
+        ex
+    else
+        _evalpoly(x, p)
+    end
+end
+
+evalpoly(x, p::AbstractVector) = _evalpoly(x, p)
+
+function _evalpoly(x, p)
+    N = length(p)
+    ex = p[end]
+    for i in N-1:-1:1
+        ex = muladd(x, ex, p[i])
+    end
+    ex
+end
+
+function evalpoly(z::Complex, p::Tuple)
+    if @generated
+        N = length(p.parameters)
+        a = :(p[end])
+        b = :(p[end-1])
+        as = []
+        for i in N-2:-1:1
+            ai = Symbol("a", i)
+            push!(as, :($ai = $a))
+            a = :(muladd(r, $ai, $b))
+            b = :(p[$i] - s * $ai)
+        end
+        ai = :a0
+        push!(as, :($ai = $a))
+        C = Expr(:block,
+                 :(x = real(z)),
+                 :(y = imag(z)),
+                 :(r = x + x),
+                 :(s = muladd(x, x, y*y)),
+                 as...,
+                 :(muladd($ai, z, $b)))
+    else
+        _evalpoly(z, p)
+    end
+end
+evalpoly(z::Complex, p::Tuple{<:Any}) = p[1]
+
+
+evalpoly(z::Complex, p::AbstractVector) = _evalpoly(z, p)
+
+function _evalpoly(z::Complex, p)
+    length(p) == 1 && return p[1]
+    N = length(p)
+    a = p[end]
+    b = p[end-1]
+
+    x = real(z)
+    y = imag(z)
+    r = 2x
+    s = muladd(x, x, y*y)
+    for i in N-2:-1:1
+        ai = a
+        a = muladd(r, ai, b)
+        b = p[i] - s * ai
+    end
+    ai = a
+    muladd(ai, z, b)
+end
+
 """
     @horner(x, p...)
-    Evaluate p[1] + x * (p[2] + x * (....)), i.e. a polynomial via Horner's rule
+
+Evaluate `p[1] + x * (p[2] + x * (....))`, i.e. a polynomial via Horner's rule.
 """
 macro horner(x, p...)
-    ex = esc(p[end])
-    for i = length(p)-1:-1:1
-        ex = :(muladd(t, $ex, $(esc(p[i]))))
-    end
-    ex = quote local r = $ex end # structure this to add exactly one line number node for the macro
-    return Expr(:block, :(local t = $(esc(x))), ex, :r)
+     xesc, pesc = esc(x), esc.(p)
+    :(invoke(evalpoly, Tuple{Any, Tuple}, $xesc, ($(pesc...),)))
 end
 
 # Evaluate p[1] + z*p[2] + z^2*p[3] + ... + z^(n-1)*p[n].  This uses
@@ -127,28 +212,8 @@ julia> @evalpoly(2, 1, 1, 1)
 ```
 """
 macro evalpoly(z, p...)
-    a = :($(esc(p[end])))
-    b = :($(esc(p[end-1])))
-    as = []
-    for i = length(p)-2:-1:1
-        ai = Symbol("a", i)
-        push!(as, :($ai = $a))
-        a = :(muladd(r, $ai, $b))
-        b = :($(esc(p[i])) - s * $ai) # see issue #15985 on fused mul-subtract
-    end
-    ai = :a0
-    push!(as, :($ai = $a))
-    C = Expr(:block,
-             :(x = real(tt)),
-             :(y = imag(tt)),
-             :(r = x + x),
-             :(s = muladd(x, x, y*y)),
-             as...,
-             :(muladd($ai, tt, $b)))
-    R = Expr(:macrocall, Symbol("@horner"), (), :tt, map(esc, p)...)
-    :(let tt = $(esc(z))
-          isa(tt, Complex) ? $C : $R
-      end)
+    zesc, pesc = esc(z), esc.(p)
+    :(evalpoly($zesc, ($(pesc...),)))
 end
 
 """
@@ -546,12 +611,23 @@ julia> hypot(3, 4im)
 ```
 """
 hypot(x::Number, y::Number) = hypot(promote(x, y)...)
-hypot(x::Complex, y::Complex) = hypot(promote(abs(x),abs(y))...)
-hypot(x::Integer, y::Integer) = hypot(promote(float(x), float(y))...)
-function hypot(x::T,y::T) where T<:AbstractFloat
-    #Return Inf if either or both imputs is Inf (Compliance with IEEE754)
+hypot(x::Complex, y::Complex) = hypot(abs(x), abs(y))
+hypot(x::T, y::T) where {T<:Real} = hypot(float(x), float(y))
+function hypot(x::T, y::T) where {T<:Number}
+    if !iszero(x)
+        z = y/x
+        z2 = z*z
+
+        abs(x) * sqrt(oneunit(z2) + z2)
+    else
+        abs(y)
+    end
+end
+
+function hypot(x::T, y::T) where T<:AbstractFloat
+    # Return Inf if either or both inputs is Inf (Compliance with IEEE754)
     if isinf(x) || isinf(y)
-        return convert(T,Inf)
+        return T(Inf)
     end
 
     # Order the operands
@@ -593,31 +669,7 @@ function hypot(x::T,y::T) where T<:Abstr
             h -= muladd(delta,delta,muladd(ay,(4*delta-ay),2*delta*(ax-2*ay)))/(2*h)
         end
     end
-    h*scale
-end
-function hypot(x::T, y::T) where T<:Number
-    ax = abs(x)
-    ay = abs(y)
-    if ax < ay
-        ax, ay = ay, ax
-    end
-    if iszero(ax)
-        r = ay / oneunit(ax)
-    else
-        r = ay / ax
-    end
-
-    rr = ax * sqrt(1 + r * r)
-
-    # Use type of rr to make sure that return type is the same for
-    # all branches
-    if isnan(r)
-        isinf(ax) && return oftype(rr, Inf)
-        isinf(ay) && return oftype(rr, Inf)
-        return oftype(rr, r)
-    else
-        return rr
-    end
+    return h*scale
 end
 
 """
@@ -778,35 +830,6 @@ function frexp(x::T) where T<:IEEEFloat
     return reinterpret(T, xu), k
 end
 
-"""
-    rem(x, y, r::RoundingMode)
-
-Compute the remainder of `x` after integer division by `y`, with the quotient rounded
-according to the rounding mode `r`. In other words, the quantity
-
-    x - y*round(x/y,r)
-
-without any intermediate rounding.
-
-- if `r == RoundNearest`, then the result is exact, and in the interval
-  ``[-|y|/2, |y|/2]``. See also [`RoundNearest`](@ref).
-
-- if `r == RoundToZero` (default), then the result is exact, and in the interval
-  ``[0, |y|)`` if `x` is positive, or ``(-|y|, 0]`` otherwise. See also [`RoundToZero`](@ref).
-
-- if `r == RoundDown`, then the result is in the interval ``[0, y)`` if `y` is positive, or
-  ``(y, 0]`` otherwise. The result may not be exact if `x` and `y` have different signs, and
-  `abs(x) < abs(y)`. See also[`RoundDown`](@ref).
-
-- if `r == RoundUp`, then the result is in the interval `(-y,0]` if `y` is positive, or
-  `[0,-y)` otherwise. The result may not be exact if `x` and `y` have the same sign, and
-  `abs(x) < abs(y)`. See also [`RoundUp`](@ref).
-
-"""
-rem(x, y, ::RoundingMode{:ToZero}) = rem(x,y)
-rem(x, y, ::RoundingMode{:Down}) = mod(x,y)
-rem(x, y, ::RoundingMode{:Up}) = mod(x,-y)
-
 rem(x::Float64, y::Float64, ::RoundingMode{:Nearest}) =
     ccall((:remainder, libm),Float64,(Float64,Float64),x,y)
 rem(x::Float32, y::Float32, ::RoundingMode{:Nearest}) =
@@ -1045,6 +1068,12 @@ This function computes a floating point
 numerically exact `2π`, and is therefore not exactly the same as `mod(x,2π)`, which would
 compute the modulus of `x` relative to division by the floating-point number `2π`.
 
+!!! note
+    Depending on the format of the input value, the closest representable value to 2π may
+    be less than 2π. For example, the expression `mod2pi(2π)` will not return `0`, because
+    the intermediate value of `2*π` is a `Float64` and `2*Float64(π) < 2*big(π)`. See
+    [`rem2pi`](@ref) for more refined control of this behavior.
+
 # Examples
 ```jldoctest
 julia> mod2pi(9*pi/4)
diff -pruN 1.3.1+dfsg-1/base/methodshow.jl 1.4.0+dfsg-1/base/methodshow.jl
--- 1.3.1+dfsg-1/base/methodshow.jl	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/base/methodshow.jl	2020-03-21 16:36:32.000000000 +0000
@@ -73,23 +73,28 @@ end
 
 const empty_sym = Symbol("")
 
-function kwarg_decl(m::Method, kwtype::DataType)
-    sig = rewrap_unionall(Tuple{kwtype, Any, unwrap_unionall(m.sig).parameters...}, m.sig)
-    kwli = ccall(:jl_methtable_lookup, Any, (Any, Any, UInt), kwtype.name.mt, sig, get_world_counter())
-    if kwli !== nothing
-        kwli = kwli::Method
-        slotnames = ccall(:jl_uncompress_argnames, Vector{Any}, (Any,), kwli.slot_syms)
-        kws = filter(x -> !(x === empty_sym || '#' in string(x)), slotnames[(kwli.nargs + 1):end])
-        # ensure the kwarg... is always printed last. The order of the arguments are not
-        # necessarily the same as defined in the function
-        i = findfirst(x -> endswith(string(x), "..."), kws)
-        if i !== nothing
-            push!(kws, kws[i])
-            deleteat!(kws, i)
+# NOTE: second argument is deprecated and is no longer used
+function kwarg_decl(m::Method, kwtype = nothing)
+    mt = get_methodtable(m)
+    if isdefined(mt, :kwsorter)
+        kwtype = typeof(mt.kwsorter)
+        sig = rewrap_unionall(Tuple{kwtype, Any, unwrap_unionall(m.sig).parameters...}, m.sig)
+        kwli = ccall(:jl_methtable_lookup, Any, (Any, Any, UInt), kwtype.name.mt, sig, get_world_counter())
+        if kwli !== nothing
+            kwli = kwli::Method
+            slotnames = ccall(:jl_uncompress_argnames, Vector{Any}, (Any,), kwli.slot_syms)
+            kws = filter(x -> !(x === empty_sym || '#' in string(x)), slotnames[(kwli.nargs + 1):end])
+            # ensure the kwarg... is always printed last. The order of the arguments are not
+            # necessarily the same as defined in the function
+            i = findfirst(x -> endswith(string(x), "..."), kws)
+            if i !== nothing
+                push!(kws, kws[i])
+                deleteat!(kws, i)
+            end
+            return kws
         end
-        return kws
     end
-    return ()
+    return Any[]
 end
 
 function show_method_params(io::IO, tv)
@@ -115,8 +120,25 @@ end
 # In case the line numbers in the source code have changed since the code was compiled,
 # allow packages to set a callback function that corrects them.
 # (Used by Revise and perhaps other packages.)
-default_methodloc(method::Method) = method.file, method.line
-const methodloc_callback = Ref{Function}(default_methodloc)
+const methodloc_callback = Ref{Union{Function, Nothing}}(nothing)
+
+# This function does the method location updating
+function updated_methodloc(m::Method)::Tuple{String, Int32}
+    file, line = m.file, m.line
+    if methodloc_callback[] !== nothing
+        try
+            file, line = invokelatest(methodloc_callback[], m)
+        catch
+        end
+    end
+    # The file defining Base.Sys gets included after this file is included so make sure
+    # this function is valid even in this intermediary state
+    if isdefined(@__MODULE__, :Sys) && Sys.BUILD_STDLIB_PATH != Sys.STDLIB
+        # BUILD_STDLIB_PATH gets defined in sysinfo.jl
+        file = replace(string(file), normpath(Sys.BUILD_STDLIB_PATH) => normpath(Sys.STDLIB))
+    end
+    return string(file), line
+end
 
 functionloc(m::Core.MethodInstance) = functionloc(m.def)
 
@@ -126,7 +148,7 @@ functionloc(m::Core.MethodInstance) = fu
 Returns a tuple `(filename,line)` giving the location of a `Method` definition.
 """
 function functionloc(m::Method)
-    file, ln = invokelatest(methodloc_callback[], m)
+    file, ln = updated_methodloc(m)
     if ln <= 0
         error("could not determine location of method definition")
     end
@@ -155,7 +177,7 @@ function functionloc(@nospecialize(f))
     return functionloc(first(mt))
 end
 
-function show(io::IO, m::Method; kwtype::Union{DataType, Nothing}=nothing)
+function show(io::IO, m::Method)
     tv, decls, file, line = arg_decl_parts(m)
     sig = unwrap_unionall(m.sig)
     ft0 = sig.parameters[1]
@@ -184,21 +206,16 @@ function show(io::IO, m::Method; kwtype:
     print(io, "(")
     join(io, String[isempty(d[2]) ? d[1] : d[1]*"::"*d[2] for d in decls[2:end]],
                  ", ", ", ")
-    if kwtype !== nothing
-        kwargs = kwarg_decl(m, kwtype)
-        if !isempty(kwargs)
-            print(io, "; ")
-            join(io, kwargs, ", ", ", ")
-        end
+    kwargs = kwarg_decl(m)
+    if !isempty(kwargs)
+        print(io, "; ")
+        join(io, kwargs, ", ", ", ")
     end
     print(io, ")")
     show_method_params(io, tv)
     print(io, " in ", m.module)
     if line > 0
-        try
-            file, line = invokelatest(methodloc_callback[], m)
-        catch
-        end
+        file, line = updated_methodloc(m)
         print(io, " at ", file, ":", line)
     end
 end
@@ -237,7 +254,6 @@ function show_method_table(io::IO, ms::M
     if header
         show_method_list_header(io, ms, str -> "\""*str*"\"")
     end
-    kwtype = isdefined(mt, :kwsorter) ? typeof(mt.kwsorter) : nothing
     n = rest = 0
     local last
 
@@ -247,12 +263,8 @@ function show_method_table(io::IO, ms::M
             n += 1
             println(io)
             print(io, "[$n] ")
-            show(io, meth; kwtype=kwtype)
-            file, line = meth.file, meth.line
-            try
-                file, line = invokelatest(methodloc_callback[], meth)
-            catch
-            end
+            show(io, meth)
+            file, line = updated_methodloc(meth)
             push!(LAST_SHOWN_LINE_INFOS, (string(file), line))
         else
             rest += 1
@@ -262,7 +274,7 @@ function show_method_table(io::IO, ms::M
     if rest > 0
         println(io)
         if rest == 1
-            show(io, last; kwtype=kwtype)
+            show(io, last)
         else
             print(io, "... $rest methods not shown")
             if hasname
@@ -325,7 +337,7 @@ function url(m::Method)
     end
 end
 
-function show(io::IO, ::MIME"text/html", m::Method; kwtype::Union{DataType, Nothing}=nothing)
+function show(io::IO, ::MIME"text/html", m::Method)
     tv, decls, file, line = arg_decl_parts(m)
     sig = unwrap_unionall(m.sig)
     ft0 = sig.parameters[1]
@@ -353,13 +365,11 @@ function show(io::IO, ::MIME"text/html",
     print(io, "(")
     join(io, String[isempty(d[2]) ? d[1] : d[1]*"::<b>"*d[2]*"</b>"
                       for d in decls[2:end]], ", ", ", ")
-    if kwtype !== nothing
-        kwargs = kwarg_decl(m, kwtype)
-        if !isempty(kwargs)
-            print(io, "; <i>")
-            join(io, kwargs, ", ", ", ")
-            print(io, "</i>")
-        end
+    kwargs = kwarg_decl(m)
+    if !isempty(kwargs)
+        print(io, "; <i>")
+        join(io, kwargs, ", ", ", ")
+        print(io, "</i>")
     end
     print(io, ")")
     if !isempty(tv)
@@ -369,10 +379,7 @@ function show(io::IO, ::MIME"text/html",
     end
     print(io, " in ", m.module)
     if line > 0
-        try
-            file, line = invokelatest(methodloc_callback[], m)
-        catch
-        end
+        file, line = updated_methodloc(m)
         u = url(m)
         if isempty(u)
             print(io, " at ", file, ":", line)
@@ -386,11 +393,10 @@ end
 function show(io::IO, mime::MIME"text/html", ms::MethodList)
     mt = ms.mt
     show_method_list_header(io, ms, str -> "<b>"*str*"</b>")
-    kwtype = isdefined(mt, :kwsorter) ? typeof(mt.kwsorter) : nothing
     print(io, "<ul>")
     for meth in ms
         print(io, "<li> ")
-        show(io, mime, meth; kwtype=kwtype)
+        show(io, mime, meth)
         print(io, "</li> ")
     end
     print(io, "</ul>")
@@ -407,11 +413,7 @@ function show(io::IO, mime::MIME"text/pl
         first = false
         print(io, "[$(i)] ")
         show(io, m)
-        file, line = m.file, m.line
-        try
-            file, line = invokelatest(methodloc_callback[], m)
-        catch
-        end
+        file, line = updated_methodloc(m)
         push!(LAST_SHOWN_LINE_INFOS, (string(file), line))
     end
 end
diff -pruN 1.3.1+dfsg-1/base/missing.jl 1.4.0+dfsg-1/base/missing.jl
--- 1.3.1+dfsg-1/base/missing.jl	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/base/missing.jl	2020-03-21 16:36:32.000000000 +0000
@@ -108,7 +108,7 @@ for f in (:(Base.zero), :(Base.one), :(B
 end
 
 # Binary operators/functions
-for f in (:(+), :(-), :(*), :(/), :(^), :(div), :(mod), :(fld), :(rem))
+for f in (:(+), :(-), :(*), :(/), :(^), :(mod), :(rem))
     @eval begin
         # Scalar with missing
         ($f)(::Missing, ::Missing) = missing
@@ -117,6 +117,10 @@ for f in (:(+), :(-), :(*), :(/), :(^),
     end
 end
 
+div(::Missing, ::Missing, r::RoundingMode) = missing
+div(::Missing, ::Number, r::RoundingMode) = missing
+div(::Number, ::Missing, r::RoundingMode) = missing
+
 min(::Missing, ::Missing) = missing
 min(::Missing, ::Any)     = missing
 min(::Any,     ::Missing) = missing
@@ -383,6 +387,8 @@ end
 Return the first value in the arguments which is not equal to [`missing`](@ref),
 if any. Otherwise return `missing`.
 
+See also [`something`](@ref).
+
 # Examples
 
 ```jldoctest
diff -pruN 1.3.1+dfsg-1/base/mpfr.jl 1.4.0+dfsg-1/base/mpfr.jl
--- 1.3.1+dfsg-1/base/mpfr.jl	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/base/mpfr.jl	2020-03-21 16:36:32.000000000 +0000
@@ -109,6 +109,7 @@ mutable struct BigFloat <: AbstractFloat
     end
 
     function BigFloat(; precision::Integer=DEFAULT_PRECISION[])
+        precision < 1 && throw(DomainError(precision, "`precision` cannot be less than 1."))
         nb = ccall((:mpfr_custom_get_size,:libmpfr), Csize_t, (Clong,), precision)
         nb = (nb + Core.sizeof(Limb) - 1) ÷ Core.sizeof(Limb) # align to number of Limb allocations required for this
         #d = Vector{Limb}(undef, nb)
@@ -953,27 +954,21 @@ end
 setprecision(f::Function, prec::Integer) = setprecision(f, BigFloat, prec)
 
 function string_mpfr(x::BigFloat, fmt::String)
-    buf = Base.StringVector(0)
-    s = _calculate_buffer_size!(buf, fmt, x)
-    resize!(buf, s)
-    _fill_buffer!(buf, fmt, x)
-    String(buf)
-end
-
-function _calculate_buffer_size!(buf, fmt, x::BigFloat)
-    ccall((:mpfr_snprintf,:libmpfr),
-        Int32, (Ptr{UInt8}, Culong, Ptr{UInt8}, Ref{BigFloat}...),
-        buf, 0, fmt, x)
-end
-
-function _fill_buffer!(buf, fmt, x::BigFloat)
-    s = length(buf)
-    # we temporarily need one more item in buffer to capture null termination
-    resize!(buf, s + 1)
-    n = ccall((:mpfr_sprintf,:libmpfr), Int32, (Ptr{UInt8}, Ptr{UInt8}, Ref{BigFloat}...), buf, fmt, x)
-    @assert n + 1 == length(buf)
-    @assert last(buf) == 0x00
-    resize!(buf, s)
+    pc = Ref{Ptr{UInt8}}()
+    n = ccall((:mpfr_asprintf,:libmpfr), Cint,
+              (Ptr{Ptr{UInt8}}, Ptr{UInt8}, Ref{BigFloat}...),
+              pc, fmt, x)
+    p = pc[]
+    # convert comma decimal separator to dot
+    for i = 1:n
+        if unsafe_load(p, i) == UInt8(',')
+            unsafe_store!(p, '.', i)
+            break
+        end
+    end
+    str = unsafe_string(p)
+    ccall((:mpfr_free_str, :libmpfr), Cvoid, (Ptr{UInt8},), p)
+    return str
 end
 
 function _prettify_bigfloat(s::String)::String
@@ -1031,8 +1026,9 @@ get_emin() = ccall((:mpfr_get_emin, :lib
 get_emin_min() = ccall((:mpfr_get_emin_min, :libmpfr), Clong, ())
 get_emin_max() = ccall((:mpfr_get_emin_max, :libmpfr), Clong, ())
 
-set_emax!(x) = ccall((:mpfr_set_emax, :libmpfr), Cvoid, (Clong,), x)
-set_emin!(x) = ccall((:mpfr_set_emin, :libmpfr), Cvoid, (Clong,), x)
+check_exponent_err(ret) = ret == 0 || throw(ArgumentError("Invalid MPFR exponent range"))
+set_emax!(x) = check_exponent_err(ccall((:mpfr_set_emax, :libmpfr), Cint, (Clong,), x))
+set_emin!(x) = check_exponent_err(ccall((:mpfr_set_emin, :libmpfr), Cint, (Clong,), x))
 
 function Base.deepcopy_internal(x::BigFloat, stackdict::IdDict)
     haskey(stackdict, x) && return stackdict[x]
diff -pruN 1.3.1+dfsg-1/base/multidimensional.jl 1.4.0+dfsg-1/base/multidimensional.jl
--- 1.3.1+dfsg-1/base/multidimensional.jl	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/base/multidimensional.jl	2020-03-21 16:36:32.000000000 +0000
@@ -8,8 +8,9 @@ module IteratorsMD
 
     import .Base: +, -, *, (:)
     import .Base: simd_outer_range, simd_inner_length, simd_index
-    using .Base: IndexLinear, IndexCartesian, AbstractCartesianIndex, fill_to_length, tail
-    using .Base.Iterators: Reverse
+    using .Base: IndexLinear, IndexCartesian, AbstractCartesianIndex, fill_to_length, tail,
+        ReshapedArray, ReshapedArrayLF, OneTo
+    using .Base.Iterators: Reverse, PartitionIterator
 
     export CartesianIndex, CartesianIndices
 
@@ -156,6 +157,8 @@ module IteratorsMD
         return I
     end
 
+    Base._ind2sub(t::Tuple, ind::CartesianIndex) = Tuple(ind)
+
     # Iteration over the elements of CartesianIndex cannot be supported until its length can be inferred,
     # see #23719
     Base.iterate(::CartesianIndex) =
@@ -461,6 +464,60 @@ module IteratorsMD
     iterate(iter::Reverse{<:CartesianIndices{0}}, state=false) = state ? nothing : (CartesianIndex(), true)
 
     Base.LinearIndices(inds::CartesianIndices{N,R}) where {N,R} = LinearIndices{N,R}(inds.indices)
+
+    # Views of reshaped CartesianIndices are used for partitions — ensure these are fast
+    const CartesianPartition{T<:CartesianIndex, P<:CartesianIndices, R<:ReshapedArray{T,1,P}} = SubArray{T,1,R,Tuple{UnitRange{Int}},false}
+    eltype(::Type{PartitionIterator{T}}) where {T<:ReshapedArrayLF} = SubArray{eltype(T), 1, T, Tuple{UnitRange{Int}}, true}
+    eltype(::Type{PartitionIterator{T}}) where {T<:ReshapedArray} = SubArray{eltype(T), 1, T, Tuple{UnitRange{Int}}, false}
+    Iterators.IteratorEltype(::Type{<:PartitionIterator{T}}) where {T<:ReshapedArray} = Iterators.IteratorEltype(T)
+
+    eltype(::Type{PartitionIterator{T}}) where {T<:OneTo} = UnitRange{eltype(T)}
+    eltype(::Type{PartitionIterator{T}}) where {T<:Union{UnitRange, StepRange, StepRangeLen, LinRange}} = T
+    Iterators.IteratorEltype(::Type{<:PartitionIterator{T}}) where {T<:Union{OneTo, UnitRange, StepRange, StepRangeLen, LinRange}} = Iterators.IteratorEltype(T)
+
+
+    @inline function iterate(iter::CartesianPartition)
+        isempty(iter) && return nothing
+        f = first(iter)
+        return (f, (f, 1))
+    end
+    @inline function iterate(iter::CartesianPartition, (state, n))
+        n >= length(iter) && return nothing
+        I = IteratorsMD.inc(state.I, first(iter.parent.parent).I, last(iter.parent.parent).I)
+        return I, (I, n+1)
+    end
+
+    @inline function simd_outer_range(iter::CartesianPartition)
+        # In general, the Cartesian Partition might start and stop in the middle of the outer
+        # dimensions — thus the outer range of a CartesianPartition is itself a
+        # CartesianPartition.
+        t = tail(iter.parent.parent.indices)
+        ci = CartesianIndices(t)
+        li = LinearIndices(t)
+        return @inbounds view(ci, li[tail(iter[1].I)...]:li[tail(iter[end].I)...])
+    end
+    function simd_outer_range(iter::CartesianPartition{CartesianIndex{2}})
+        # But for two-dimensional Partitions the above is just a simple one-dimensional range
+        # over the second dimension; we don't need to worry about non-rectangular staggers in
+        # higher dimensions.
+        return @inbounds CartesianIndices((iter[1][2]:iter[end][2],))
+    end
+    @inline function simd_inner_length(iter::CartesianPartition, I::CartesianIndex)
+        inner = iter.parent.parent.indices[1]
+        @inbounds fi = iter[1].I
+        @inbounds li = iter[end].I
+        inner_start = I.I == tail(fi) ? fi[1] : first(inner)
+        inner_end   = I.I == tail(li) ? li[1] : last(inner)
+        return inner_end - inner_start + 1
+    end
+    @inline function simd_index(iter::CartesianPartition, Ilast::CartesianIndex, I1::Int)
+        # I1 is the 0-based distance from the first dimension's offest
+        offset = first(iter.parent.parent.indices[1]) # (this is 1 for 1-based arrays)
+        # In the first column we need to also add in the iter's starting point (branchlessly)
+        f = @inbounds iter[1]
+        startoffset = (Ilast.I == tail(f.I))*(f[1] - 1)
+        CartesianIndex((I1 + offset + startoffset, Ilast.I...))
+    end
 end  # IteratorsMD
 
 
@@ -898,7 +955,7 @@ julia> y
 """
 copyto!(dest, src)
 
-function copyto!(dest::AbstractArray{T,N}, src::AbstractArray{T,N}) where {T,N}
+function copyto!(dest::AbstractArray{T1,N}, src::AbstractArray{T2,N}) where {T1,T2,N}
     checkbounds(dest, axes(src)...)
     src′ = unalias(dest, src)
     for I in eachindex(IndexStyle(src′,dest), src′)
diff -pruN 1.3.1+dfsg-1/base/namedtuple.jl 1.4.0+dfsg-1/base/namedtuple.jl
--- 1.3.1+dfsg-1/base/namedtuple.jl	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/base/namedtuple.jl	2020-03-21 16:36:32.000000000 +0000
@@ -63,12 +63,6 @@ Core.NamedTuple
 
 if nameof(@__MODULE__) === :Base
 
-"""
-    NamedTuple{names,T}(args::Tuple)
-
-Construct a named tuple with the given `names` (a tuple of Symbols) and field types `T`
-(a `Tuple` type) from a tuple of values.
-"""
 @eval function NamedTuple{names,T}(args::Tuple) where {names, T <: Tuple}
     if length(args) != length(names::Tuple)
         throw(ArgumentError("Wrong number of arguments to named tuple constructor."))
@@ -78,12 +72,6 @@ Construct a named tuple with the given `
     $(Expr(:splatnew, :(NamedTuple{names,T}), :(T(args))))
 end
 
-"""
-    NamedTuple{names}(nt::NamedTuple)
-
-Construct a named tuple by selecting fields in `names` (a tuple of Symbols) from
-another named tuple.
-"""
 function NamedTuple{names}(nt::NamedTuple) where {names}
     if @generated
         types = Tuple{(fieldtype(nt, n) for n in names)...}
@@ -312,3 +300,27 @@ function structdiff(a::NamedTuple{an}, b
         NamedTuple{names,types}(map(n->getfield(a, n), names))
     end
 end
+
+"""
+    setindex(nt::NamedTuple, val, key::Symbol)
+
+Constructs a new `NamedTuple` with the key `key` set to `val`.
+If `key` is already in the keys of `nt`, `val` replaces the old value.
+
+```jldoctest
+julia> nt = (a = 3,)
+(a = 3,)
+
+julia> Base.setindex(nt, 33, :b)
+(a = 3, b = 33)
+
+julia> Base.setindex(nt, 4, :a)
+(a = 4,)
+
+julia> Base.setindex(nt, "a", :a)
+(a = "a",)
+```
+"""
+function setindex(nt::NamedTuple, v, idx::Symbol)
+    merge(nt, (; idx => v))
+end
diff -pruN 1.3.1+dfsg-1/base/number.jl 1.4.0+dfsg-1/base/number.jl
--- 1.3.1+dfsg-1/base/number.jl	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/base/number.jl	2020-03-21 16:36:32.000000000 +0000
@@ -88,30 +88,6 @@ last(x::Number) = x
 copy(x::Number) = x # some code treats numbers as collection-like
 
 """
-    divrem(x, y)
-
-The quotient and remainder from Euclidean division. Equivalent to `(div(x,y), rem(x,y))` or
-`(x÷y, x%y)`.
-
-# Examples
-```jldoctest
-julia> divrem(3,7)
-(0, 3)
-
-julia> divrem(7,3)
-(2, 1)
-```
-"""
-divrem(x,y) = (div(x,y),rem(x,y))
-
-"""
-    fldmod(x, y)
-
-The floored quotient and modulus after division. Equivalent to `(fld(x,y), mod(x,y))`.
-"""
-fldmod(x,y) = (fld(x,y),mod(x,y))
-
-"""
     signbit(x)
 
 Returns `true` if the value of the sign of `x` is negative, otherwise `false`.
diff -pruN 1.3.1+dfsg-1/base/operators.jl 1.4.0+dfsg-1/base/operators.jl
--- 1.3.1+dfsg-1/base/operators.jl	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/base/operators.jl	2020-03-21 16:36:32.000000000 +0000
@@ -682,40 +682,6 @@ function >>>(x::Integer, c::Unsigned)
 end
 >>>(x::Integer, c::Int) = c >= 0 ? x >>> unsigned(c) : x << unsigned(-c)
 
-# fallback div, fld, and cld implementations
-# NOTE: C89 fmod() and x87 FPREM implicitly provide truncating float division,
-# so it is used here as the basis of float div().
-div(x::T, y::T) where {T<:Real} = convert(T,round((x-rem(x,y))/y))
-
-"""
-    fld(x, y)
-
-Largest integer less than or equal to `x/y`.
-
-# Examples
-```jldoctest
-julia> fld(7.3,5.5)
-1.0
-```
-"""
-fld(x::T, y::T) where {T<:Real} = convert(T,round((x-mod(x,y))/y))
-
-"""
-    cld(x, y)
-
-Smallest integer larger than or equal to `x/y`.
-
-# Examples
-```jldoctest
-julia> cld(5.5,2.2)
-3.0
-```
-"""
-cld(x::T, y::T) where {T<:Real} = convert(T,round((x-modCeil(x,y))/y))
-#rem(x::T, y::T) where {T<:Real} = convert(T,x-y*trunc(x/y))
-#mod(x::T, y::T) where {T<:Real} = convert(T,x-y*floor(x/y))
-modCeil(x::T, y::T) where {T<:Real} = convert(T,x-y*ceil(x/y))
-
 # operator alias
 
 """
@@ -752,6 +718,9 @@ julia> 9 ÷ 4
 
 julia> -5 ÷ 3
 -1
+
+julia> 5.0 ÷ 2
+2.0
 ```
 """
 div
@@ -861,6 +830,13 @@ julia> [1:5;] |> x->x.^2 |> sum |> inv
 Compose functions: i.e. `(f ∘ g)(args...)` means `f(g(args...))`. The `∘` symbol can be
 entered in the Julia REPL (and most editors, appropriately configured) by typing `\\circ<tab>`.
 
+Function composition also works in prefix form: `∘(f, g)` is the same as `f ∘ g`.
+The prefix form supports composition of multiple functions: `∘(f, g, h) = f ∘ g ∘ h`
+and splatting `∘(fs...)` for composing an iterable collection of functions.
+
+!!! compat "Julia 1.4"
+    Multiple function composition requires at least Julia 1.4.
+
 # Examples
 ```jldoctest
 julia> map(uppercase∘first, ["apple", "banana", "carrot"])
@@ -868,10 +844,20 @@ julia> map(uppercase∘first, ["apple",
  'A'
  'B'
  'C'
+
+julia> fs = [
+           x -> 2x
+           x -> x/2
+           x -> x-1
+           x -> x+1
+       ];
+
+julia> ∘(fs...)(3)
+3.0
 ```
 """
 ∘(f, g) = (x...)->f(g(x...))
-
+∘(f, g, h...) = ∘(f ∘ g, h...)
 
 """
     !f::Function
diff -pruN 1.3.1+dfsg-1/base/ordering.jl 1.4.0+dfsg-1/base/ordering.jl
--- 1.3.1+dfsg-1/base/ordering.jl	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/base/ordering.jl	2020-03-21 16:36:32.000000000 +0000
@@ -27,11 +27,12 @@ end
 
 ReverseOrdering(rev::ReverseOrdering) = rev.fwd
 ReverseOrdering(fwd::Fwd) where {Fwd} = ReverseOrdering{Fwd}(fwd)
+ReverseOrdering() = ReverseOrdering(ForwardOrdering())
 
 const DirectOrdering = Union{ForwardOrdering,ReverseOrdering{ForwardOrdering}}
 
 const Forward = ForwardOrdering()
-const Reverse = ReverseOrdering(Forward)
+const Reverse = ReverseOrdering()
 
 struct By{T} <: Ordering
     by::T
diff -pruN 1.3.1+dfsg-1/base/path.jl 1.4.0+dfsg-1/base/path.jl
--- 1.3.1+dfsg-1/base/path.jl	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/base/path.jl	2020-03-21 16:36:32.000000000 +0000
@@ -52,7 +52,7 @@ first component is always the empty stri
 splitdrive(path::AbstractString)
 
 """
-    homedir() -> AbstractString
+    homedir() -> String
 
 Return the current user's home directory.
 
@@ -79,9 +79,9 @@ end
 
 
 if Sys.iswindows()
-    isabspath(path::String) = occursin(path_absolute_re, path)
+    isabspath(path::AbstractString) = occursin(path_absolute_re, path)
 else
-    isabspath(path::String) = startswith(path, '/')
+    isabspath(path::AbstractString) = startswith(path, '/')
 end
 
 """
@@ -198,13 +198,8 @@ function splitext(path::String)
     a*m.captures[1], String(m.captures[2])
 end
 
-function pathsep(paths::AbstractString...)
-    for path in paths
-        m = match(path_separator_re, String(path))
-        m !== nothing && return m.match[1:1]
-    end
-    return path_separator
-end
+# NOTE: deprecated in 1.4
+pathsep() = path_separator
 
 """
     splitpath(path::AbstractString) -> Vector{String}
@@ -226,6 +221,8 @@ julia> splitpath("/home/myuser/example.j
  "example.jl"
 ```
 """
+splitpath(p::AbstractString) = splitpath(String(p))
+
 function splitpath(p::String)
     drive, p = splitdrive(p)
     out = String[]
@@ -244,37 +241,88 @@ function splitpath(p::String)
     return out
 end
 
-joinpath(a::AbstractString) = a
+joinpath(path::AbstractString)::String = path
+
+if Sys.iswindows()
+
+function joinpath(path::AbstractString, paths::AbstractString...)::String
+    result_drive, result_path = splitdrive(path)
+
+    local p_drive, p_path
+    for p in paths
+        p_drive, p_path = splitdrive(p)
+
+        if startswith(p_path, ('\\', '/'))
+            # second path is absolute
+            if !isempty(p_drive) || !isempty(result_drive)
+                result_drive = p_drive
+            end
+            result_path = p_path
+            continue
+        elseif !isempty(p_drive) && p_drive != result_drive
+            if lowercase(p_drive) != lowercase(result_drive)
+                # different drives, ignore the first path entirely
+                result_drive = p_drive
+                result_path = p_path
+                continue
+            end
+        end
+
+        # second path is relative to the first
+        if !isempty(result_path) && result_path[end] ∉ ('\\', '/')
+            result_path *= "\\"
+        end
+
+        result_path = result_path * p_path
+    end
+
+    # add separator between UNC and non-absolute path
+    if !isempty(p_path) && result_path[1] ∉ ('\\', '/') && !isempty(result_drive) && result_drive[end] != ':'
+        return result_drive * "\\" * result_path
+    end
+
+    return result_drive * result_path
+end
+
+else
+
+function joinpath(path::AbstractString, paths::AbstractString...)::String
+    for p in paths
+        if isabspath(p)
+            path = p
+        elseif isempty(path) || path[end] == '/'
+            path *= p
+        else
+            path *= "/" * p
+        end
+    end
+    return path
+end
+
+end # os-test
 
 """
-    joinpath(parts...) -> AbstractString
+    joinpath(parts::AbstractString...) -> String
 
 Join path components into a full path. If some argument is an absolute path or
 (on Windows) has a drive specification that doesn't match the drive computed for
 the join of the preceding paths, then prior components are dropped.
 
+Note on Windows since there is a current directory for each drive, `joinpath("c:", "foo")`
+represents a path relative to the current directory on drive "c:" so this is equal to "c:foo",
+not "c:\\foo". Furthermore, `joinpath` treats this as a non-absolute path and ignores the drive
+letter casing, hence `joinpath("C:\\A","c:b") = "C:\\A\\b"`.
+
 # Examples
 ```jldoctest
 julia> joinpath("/home/myuser", "example.jl")
 "/home/myuser/example.jl"
 ```
 """
-joinpath(a::AbstractString, b::AbstractString, c::AbstractString...) = joinpath(joinpath(a,b), c...)
-
-function joinpath(a::String, b::String)
-    isabspath(b) && return b
-    A, a = splitdrive(a)
-    B, b = splitdrive(b)
-    !isempty(B) && A != B && return string(B,b)
-    C = isempty(B) ? A : B
-    isempty(a)                              ? string(C,b) :
-    occursin(path_separator_re, a[end:end]) ? string(C,a,b) :
-                                              string(C,a,pathsep(a,b),b)
-end
-joinpath(a::AbstractString, b::AbstractString) = joinpath(String(a), String(b))
+joinpath
 
 """
-    normpath(path::AbstractString) -> AbstractString
+    normpath(path::AbstractString) -> String
 
 Normalize a path, removing "." and ".." entries.
 
@@ -317,10 +365,17 @@ function normpath(path::String)
     end
     string(drive,path)
 end
+
+"""
+    normpath(path::AbstractString, paths::AbstractString...) -> String
+
+Convert a set of paths to a normalized path by joining them together and removing
+"." and ".." entries. Equivalent to `normpath(joinpath(path, paths...))`.
+"""
 normpath(a::AbstractString, b::AbstractString...) = normpath(joinpath(a,b...))
 
 """
-    abspath(path::AbstractString) -> AbstractString
+    abspath(path::AbstractString) -> String
 
 Convert a path to an absolute path by adding the current directory if necessary.
 Also normalizes the path as in [`normpath`](@ref).
@@ -328,7 +383,7 @@ Also normalizes the path as in [`normpat
 abspath(a::String) = normpath(isabspath(a) ? a : joinpath(pwd(),a))
 
 """
-    abspath(path::AbstractString, paths::AbstractString...) -> AbstractString
+    abspath(path::AbstractString, paths::AbstractString...) -> String
 
 Convert a set of paths to an absolute path by joining them together and adding the
 current directory if necessary. Equivalent to `abspath(joinpath(path, paths...))`.
@@ -355,7 +410,7 @@ end # os-test
 
 
 """
-    realpath(path::AbstractString) -> AbstractString
+    realpath(path::AbstractString) -> String
 
 Canonicalize a path by expanding symbolic links and removing "." and ".." entries.
 On case-insensitive case-preserving filesystems (typically Mac and Windows), the
@@ -462,6 +517,6 @@ end
 relpath(path::AbstractString, startpath::AbstractString) =
     relpath(String(path), String(startpath))
 
-for f in (:isabspath, :isdirpath, :splitdir, :splitdrive, :splitext, :normpath, :abspath)
+for f in (:isdirpath, :splitdir, :splitdrive, :splitext, :normpath, :abspath)
     @eval $f(path::AbstractString) = $f(String(path))
 end
diff -pruN 1.3.1+dfsg-1/base/pointer.jl 1.4.0+dfsg-1/base/pointer.jl
--- 1.3.1+dfsg-1/base/pointer.jl	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/base/pointer.jl	2020-03-21 16:36:32.000000000 +0000
@@ -159,3 +159,6 @@ isless(x::Ptr{T}, y::Ptr{T}) where {T} =
 +(x::Ptr, y::Integer) = oftype(x, add_ptr(UInt(x), (y % UInt) % UInt))
 -(x::Ptr, y::Integer) = oftype(x, sub_ptr(UInt(x), (y % UInt) % UInt))
 +(x::Integer, y::Ptr) = y + x
+
+unsigned(x::Ptr) = UInt(x)
+signed(x::Ptr) = Int(x)
diff -pruN 1.3.1+dfsg-1/base/printf.jl 1.4.0+dfsg-1/base/printf.jl
--- 1.3.1+dfsg-1/base/printf.jl	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/base/printf.jl	1970-01-01 00:00:00.000000000 +0000
@@ -1,1254 +0,0 @@
-# This file is a part of Julia. License is MIT: https://julialang.org/license
-
-module Printf
-using .Base.Grisu
-using .Base.GMP
-
-### printf formatter generation ###
-const SmallFloatingPoint = Union{Float64,Float32,Float16}
-const SmallNumber = Union{SmallFloatingPoint,Base.BitInteger}
-
-function gen(s::AbstractString)
-    args = []
-    blk = Expr(:block, :(local neg, pt, len, exp, do_out, args, buf))
-    gotbuf = false
-    for x in parse(s)
-        if isa(x,AbstractString)
-            push!(blk.args, :(print(out, $(length(x)==1 ? x[1] : x))))
-        else
-            c = lowercase(x[end])
-            f = c=='f' ? gen_f :
-                c=='e' ? gen_e :
-                c=='a' ? gen_a :
-                c=='g' ? gen_g :
-                c=='c' ? gen_c :
-                c=='s' ? gen_s :
-                c=='p' ? gen_p :
-                         gen_d
-            if !gotbuf && c != 'c' && c != 's' && c != 'p'
-                push!(blk.args, :(buf = $Grisu.getbuf()))
-                gotbuf = true
-            end
-            arg, ex = f(x...)
-            push!(args, arg)
-            push!(blk.args, ex)
-        end
-    end
-    push!(blk.args, :nothing)
-    return args, blk
-end
-
-### printf format string parsing ###
-
-function parse(s::AbstractString)
-    # parse format string into strings and format tuples
-    list = []
-    a = Iterators.Stateful(pairs(s))
-    lastparse = firstindex(s)
-    lastidx = 0 # invariant: lastidx == prevind(s, idx)
-    for (idx, c) in a
-        if c == '%'
-            lastparse > lastidx || push!(list, s[lastparse:lastidx])
-            flags, width, precision, conversion = parse1!(s,  a)
-            '\'' in flags && error("printf format flag ' not yet supported")
-            conversion == 'n'    && error("printf feature %n not supported")
-            push!(list, conversion == '%' ? "%" : (flags,width,precision,conversion))
-            lastparse = isempty(a) ? lastindex(s)+1 : Base.peek(a)[1]
-        end
-        lastidx = idx
-    end
-    lastparse > lastindex(s) || push!(list, s[lastparse:end])
-    # coalesce adjacent strings
-    i = j = 1
-    while i < length(list)
-        if isa(list[i],AbstractString)
-            for outer j = i+1:length(list)
-                if !isa(list[j],AbstractString)
-                    j -= 1
-                    break
-                end
-                list[i] *= list[j]
-            end
-            deleteat!(list,i+1:j)
-        end
-        i += 1
-    end
-    return list
-end
-
-## parse a single printf specifier ##
-
-# printf specifiers:
-#   %                       # start
-#   (\d+\$)?                # arg (not supported)
-#   [\-\+#0' ]*             # flags
-#   (\d+)?                  # width
-#   (\.\d*)?                # precision
-#   (h|hh|l|ll|L|j|t|z|q)?  # modifier (ignored)
-#   [diouxXeEfFgGaAcCsSp%]  # conversion
-
-pop_or_die!(s, a) = !isempty(a) ? popfirst!(a) :
-    throw(ArgumentError("invalid printf format string: $(repr(s))"))
-
-function parse1!(s, a)
-    width = 0
-    precision = -1
-    k, c = pop_or_die!(s, a)
-    j = k
-    # handle %%
-    if c == '%'
-        return "", width, precision, c
-    end
-    # parse flags
-    while c in "#0- + '"
-        k, c = pop_or_die!(s, a)
-    end
-    flags = String(s[j:k-1]) # All flags are 1 byte
-    # parse width
-    while '0' <= c <= '9'
-        width = 10*width + c-'0'
-        _, c = pop_or_die!(s, a)
-    end
-    # parse precision
-    if c == '.'
-        _, c = pop_or_die!(s, a)
-        if '0' <= c <= '9'
-            precision = 0
-            while '0' <= c <= '9'
-                precision = 10*precision + c-'0'
-                _, c = pop_or_die!(s, a)
-            end
-        end
-    end
-    # parse length modifer (ignored)
-    if c == 'h' || c == 'l'
-        prev = c
-        _, c = pop_or_die!(s, a)
-        if c == prev
-            _, c = pop_or_die!(s, a)
-        end
-    elseif c in "Ljqtz"
-        _, c = pop_or_die!(s, a)
-    end
-    # validate conversion
-    if !(c in "diouxXDOUeEfFgGaAcCsSpn")
-        throw(ArgumentError("invalid printf format string: $(repr(s))"))
-    end
-    # TODO: warn about silly flag/conversion combinations
-    flags, width, precision, c
-end
-
-### printf formatter generation ###
-
-function special_handler(flags::String, width::Int)
-    @gensym x
-    blk = Expr(:block)
-    pad = '-' in flags ? rpad : lpad
-    pos = '+' in flags ? "+" :
-          ' ' in flags ? " " : ""
-    abn = quote
-        isnan($x) ? $(pad("NaN", width)) :
-         $x < 0   ? $(pad("-Inf", width)) :
-                    $(pad("$(pos)Inf", width))
-    end
-    ex = :(isfinite($x) ? $blk : print(out, $abn))
-    x, ex, blk
-end
-
-function pad(m::Int, n, c::Char)
-    if m <= 1
-        :($n > 0 && print(out,$c))
-    else
-        @gensym i
-        quote
-            $i = $n
-            while $i > 0
-                print(out,$c)
-                $i -= 1
-            end
-        end
-    end
-end
-
-function dynamic_pad(m, val, c::Char)
-    @gensym i
-    quote
-        if $m <= 1
-            $val > 0 && print(out,$c)
-        else
-            $i = $val
-            while $i > 0
-                print(out,$c)
-                $i -= 1
-            end
-        end
-    end
-end
-
-# returns the number of (ASCII) chars output by print_fixed
-function print_fixed_width(precision, pt, ndigits, trailingzeros=true)
-    count = 0
-    if pt <= 0
-        # 0.0dddd0
-        count += 2
-        precision += pt
-        if pt < 0
-            count -= pt
-        end
-        count += ndigits
-        precision -= ndigits
-    elseif ndigits <= pt
-        # dddd000.000000
-        count += ndigits
-        if ndigits < pt
-            count += pt - ndigits
-        end
-        count += trailingzeros
-    else # 0 < pt < ndigits
-        # dd.dd0000
-        ndigits -= pt
-        count += pt + 1 + ndigits
-        precision -= ndigits
-    end
-    if trailingzeros && precision > 0
-        count += precision
-    end
-    return count
-end
-
-# note: if print_fixed is changed, print_fixed_width should be changed accordingly
-function print_fixed(out, precision, pt, ndigits, trailingzeros=true, buf = Grisu.getbuf())
-    pdigits = pointer(buf)
-    if pt <= 0
-        # 0.0dddd0
-        print(out, '0')
-        print(out, '.')
-        precision += pt
-        while pt < 0
-            print(out, '0')
-            pt += 1
-        end
-        unsafe_write(out, pdigits, ndigits)
-        precision -= ndigits
-    elseif ndigits <= pt
-        # dddd000.000000
-        unsafe_write(out, pdigits, ndigits)
-        while ndigits < pt
-            print(out, '0')
-            ndigits += 1
-        end
-        if trailingzeros
-            print(out, '.')
-        end
-    else # 0 < pt < ndigits
-        # dd.dd0000
-        ndigits -= pt
-        unsafe_write(out, pdigits, pt)
-        print(out, '.')
-        unsafe_write(out, pdigits+pt, ndigits)
-        precision -= ndigits
-    end
-    if trailingzeros
-        while precision > 0
-            print(out, '0')
-            precision -= 1
-        end
-    end
-end
-
-function print_exp_e(out, exp::Integer)
-    print(out, exp < 0 ? '-' : '+')
-    exp = abs(exp)
-    d = div(exp,100)
-    if d > 0
-        if d >= 10
-            print(out, exp)
-            return
-        end
-        print(out, Char('0'+d))
-    end
-    exp = rem(exp,100)
-    print(out, Char('0'+div(exp,10)))
-    print(out, Char('0'+rem(exp,10)))
-end
-
-function print_exp_a(out, exp::Integer)
-    print(out, exp < 0 ? '-' : '+')
-    exp = abs(exp)
-    print(out, exp)
-end
-
-
-function gen_d(flags::String, width::Int, precision::Int, c::Char)
-    # print integer:
-    #  [dDiu]: print decimal digits
-    #  [o]:    print octal digits
-    #  [x]:    print hex digits, lowercase
-    #  [X]:    print hex digits, uppercase
-    #
-    # flags:
-    #  (#): prefix hex with 0x/0X; octal leads with 0
-    #  (0): pad left with zeros
-    #  (-): left justify
-    #  ( ): precede non-negative values with " "
-    #  (+): precede non-negative values with "+"
-    #
-    x, ex, blk = special_handler(flags,width)
-    # interpret the number
-    prefix = ""
-    if lowercase(c)=='o'
-        fn = '#' in flags ? :decode_0ct : :decode_oct
-    elseif c=='x'
-        '#' in flags && (prefix = "0x")
-        fn = :decode_hex
-    elseif c=='X'
-        '#' in flags && (prefix = "0X")
-        fn = :decode_HEX
-    else
-        fn = :decode_dec
-    end
-    push!(blk.args, :((do_out, args) = $fn(out, $x, $flags, $width, $precision, $c, buf)))
-    ifblk = Expr(:if, :do_out, Expr(:block))
-    push!(blk.args, ifblk)
-    blk = ifblk.args[2]
-    push!(blk.args, :((len, pt, neg) = args))
-    # calculate padding
-    width -= length(prefix)
-    space_pad = width > max(1,precision) && '-' in flags ||
-                precision < 0 && width > 1 && !('0' in flags) ||
-                precision >= 0 && width > precision
-    padding = nothing
-    if precision < 1; precision = 1; end
-    if space_pad
-        if '+' in flags || ' ' in flags
-            width -= 1
-            if width > precision
-                padding = :($width-(pt > $precision ? pt : $precision))
-            end
-        else
-            if width > precision
-                padding = :($width-neg-(pt > $precision ? pt : $precision))
-            end
-        end
-    end
-    # print space padding
-    if padding !== nothing && !('-' in flags)
-        push!(blk.args, pad(width-precision, padding, ' '))
-    end
-    # print sign
-    '+' in flags ? push!(blk.args, :(print(out, neg ? '-' : '+'))) :
-    ' ' in flags ? push!(blk.args, :(print(out, neg ? '-' : ' '))) :
-                   push!(blk.args, :(neg && print(out, '-')))
-    # print prefix
-    for ch in prefix
-        push!(blk.args, :(print(out, $ch)))
-    end
-    # print zero padding & leading zeros
-    if space_pad && precision > 1
-        push!(blk.args, pad(precision-1, :($precision-pt), '0'))
-    elseif !space_pad && width > 1
-        zeros = '+' in flags || ' ' in flags ? :($(width-1)-pt) : :($width-neg-pt)
-        push!(blk.args, pad(width-1, zeros, '0'))
-    end
-    # print integer
-    push!(blk.args, :(unsafe_write(out, pointer(buf), pt)))
-    # print padding
-    if padding !== nothing && '-' in flags
-        push!(blk.args, pad(width-precision, padding, ' '))
-    end
-    # return arg, expr
-    :(($x)::Real), ex
-end
-
-function gen_f(flags::String, width::Int, precision::Int, c::Char)
-    # print to fixed trailing precision
-    #  [fF]: the only choice
-    #
-    # flags
-    #  (#): always print a decimal point
-    #  (0): pad left with zeros
-    #  (-): left justify
-    #  ( ): precede non-negative values with " "
-    #  (+): precede non-negative values with "+"
-    #
-    x, ex, blk = special_handler(flags,width)
-    # interpret the number
-    if precision < 0; precision = 6; end
-    push!(blk.args, :((do_out, args) = fix_dec(out, $x, $flags, $width, $precision, $c, buf)))
-    ifblk = Expr(:if, :do_out, Expr(:block))
-    push!(blk.args, ifblk)
-    blk = ifblk.args[2]
-    push!(blk.args, :((len, pt, neg) = args))
-    # calculate padding
-    padding = nothing
-    if precision > 0 || '#' in flags
-        width -= precision+1
-    end
-    if '+' in flags || ' ' in flags
-        width -= 1
-        if width > 1
-            padding = :($width-(pt > 0 ? pt : 1))
-        end
-    else
-        if width > 1
-            padding = :($width-(pt > 0 ? pt : 1)-neg)
-        end
-    end
-    # print space padding
-    if padding !== nothing && !('-' in flags) && !('0' in flags)
-        push!(blk.args, pad(width-1, padding, ' '))
-    end
-    # print sign
-    '+' in flags ? push!(blk.args, :(print(out, neg ? '-' : '+'))) :
-    ' ' in flags ? push!(blk.args, :(print(out, neg ? '-' : ' '))) :
-                   push!(blk.args, :(neg && print(out, '-')))
-    # print zero padding
-    if padding !== nothing && !('-' in flags) && '0' in flags
-        push!(blk.args, pad(width-1, padding, '0'))
-    end
-    # print digits
-    if precision > 0
-        push!(blk.args, :(print_fixed(out,$precision,pt,len,true,buf)))
-    else
-        push!(blk.args, :(unsafe_write(out, pointer(buf), len)))
-        push!(blk.args, :(while pt >= (len+=1) print(out,'0') end))
-        '#' in flags && push!(blk.args, :(print(out, '.')))
-    end
-    # print space padding
-    if padding !== nothing && '-' in flags
-        push!(blk.args, pad(width-1, padding, ' '))
-    end
-    # return arg, expr
-    :(($x)::Real), ex
-end
-
-function gen_e(flags::String, width::Int, precision::Int, c::Char, inside_g::Bool=false)
-    # print float in scientific form:
-    #  [e]: use 'e' to introduce exponent
-    #  [E]: use 'E' to introduce exponent
-    #
-    # flags:
-    #  (#): always print a decimal point
-    #  (0): pad left with zeros
-    #  (-): left justify
-    #  ( ): precede non-negative values with " "
-    #  (+): precede non-negative values with "+"
-    #
-    x, ex, blk = if inside_g
-        @gensym x
-        blk = Expr(:block)
-        x, blk, blk
-    else
-        special_handler(flags,width)
-    end
-    # interpret the number
-    if precision < 0; precision = 6; end
-    ndigits = min(precision+1,length(Grisu.getbuf())-1)
-    push!(blk.args, :((do_out, args) = ini_dec(out,$x,$ndigits, $flags, $width, $precision, $c, buf)))
-    push!(blk.args, :(digits = buf))
-    ifblk = Expr(:if, :do_out, Expr(:block))
-    push!(blk.args, ifblk)
-    blk = ifblk.args[2]
-    push!(blk.args, :((len, pt, neg) = args))
-    push!(blk.args, :(exp = pt-1))
-    expmark = isuppercase(c) ? "E" : "e"
-    if precision==0 && '#' in flags
-        expmark = string(".",expmark)
-    end
-    # calculate padding
-    padding = nothing
-    width -= precision+length(expmark)+(precision>0)+4
-    # 4 = leading + expsign + 2 exp digits
-    if '+' in flags || ' ' in flags
-        width -= 1 # for the sign indicator
-        if width > 0
-            padding = quote
-                padn=$width
-                if (exp<=-100)|(100<=exp)
-                    if isa($x,SmallNumber)
-                        padn -= 1
-                    else
-                        padn -= Base.ndigits0z(exp) - 2
-                    end
-                end
-                padn
-            end
-        end
-    else
-        if width > 0
-            padding = quote
-                padn=$width-neg
-                if (exp<=-100)|(100<=exp)
-                    if isa($x,SmallNumber)
-                        padn -= 1
-                    else
-                        padn -= Base.ndigits0z(exp) - 2
-                    end
-                end
-                padn
-            end
-        end
-    end
-    # print space padding
-    if padding !== nothing && !('-' in flags) && !('0' in flags)
-        push!(blk.args, pad(width, padding, ' '))
-    end
-    # print sign
-    '+' in flags ? push!(blk.args, :(print(out, neg ? '-' : '+'))) :
-    ' ' in flags ? push!(blk.args, :(print(out, neg ? '-' : ' '))) :
-                   push!(blk.args, :(neg && print(out, '-')))
-    # print zero padding
-    if padding !== nothing && !('-' in flags) && '0' in flags
-        push!(blk.args, pad(width, padding, '0'))
-    end
-    # print digits
-    push!(blk.args, :(write(out, digits[1])))
-    if precision > 0
-        if inside_g && !('#' in flags)
-            push!(blk.args, :(endidx = $ndigits;
-                              while endidx > 1 && digits[endidx] == UInt8('0')
-                                  endidx -= 1
-                              end;
-                              if endidx > 1
-                                  print(out, '.')
-                                  unsafe_write(out, pointer(digits)+1, endidx-1)
-                              end
-                              ))
-        else
-            push!(blk.args, :(print(out, '.')))
-            push!(blk.args, :(unsafe_write(out, pointer(digits)+1, $(ndigits-1))))
-            if ndigits < precision+1
-                n = precision+1-ndigits
-                push!(blk.args, pad(n, n, '0'))
-            end
-        end
-    end
-    for ch in expmark
-        push!(blk.args, :(print(out, $ch)))
-    end
-    push!(blk.args, :(print_exp_e(out, exp)))
-    # print space padding
-    if padding !== nothing && '-' in flags
-        push!(blk.args, pad(width, padding, ' '))
-    end
-    # return arg, expr
-    :(($x)::Real), ex
-end
-
-function gen_a(flags::String, width::Int, precision::Int, c::Char)
-    # print float in hexadecimal format
-    #  [a]: lowercase hex float, e.g. -0x1.cfp-2
-    #  [A]: uppercase hex float, e.g. -0X1.CFP-2
-    #
-    # flags:
-    #  (#): always print a decimal point
-    #  (0): pad left with zeros
-    #  (-): left justify
-    #  ( ): precede non-negative values with " "
-    #  (+): precede non-negative values with "+"
-    #
-    x, ex, blk = special_handler(flags,width)
-    if c == 'A'
-        hexmark, expmark = "0X", "P"
-        fn = :ini_HEX
-    else
-        hexmark, expmark = "0x", "p"
-        fn = :ini_hex
-    end
-    # if no precision, print max non-zero
-    if precision < 0
-        push!(blk.args, :((do_out, args) = $fn(out,$x, $flags, $width, $precision, $c, buf)))
-    else
-        ndigits = min(precision+1,length(Grisu.getbuf())-1)
-        push!(blk.args, :((do_out, args) = $fn(out,$x,$ndigits, $flags, $width, $precision, $c, buf)))
-    end
-    push!(blk.args, :(digits = buf))
-    ifblk = Expr(:if, :do_out, Expr(:block))
-    push!(blk.args, ifblk)
-    blk = ifblk.args[2]
-    push!(blk.args, :((len, exp, neg) = args))
-    if precision==0 && '#' in flags
-        expmark = string(".",expmark)
-    end
-    # calculate padding
-    padding = nothing
-    if precision > 0
-        width -= precision+length(hexmark)+length(expmark)+4
-        # 4 = leading + expsign + 1 exp digit + decimal
-    else
-        width -= length(hexmark)+length(expmark)+3+(precision<0 && '#' in flags)
-        # 3 = leading + expsign + 1 exp digit
-    end
-    if '+' in flags || ' ' in flags
-        width -= 1 # for the sign indicator
-        if width > 0
-            padding = :($(width+1) - Base.ndigits(exp))
-        end
-    else
-        if width > 0
-            padding = :($(width+1) - neg - Base.ndigits(exp))
-        end
-    end
-    if precision < 0 && width > 0
-        if '#' in flags
-            padding = :($padding - (len-1))
-        else
-            padding = :($padding - (len>1 ? len : 0))
-        end
-    end
-    # print space padding
-    if padding !== nothing && !('-' in flags) && !('0' in flags)
-        push!(blk.args, pad(width, padding, ' '))
-    end
-    # print sign
-    '+' in flags ? push!(blk.args, :(print(out, neg ? '-' : '+'))) :
-    ' ' in flags ? push!(blk.args, :(print(out, neg ? '-' : ' '))) :
-                    push!(blk.args, :(neg && print(out, '-')))
-    # hex prefix
-    for ch in hexmark
-        push!(blk.args, :(print(out, $ch)))
-    end
-    # print zero padding
-    if padding !== nothing && !('-' in flags) && '0' in flags
-        push!(blk.args, pad(width, padding, '0'))
-    end
-    # print digits: assumes ASCII/UTF8 encoding of digits is okay for `out`
-    push!(blk.args, :(write(out, digits[1])))
-    if precision > 0
-        push!(blk.args, :(print(out, '.')))
-        push!(blk.args, :(unsafe_write(out, pointer(digits)+1, $(ndigits-1))))
-        if ndigits < precision+1
-            n = precision+1-ndigits
-            push!(blk.args, pad(n, n, '0'))
-        end
-    elseif precision < 0
-        ifvpblk = Expr(:if, :(len > 1), Expr(:block))
-        vpblk = ifvpblk.args[2]
-        if '#' in flags
-            push!(blk.args, :(print(out, '.')))
-        else
-            push!(vpblk.args, :(print(out, '.')))
-        end
-        push!(vpblk.args, :(unsafe_write(out, pointer(digits)+1, len-1)))
-        push!(blk.args, ifvpblk)
-    end
-    for ch in expmark
-        push!(blk.args, :(print(out, $ch)))
-    end
-    push!(blk.args, :(print_exp_a(out, exp)))
-    # print space padding
-    if padding !== nothing && '-' in flags
-        push!(blk.args, pad(width, padding, ' '))
-    end
-    # return arg, expr
-    :(($x)::Real), ex
-end
-
-function gen_c(flags::String, width::Int, precision::Int, c::Char)
-    # print a character:
-    #  [cC]: both the same for us (Unicode)
-    #
-    # flags:
-    #  (0): pad left with zeros
-    #  (-): left justify
-    #
-    @gensym x
-    blk = Expr(:block, :($x = Char($x)))
-    if width > 1 && !('-' in flags)
-        p = '0' in flags ? '0' : ' '
-        push!(blk.args, pad(width-1, :($width-textwidth($x)), p))
-    end
-    push!(blk.args, :(print(out, $x)))
-    if width > 1 && '-' in flags
-        push!(blk.args, pad(width-1, :($width-textwidth($x)), ' '))
-    end
-    :(($x)::Integer), blk
-end
-
-function _limit(s, prec)
-    prec >= sizeof(s) && return s
-    p = prevind(s, prec+1)
-    n = nextind(s, p)-1
-    s[1:(prec>=n ? n : prevind(s,p))]
-end
-
-function gen_s(flags::String, width::Int, precision::Int, c::Char)
-    # print a string:
-    #  [sS]: both the same for us (Unicode)
-    #
-    # flags:
-    #  (-): left justify
-    #  (#): use `show`/`repr` instead of `print`/`string`
-    #
-    @gensym x
-    blk = Expr(:block)
-    if width > 0
-        if !('#' in flags)
-            push!(blk.args, :($x = string($x)))
-        else
-            push!(blk.args, :($x = repr($x)))
-        end
-        if precision!=-1
-            push!(blk.args, :($x = _limit($x, $precision)))
-        end
-        if !('-' in flags)
-            push!(blk.args, pad(width, :($width-textwidth($x)), ' '))
-        end
-        push!(blk.args, :(print(out, $x)))
-        if '-' in flags
-            push!(blk.args, pad(width, :($width-textwidth($x)), ' '))
-        end
-    else
-        if precision!=-1
-            push!(blk.args, :(io = IOBuffer()))
-        else
-            push!(blk.args, :(io = out))
-        end
-        if !('#' in flags)
-            push!(blk.args, :(print(io, $x)))
-        else
-            push!(blk.args, :(show(io, $x)))
-        end
-        if precision!=-1
-            push!(blk.args, :(print(out, _limit(String(take!(io)), $precision))))
-        end
-    end
-    :(($x)::Any), blk
-end
-
-# TODO: faster pointer printing.
-
-function gen_p(flags::String, width::Int, precision::Int, c::Char)
-    # print pointer:
-    #  [p]: the only option
-    #
-    # flags:
-    #  (-): left justify
-    #
-    @gensym x
-    blk = Expr(:block)
-    ptrwidth = Sys.WORD_SIZE>>2
-    width -= ptrwidth+2
-    if width > 0 && !('-' in flags)
-        push!(blk.args, pad(width, width, ' '))
-    end
-    push!(blk.args, :(print(out, '0')))
-    push!(blk.args, :(print(out, 'x')))
-    push!(blk.args, :(print(out, String(string(unsigned($x), pad = $ptrwidth, base = 16)))))
-    if width > 0 && '-' in flags
-        push!(blk.args, pad(width, width, ' '))
-    end
-    :(($x)::Ptr), blk
-end
-
-function gen_g(flags::String, width::Int, precision::Int, c::Char)
-    # print to fixed trailing precision
-    #  [g]: lower case e on scientific
-    #  [G]: Upper case e on scientific
-    #
-    # flags
-    #  (#): always print a decimal point
-    #  (0): pad left with zeros
-    #  (-): left justify
-    #  ( ): precede non-negative values with " "
-    #  (+): precede non-negative values with "+"
-    #
-    x, ex, blk = special_handler(flags,width)
-    if precision < 0; precision = 6; end
-    ndigits = min(precision+1,length(Grisu.getbuf())-1)
-    # See if anyone else wants to handle it
-    push!(blk.args, :((do_out, args) = ini_dec(out,$x,$ndigits, $flags, $width, $precision, $c, buf)))
-    ifblk = Expr(:if, :do_out, Expr(:block))
-    push!(blk.args, ifblk)
-    blk = ifblk.args[2]
-    push!(blk.args, :((len, pt, neg) = args))
-    push!(blk.args, :(exp = pt-1))
-    push!(blk.args, :(do_f = $precision > exp >= -4)) # Should we interpret like %f or %e?
-    feblk = Expr(:if, :do_f, Expr(:block), Expr(:block))
-    push!(blk.args, feblk)
-    fblk = feblk.args[2]
-    eblk = feblk.args[3]
-
-    ### %f branch
-    # Follow the same logic as gen_f() but more work has to be deferred until runtime
-    # because precision is unknown until then.
-    push!(fblk.args, :(fprec = $precision - (exp+1)))
-    push!(fblk.args, :((do_out, args) = fix_dec(out, $x, $flags, $width, fprec, $c - 1, buf)))
-    fifblk = Expr(:if, :do_out, Expr(:block))
-    push!(fblk.args, fifblk)
-    blk = fifblk.args[2]
-    push!(blk.args, :((len, pt, neg) = args))
-    push!(blk.args, :(padding = 0))
-    push!(blk.args, :(width = $width))
-    # need to compute value before left-padding since trailing zeros are elided
-    push!(blk.args, :(width -= print_fixed_width(fprec,pt,len,$('#' in flags))))
-    if '+' in flags || ' ' in flags
-        push!(blk.args, :(width -= 1))
-    else
-        push!(blk.args, :(if neg width -= 1; end))
-    end
-    push!(blk.args, :(if width >= 1 padding = width; end))
-    # print space padding
-    if !('-' in flags) && !('0' in flags)
-        padexpr = dynamic_pad(:width, :padding, ' ')
-        push!(blk.args, :(if padding > 0
-                          $padexpr; end))
-    end
-    # print sign
-    '+' in flags ? push!(blk.args, :(print(out, neg ? '-' : '+'))) :
-    ' ' in flags ? push!(blk.args, :(print(out, neg ? '-' : ' '))) :
-                   push!(blk.args, :(neg && print(out, '-')))
-    # print zero padding
-    if !('-' in flags) && '0' in flags
-        padexpr = dynamic_pad(:width, :padding, '0')
-        push!(blk.args, :(if padding > 0
-                          $padexpr; end))
-    end
-    # finally print value
-    push!(blk.args, :(print_fixed(out,fprec,pt,len,$('#' in flags),buf)))
-    # print space padding
-    if '-' in flags
-        padexpr = dynamic_pad(:width, :padding, ' ')
-        push!(blk.args, :(if padding > 0
-                          $padexpr; end))
-    end
-
-    ### %e branch
-    # Here we can do all the work at macro expansion time
-    var, eex = gen_e(flags, width, precision-1, c, true)
-    push!(eblk.args, :($(var.args[1]) = $x))
-    push!(eblk.args, eex)
-
-    :(($x)::Real), ex
-end
-
-### core unsigned integer decoding functions ###
-
-macro handle_zero(ex, digits)
-    quote
-        if $(esc(ex)) == 0
-            $(esc(digits))[1] = '0'
-            return Int32(1), Int32(1), $(esc(:neg))
-        end
-    end
-end
-
-decode_oct(out, d, flags::String, width::Int, precision::Int, c::Char, digits) = (true, decode_oct(d, digits))
-decode_0ct(out, d, flags::String, width::Int, precision::Int, c::Char, digits) = (true, decode_0ct(d, digits))
-decode_dec(out, d, flags::String, width::Int, precision::Int, c::Char, digits) = (true, decode_dec(d, digits))
-decode_hex(out, d, flags::String, width::Int, precision::Int, c::Char, digits) = (true, decode_hex(d, digits))
-decode_HEX(out, d, flags::String, width::Int, precision::Int, c::Char, digits) = (true, decode_HEX(d, digits))
-fix_dec(out, d, flags::String, width::Int, precision::Int, c::Char, digits) = (true, fix_dec(d, precision, digits))
-ini_dec(out, d, ndigits::Int, flags::String, width::Int, precision::Int, c::Char, digits) = (true, ini_dec(d, ndigits, digits))
-ini_hex(out, d, ndigits::Int, flags::String, width::Int, precision::Int, c::Char, digits) = (true, ini_hex(d, ndigits, digits))
-ini_HEX(out, d, ndigits::Int, flags::String, width::Int, precision::Int, c::Char, digits) = (true, ini_HEX(d, ndigits, digits))
-ini_hex(out, d, flags::String, width::Int, precision::Int, c::Char, digits) = (true, ini_hex(d, digits))
-ini_HEX(out, d, flags::String, width::Int, precision::Int, c::Char, digits) = (true, ini_HEX(d, digits))
-
-
-# fallbacks for Real types without explicit decode_* implementation
-decode_oct(d::Real, digits) = decode_oct(Integer(d), digits)
-decode_0ct(d::Real, digits) = decode_0ct(Integer(d), digits)
-decode_dec(d::Real, digits) = decode_dec(Integer(d), digits)
-decode_hex(d::Real, digits) = decode_hex(Integer(d), digits)
-decode_HEX(d::Real, digits) = decode_HEX(Integer(d), digits)
-
-handlenegative(d::Unsigned) = (false, d)
-function handlenegative(d::Integer)
-    if d < 0
-        return true, unsigned(oftype(d,-d))
-    else
-        return false, unsigned(d)
-    end
-end
-
-function decode_oct(d::Integer, digits)
-    neg, x = handlenegative(d)
-    @handle_zero x digits
-    pt = i = div((sizeof(x)<<3)-leading_zeros(x)+2,3)
-    while i > 0
-        digits[i] = 48+(x&0x7)
-        x >>= 3
-        i -= 1
-    end
-    return Int32(pt), Int32(pt), neg
-end
-
-function decode_0ct(d::Integer, digits)
-    neg, x = handlenegative(d)
-    # doesn't need special handling for zero
-    pt = i = div((sizeof(x)<<3)-leading_zeros(x)+5,3)
-    while i > 0
-        digits[i] = 48+(x&0x7)
-        x >>= 3
-        i -= 1
-    end
-    return Int32(pt), Int32(pt), neg
-end
-
-function decode_dec(d::Integer, digits)
-    neg, x = handlenegative(d)
-    @handle_zero x digits
-    pt = i = Base.ndigits0z(x)
-    while i > 0
-        digits[i] = 48+rem(x,10)
-        x = div(x,10)
-        i -= 1
-    end
-    return Int32(pt), Int32(pt), neg
-end
-
-function decode_hex(d::Integer, symbols::AbstractArray{UInt8,1}, digits)
-    neg, x = handlenegative(d)
-    @handle_zero x digits
-    pt = i = (sizeof(x)<<1)-(leading_zeros(x)>>2)
-    while i > 0
-        digits[i] = symbols[(x&0xf)+1]
-        x >>= 4
-        i -= 1
-    end
-    return Int32(pt), Int32(pt), neg
-end
-
-const hex_symbols = b"0123456789abcdef"
-const HEX_symbols = b"0123456789ABCDEF"
-
-decode_hex(x::Integer, digits) = decode_hex(x,hex_symbols,digits)
-decode_HEX(x::Integer, digits) = decode_hex(x,HEX_symbols,digits)
-
-function decode(b::Int, x::BigInt, digits)
-    neg = x.size < 0
-    pt = Base.ndigits(x, base=abs(b))
-    length(digits) < pt+1 && resize!(digits, pt+1)
-    neg && (x.size = -x.size)
-    GMP.MPZ.get_str!(digits, b, x)
-    neg && (x.size = -x.size)
-    return Int32(pt), Int32(pt), neg
-end
-decode_oct(x::BigInt, digits) = decode(8, x, digits)
-decode_dec(x::BigInt, digits) = decode(10, x, digits)
-decode_hex(x::BigInt, digits) = decode(16, x, digits)
-decode_HEX(x::BigInt, digits) = decode(-16, x, digits)
-
-function decode_0ct(x::BigInt, digits)
-    neg = x.size < 0
-    digits[1] = '0'
-    if x.size == 0
-        return Int32(1), Int32(1), neg
-    end
-    pt = Base.ndigits0z(x, 8) + 1
-    length(digits) < pt+1 && resize!(digits, pt+1)
-    neg && (x.size = -x.size)
-    p = convert(Ptr{UInt8}, digits) + 1
-    GMP.MPZ.get_str!(p, 8, x)
-    neg && (x.size = -x.size)
-    return neg, Int32(pt), Int32(pt)
-end
-
-### decoding functions directly used by printf generated code ###
-
-# decode_*(x)=> fixed precision, to 0th place, filled out
-# fix_*(x,n) => fixed precision, to nth place, not filled out
-# ini_*(x,n) => n initial digits, filled out
-
-# alternate versions:
-#   *_0ct(x,n) => ensure that the first octal digits is zero
-#   *_HEX(x,n) => use uppercase digits for hexadecimal
-
-# - returns (len, point, neg)
-# - implies len = point
-#
-
-function decode_dec(x::SmallFloatingPoint, digits)
-    if x == 0.0
-        digits[1] = '0'
-        return (Int32(1), Int32(1), false)
-    end
-    len,pt,neg = grisu(x,Grisu.FIXED,0,digits)
-    if len == 0
-        digits[1] = '0'
-        return (Int32(1), Int32(1), false)
-    else
-        for i = len+1:pt
-            digits[i] = '0'
-        end
-    end
-    return Int32(len), Int32(pt), neg
-end
-# TODO: implement decode_oct, decode_0ct, decode_hex, decode_HEX for SmallFloatingPoint
-
-## fix decoding functions ##
-#
-# - returns (neg, point, len)
-# - if len less than point, trailing zeros implied
-#
-
-# fallback for Real types without explicit fix_dec implementation
-fix_dec(x::Real, n::Int, digits) = fix_dec(float(x),n,digits)
-
-fix_dec(x::Integer, n::Int, digits) = decode_dec(x, digits)
-
-function fix_dec(x::SmallFloatingPoint, n::Int, digits)
-    if n > length(digits)-1; n = length(digits)-1; end
-    len,pt,neg = grisu(x,Grisu.FIXED,n,digits)
-    if len == 0
-        digits[1] = '0'
-        return (Int32(1), Int32(1), neg)
-    end
-    return Int32(len), Int32(pt), neg
-end
-
-## ini decoding functions ##
-#
-# - returns (neg, point, len)
-# - implies len = n (requested digits)
-#
-
-# fallback for Real types without explicit fix_dec implementation
-ini_dec(x::Real, n::Int, digits) = ini_dec(float(x),n,digits)
-
-function ini_dec(d::Integer, n::Int, digits)
-    neg, x = handlenegative(d)
-    k = ndigits(x)
-    if k <= n
-        pt = k
-        for i = k:-1:1
-            digits[i] = '0'+rem(x,10)
-            x = div(x,10)
-        end
-        for i = k+1:n
-            digits[i] = '0'
-        end
-    else
-        p = Base.powers_of_ten[k-n+1]
-        r = rem(x,p)
-        if r >= (p>>1)
-            x += p
-            if x >= Base.powers_of_ten[k+1]
-                p *= 10
-                k += 1
-            end
-        end
-        pt = k
-        x = div(x,p)
-        for i = n:-1:1
-            digits[i] = '0'+rem(x,10)
-            x = div(x,10)
-        end
-    end
-    return n, pt, neg
-end
-
-function ini_dec(x::SmallFloatingPoint, n::Int, digits)
-    if x == 0.0
-        ccall(:memset, Ptr{Cvoid}, (Ptr{Cvoid}, Cint, Csize_t), digits, '0', n)
-        return Int32(1), Int32(1), signbit(x)
-    else
-        len,pt,neg = grisu(x,Grisu.PRECISION,n,digits)
-    end
-    return Int32(len), Int32(pt), neg
-end
-
-function ini_dec(x::BigInt, n::Int, digits)
-    if x.size == 0
-        ccall(:memset, Ptr{Cvoid}, (Ptr{Cvoid}, Cint, Csize_t), digits, '0', n)
-        return Int32(1), Int32(1), false
-    end
-    d = Base.ndigits0z(x)
-    if d <= n
-        info = decode_dec(x)
-        d == n && return info
-        p = convert(Ptr{Cvoid}, digits) + info[2]
-        ccall(:memset, Ptr{Cvoid}, (Ptr{Cvoid}, Cint, Csize_t), p, '0', n - info[2])
-        return info
-    end
-    return (n, d, decode_dec(round(BigInt,x/big(10)^(d-n)))[3])
-end
-
-
-ini_hex(x::Real, n::Int, digits) = ini_hex(x,n,hex_symbols,digits)
-ini_HEX(x::Real, n::Int, digits) = ini_hex(x,n,HEX_symbols,digits)
-
-ini_hex(x::Real, digits) = ini_hex(x,hex_symbols,digits)
-ini_HEX(x::Real, digits) = ini_hex(x,HEX_symbols,digits)
-
-ini_hex(x::Real, n::Int, symbols::AbstractArray{UInt8,1}, digits) = ini_hex(float(x), n, symbols, digits)
-ini_hex(x::Real, symbols::AbstractArray{UInt8,1}, digits) = ini_hex(float(x), symbols, digits)
-
-function ini_hex(x::SmallFloatingPoint, n::Int, symbols::AbstractArray{UInt8,1}, digits)
-    x = Float64(x)
-    if x == 0.0
-        ccall(:memset, Ptr{Cvoid}, (Ptr{Cvoid}, Cint, Csize_t), digits, '0', n)
-        return Int32(1), Int32(0), signbit(x)
-    else
-        s, p = frexp(x)
-        sigbits = 4*min(n-1,13)
-        s = 0.25*round(ldexp(s,1+sigbits))
-        # ensure last 2 exponent bits either 01 or 10
-        u = (reinterpret(UInt64,s) & 0x003f_ffff_ffff_ffff) >> (52-sigbits)
-        if n > 14
-            ccall(:memset, Ptr{Cvoid}, (Ptr{Cvoid}, Cint, Csize_t), digits, '0', n)
-        end
-        i = (sizeof(u)<<1)-(leading_zeros(u)>>2)
-        while i > 0
-            digits[i] = symbols[(u&0xf)+1]
-            u >>= 4
-            i -= 1
-        end
-        # pt is the binary exponent
-        return Int32(n), Int32(p-1), x < 0.0
-    end
-end
-
-function ini_hex(x::SmallFloatingPoint, symbols::AbstractArray{UInt8,1}, digits)
-    x = Float64(x)
-    if x == 0.0
-        ccall(:memset, Ptr{Cvoid}, (Ptr{Cvoid}, Cint, Csize_t), digits, '0', 1)
-        return Int32(1), Int32(0), signbit(x)
-    else
-        s, p = frexp(x)
-        s *= 2.0
-        u = (reinterpret(UInt64,s) & 0x001f_ffff_ffff_ffff)
-        t = (trailing_zeros(u) >> 2)
-        u >>= (t<<2)
-        n = 14-t
-        for i = n:-1:1
-            digits[i] = symbols[(u&0xf)+1]
-            u >>= 4
-        end
-        # pt is the binary exponent
-        return Int32(n), Int32(p-1), x < 0.0
-    end
-end
-
-function ini_hex(x::Integer, digits)
-    len,pt,neg = decode_hex(x, digits)
-    pt = (len-1)<<2
-    len,pt,neg
-end
-function ini_HEX(x::Integer, digits)
-    len,pt,neg = decode_HEX(x, digits)
-    pt = (len-1)<<2
-    len,pt,neg
-end
-
-# not implemented
-ini_hex(x::Integer,ndigits::Int,digits) = throw(MethodError(ini_hex,(x,ndigits,digits)))
-
-#BigFloat
-fix_dec(out, d::BigFloat, flags::String, width::Int, precision::Int, c::Char, digits) = bigfloat_printf(out, d, flags, width, precision, c, digits)
-ini_dec(out, d::BigFloat, ndigits::Int, flags::String, width::Int, precision::Int, c::Char, digits) = bigfloat_printf(out, d, flags, width, precision, c, digits)
-ini_hex(out, d::BigFloat, ndigits::Int, flags::String, width::Int, precision::Int, c::Char, digits) = bigfloat_printf(out, d, flags, width, precision, c, digits)
-ini_HEX(out, d::BigFloat, ndigits::Int, flags::String, width::Int, precision::Int, c::Char, digits) = bigfloat_printf(out, d, flags, width, precision, c, digits)
-ini_hex(out, d::BigFloat, flags::String, width::Int, precision::Int, c::Char, digits) = bigfloat_printf(out, d, flags, width, precision, c, digits)
-ini_HEX(out, d::BigFloat, flags::String, width::Int, precision::Int, c::Char, digits) = bigfloat_printf(out, d, flags, width, precision, c, digits)
-function bigfloat_printf(out, d::BigFloat, flags::String, width::Int, precision::Int, c::Char, digits)
-    fmt_len = sizeof(flags)+4
-    if width > 0
-        fmt_len += ndigits(width)
-    end
-    if precision >= 0
-        fmt_len += ndigits(precision)+1
-    end
-    fmt = IOBuffer(maxsize=fmt_len)
-    print(fmt, '%')
-    print(fmt, flags)
-    if width > 0
-        print(fmt, width)
-    end
-    if precision == 0
-        print(fmt, '.')
-        print(fmt, '0')
-    elseif precision > 0
-        print(fmt, '.')
-        print(fmt, precision)
-    end
-    print(fmt, 'R')
-    print(fmt, c)
-    write(fmt, UInt8(0))
-    printf_fmt = take!(fmt)
-    @assert length(printf_fmt) == fmt_len
-    bufsiz = length(digits)
-    lng = ccall((:mpfr_snprintf,:libmpfr), Int32,
-                (Ptr{UInt8}, Culong, Ptr{UInt8}, Ref{BigFloat}...),
-                digits, bufsiz, printf_fmt, d)
-    lng > 0 || error("invalid printf formatting for BigFloat")
-    unsafe_write(out, pointer(digits), min(lng, bufsiz-1))
-    return (false, ())
-end
-
-### external printf interface ###
-
-is_str_expr(ex) =
-    isa(ex,Expr) && (ex.head === :string || (ex.head === :macrocall && isa(ex.args[1],Symbol) &&
-    endswith(string(ex.args[1]),"str")))
-
-function _printf(macroname, io, fmt, args)
-    isa(fmt, AbstractString) || throw(ArgumentError("$macroname: format must be a plain static string (no interpolation or prefix)"))
-    sym_args, blk = gen(fmt)
-
-    has_splatting = false
-    for arg in args
-       if isa(arg, Expr) && arg.head === :...
-          has_splatting = true
-          break
-       end
-    end
-
-    #
-    #  Immediately check for corresponding arguments if there is no splatting
-    #
-    if !has_splatting && length(sym_args) != length(args)
-       throw(ArgumentError("$macroname: wrong number of arguments ($(length(args))) should be ($(length(sym_args)))"))
-    end
-
-    for i = length(sym_args):-1:1
-        var = sym_args[i].args[1]
-        if has_splatting
-           pushfirst!(blk.args, :($var = G[$i]))
-        else
-           pushfirst!(blk.args, :($var = $(esc(args[i]))))
-        end
-    end
-
-    #
-    #  Delay generation of argument list and check until evaluation time instead of macro
-    #  expansion time if there is splatting.
-    #
-    if has_splatting
-       x = Expr(:call,:tuple,args...)
-       pushfirst!(blk.args,
-          quote
-             G = $(esc(x))
-             if length(G) != $(length(sym_args))
-                 throw(ArgumentError(string($macroname,": wrong number of arguments (",length(G),") should be (",$(length(sym_args)),")")))
-             end
-          end
-       )
-    end
-
-    pushfirst!(blk.args, :(out = $io))
-    Expr(:let, Expr(:block), blk)
-end
-
-macro printf(args...)
-    isempty(args) && throw(ArgumentError("@printf: called with no arguments"))
-    if isa(args[1], AbstractString) || is_str_expr(args[1])
-        _printf("@printf", :stdout, args[1], args[2:end])
-    else
-        (length(args) >= 2 && (isa(args[2], AbstractString) || is_str_expr(args[2]))) ||
-            throw(ArgumentError("@printf: first or second argument must be a format string"))
-        _printf("@printf", esc(args[1]), args[2], args[3:end])
-    end
-end
-
-macro sprintf(args...)
-    isempty(args) && throw(ArgumentError("@sprintf: called with zero arguments"))
-    isa(args[1], AbstractString) || is_str_expr(args[1]) ||
-        throw(ArgumentError("@sprintf: first argument must be a format string"))
-    letexpr = _printf("@sprintf", :(IOBuffer()), args[1], args[2:end])
-    push!(letexpr.args[2].args, :(String(take!(out))))
-    letexpr
-end
-
-end # module
diff -pruN 1.3.1+dfsg-1/base/process.jl 1.4.0+dfsg-1/base/process.jl
--- 1.3.1+dfsg-1/base/process.jl	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/base/process.jl	2020-03-21 16:36:32.000000000 +0000
@@ -539,7 +539,7 @@ function pipeline_error(procs::ProcessCh
 end
 
 """
-    kill(p::Process, signum=SIGTERM)
+    kill(p::Process, signum=Base.SIGTERM)
 
 Send a signal to a process. The default is to terminate the process.
 Returns successfully if the process has already exited, but throws an
diff -pruN 1.3.1+dfsg-1/base/promotion.jl 1.4.0+dfsg-1/base/promotion.jl
--- 1.3.1+dfsg-1/base/promotion.jl	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/base/promotion.jl	2020-03-21 16:36:32.000000000 +0000
@@ -349,9 +349,6 @@ muladd(x::Number, y::Number, z::Number)
 <( x::Real, y::Real)     = (< )(promote(x,y)...)
 <=(x::Real, y::Real)     = (<=)(promote(x,y)...)
 
-div(x::Real, y::Real) = div(promote(x,y)...)
-fld(x::Real, y::Real) = fld(promote(x,y)...)
-cld(x::Real, y::Real) = cld(promote(x,y)...)
 rem(x::Real, y::Real) = rem(promote(x,y)...)
 mod(x::Real, y::Real) = mod(promote(x,y)...)
 
diff -pruN 1.3.1+dfsg-1/base/range.jl 1.4.0+dfsg-1/base/range.jl
--- 1.3.1+dfsg-1/base/range.jl	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/base/range.jl	2020-03-21 16:36:32.000000000 +0000
@@ -1010,14 +1010,14 @@ function _define_range_op(@nospecialize
         function $f(r1::OrdinalRange, r2::OrdinalRange)
             r1l = length(r1)
             (r1l == length(r2) ||
-             throw(DimensionMismatch("argument dimensions must match")))
+             throw(DimensionMismatch("argument dimensions must match: length of r1 is $r1l, length of r2 is $(length(r2))")))
             range($f(first(r1), first(r2)), step=$f(step(r1), step(r2)), length=r1l)
         end
 
         function $f(r1::LinRange{T}, r2::LinRange{T}) where T
             len = r1.len
             (len == r2.len ||
-             throw(DimensionMismatch("argument dimensions must match")))
+             throw(DimensionMismatch("argument dimensions must match: length of r1 is $len, length of r2 is $(r2.len)")))
             LinRange{T}(convert(T, $f(first(r1), first(r2))),
                         convert(T, $f(last(r1), last(r2))), len)
         end
@@ -1033,7 +1033,7 @@ _define_range_op(:-)
 function +(r1::StepRangeLen{T,S}, r2::StepRangeLen{T,S}) where {T,S}
     len = length(r1)
     (len == length(r2) ||
-        throw(DimensionMismatch("argument dimensions must match")))
+     throw(DimensionMismatch("argument dimensions must match: length of r1 is $len, length of r2 is $(length(r2))")))
     StepRangeLen(first(r1)+first(r2), step(r1)+step(r2), len)
 end
 
diff -pruN 1.3.1+dfsg-1/base/rational.jl 1.4.0+dfsg-1/base/rational.jl
--- 1.3.1+dfsg-1/base/rational.jl	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/base/rational.jl	2020-03-21 16:36:32.000000000 +0000
@@ -11,12 +11,18 @@ struct Rational{T<:Integer} <: Real
     den::T
 
     function Rational{T}(num::Integer, den::Integer) where T<:Integer
-        num == den == zero(T) && __throw_rational_argerror(T)
-        num2, den2 = signbit(den) ? divgcd(-num, -den) : divgcd(num, den)
-        new(num2, den2)
+        num == den == zero(T) && __throw_rational_argerror_zero(T)
+        num2, den2 = divgcd(num, den)
+        if T<:Signed && signbit(den2)
+            den2 = -den2
+            signbit(den2) && __throw_rational_argerror_typemin(T)
+            num2 = -num2
+        end
+        return new(num2, den2)
     end
 end
-@noinline __throw_rational_argerror(T) = throw(ArgumentError("invalid rational: zero($T)//zero($T)"))
+@noinline __throw_rational_argerror_zero(T) = throw(ArgumentError("invalid rational: zero($T)//zero($T)"))
+@noinline __throw_rational_argerror_typemin(T) = throw(ArgumentError("invalid rational: denominator can't be typemin($T)"))
 
 Rational(n::T, d::T) where {T<:Integer} = Rational{T}(n,d)
 Rational(n::Integer, d::Integer) = Rational(promote(n,d)...)
@@ -350,21 +356,29 @@ end
 ==(z::Complex , x::Rational) = isreal(z) & (real(z) == x)
 ==(x::Rational, z::Complex ) = isreal(z) & (real(z) == x)
 
-for op in (:div, :fld, :cld)
+function div(x::Rational, y::Integer, r::RoundingMode)
+    xn,yn = divgcd(x.num,y)
+    div(xn, checked_mul(x.den,yn), r)
+end
+function div(x::Integer, y::Rational, r::RoundingMode)
+    xn,yn = divgcd(x,y.num)
+    div(checked_mul(xn,y.den), yn, r)
+end
+function div(x::Rational, y::Rational, r::RoundingMode)
+    xn,yn = divgcd(x.num,y.num)
+    xd,yd = divgcd(x.den,y.den)
+    div(checked_mul(xn,yd), checked_mul(xd,yn), r)
+end
+
+# For compatibility - to be removed in 2.0 when the generic fallbacks
+# are removed from div.jl
+div(x::T, y::T, r::RoundingMode) where {T<:Rational} =
+    invoke(div, Tuple{Rational, Rational, RoundingMode}, x, y, r)
+for (S, T) in ((Rational, Integer), (Integer, Rational), (Rational, Rational))
     @eval begin
-        function ($op)(x::Rational, y::Integer )
-            xn,yn = divgcd(x.num,y)
-            ($op)(xn, checked_mul(x.den,yn))
-        end
-        function ($op)(x::Integer,  y::Rational)
-            xn,yn = divgcd(x,y.num)
-            ($op)(checked_mul(xn,y.den), yn)
-        end
-        function ($op)(x::Rational, y::Rational)
-            xn,yn = divgcd(x.num,y.num)
-            xd,yd = divgcd(x.den,y.den)
-            ($op)(checked_mul(xn,yd), checked_mul(xd,yn))
-        end
+        div(x::$S, y::$T) = div(x, y, RoundToZero)
+        fld(x::$S, y::$T) = div(x, y, RoundDown)
+        cld(x::$S, y::$T) = div(x, y, RoundUp)
     end
 end
 
@@ -449,3 +463,20 @@ function lerpi(j::Integer, d::Integer, a
 end
 
 float(::Type{Rational{T}}) where {T<:Integer} = float(T)
+
+gcd(x::Rational, y::Rational) = gcd(x.num, y.num) // lcm(x.den, y.den)
+lcm(x::Rational, y::Rational) = lcm(x.num, y.num) // gcd(x.den, y.den)
+function gcdx(x::Rational, y::Rational)
+    c = gcd(x, y)
+    if iszero(c.num)
+        a, b = one(c.num), c.num
+    elseif iszero(c.den)
+        a = ifelse(iszero(x.den), one(c.den), c.den)
+        b = ifelse(iszero(y.den), one(c.den), c.den)
+    else
+        idiv(x, c) = div(x.num, c.num) * div(c.den, x.den)
+        _, a, b = gcdx(idiv(x, c), idiv(y, c))
+    end
+    c, a, b
+end
+
diff -pruN 1.3.1+dfsg-1/base/reducedim.jl 1.4.0+dfsg-1/base/reducedim.jl
--- 1.3.1+dfsg-1/base/reducedim.jl	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/base/reducedim.jl	2020-03-21 16:36:32.000000000 +0000
@@ -4,7 +4,7 @@
 
 # for reductions that expand 0 dims to 1
 reduced_index(i::OneTo) = OneTo(1)
-reduced_index(i::Union{Slice, IdentityUnitRange}) = first(i):first(i)
+reduced_index(i::Union{Slice, IdentityUnitRange}) = oftype(i, first(i):first(i))
 reduced_index(i::AbstractUnitRange) =
     throw(ArgumentError(
 """
@@ -144,7 +144,7 @@ for (f1, f2, initval) in ((:min, :max, :
             # otherwise use the min/max of the first slice as initial value
             v0 = mapreduce(f, $f2, A1)
 
-            # but NaNs need to be avoided as intial values
+            # but NaNs need to be avoided as initial values
             v0 = v0 != v0 ? typeof(v0)($initval) : v0
 
             T = _realtype(f, promote_union(eltype(A)))
diff -pruN 1.3.1+dfsg-1/base/reduce.jl 1.4.0+dfsg-1/base/reduce.jl
--- 1.3.1+dfsg-1/base/reduce.jl	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/base/reduce.jl	2020-03-21 16:36:32.000000000 +0000
@@ -36,31 +36,116 @@ mul_prod(x::Real, y::Real)::Real = x * y
 
 ## foldl && mapfoldl
 
-function mapfoldl_impl(f, op, nt::NamedTuple{(:init,)}, itr, i...)
-    init = nt.init
+function mapfoldl_impl(f::F, op::OP, nt, itr) where {F,OP}
+    op′, itr′ = _xfadjoint(BottomRF(op), Generator(f, itr))
+    return foldl_impl(op′, nt, itr′)
+end
+
+function foldl_impl(op::OP, nt, itr) where {OP}
+    v = _foldl_impl(op, get(nt, :init, _InitialValue()), itr)
+    v isa _InitialValue && return reduce_empty_iter(op, itr)
+    return v
+end
+
+function _foldl_impl(op::OP, init, itr) where {OP}
     # Unroll the while loop once; if init is known, the call to op may
     # be evaluated at compile time
-    y = iterate(itr, i...)
+    y = iterate(itr)
     y === nothing && return init
-    v = op(init, f(y[1]))
+    v = op(init, y[1])
     while true
         y = iterate(itr, y[2])
         y === nothing && break
-        v = op(v, f(y[1]))
+        v = op(v, y[1])
     end
     return v
 end
 
-function mapfoldl_impl(f, op, nt::NamedTuple{()}, itr)
-    y = iterate(itr)
-    if y === nothing
-        return Base.mapreduce_empty_iter(f, op, itr, IteratorEltype(itr))
-    end
-    x, i = y
-    init = mapreduce_first(f, op, x)
-    return mapfoldl_impl(f, op, (init=init,), itr, i)
+struct _InitialValue end
+
+"""
+    BottomRF(rf) -> rf′
+
+"Bottom" reducing function.  This is a thin wrapper around the `op` argument
+passed to `foldl`-like functions for handling the initial invocation to call
+[`reduce_first`](@ref).
+"""
+struct BottomRF{T}
+    rf::T
+end
+
+@inline (op::BottomRF)(::_InitialValue, x) = reduce_first(op.rf, x)
+@inline (op::BottomRF)(acc, x) = op.rf(acc, x)
+
+"""
+    MappingRF(f, rf) -> rf′
+
+Create a mapping reducing function `rf′(acc, x) = rf(acc, f(x))`.
+"""
+struct MappingRF{F, T}
+    f::F
+    rf::T
+end
+
+@inline (op::MappingRF)(acc, x) = op.rf(acc, op.f(x))
+
+"""
+    FilteringRF(f, rf) -> rf′
+
+Create a filtering reducing function `rf′(acc, x) = f(x) ? rf(acc, x) : acc`.
+"""
+struct FilteringRF{F, T}
+    f::F
+    rf::T
+end
+
+@inline (op::FilteringRF)(acc, x) = op.f(x) ? op.rf(acc, x) : acc
+
+"""
+    FlatteningRF(rf) -> rf′
+
+Create a flattening reducing function that is roughly equivalent to
+`rf′(acc, x) = foldl(rf, x; init=acc)`.
+"""
+struct FlatteningRF{T}
+    rf::T
 end
 
+@inline function (op::FlatteningRF)(acc, x)
+    op′, itr′ = _xfadjoint(op.rf, x)
+    return _foldl_impl(op′, acc, itr′)
+end
+
+"""
+    _xfadjoint(op, itr) -> op′, itr′
+
+Given a pair of reducing function `op` and an iterator `itr`, return a pair
+`(op′, itr′)` of similar types.  If the iterator `itr` is transformed by an
+iterator transform `ixf` whose adjoint transducer `xf` is known, `op′ = xf(op)`
+and `itr′ = ixf⁻¹(itr)` is returned.  Otherwise, `op` and `itr` are returned
+as-is.  For example, transducer `rf -> MappingRF(f, rf)` is the adjoint of
+iterator transform `itr -> Generator(f, itr)`.
+
+Nested iterator transforms are converted recursively.  That is to say,
+given `op` and
+
+    itr = (ixf₁ ∘ ixf₂ ∘ ... ∘ ixfₙ)(itr′)
+
+what is returned is `itr′` and
+
+    op′ = (xfₙ ∘ ... ∘ xf₂ ∘ xf₁)(op)
+"""
+_xfadjoint(op, itr) = (op, itr)
+_xfadjoint(op, itr::Generator) =
+    if itr.f === identity
+        _xfadjoint(op, itr.iter)
+    else
+        _xfadjoint(MappingRF(itr.f, op), itr.iter)
+    end
+_xfadjoint(op, itr::Filter) =
+    _xfadjoint(FilteringRF(itr.flt, op), itr.itr)
+_xfadjoint(op, itr::Flatten) =
+    _xfadjoint(FlatteningRF(op), itr.it)
 
 """
     mapfoldl(f, op, itr; [init])
@@ -91,22 +176,20 @@ foldl(op, itr; kw...) = mapfoldl(identit
 
 ## foldr & mapfoldr
 
-mapfoldr_impl(f, op, nt::NamedTuple{(:init,)}, itr) =
-    mapfoldl_impl(f, (x,y) -> op(y,x), nt, Iterators.reverse(itr))
+function mapfoldr_impl(f, op, nt, itr)
+    op′, itr′ = _xfadjoint(BottomRF(FlipArgs(op)), Generator(f, itr))
+    return foldl_impl(op′, nt, _reverse(itr′))
+end
 
-# we can't just call mapfoldl_impl with (x,y) -> op(y,x), because
-# we need to use the type of op for mapreduce_empty_iter and mapreduce_first.
-function mapfoldr_impl(f, op, nt::NamedTuple{()}, itr)
-    ritr = Iterators.reverse(itr)
-    y = iterate(ritr)
-    if y === nothing
-        return Base.mapreduce_empty_iter(f, op, itr, IteratorEltype(itr))
-    end
-    x, i = y
-    init = mapreduce_first(f, op, x)
-    return mapfoldl_impl(f, (x,y) -> op(y,x), (init=init,), ritr, i)
+_reverse(itr) = Iterators.reverse(itr)
+_reverse(itr::Tuple) = reverse(itr)  #33235
+
+struct FlipArgs{F}
+    f::F
 end
 
+@inline (f::FlipArgs)(x, y) = f.f(y, x)
+
 """
     mapfoldr(f, op, itr; [init])
 
@@ -234,6 +317,11 @@ reduce_empty(::typeof(mul_prod), T) = re
 reduce_empty(::typeof(mul_prod), ::Type{T}) where {T<:SmallSigned}  = one(Int)
 reduce_empty(::typeof(mul_prod), ::Type{T}) where {T<:SmallUnsigned} = one(UInt)
 
+reduce_empty(op::BottomRF, T) = reduce_empty(op.rf, T)
+reduce_empty(op::MappingRF, T) = mapreduce_empty(op.f, op.rf, T)
+reduce_empty(op::FilteringRF, T) = reduce_empty(op.rf, T)
+reduce_empty(op::FlipArgs, T) = reduce_empty(op.f, T)
+
 """
     Base.mapreduce_empty(f, op, T)
 
@@ -251,10 +339,13 @@ mapreduce_empty(::typeof(abs2), op, T)
 mapreduce_empty(f::typeof(abs),  ::typeof(max), T) = abs(zero(T))
 mapreduce_empty(f::typeof(abs2), ::typeof(max), T) = abs2(zero(T))
 
-mapreduce_empty_iter(f, op, itr, ::HasEltype) = mapreduce_empty(f, op, eltype(itr))
-mapreduce_empty_iter(f, op::typeof(&), itr, ::EltypeUnknown) = true
-mapreduce_empty_iter(f, op::typeof(|), itr, ::EltypeUnknown) = false
-mapreduce_empty_iter(f, op, itr, ::EltypeUnknown) = _empty_reduce_error()
+# For backward compatibility:
+mapreduce_empty_iter(f, op, itr, ItrEltype) =
+    reduce_empty_iter(MappingRF(f, op), itr, ItrEltype)
+
+@inline reduce_empty_iter(op, itr) = reduce_empty_iter(op, itr, IteratorEltype(itr))
+@inline reduce_empty_iter(op, itr, ::HasEltype) = reduce_empty(op, eltype(itr))
+reduce_empty_iter(op, itr, ::EltypeUnknown) = _empty_reduce_error()
 
 # handling of single-element iterators
 """
diff -pruN 1.3.1+dfsg-1/base/reflection.jl 1.4.0+dfsg-1/base/reflection.jl
--- 1.3.1+dfsg-1/base/reflection.jl	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/base/reflection.jl	2020-03-21 16:36:32.000000000 +0000
@@ -317,10 +317,11 @@ datatype_fieldtypes(x::DataType) = ccall
 
 struct DataTypeLayout
     nfields::UInt32
-    alignment::UInt32
-    # alignment : 28;
+    npointers::UInt32
+    firstptr::Int32
+    alignment::UInt16
+    flags::UInt16
     # haspadding : 1;
-    # pointerfree : 1;
     # fielddesc_type : 2;
 end
 
@@ -334,7 +335,7 @@ function datatype_alignment(dt::DataType
     @_pure_meta
     dt.layout == C_NULL && throw(UndefRefError())
     alignment = unsafe_load(convert(Ptr{DataTypeLayout}, dt.layout)).alignment
-    return Int(alignment & 0x1FF)
+    return Int(alignment)
 end
 
 # amount of total space taken by T when stored in a container
@@ -367,8 +368,8 @@ Can be called on any `isconcretetype`.
 function datatype_haspadding(dt::DataType)
     @_pure_meta
     dt.layout == C_NULL && throw(UndefRefError())
-    alignment = unsafe_load(convert(Ptr{DataTypeLayout}, dt.layout)).alignment
-    return (alignment >> 9) & 1 == 1
+    flags = unsafe_load(convert(Ptr{DataTypeLayout}, dt.layout)).flags
+    return flags & 1 == 1
 end
 
 """
@@ -380,8 +381,8 @@ Can be called on any `isconcretetype`.
 function datatype_pointerfree(dt::DataType)
     @_pure_meta
     dt.layout == C_NULL && throw(UndefRefError())
-    alignment = unsafe_load(convert(Ptr{DataTypeLayout}, dt.layout)).alignment
-    return (alignment >> 10) & 0xFFFFF == 0
+    npointers = unsafe_load(convert(Ptr{DataTypeLayout}, dt.layout)).npointers
+    return npointers == 0
 end
 
 """
@@ -396,8 +397,8 @@ See also [`fieldoffset`](@ref).
 function datatype_fielddesc_type(dt::DataType)
     @_pure_meta
     dt.layout == C_NULL && throw(UndefRefError())
-    alignment = unsafe_load(convert(Ptr{DataTypeLayout}, dt.layout)).alignment
-    return (alignment >> 30) & 3
+    flags = unsafe_load(convert(Ptr{DataTypeLayout}, dt.layout)).flags
+    return (flags >> 1) & 3
 end
 
 """
@@ -589,7 +590,9 @@ end
 Compute a type that contains the intersection of `T` and `S`. Usually this will be the
 smallest such type or one close to it.
 """
-typeintersect(@nospecialize(a),@nospecialize(b)) = (@_pure_meta; ccall(:jl_type_intersection, Any, (Any,Any), a, b))
+typeintersect(@nospecialize(a), @nospecialize(b)) = (@_pure_meta; ccall(:jl_type_intersection, Any, (Any, Any), a, b))
+
+morespecific(@nospecialize(a), @nospecialize(b)) = ccall(:jl_type_morespecific, Cint, (Any, Any), a, b) != 0
 
 """
     fieldoffset(type, i)
@@ -860,19 +863,29 @@ function MethodList(mt::Core.MethodTable
 end
 
 """
-    methods(f, [types])
+    methods(f, [types], [module])
+
+Return the method table for `f`.
 
-Returns the method table for `f`.
+If `types` is specified, return an array of methods whose types match.
+If `module` is specified, return an array of methods defined in that module.
+A list of modules can also be specified as an array.
 
-If `types` is specified, returns an array of methods whose types match.
+!!! compat "Julia 1.4"
+    At least Julia 1.4 is required for specifying a module.
 """
-function methods(@nospecialize(f), @nospecialize(t))
+function methods(@nospecialize(f), @nospecialize(t),
+                 @nospecialize(mod::Union{Module,AbstractArray{Module},Nothing}=nothing))
+    if mod isa Module
+        mod = (mod,)
+    end
     if isa(f, Core.Builtin)
         throw(ArgumentError("argument is not a generic function"))
     end
     t = to_tuple_type(t)
     world = typemax(UInt)
-    return MethodList(Method[m[3] for m in _methods(f, t, -1, world)], typeof(f).name.mt)
+    MethodList(Method[m[3] for m in _methods(f, t, -1, world) if mod === nothing || m[3].module in mod],
+               typeof(f).name.mt)
 end
 
 methods(f::Core.Builtin) = MethodList(Method[], typeof(f).name.mt)
@@ -885,9 +898,11 @@ function methods_including_ambiguous(@no
     ms = ccall(:jl_matching_methods, Any, (Any, Cint, Cint, UInt, Ptr{UInt}, Ptr{UInt}), tt, -1, 1, world, min, max)::Array{Any,1}
     return MethodList(Method[m[3] for m in ms], typeof(f).name.mt)
 end
-function methods(@nospecialize(f))
+
+function methods(@nospecialize(f),
+                 @nospecialize(mod::Union{Module,AbstractArray{Module},Nothing}=nothing))
     # return all matches
-    return methods(f, Tuple{Vararg{Any}})
+    return methods(f, Tuple{Vararg{Any}}, mod)
 end
 
 function visit(f, mt::Core.MethodTable)
@@ -1166,6 +1181,11 @@ function nameof(f::Function)
     return mt.name
 end
 
+function nameof(f::Core.IntrinsicFunction)
+    name = ccall(:jl_intrinsic_name, Ptr{UInt8}, (Core.IntrinsicFunction,), f)
+    return ccall(:jl_symbol, Ref{Symbol}, (Ptr{UInt8},), name)
+end
+
 """
     parentmodule(f::Function) -> Module
 
@@ -1232,7 +1252,7 @@ function hasmethod(@nospecialize(f), @no
     hasmethod(f, t, world=world) || return false
     isempty(kwnames) && return true
     m = which(f, t)
-    kws = kwarg_decl(m, Core.kwftype(typeof(f)))
+    kws = kwarg_decl(m)
     for kw in kws
         endswith(String(kw), "...") && return true
     end
diff -pruN 1.3.1+dfsg-1/base/refpointer.jl 1.4.0+dfsg-1/base/refpointer.jl
--- 1.3.1+dfsg-1/base/refpointer.jl	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/base/refpointer.jl	2020-03-21 16:36:32.000000000 +0000
@@ -74,7 +74,7 @@ RefArray(x::AbstractArray{T}, i::Int=1,
 convert(::Type{Ref{T}}, x::AbstractArray{T}) where {T} = RefArray(x, 1)
 
 function unsafe_convert(P::Type{Ptr{T}}, b::RefArray{T}) where T
-    if datatype_pointerfree(RefValue{T})
+    if allocatedinline(T)
         p = pointer(b.x, b.i)
     elseif isconcretetype(T) && T.mutable
         p = pointer_from_objref(b.x[b.i])
diff -pruN 1.3.1+dfsg-1/base/refvalue.jl 1.4.0+dfsg-1/base/refvalue.jl
--- 1.3.1+dfsg-1/base/refvalue.jl	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/base/refvalue.jl	2020-03-21 16:36:32.000000000 +0000
@@ -11,7 +11,7 @@ RefValue(x::T) where {T} = RefValue{T}(x
 isassigned(x::RefValue) = isdefined(x, :x)
 
 function unsafe_convert(P::Type{Ptr{T}}, b::RefValue{T}) where T
-    if datatype_pointerfree(RefValue{T})
+    if allocatedinline(T)
         p = pointer_from_objref(b)
     elseif isconcretetype(T) && T.mutable
         p = pointer_from_objref(b.x)
diff -pruN 1.3.1+dfsg-1/base/ryu/exp.jl 1.4.0+dfsg-1/base/ryu/exp.jl
--- 1.3.1+dfsg-1/base/ryu/exp.jl	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/base/ryu/exp.jl	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1,264 @@
+@inline function writeexp(buf, pos, v::T,
+    precision=-1, plus=false, space=false, hash=false,
+    expchar=UInt8('e'), decchar=UInt8('.'), trimtrailingzeros=false) where {T <: Base.IEEEFloat}
+    @assert 0 < pos <= length(buf)
+    x = Float64(v)
+    neg = signbit(x)
+    # special cases
+    if x == 0
+        if neg
+            buf[pos] = UInt8('-')
+            pos += 1
+        elseif plus
+            buf[pos] = UInt8('+')
+            pos += 1
+        elseif space
+            buf[pos] = UInt8(' ')
+            pos += 1
+        end
+        buf[pos] = UInt8('0')
+        pos += 1
+        if precision > 0
+            buf[pos] = decchar
+            pos += 1
+            for _ = 1:precision
+                buf[pos] = UInt8('0')
+                pos += 1
+            end
+        elseif hash
+            buf[pos] = decchar
+            pos += 1
+        end
+        buf[pos] = expchar
+        buf[pos + 1] = UInt8('+')
+        buf[pos + 2] = UInt8('0')
+        buf[pos + 3] = UInt8('0')
+        return pos + 4
+    elseif isnan(x)
+        buf[pos] = UInt8('N')
+        buf[pos + 1] = UInt8('a')
+        buf[pos + 2] = UInt8('N')
+        return pos + 3
+    elseif !isfinite(x)
+        if neg
+            buf[pos] = UInt8('-')
+            pos += 1
+        elseif plus
+            buf[pos] = UInt8('+')
+            pos += 1
+        elseif space
+            buf[pos] = UInt8(' ')
+            pos += 1
+        end
+        buf[pos] = UInt8('I')
+        buf[pos + 1] = UInt8('n')
+        buf[pos + 2] = UInt8('f')
+        return pos + 3
+    end
+
+    bits = Core.bitcast(UInt64, x)
+    mant = bits & MANTISSA_MASK
+    exp = Int((bits >> 52) & EXP_MASK)
+
+    if exp == 0
+        e2 = 1 - 1023 - 52
+        m2 = mant
+    else
+        e2 = exp - 1023 - 52
+        m2 = (Int64(1) << 52) | mant
+    end
+    nonzero = false
+    precision += 1
+    if neg
+        buf[pos] = UInt8('-')
+        pos += 1
+    elseif plus
+        buf[pos] = UInt8('+')
+        pos += 1
+    elseif space
+        buf[pos] = UInt8(' ')
+        pos += 1
+    end
+    digits = 0
+    printedDigits = 0
+    availableDigits = 0
+    e = 0
+    if e2 >= -52
+        idx = e2 < 0 ? 0 : indexforexp(e2)
+        p10bits = pow10bitsforindex(idx)
+        len = lengthforindex(idx)
+        i = len - 1
+        while i >= 0
+            j = p10bits - e2
+            #=@inbounds=# mula, mulb, mulc = POW10_SPLIT[POW10_OFFSET[idx + 1] + i + 1]
+            digits = mulshiftmod1e9(m2 << 8, mula, mulb, mulc, j + 8)
+            if printedDigits != 0
+                if printedDigits + 9 > precision
+                    availableDigits = 9
+                    break
+                end
+                pos = append_nine_digits(digits, buf, pos)
+                printedDigits += 9
+            elseif digits != 0
+                availableDigits = decimallength(digits)
+                e = i * 9 + availableDigits - 1
+                if availableDigits > precision
+                    break
+                end
+                if precision > 1
+                    pos = append_d_digits(availableDigits, digits, buf, pos, decchar)
+                else
+                    buf[pos] = UInt8('0') + digits
+                    pos += 1
+                    if hash
+                        buf[pos] = decchar
+                        pos += 1
+                    end
+                end
+                printedDigits = availableDigits
+                availableDigits = 0
+            end
+            i -= 1
+        end
+    end
+    if e2 < 0 && availableDigits == 0
+        idx = div(-e2, 16)
+        i = MIN_BLOCK_2[idx + 1]
+        while i < 200
+            j = 120 + (-e2 - 16 * idx)
+            p = POW10_OFFSET_2[idx + 1] + i - MIN_BLOCK_2[idx + 1]
+            if p >= POW10_OFFSET_2[idx + 2]
+                digits = 0
+            else
+                #=@inbounds=# mula, mulb, mulc = POW10_SPLIT_2[p + 1]
+                digits = mulshiftmod1e9(m2 << 8, mula, mulb, mulc, j + 8)
+            end
+            if printedDigits != 0
+                if printedDigits + 9 > precision
+                    availableDigits = 9
+                    break
+                end
+                pos = append_nine_digits(digits, buf, pos)
+                printedDigits += 9
+            elseif digits != 0
+                availableDigits = decimallength(digits)
+                e = -(i + 1) * 9 + availableDigits - 1
+                if availableDigits > precision
+                    break
+                end
+                if precision > 1
+                    pos = append_d_digits(availableDigits, digits, buf, pos, decchar)
+                else
+                    buf[pos] = UInt8('0') + digits
+                    pos += 1
+                    if hash
+                        buf[pos] = decchar
+                        pos += 1
+                    end
+                end
+                printedDigits = availableDigits
+                availableDigits = 0
+            end
+            i += 1
+        end
+    end
+    maximum = precision - printedDigits
+    if availableDigits == 0
+        digits = 0
+    end
+    lastDigit = 0
+    if availableDigits > maximum
+        for k = 0:(availableDigits - maximum - 1)
+            lastDigit = digits % 10
+            digits = div(digits, 10)
+        end
+    end
+    roundUp = 0
+    if lastDigit != 5
+        roundUp = lastDigit > 5
+    else
+        rexp = precision - e
+        requiredTwos = -e2 - rexp
+        trailingZeros = requiredTwos <= 0 ||
+            (requiredTwos < 60 && pow2(m2, requiredTwos))
+        if rexp < 0
+            requiredFives = -rexp
+            trailingZeros = trailingZeros & pow5(m2, requiredFives)
+        end
+        roundUp = trailingZeros ? 2 : 1
+    end
+    if printedDigits != 0
+        if digits == 0
+            for _ = 1:maximum
+                buf[pos] = UInt8('0')
+                pos += 1
+            end
+        else
+            pos = append_c_digits(maximum, digits, buf, pos)
+        end
+    else
+        if precision > 1
+            pos = append_d_digits(maximum, digits, buf, pos, decchar)
+        else
+            buf[pos] = UInt8('0') + digits
+            pos += 1
+            if hash
+                buf[pos] = decchar
+                pos += 1
+            end
+        end
+    end
+    if roundUp != 0
+        roundPos = pos
+        while true
+            roundPos -= 1
+            if roundPos == 0 || buf[roundPos] == UInt8('-')
+                buf[roundPos + 1] = UInt8('1')
+                e += 1
+                break
+            end
+            c = roundPos > 0 ? buf[roundPos] : 0x00
+            if c == decchar
+                continue
+            elseif c == UInt8('9')
+                buf[roundPos] = UInt8('0')
+                roundUp = 1
+                continue
+            else
+                if roundUp == 2 && UInt8(c) % 2 == 0
+                    break
+                end
+                buf[roundPos] = c + 1
+                break
+            end
+        end
+    end
+    if trimtrailingzeros
+        while buf[pos - 1] == UInt8('0')
+            pos -= 1
+        end
+        if buf[pos - 1] == decchar && !hash
+            pos -= 1
+        end
+    end
+    buf[pos] = expchar
+    pos += 1
+    if e < 0
+        buf[pos] = UInt8('-')
+        pos += 1
+        e = -e
+    else
+        buf[pos] = UInt8('+')
+        pos += 1
+    end
+    if e >= 100
+        c = e % 10
+        unsafe_copyto!(buf, pos, DIGIT_TABLE, 2 * div(e, 10) + 1, 2)
+        buf[pos + 2] = UInt8('0') + c
+        pos += 3
+    else
+        unsafe_copyto!(buf, pos, DIGIT_TABLE, 2 * e + 1, 2)
+        pos += 2
+    end
+    return pos
+end
diff -pruN 1.3.1+dfsg-1/base/ryu/fixed.jl 1.4.0+dfsg-1/base/ryu/fixed.jl
--- 1.3.1+dfsg-1/base/ryu/fixed.jl	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/base/ryu/fixed.jl	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1,210 @@
+@inline function writefixed(buf, pos, v::T,
+    precision=-1, plus=false, space=false, hash=false,
+    decchar=UInt8('.'), trimtrailingzeros=false) where {T <: Base.IEEEFloat}
+    @assert 0 < pos <= length(buf)
+    x = Float64(v)
+    neg = signbit(x)
+    # special cases
+    if x == 0
+        if neg
+            buf[pos] = UInt8('-')
+            pos += 1
+        elseif plus
+            buf[pos] = UInt8('+')
+            pos += 1
+        elseif space
+            buf[pos] = UInt8(' ')
+            pos += 1
+        end
+        buf[pos] = UInt8('0')
+        pos += 1
+        if precision > 0
+            buf[pos] = decchar
+            pos += 1
+            if trimtrailingzeros
+                precision = 1
+            end
+            for _ = 1:precision
+                buf[pos] = UInt8('0')
+                pos += 1
+            end
+        elseif hash
+            buf[pos] = decchar
+            pos += 1
+        end
+        return pos
+    elseif isnan(x)
+        buf[pos] = UInt8('N')
+        buf[pos + 1] = UInt8('a')
+        buf[pos + 2] = UInt8('N')
+        return pos + 3
+    elseif !isfinite(x)
+        if neg
+            buf[pos] = UInt8('-')
+            pos += 1
+        elseif plus
+            buf[pos] = UInt8('+')
+            pos += 1
+        elseif space
+            buf[pos] = UInt8(' ')
+            pos += 1
+        end
+        buf[pos] = UInt8('I')
+        buf[pos + 1] = UInt8('n')
+        buf[pos + 2] = UInt8('f')
+        return pos + 3
+    end
+
+    bits = Core.bitcast(UInt64, x)
+    mant = bits & MANTISSA_MASK
+    exp = Int((bits >> 52) & EXP_MASK)
+
+    if exp == 0
+        e2 = 1 - 1023 - 52
+        m2 = mant
+    else
+        e2 = exp - 1023 - 52
+        m2 = (Int64(1) << 52) | mant
+    end
+    nonzero = false
+    if neg
+        buf[pos] = UInt8('-')
+        pos += 1
+    elseif plus
+        buf[pos] = UInt8('+')
+        pos += 1
+    elseif space
+        buf[pos] = UInt8(' ')
+        pos += 1
+    end
+    if e2 >= -52
+        idx = e2 < 0 ? 0 : indexforexp(e2)
+        p10bits = pow10bitsforindex(idx)
+        len = lengthforindex(idx)
+        i = len - 1
+        while i >= 0
+            j = p10bits - e2
+            #=@inbounds=# mula, mulb, mulc = POW10_SPLIT[POW10_OFFSET[idx + 1] + i + 1]
+            digits = mulshiftmod1e9(m2 << 8, mula, mulb, mulc, j + 8)
+            if nonzero
+                pos = append_nine_digits(digits, buf, pos)
+            elseif digits != 0
+                olength = decimallength(digits)
+                pos = append_n_digits(olength, digits, buf, pos)
+                nonzero = true
+            end
+            i -= 1
+        end
+    end
+    if !nonzero
+        buf[pos] = UInt8('0')
+        pos += 1
+    end
+    if precision > 0 || hash
+        buf[pos] = decchar
+        pos += 1
+    end
+    if e2 < 0
+        idx = div(-e2, 16)
+        blocks = div(precision, 9) + 1
+        roundUp = 0
+        i = 0
+        if blocks <= MIN_BLOCK_2[idx + 1]
+            i = blocks
+            for _ = 1:precision
+                buf[pos] = UInt8('0')
+                pos += 1
+            end
+        elseif i < MIN_BLOCK_2[idx + 1]
+            i = MIN_BLOCK_2[idx + 1]
+            for _ = 1:(9 * i)
+                buf[pos] = UInt8('0')
+                pos += 1
+            end
+        end
+        while i < blocks
+            j = 120 + (-e2 - 16 * idx)
+            p = POW10_OFFSET_2[idx + 1] + UInt32(i) - MIN_BLOCK_2[idx + 1]
+            if p >= POW10_OFFSET_2[idx + 2]
+                for _ = 1:(precision - 9 * i)
+                    buf[pos] = UInt8('0')
+                    pos += 1
+                end
+                break
+            end
+            #=@inbounds=# mula, mulb, mulc = POW10_SPLIT_2[p + 1]
+            digits = mulshiftmod1e9(m2 << 8, mula, mulb, mulc, j + 8)
+            if i < blocks - 1
+                pos = append_nine_digits(digits, buf, pos)
+            else
+                maximum = precision - 9 * i
+                lastDigit = 0
+                k = 0
+                while k < 9 - maximum
+                    # global digits, lastDigit, k
+                    lastDigit = digits % 10
+                    digits = div(digits, 10)
+                    k += 1
+                end
+                if lastDigit != 5
+                    roundUp = lastDigit > 5
+                else
+                    requiredTwos = -e2 - precision - 1
+                    trailingZeros = requiredTwos <= 0 || (requiredTwos < 60 && pow2(m2, requiredTwos))
+                    roundUp = trailingZeros ? 2 : 1
+                end
+                if maximum > 0
+                    pos = append_c_digits(maximum, digits, buf, pos)
+                end
+                break
+            end
+            i += 1
+        end
+        if roundUp != 0
+            roundPos = pos
+            dotPos = 1
+            while true
+                roundPos -= 1
+                if roundPos == 0 || (buf[roundPos] == UInt8('-'))
+                    buf[roundPos + 1] = UInt8('1')
+                    if dotPos > 1
+                        buf[dotPos] = UInt8('0')
+                        buf[dotPos + 1] = decchar
+                    end
+                    buf[pos] = UInt8('0')
+                    pos += 1
+                    break
+                end
+                c = roundPos > 0 ? buf[roundPos] : 0x00
+                if c == decchar
+                    dotPos = roundPos
+                    continue
+                elseif c == UInt8('9')
+                    buf[roundPos] = UInt8('0')
+                    roundUp = 1
+                    continue
+                else
+                    if roundUp == 2 && UInt8(c) % 2 == 0
+                        break
+                    end
+                    buf[roundPos] = c + 1
+                    break
+                end
+            end
+        end
+    else
+        for _ = 1:precision
+            buf[pos] = UInt8('0')
+            pos += 1
+        end
+    end
+    if trimtrailingzeros
+        while buf[pos - 1] == UInt8('0')
+            pos -= 1
+        end
+        if buf[pos - 1] == decchar && !hash
+            pos -= 1
+        end
+    end
+    return pos
+end
diff -pruN 1.3.1+dfsg-1/base/ryu/LICENSE.md 1.4.0+dfsg-1/base/ryu/LICENSE.md
--- 1.3.1+dfsg-1/base/ryu/LICENSE.md	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/base/ryu/LICENSE.md	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1,25 @@
+The code in this directory (base/ryu) is a derivative based on the work in the https://github.com/ulfjack/ryu repository, which allows the use of the Boost software license, included below.
+
+Boost Software License - Version 1.0 - August 17th, 2003
+
+Permission is hereby granted, free of charge, to any person or organization
+obtaining a copy of the software and accompanying documentation covered by
+this license (the "Software") to use, reproduce, display, distribute,
+execute, and transmit the Software, and to prepare derivative works of the
+Software, and to permit third-parties to whom the Software is furnished to
+do so, all subject to the following:
+
+The copyright notices in the Software and this entire statement, including
+the above license grant, this restriction and the following disclaimer,
+must be included in all copies of the Software, in whole or in part, and
+all derivative works of the Software, unless such copies or derivative
+works are solely in the form of machine-executable object code generated by
+a source language processor.
+
+THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
+IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
+FITNESS FOR A PARTICULAR PURPOSE, TITLE AND NON-INFRINGEMENT. IN NO EVENT
+SHALL THE COPYRIGHT HOLDERS OR ANYONE DISTRIBUTING THE SOFTWARE BE LIABLE
+FOR ANY DAMAGES OR OTHER LIABILITY, WHETHER IN CONTRACT, TORT OR OTHERWISE,
+ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
+DEALINGS IN THE SOFTWARE.
\ No newline at end of file
diff -pruN 1.3.1+dfsg-1/base/ryu/Ryu.jl 1.4.0+dfsg-1/base/ryu/Ryu.jl
--- 1.3.1+dfsg-1/base/ryu/Ryu.jl	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/base/ryu/Ryu.jl	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1,130 @@
+module Ryu
+
+import .Base: significand_bits, significand_mask, exponent_bits, exponent_mask, exponent_bias, exponent_max, uinttype
+
+include("utils.jl")
+include("shortest.jl")
+include("fixed.jl")
+include("exp.jl")
+
+"""
+    Ryu.neededdigits(T)
+
+Number of digits necessary to represent type `T` in fixed-precision decimal.
+"""
+neededdigits(::Type{Float64}) = 309 + 17
+neededdigits(::Type{Float32}) = 39 + 9 + 2
+neededdigits(::Type{Float16}) = 9 + 5 + 9
+
+"""
+    Ryu.writeshortest(x, plus=false, space=false, hash=true, precision=-1, expchar=UInt8('e'), padexp=false, decchar=UInt8('.'), typed=false, compact=false)
+    Ryu.writeshortest(buf::Vector{UInt8}, pos::Int, x, args...)
+
+Convert a float value `x` into its "shortest" decimal string, which can be parsed back to the same value.
+This function allows achieving the `%g` printf format.
+Note the 2nd method allows passing in a byte buffer and position directly; callers must ensure the buffer has sufficient room to hold the entire decimal string.
+
+Various options for the output format include:
+  * `plus`: for positive `x`, prefix decimal string with a `'+'` character
+  * `space`: for positive `x`, prefix decimal string with a `' '` character; overridden if `plus=true`
+  * `hash`: whether the decimal point should be written, even if no additional digits are needed for precision
+  * `precision`: minimum number of digits to be included in the decimal string; extra `'0'` characters will be added for padding if necessary
+  * `expchar`: character to use exponent component in scientific notation
+  * `padexp`: whether two digits should always be written, even for single-digit exponents (e.g. `e+1` becomes `e+01`)
+  * `decchar`: decimal point character to be used
+  * `typed`: whether additional type information should be printed for `Float16` / `Float32`
+  * `compact`: output will be limited to 6 significant digits
+"""
+function writeshortest(x::T,
+        plus::Bool=false,
+        space::Bool=false,
+        hash::Bool=true,
+        precision::Integer=-1,
+        expchar::UInt8=UInt8('e'),
+        padexp::Bool=false,
+        decchar::UInt8=UInt8('.'),
+        typed::Bool=false,
+        compact::Bool=false) where {T <: Base.IEEEFloat}
+    buf = Base.StringVector(neededdigits(T))
+    pos = writeshortest(buf, 1, x, plus, space, hash, precision, expchar, padexp, decchar, typed, compact)
+    return String(resize!(buf, pos - 1))
+end
+
+"""
+    Ryu.writefixed(x, precision, plus=false, space=false, hash=false, decchar=UInt8('.'), trimtrailingzeros=false)
+    Ryu.writefixed(buf::Vector{UInt8}, pos::Int, x, args...)
+
+Convert a float value `x` into a "fixed" size decimal string of the provided precision.
+This function allows achieving the `%f` printf format.
+Note the 2nd method allows passing in a byte buffer and position directly; callers must ensure the buffer has sufficient room to hold the entire decimal string.
+
+Various options for the output format include:
+  * `plus`: for positive `x`, prefix decimal string with a `'+'` character
+  * `space`: for positive `x`, prefix decimal string with a `' '` character; overridden if `plus=true`
+  * `hash`: whether the decimal point should be written, even if no additional digits are needed for precision
+  * `precision`: minimum number of significant digits to be included in the decimal string; extra `'0'` characters will be added for padding if necessary
+  * `decchar`: decimal point character to be used
+  * `trimtrailingzeros`: whether trailing zeros should be removed
+"""
+function writefixed(x::T,
+    precision::Integer,
+    plus::Bool=false,
+    space::Bool=false,
+    hash::Bool=false,
+    decchar::UInt8=UInt8('.'),
+    trimtrailingzeros::Bool=false) where {T <: Base.IEEEFloat}
+    buf = Base.StringVector(precision + neededdigits(T))
+    pos = writefixed(buf, 1, x, precision, plus, space, hash, decchar, trimtrailingzeros)
+    return String(resize!(buf, pos - 1))
+end
+
+"""
+    Ryu.writeexp(x, precision, plus=false, space=false, hash=false, expchar=UInt8('e'), decchar=UInt8('.'), trimtrailingzeros=false)
+    Ryu.writeexp(buf::Vector{UInt8}, pos::Int, x, args...)
+
+Convert a float value `x` into a scientific notation decimal string.
+This function allows achieving the `%e` printf format.
+Note the 2nd method allows passing in a byte buffer and position directly; callers must ensure the buffer has sufficient room to hold the entire decimal string.
+
+Various options for the output format include:
+  * `plus`: for positive `x`, prefix decimal string with a `'+'` character
+  * `space`: for positive `x`, prefix decimal string with a `' '` character; overridden if `plus=true`
+  * `hash`: whether the decimal point should be written, even if no additional digits are needed for precision
+  * `precision`: minimum number of significant digits to be included in the decimal string; extra `'0'` characters will be added for padding if necessary
+  * `expchar`: character to use exponent component in scientific notation
+  * `decchar`: decimal point character to be used
+  * `trimtrailingzeros`: whether trailing zeros should be removed
+"""
+function writeexp(x::T,
+    precision::Integer,
+    plus::Bool=false,
+    space::Bool=false,
+    hash::Bool=false,
+    expchar::UInt8=UInt8('e'),
+    decchar::UInt8=UInt8('.'),
+    trimtrailingzeros::Bool=false) where {T <: Base.IEEEFloat}
+    buf = Base.StringVector(precision + neededdigits(T))
+    pos = writeexp(buf, 1, x, precision, plus, space, hash, expchar, decchar, trimtrailingzeros)
+    return String(resize!(buf, pos - 1))
+end
+
+function Base.show(io::IO, x::T, forceuntyped::Bool=false, fromprint::Bool=false) where {T <: Base.IEEEFloat}
+    compact = get(io, :compact, false)
+    buf = Base.StringVector(neededdigits(T))
+    typed = !forceuntyped && !compact && get(io, :typeinfo, Any) != typeof(x)
+    pos = writeshortest(buf, 1, x, false, false, true, -1,
+        (x isa Float32 && !fromprint) ? UInt8('f') : UInt8('e'), false, UInt8('.'), typed, compact)
+    write(io, resize!(buf, pos - 1))
+    return
+end
+
+function Base.string(x::T) where {T <: Base.IEEEFloat}
+    buf = Base.StringVector(neededdigits(T))
+    pos = writeshortest(buf, 1, x, false, false, true, -1,
+        UInt8('e'), false, UInt8('.'), false, false)
+    return String(resize!(buf, pos - 1))
+end
+
+Base.print(io::IO, x::Union{Float16, Float32}) = show(io, x, true, true)
+
+end # module
diff -pruN 1.3.1+dfsg-1/base/ryu/shortest.jl 1.4.0+dfsg-1/base/ryu/shortest.jl
--- 1.3.1+dfsg-1/base/ryu/shortest.jl	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/base/ryu/shortest.jl	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1,495 @@
+"""
+    b, e10 = reduce_shortest(f[, maxsignif])
+
+Reduce to shortest decimal representation where `abs(f) == b * 10^e10` and `b` is an
+integer. If a `maxsignif` argument is provided, then `b < maxsignif`.
+"""
+@inline function reduce_shortest(f::T, maxsignif=nothing) where {T}
+    U = uinttype(T)
+    uf = reinterpret(U, f)
+    m = uf & significand_mask(T)
+    e = Int((uf & exponent_mask(T)) >> significand_bits(T))
+
+    ## Step 1
+    #  mf * 2^ef == f
+    mf = (one(U) << significand_bits(T)) | m
+    ef = e - exponent_bias(T) - significand_bits(T)
+    f_isinteger = mf & ((one(U) << -ef) - one(U)) == 0
+
+    if ef > 0 || ef < -Base.significand_bits(T) || !f_isinteger
+        # fixup subnormals
+        if e == 0
+            ef = 1 - exponent_bias(T) - significand_bits(T)
+            mf = m
+        end
+
+        ## Step 2
+        #  u * 2^e2 == (f + prevfloat(f))/2
+        #  v * 2^e2 == f
+        #  w * 2^e2 == (f + nextfloat(f))/2
+        e2 = ef - 2
+        mf_iseven = iseven(mf) # trailing bit of significand is zero
+
+        v = U(4) * mf
+        w = v + U(2)
+        u_shift_half = m == 0 && e > 1 # if first element of binade, other than first normal one
+        u = v - U(2) + u_shift_half
+
+        ## Step 3
+        #  a == floor(u * 2^e2 / 10^e10), exact if a_allzero
+        #  b == floor(v * 2^e2 / 10^e10), exact if b_allzero
+        #  c == floor(w * 2^e2 / 10^e10)
+        a_allzero = false
+        b_allzero = false
+        b_lastdigit = 0x00
+        if e2 >= 0
+            q = log10pow2(e2) - (T == Float64 ? (e2 > 3) : 0)
+            e10 = q
+            k = pow5_inv_bitcount(T) + pow5bits(q) - 1
+            i = -e2 + q + k
+            a, b, c = mulshiftinvsplit(T, u, v, w, q, i)
+            if T == Float32 || T == Float16
+                if q != 0 && div(c - 1, 10) <= div(a, 10)
+                    l = pow5_inv_bitcount(T) + pow5bits(q - 1) - 1
+                    mul = pow5invsplit_lookup(T, q-1)
+                    b_lastdigit = (mulshift(v, mul, -e2 + q - 1 + l) % 10) % UInt8
+                end
+            end
+            if q <= qinvbound(T)
+                if ((v % UInt32) - 5 * div(v, 5)) == 0
+                    b_allzero = pow5(v, q)
+                elseif mf_iseven
+                    a_allzero = pow5(u, q)
+                else
+                    c -= pow5(w, q)
+                end
+            end
+        else
+            q = log10pow5(-e2) - (T == Float64 ? (-e2 > 1) : 0)
+            e10 = q + e2
+            i = -e2 - q
+            k = pow5bits(i) - pow5_bitcount(T)
+            j = q - k
+            a, b, c = mulshiftsplit(T, u, v, w, i, j)
+            if T == Float32 || T == Float16
+                if q != 0 && div(c - 1, 10) <= div(a, 10)
+                    j = q - 1 - (pow5bits(i + 1) - pow5_bitcount(T))
+                    mul = pow5split_lookup(T, i+1)
+                    b_lastdigit = (mulshift(v, mul, j) % 10) % UInt8
+                end
+            end
+            if q <= 1
+                b_allzero = true
+                if mf_iseven
+                    a_allzero = !u_shift_half
+                else
+                    c -= 1
+                end
+            elseif q < qbound(T)
+                b_allzero = pow2(v, q - (T != Float64))
+            end
+        end
+
+        ## Step 4: reduction
+        if a_allzero || b_allzero
+            # a) slow loop
+            while true
+                c_div10 = div(c, 10)
+                a_div10 = div(a, 10)
+                if c_div10 <= a_div10
+                    break
+                end
+                a_mod10 = (a % UInt32) - UInt32(10) * (a_div10 % UInt32)
+                b_div10 = div(b, 10)
+                b_mod10 = (b % UInt32) - UInt32(10) * (b_div10 % UInt32)
+                a_allzero &= a_mod10 == 0
+                b_allzero &= b_lastdigit == 0
+                b_lastdigit = b_mod10 % UInt8
+                b = b_div10
+                c = c_div10
+                a = a_div10
+                e10 += 1
+            end
+            if a_allzero
+                while true
+                    a_div10 = div(a, 10)
+                    a_mod10 = (a % UInt32) - UInt32(10) * (a_div10 % UInt32)
+                    if a_mod10 != 0 && (maxsignif === nothing || b < maxsignif)
+                        break
+                    end
+                    c_div10 = div(c, 10)
+                    b_div10 = div(b, 10)
+                    b_mod10 = (b % UInt32) - UInt32(10) * (b_div10 % UInt32)
+                    b_allzero &= b_lastdigit == 0
+                    b_lastdigit = b_mod10 % UInt8
+                    b = b_div10
+                    c = c_div10
+                    a = a_div10
+                    e10 += 1
+                end
+            end
+            if b_allzero && b_lastdigit == 5 && iseven(b)
+                b_lastdigit = UInt8(4)
+            end
+            roundup = (b == a && (!mf_iseven || !a_allzero)) || b_lastdigit >= 5
+        else
+            # b) specialized for common case (99% Float64, 96% Float32)
+            roundup = b_lastdigit >= 5
+            c_div100 = div(c, 100)
+            a_div100 = div(a, 100)
+            if c_div100 > a_div100
+                b_div100 = div(b, 100)
+                b_mod100 = (b % UInt32) - UInt32(100) * (b_div100 % UInt32)
+                roundup = b_mod100 >= 50
+                b = b_div100
+                c = c_div100
+                a = a_div100
+                e10 += 2
+            end
+            while true
+                c_div10 = div(c, 10)
+                a_div10 = div(a, 10)
+                if c_div10 <= a_div10
+                    break
+                end
+                b_div10 = div(b, 10)
+                b_mod10 = (b % UInt32) - UInt32(10) * (b_div10 % UInt32)
+                roundup = b_mod10 >= 5
+                b = b_div10
+                c = c_div10
+                a = a_div10
+                e10 += 1
+            end
+            roundup = (b == a || roundup)
+        end
+        if maxsignif !== nothing && b > maxsignif
+            # reduce to max significant digits
+            while true
+                b_div10 = div(b, 10)
+                b_mod10 = (b % UInt32) - UInt32(10) * (b_div10 % UInt32)
+                if b <= maxsignif
+                    break
+                end
+                b = b_div10
+                roundup = (b_allzero && iseven(b)) ? b_mod10 > 5 : b_mod10 >= 5
+                b_allzero &= b_mod10 == 0
+                e10 += 1
+            end
+            b = b + roundup
+
+            # remove trailing zeros
+            while true
+                b_div10 = div(b, 10)
+                b_mod10 = (b % UInt32) - UInt32(10) * (b_div10 % UInt32)
+                if b_mod10 != 0
+                    break
+                end
+                b = b_div10
+                e10 += 1
+            end
+        else
+            b = b + roundup
+        end
+    else
+        # c) specialized f an integer < 2^53
+        b = mf >> -ef
+        e10 = 0
+
+        if maxsignif !== nothing && b > maxsignif
+            b_allzero = true
+            # reduce to max significant digits
+            while true
+                b_div10 = div(b, 10)
+                b_mod10 = (b % UInt32) - UInt32(10) * (b_div10 % UInt32)
+                if b <= maxsignif
+                    break
+                end
+                b = b_div10
+                roundup = (b_allzero && iseven(b)) ? b_mod10 > 5 : b_mod10 >= 5
+                b_allzero &= b_mod10 == 0
+                e10 += 1
+            end
+            b = b + roundup
+        end
+        while true
+            b_div10 = div(b, 10)
+            b_mod10 = (b % UInt32) - UInt32(10) * (b_div10 % UInt32)
+            if b_mod10 != 0
+                break
+            end
+            b = b_div10
+            e10 += 1
+        end
+    end
+    return b, e10
+end
+
+
+@inline function writeshortest(buf::Vector{UInt8}, pos, x::T,
+                               plus=false, space=false, hash=true,
+                               precision=-1, expchar=UInt8('e'), padexp=false, decchar=UInt8('.'),
+                               typed=false, compact=false) where {T}
+    @assert 0 < pos <= length(buf)
+    neg = signbit(x)
+    # special cases
+    if x == 0
+        if neg
+            buf[pos] = UInt8('-')
+            pos += 1
+        elseif plus
+            buf[pos] = UInt8('+')
+            pos += 1
+        elseif space
+            buf[pos] = UInt8(' ')
+            pos += 1
+        end
+        buf[pos] = UInt8('0')
+        pos += 1
+        if hash
+            buf[pos] = decchar
+            pos += 1
+        end
+        if precision == -1
+            buf[pos] = UInt8('0')
+            pos += 1
+            if typed && x isa Float32
+                buf[pos] = UInt8('f')
+                buf[pos + 1] = UInt8('0')
+                pos += 2
+            end
+            return pos
+        end
+        while precision > 1
+            buf[pos] = UInt8('0')
+            pos += 1
+            precision -= 1
+        end
+        if typed && x isa Float32
+            buf[pos] = UInt8('f')
+            buf[pos + 1] = UInt8('0')
+            pos += 2
+        end
+        return pos
+    elseif isnan(x)
+        buf[pos] = UInt8('N')
+        buf[pos + 1] = UInt8('a')
+        buf[pos + 2] = UInt8('N')
+        if typed
+            if x isa Float32
+                buf[pos + 3] = UInt8('3')
+                buf[pos + 4] = UInt8('2')
+            elseif x isa Float16
+                buf[pos + 3] = UInt8('1')
+                buf[pos + 4] = UInt8('6')
+            end
+        end
+        return pos + 3 + (typed && x isa Union{Float32, Float16} ? 2 : 0)
+    elseif !isfinite(x)
+        if neg
+            buf[pos] = UInt8('-')
+        end
+        buf[pos + neg] = UInt8('I')
+        buf[pos + neg + 1] = UInt8('n')
+        buf[pos + neg + 2] = UInt8('f')
+        if typed
+            if x isa Float32
+                buf[pos + neg + 3] = UInt8('3')
+                buf[pos + neg + 4] = UInt8('2')
+            elseif x isa Float16
+                buf[pos + neg + 3] = UInt8('1')
+                buf[pos + neg + 4] = UInt8('6')
+            end
+        end
+        return pos + neg + 3 + (typed && x isa Union{Float32, Float16} ? 2 : 0)
+    end
+
+    output, nexp = reduce_shortest(x, compact ? 999_999 : nothing)
+
+    if typed && x isa Float16
+        buf[pos] = UInt8('F')
+        buf[pos + 1] = UInt8('l')
+        buf[pos + 2] = UInt8('o')
+        buf[pos + 3] = UInt8('a')
+        buf[pos + 4] = UInt8('t')
+        buf[pos + 5] = UInt8('1')
+        buf[pos + 6] = UInt8('6')
+        buf[pos + 7] = UInt8('(')
+        pos += 8
+    end
+    if neg
+        buf[pos] = UInt8('-')
+        pos += 1
+    elseif plus
+        buf[pos] = UInt8('+')
+        pos += 1
+    elseif space
+        buf[pos] = UInt8(' ')
+        pos += 1
+    end
+
+    olength = decimallength(output)
+    exp_form = true
+    pt = nexp + olength
+    if -4 < pt <= (precision == -1 ? (T == Float16 ? 3 : 6) : precision)
+        exp_form = false
+        if pt <= 0
+            buf[pos] = UInt8('0')
+            pos += 1
+            buf[pos] = decchar
+            pos += 1
+            for _ = 1:abs(pt)
+                buf[pos] = UInt8('0')
+                pos += 1
+            end
+            # elseif pt >= olength
+            # nothing to do at this point
+            # else
+            # nothing to do at this point
+        end
+    else
+        pos += 1
+    end
+    i = 0
+    ptr = pointer(buf)
+    ptr2 = pointer(DIGIT_TABLE)
+    if (output >> 32) != 0
+        q = output ÷ 100000000
+        output2 = (output % UInt32) - UInt32(100000000) * (q % UInt32)
+        output = q
+
+        c = output2 % UInt32(10000)
+        output2 = div(output2, UInt32(10000))
+        d = output2 % UInt32(10000)
+        c0 = (c % 100) << 1
+        c1 = (c ÷ 100) << 1
+        d0 = (d % 100) << 1
+        d1 = (d ÷ 100) << 1
+        memcpy(ptr, pos + olength - 2, ptr2, c0 + 1, 2)
+        memcpy(ptr, pos + olength - 4, ptr2, c1 + 1, 2)
+        memcpy(ptr, pos + olength - 6, ptr2, d0 + 1, 2)
+        memcpy(ptr, pos + olength - 8, ptr2, d1 + 1, 2)
+        i += 8
+    end
+    output2 = output % UInt32
+    while output2 >= 10000
+        c = output2 % UInt32(10000)
+        output2 = div(output2, UInt32(10000))
+        c0 = (c % 100) << 1
+        c1 = (c ÷ 100) << 1
+        memcpy(ptr, pos + olength - i - 2, ptr2, c0 + 1, 2)
+        memcpy(ptr, pos + olength - i - 4, ptr2, c1 + 1, 2)
+        i += 4
+    end
+    if output2 >= 100
+        c = (output2 % UInt32(100)) << 1
+        output2 = div(output2, UInt32(100))
+        memcpy(ptr, pos + olength - i - 2, ptr2, c + 1, 2)
+        i += 2
+    end
+    if output2 >= 10
+        c = output2 << 1
+        buf[pos + 1] = DIGIT_TABLE[c + 2]
+        buf[pos - exp_form] = DIGIT_TABLE[c + 1]
+    else
+        buf[pos - exp_form] = UInt8('0') + (output2 % UInt8)
+    end
+
+    if !exp_form
+        if pt <= 0
+            pos += olength
+            precision -= olength
+            while hash && precision > 0
+                buf[pos] = UInt8('0')
+                pos += 1
+                precision -= 1
+            end
+        elseif pt >= olength
+            pos += olength
+            precision -= olength
+            for _ = 1:nexp
+                buf[pos] = UInt8('0')
+                pos += 1
+                precision -= 1
+            end
+            if hash
+                buf[pos] = decchar
+                pos += 1
+                if precision < 0
+                    buf[pos] = UInt8('0')
+                    pos += 1
+                end
+                while precision > 0
+                    buf[pos] = UInt8('0')
+                    pos += 1
+                    precision -= 1
+                end
+            end
+        else
+            pointoff = olength - abs(nexp)
+            memmove(ptr, pos + pointoff + 1, ptr, pos + pointoff, olength - pointoff + 1)
+            buf[pos + pointoff] = decchar
+            pos += olength + 1
+            precision -= olength
+            while hash && precision > 0
+                buf[pos] = UInt8('0')
+                pos += 1
+                precision -= 1
+            end
+        end
+        if typed && x isa Float32
+            buf[pos] = UInt8('f')
+            buf[pos + 1] = UInt8('0')
+            pos += 2
+        end
+    else
+        if olength > 1 || hash
+            buf[pos] = decchar
+            pos += olength
+            precision -= olength
+        end
+        if hash && olength == 1
+            buf[pos] = UInt8('0')
+            pos += 1
+        end
+        while hash && precision > 0
+            buf[pos] = UInt8('0')
+            pos += 1
+            precision -= 1
+        end
+
+        buf[pos] = expchar
+        pos += 1
+        exp2 = nexp + olength - 1
+        if exp2 < 0
+            buf[pos] = UInt8('-')
+            pos += 1
+            exp2 = -exp2
+        elseif padexp
+            buf[pos] = UInt8('+')
+            pos += 1
+        end
+
+        if exp2 >= 100
+            c = exp2 % 10
+            memcpy(ptr, pos, ptr2, 2 * div(exp2, 10) + 1, 2)
+            buf[pos + 2] = UInt8('0') + (c % UInt8)
+            pos += 3
+        elseif exp2 >= 10
+            memcpy(ptr, pos, ptr2, 2 * exp2 + 1, 2)
+            pos += 2
+        else
+            if padexp
+                buf[pos] = UInt8('0')
+                pos += 1
+            end
+            buf[pos] = UInt8('0') + (exp2 % UInt8)
+            pos += 1
+        end
+    end
+    if typed && x isa Float16
+        buf[pos] = UInt8(')')
+        pos += 1
+    end
+
+    return pos
+end
diff -pruN 1.3.1+dfsg-1/base/ryu/utils.jl 1.4.0+dfsg-1/base/ryu/utils.jl
--- 1.3.1+dfsg-1/base/ryu/utils.jl	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/base/ryu/utils.jl	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1,410 @@
+const MANTISSA_MASK = Base.significand_mask(Float64)
+const EXP_MASK = Base.exponent_mask(Float64) >> Base.significand_bits(Float64)
+
+memcpy(d, doff, s, soff, n) = (ccall(:memcpy, Ptr{Cvoid}, (Ptr{Cvoid}, Ptr{Cvoid}, Csize_t), d + doff - 1, s + soff - 1, n); nothing)
+memmove(d, doff, s, soff, n) = (ccall(:memmove, Ptr{Cvoid}, (Ptr{Cvoid}, Ptr{Cvoid}, Csize_t), d + doff - 1, s + soff - 1, n); nothing)
+
+# Note: these are smaller than the values given in Figure 4 from the paper
+# see https://github.com/ulfjack/ryu/issues/119
+pow5_bitcount(::Type{Float16}) = 30
+pow5_bitcount(::Type{Float32}) = 61
+pow5_bitcount(::Type{Float64}) = 121
+
+pow5_inv_bitcount(::Type{Float16}) = 30
+pow5_inv_bitcount(::Type{Float32}) = 59
+pow5_inv_bitcount(::Type{Float64}) = 122
+
+qinvbound(::Type{Float16}) = 4
+qinvbound(::Type{Float32}) = 9
+qinvbound(::Type{Float64}) = 21
+
+qbound(::Type{Float16}) = 15
+qbound(::Type{Float32}) = 31
+qbound(::Type{Float64}) = 63
+
+"""
+    Ryu.log10pow2(e::Integer)
+
+Computes `floor(log10(2^e))`. This is valid for all `e < 1651`.
+"""
+log10pow2(e) = (e * 78913) >> 18
+
+
+"""
+    Ryu.log10pow5(e::Integer)
+
+Computes `floor(log10(5^e))`. This is valid for all `e < 2621`.
+"""
+log10pow5(e) = (e * 732923) >> 20
+
+"""
+    Ryu.pow5bits(e)
+
+Computes `e == 0 ? 1 : ceil(log2(5^e))`. This is valid for `e < 3529` (if performend in `Int32` arithmetic).
+"""
+pow5bits(e) = ((e * 1217359) >> 19) + 1
+
+""""
+     Ryu.mulshift(m::U, mula, j) where {U<:Unsigned}
+
+Compute `(m * mul) >> j`, where `j >= 8*sizeof(U)`. The type of the results is the larger of `U` or `UInt32`.
+"""
+@inline function mulshift(m::U, mul, j) where {U<:Unsigned}
+    W = widen(U)
+    nbits = 8*sizeof(U)
+    return ((((W(m) * (mul % U)) >> nbits) + W(m) * (mul >> nbits)) >> (j - nbits)) % promote_type(U,UInt32)
+end
+
+indexforexp(e) = div(e + 15, 16)
+pow10bitsforindex(idx) = 16 * idx + 120
+lengthforindex(idx) = div(((Int64(16 * idx) * 1292913986) >> 32) + 1 + 16 + 8, 9)
+
+"""
+    Ryu.pow5(x, p)
+
+Return `true` if `5^p` is a divisor of `x`.
+"""
+@inline function pow5(x, p)
+    count = 0
+    while true
+        q = div(x, 5)
+        r = x - 5 * q
+        r != 0 && return count >= p
+        x = q
+        count += 1
+    end
+end
+
+"""
+    Ryu.pow2(x, p)
+
+Return `true` if `2^p` is a divisor of `x`. In other words, if the trailing `p` bits of `x` are zero.
+"""
+pow2(x, p) = (x & ((Int64(1) << p) - 1)) == 0
+
+"""
+    Ryu.decimallength(v)
+
+The number of decimal digits of the integer `v`.
+"""
+@inline function decimallength(v)
+    v >= 10000000000000000 && return 17
+    v >= 1000000000000000 && return 16
+    v >= 100000000000000 && return 15
+    v >= 10000000000000 && return 14
+    v >= 1000000000000 && return 13
+    v >= 100000000000 && return 12
+    v >= 10000000000 && return 11
+    v >= 1000000000 && return 10
+    v >= 100000000 && return 9
+    v >= 10000000 && return 8
+    v >= 1000000 && return 7
+    v >= 100000 && return 6
+    v >= 10000 && return 5
+    v >= 1000 && return 4
+    v >= 100 && return 3
+    v >= 10 && return 2
+    return 1
+end
+@inline function decimallength(v::UInt32)
+    v >= 100000000 && return 9
+    v >= 10000000 && return 8
+    v >= 1000000 && return 7
+    v >= 100000 && return 6
+    v >= 10000 && return 5
+    v >= 1000 && return 4
+    v >= 100 && return 3
+    v >= 10 && return 2
+    return 1
+end
+@inline function decimallength(v::UInt16)
+    v >= 10000 && return 5
+    v >= 1000 && return 4
+    v >= 100 && return 3
+    v >= 10 && return 2
+    return 1
+end
+
+@inline function mulshiftinvsplit(::Type{T}, mv, mp, mm, i, j) where {T}
+    mul = pow5invsplit_lookup(T, i)
+    vr = mulshift(mv, mul, j)
+    vp = mulshift(mp, mul, j)
+    vm = mulshift(mm, mul, j)
+    return vr, vp, vm
+end
+
+@inline function mulshiftsplit(::Type{T}, mv, mp, mm, i, j) where {T}
+    mul = pow5split_lookup(T, i)
+    vr = mulshift(mv, mul, j)
+    vp = mulshift(mp, mul, j)
+    vm = mulshift(mm, mul, j)
+    return vr, vp, vm
+end
+
+"""
+    Ryu.umul256(a::UInt128, bHi::UInt64, bLo::UInt64)::Tuple{UInt128, UInt128}
+
+Compute `p = a*b` where `b = bLo + bHi<<64`, returning the result as `pLo, pHi` where `p = pLo + pHi<<128`.
+"""
+@inline function umul256(a, bHi, bLo)
+    aLo = a % UInt64
+    aHi = (a >> 64) % UInt64
+
+    b00 = UInt128(aLo) * bLo
+    b01 = UInt128(aLo) * bHi
+    b10 = UInt128(aHi) * bLo
+    b11 = UInt128(aHi) * bHi
+
+    b00Lo = b00 % UInt64
+    b00Hi = (b00 >> 64) % UInt64
+
+    mid1 = b10 + b00Hi
+    mid1Lo = mid1 % UInt64
+    mid1Hi = (mid1 >> 64) % UInt64
+
+    mid2 = b01 + mid1Lo
+    mid2Lo = mid2 % UInt64
+    mid2Hi = (mid2 >> 64) % UInt64
+
+    pHi = b11 + mid1Hi + mid2Hi
+    pLo = (UInt128(mid2Lo) << 64) | b00Lo
+    return pLo, pHi
+end
+
+"""
+    Ryu.umul256_hi(a::UInt128, bHi::UInt64, bLo::UInt64)::UInt128
+
+Compute `pHi = (a*b)>>128` where `b = bLo + bHi<<64`.
+"""
+@inline umul256_hi(a, bHi, bLo) = umul256(a, bHi, bLo)[2]
+
+"""
+    Ryu.mulshiftmod1e9(m, mula, mulb, mulc, j)::UInt32
+
+Compute `(m * mul) >> j % 10^9` where `mul = mula + mulb<<64 + mulc<<128`, and `j >= 128`.
+"""
+@inline function mulshiftmod1e9(m, mula, mulb, mulc, j)
+    b0 = UInt128(m) * mula
+    b1 = UInt128(m) * mulb
+    b2 = UInt128(m) * mulc
+    mid = b1 + ((b0 >> 64) % UInt64)
+    s1 = b2 + ((mid >> 64) % UInt64)
+    v = s1 >> (j - 128)
+    multiplied = umul256_hi(v, 0x89705F4136B4A597, 0x31680A88F8953031)
+    shifted = (multiplied >> 29) % UInt32
+    return (v % UInt32) - UInt32(1000000000) * shifted
+end
+
+@inline function append_n_digits(olength, digits, buf, pos)
+    i = 0
+    while digits >= 10000
+        c = digits % 10000
+        digits = div(digits, 10000)
+        c0 = (c % 100) << 1
+        c1 = div(c, 100) << 1
+        unsafe_copyto!(buf, pos + olength - i - 2, DIGIT_TABLE, c0 + 1, 2)
+        unsafe_copyto!(buf, pos + olength - i - 4, DIGIT_TABLE, c1 + 1, 2)
+        i += 4
+    end
+    if digits >= 100
+        c = (digits % 100) << 1
+        digits = div(digits, 100)
+        unsafe_copyto!(buf, pos + olength - i - 2, DIGIT_TABLE, c + 1, 2)
+        i += 2
+    end
+    if digits >= 10
+        c = digits << 1
+        unsafe_copyto!(buf, pos + olength - i - 2, DIGIT_TABLE, c + 1, 2)
+        i += 2
+    else
+        buf[pos] = UInt8('0') + digits
+        i += 1
+    end
+    return pos + i
+end
+
+@inline function append_d_digits(olength, digits, buf, pos, decchar)
+    i = 0
+    while digits >= 10000
+        c = digits % 10000
+        digits = div(digits, 10000)
+        c0 = (c % 100) << 1
+        c1 = div(c, 100) << 1
+        unsafe_copyto!(buf, pos + olength + 1 - i - 2, DIGIT_TABLE, c0 + 1, 2)
+        unsafe_copyto!(buf, pos + olength + 1 - i - 4, DIGIT_TABLE, c1 + 1, 2)
+        i += 4
+    end
+    if digits >= 100
+        c = (digits % 100) << 1
+        digits = div(digits, 100)
+        unsafe_copyto!(buf, pos + olength + 1 - i - 2, DIGIT_TABLE, c + 1, 2)
+        i += 2
+    end
+    if digits >= 10
+        c = digits << 1
+        buf[pos] = DIGIT_TABLE[c + 1]
+        buf[pos + 1] = decchar
+        buf[pos + 2] = DIGIT_TABLE[c + 2]
+        i += 3
+    else
+        buf[pos] = UInt8('0') + digits
+        buf[pos + 1] = decchar
+        i += 2
+    end
+    return pos + i
+end
+
+@inline function append_c_digits(count, digits, buf, pos)
+    i = 0
+    while i < count - 1
+        c = (digits % 100) << 1
+        digits = div(digits, 100)
+        unsafe_copyto!(buf, pos + count - i - 2, DIGIT_TABLE, c + 1, 2)
+        i += 2
+    end
+    if i < count
+        buf[pos + count - i - 1] = UInt8('0') + (digits % 10)
+        i += 1
+    end
+    return pos + i
+end
+
+@inline function append_nine_digits(digits, buf, pos)
+    if digits == 0
+        for _ = 1:9
+            buf[pos] = UInt8('0')
+            pos += 1
+        end
+        return pos
+    end
+    i = 0
+    while i < 5
+        c = digits % 10000
+        digits = div(digits, 10000)
+        c0 = (c % 100) << 1
+        c1 = div(c, 100) << 1
+        unsafe_copyto!(buf, pos + 7 - i, DIGIT_TABLE, c0 + 1, 2)
+        unsafe_copyto!(buf, pos + 5 - i, DIGIT_TABLE, c1 + 1, 2)
+        i += 4
+    end
+    buf[pos] = UInt8('0') + digits
+    i += 1
+    return pos + i
+end
+
+const BIG_MASK = (big(1) << 64) - 1
+
+const POW10_SPLIT = collect(Iterators.flatten(map(0:63) do idx
+    pow10bits = pow10bitsforindex(idx)
+    map(0:lengthforindex(idx)-1) do i
+        v = (div(big(1) << pow10bits, big(10)^(9 * i)) + 1) % ((big(10)^9) << 136)
+        return (UInt64(v & BIG_MASK), UInt64((v >> 64) & BIG_MASK), UInt64((v >> 128) & BIG_MASK))
+    end
+end))
+
+function generateinversetables()
+    POW10_OFFSET_2 = Vector{UInt16}(undef, 68 + 1)
+    MIN_BLOCK_2 = fill(0xff, 68 + 1)
+    POW10_SPLIT_2 = Tuple{UInt64, UInt64, UInt64}[]
+    lowerCutoff = big(1) << (54 + 8)
+    for idx = 0:67
+        POW10_OFFSET_2[idx + 1] = length(POW10_SPLIT_2)
+        i = 0
+        while true
+            v = ((big(10)^(9 * (i + 1)) >> (-(120 - 16 * idx))) % (big(10)^9) << (120 + 16))
+            if MIN_BLOCK_2[idx + 1] == 0xff && ((v * lowerCutoff) >> 128) == 0
+                i += 1
+                continue
+            end
+            if MIN_BLOCK_2[idx + 1] == 0xff
+                MIN_BLOCK_2[idx + 1] = i
+            end
+            v == 0 && break
+            push!(POW10_SPLIT_2, ((v & BIG_MASK) % UInt64, ((v >> 64) & BIG_MASK) % UInt64, ((v >> 128) & BIG_MASK) % UInt64))
+            i += 1
+        end
+    end
+    POW10_OFFSET_2[end] = length(POW10_SPLIT_2)
+    MIN_BLOCK_2[end] = 0x00
+
+    return POW10_OFFSET_2, MIN_BLOCK_2, POW10_SPLIT_2
+end
+
+const POW10_OFFSET_2, MIN_BLOCK_2, POW10_SPLIT_2 = generateinversetables()
+
+"""
+    Ryu.pow5invsplit(T, i)
+
+Compute `floor(2^k/5^i)+1`, where `k = pow5bits(i) - 1 + pow5_inv_bitcount(T)`. The result
+is an unsigned integer twice as wide as `T` (i.e. a `UInt128` if `T == Float64`), with
+`pow5_inv_bitcount(T)` significant bits.
+"""
+function pow5invsplit(::Type{T}, i) where {T<:AbstractFloat}
+    W = widen(uinttype(T))
+    pow = big(5)^i
+    inv = div(big(1) << (ndigits(pow, base=2) - 1 + pow5_inv_bitcount(T)), pow) + 1
+    return W(inv)
+end
+
+"""
+    Ryu.pow5invsplit_lookup(T, i)
+
+[`pow5invsplit`](@ref) computed via lookup table.
+"""
+function pow5invsplit_lookup end
+for T in (Float64, Float32, Float16)
+    e2_max = exponent_max(T) - precision(T) - 2
+    i_max = log10pow2(e2_max)
+    table = [pow5invsplit(T, i) for i = 0:i_max]
+    @eval pow5invsplit_lookup(::Type{$T}, i) = @inbounds($table[i+1])
+end
+
+
+"""
+    Ryu.pow5split(T, i)
+
+Compute `floor(5^i/2^k)`, where `k = pow5bits(i) - pow5_bitcount(T)`. The result is an
+unsigned integer twice as wide as `T` (i.e. a `UInt128` if `T == Float64`), with
+`pow5_bitcount(T)` significant bits.
+"""
+function pow5split(::Type{T}, i) where {T<:AbstractFloat}
+    W = widen(uinttype(T))
+    pow = big(5)^i
+    return W(pow >> (ndigits(pow, base=2) - pow5_bitcount(T)))
+end
+
+"""
+    Ryu.pow5split_lookup(T, i)
+
+[`pow5split`](@ref) computed via lookup table.
+"""
+function pow5split_lookup end
+for T in (Float64, Float32, Float16)
+    e2_min = 1 - exponent_bias(T) - significand_bits(T) - 2
+    i_max = 1 - e2_min - log10pow5(-e2_min)
+    table = [pow5split(T, i) for i = 0:i_max]
+    @eval pow5split_lookup(::Type{$T}, i) = @inbounds($table[i+1])
+end
+
+const DIGIT_TABLE = UInt8[
+  '0','0','0','1','0','2','0','3','0','4','0','5','0','6','0','7','0','8','0','9',
+  '1','0','1','1','1','2','1','3','1','4','1','5','1','6','1','7','1','8','1','9',
+  '2','0','2','1','2','2','2','3','2','4','2','5','2','6','2','7','2','8','2','9',
+  '3','0','3','1','3','2','3','3','3','4','3','5','3','6','3','7','3','8','3','9',
+  '4','0','4','1','4','2','4','3','4','4','4','5','4','6','4','7','4','8','4','9',
+  '5','0','5','1','5','2','5','3','5','4','5','5','5','6','5','7','5','8','5','9',
+  '6','0','6','1','6','2','6','3','6','4','6','5','6','6','6','7','6','8','6','9',
+  '7','0','7','1','7','2','7','3','7','4','7','5','7','6','7','7','7','8','7','9',
+  '8','0','8','1','8','2','8','3','8','4','8','5','8','6','8','7','8','8','8','9',
+  '9','0','9','1','9','2','9','3','9','4','9','5','9','6','9','7','9','8','9','9'
+]
+
+const POW10_OFFSET = UInt16[
+  0, 2, 5, 8, 12, 16, 21, 26, 32, 39,
+  46, 54, 62, 71, 80, 90, 100, 111, 122, 134,
+  146, 159, 173, 187, 202, 217, 233, 249, 266, 283,
+  301, 319, 338, 357, 377, 397, 418, 440, 462, 485,
+  508, 532, 556, 581, 606, 632, 658, 685, 712, 740,
+  769, 798, 828, 858, 889, 920, 952, 984, 1017, 1050,
+  1084, 1118, 1153, 1188
+]
diff -pruN 1.3.1+dfsg-1/base/set.jl 1.4.0+dfsg-1/base/set.jl
--- 1.3.1+dfsg-1/base/set.jl	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/base/set.jl	2020-03-21 16:36:32.000000000 +0000
@@ -373,7 +373,7 @@ function allunique(C)
     true
 end
 
-allunique(::Set) = true
+allunique(::Union{AbstractSet,AbstractDict}) = true
 
 allunique(r::AbstractRange{T}) where {T} = (step(r) != zero(T)) || (length(r) <= 1)
 allunique(r::StepRange{T,S}) where {T,S} = (step(r) != zero(S)) || (length(r) <= 1)
@@ -439,7 +439,10 @@ julia> replace!([1, 2, 1, 3], 1=>0, 2=>4
  3
 
 julia> replace!(Set([1, 2, 3]), 1=>0)
-Set([0, 2, 3])
+Set{Int64} with 3 elements:
+  0
+  2
+  3
 ```
 """
 replace!(A, old_new::Pair...; count::Integer=typemax(Int)) =
@@ -479,7 +482,9 @@ Dict{Int64,Int64} with 2 entries:
   1 => 3
 
 julia> replace!(x->2x, Set([3, 6]))
-Set([6, 12])
+Set{Int64} with 2 elements:
+  6
+  12
 ```
 """
 replace!(new::Callable, A; count::Integer=typemax(Int)) =
diff -pruN 1.3.1+dfsg-1/base/shell.jl 1.4.0+dfsg-1/base/shell.jl
--- 1.3.1+dfsg-1/base/shell.jl	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/base/shell.jl	2020-03-21 16:36:32.000000000 +0000
@@ -253,3 +253,62 @@ julia> Base.shell_escape_posixly("echo",
 """
 shell_escape_posixly(args::AbstractString...) =
     sprint(print_shell_escaped_posixly, args...)
+
+
+function print_shell_escaped_winsomely(io::IO, args::AbstractString...)
+    first = true
+    for arg in args
+        first || write(io, ' ')
+        first = false
+        # Quote any arg that contains a whitespace (' ' or '\t') or a double quote mark '"'.
+        # It's also valid to quote an arg with just a whitespace,
+        # but the following may be 'safer', and both implementations are valid anyways.
+        quotes = any(c -> c in (' ', '\t', '"'), arg) || isempty(arg)
+        quotes && write(io, '"')
+        backslashes = 0
+        for c in arg
+            if c == '\\'
+                backslashes += 1
+            else
+                # escape all backslashes and the following double quote
+                c == '"' && (backslashes = backslashes * 2 + 1)
+                for j = 1:backslashes
+                    # backslashes aren't special here
+                    write(io, '\\')
+                end
+                backslashes = 0
+                write(io, c)
+            end
+        end
+        # escape all backslashes, letting the terminating double quote we add below to then be interpreted as a special char
+        quotes && (backslashes *= 2)
+        for j = 1:backslashes
+            write(io, '\\')
+        end
+        quotes && write(io, '"')
+    end
+    return nothing
+end
+
+
+"""
+     shell_escaped_winsomely(args::Union{Cmd,AbstractString...})::String
+
+Convert the collection of strings `args` into single string suitable for passing as the argument
+string for a Windows command line. Windows passes the entire command line as a single string to
+the application (unlike POSIX systems, where the list of arguments are passed separately).
+Many Windows API applications (including julia.exe), use the conventions of the [Microsoft C
+runtime](https://docs.microsoft.com/en-us/cpp/c-language/parsing-c-command-line-arguments) to
+split that command line into a list of strings. This function implements the inverse of such a
+C runtime command-line parser. It joins command-line arguments to be passed to a Windows console
+application into a command line, escaping or quoting meta characters such as space,
+double quotes and backslash where needed. This may be useful in concert with the `windows_verbatim`
+flag to [`Cmd`](@ref) when constructing process pipelines.
+
+# Example
+```jldoctest
+julia> println(shell_escaped_winsomely("A B\\", "C"))
+"A B\\" C
+"""
+shell_escape_winsomely(args::AbstractString...) =
+    sprint(print_shell_escaped_winsomely, args..., sizehint=(sum(length, args)) + 3*length(args))
diff -pruN 1.3.1+dfsg-1/base/show.jl 1.4.0+dfsg-1/base/show.jl
--- 1.3.1+dfsg-1/base/show.jl	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/base/show.jl	2020-03-21 16:36:32.000000000 +0000
@@ -1,6 +1,8 @@
 # This file is a part of Julia. License is MIT: https://julialang.org/license
 
-show(io::IO, ::UndefInitializer) = print(io, "array initializer with undefined values")
+function show(io::IO, ::MIME"text/plain", u::UndefInitializer)
+    print(io, u, ": array initializer with undefined values")
+end
 
 # first a few multiline show functions for types defined before the MIME type:
 
@@ -22,7 +24,7 @@ function show(io::IO, ::MIME"text/plain"
     ft = typeof(f)
     mt = ft.name.mt
     if isa(f, Core.IntrinsicFunction)
-        show(io, f)
+        print(io, f)
         id = Core.Intrinsics.bitcast(Int32, f)
         print(io, " (intrinsic function #$id)")
     elseif isa(f, Core.Builtin)
@@ -111,7 +113,10 @@ function show(io::IO, ::MIME"text/plain"
 
     for (i, (k, v)) in enumerate(t)
         print(io, "\n  ")
-        i == rows < length(t) && (print(io, rpad("⋮", keylen), " => ⋮"); break)
+        if i == rows < length(t)
+            print(io, rpad("⋮", keylen), " => ⋮")
+            break
+        end
 
         if limit
             key = rpad(_truncate_at_width_or_chars(ks[i], keylen, "\r\n"), keylen)
@@ -130,6 +135,48 @@ function show(io::IO, ::MIME"text/plain"
     end
 end
 
+function summary(io::IO, t::AbstractSet)
+    n = length(t)
+    showarg(io, t, true)
+    print(io, " with ", n, (n==1 ? " element" : " elements"))
+end
+
+function show(io::IO, ::MIME"text/plain", t::AbstractSet{T}) where T
+    # show more descriptively, with one line per value
+    recur_io = IOContext(io, :SHOWN_SET => t)
+    limit::Bool = get(io, :limit, false)
+
+    summary(io, t)
+    isempty(t) && return
+    print(io, ":")
+    show_circular(io, t) && return
+    if limit
+        sz = displaysize(io)
+        rows, cols = sz[1] - 3, sz[2]
+        rows < 2   && (print(io, " …"); return)
+        cols -= 2 # Subtract the width of prefix "  "
+        cols < 4  && (cols = 4) # Minimum widths of 4 for value
+        rows -= 1 # Subtract the summary
+    else
+        rows = cols = typemax(Int)
+    end
+
+    for (i, v) in enumerate(t)
+        print(io, "\n  ")
+        if i == rows < length(t)
+            print(io, rpad("⋮", 2))
+            break
+        end
+
+        if limit
+            str = sprint(show, v, context=recur_io, sizehint=0)
+            print(io, _truncate_at_width_or_chars(str, cols, "\r\n"))
+        else
+            show(recur_io, v)
+        end
+    end
+end
+
 function show(io::IO, ::MIME"text/plain", opt::JLOptions)
     println(io, "JLOptions(")
     fields = fieldnames(JLOptions)
@@ -401,11 +448,15 @@ end
 show(io::IO, f::Function) = show_function(io, f, get(io, :compact, false))
 print(io::IO, f::Function) = show_function(io, f, true)
 
-function show(io::IO, x::Core.IntrinsicFunction)
-    name = ccall(:jl_intrinsic_name, Cstring, (Core.IntrinsicFunction,), x)
-    print(io, unsafe_string(name))
+function show(io::IO, f::Core.IntrinsicFunction)
+    if !get(io, :compact, false)
+        print(io, "Core.Intrinsics.")
+    end
+    print(io, nameof(f))
 end
 
+print(io::IO, f::Core.IntrinsicFunction) = print(io, nameof(f))
+
 show(io::IO, ::Core.TypeofBottom) = print(io, "Union{}")
 show(io::IO, ::MIME"text/plain", ::Core.TypeofBottom) = print(io, "Union{}")
 
@@ -715,7 +766,7 @@ end
 show(io::IO, t::Tuple) = show_delim_array(io, t, '(', ',', ')', true)
 show(io::IO, v::SimpleVector) = show_delim_array(io, v, "svec(", ',', ')', false)
 
-show(io::IO, s::Symbol) = show_unquoted_quote_expr(io, s, 0, 0)
+show(io::IO, s::Symbol) = show_unquoted_quote_expr(io, s, 0, 0, 0)
 
 ## Abstract Syntax Tree (AST) printing ##
 
@@ -746,12 +797,19 @@ const ExprNode = Union{Expr, QuoteNode,
                        Core.Compiler.GotoIfNot, Core.Compiler.ReturnNode}
 # Operators have precedence levels from 1-N, and show_unquoted defaults to a
 # precedence level of 0 (the fourth argument). The top-level print and show
-# methods use a precedence of -1 to specially allow space-separated macro syntax
-print(        io::IO, ex::ExprNode)    = (show_unquoted(io, ex, 0, -1); nothing)
-show(         io::IO, ex::ExprNode)    = show_unquoted_quote_expr(io, ex, 0, -1)
+# methods use a precedence of -1 to specially allow space-separated macro syntax.
+# IOContext(io, :unquote_fallback => false) tells show_unquoted to treat any
+# Expr whose head is :$ as if it is inside a quote, preventing fallback to the
+# "unhandled" case: this is used by print/string to be lawful to Rule 1 above.
+# On the countrary, show/repr have to follow Rule 2, requiring any Expr whose
+# head is :$ and which is not inside a quote to fallback to the "unhandled" case:
+# this is behavior is triggered by IOContext(io, :unquote_fallback => true)
+print(        io::IO, ex::ExprNode)    = (show_unquoted(IOContext(io, :unquote_fallback => false), ex, 0, -1); nothing)
+show(         io::IO, ex::ExprNode)    = show_unquoted_quote_expr(IOContext(io, :unquote_fallback => true), ex, 0, -1, 0)
 show_unquoted(io::IO, ex)              = show_unquoted(io, ex, 0, 0)
 show_unquoted(io::IO, ex, indent::Int) = show_unquoted(io, ex, indent, 0)
 show_unquoted(io::IO, ex, ::Int,::Int) = show(io, ex)
+show_unquoted(io::IO, ex, indent::Int, prec::Int, ::Int) = show_unquoted(io, ex, indent, prec)
 
 ## AST printing constants ##
 
@@ -762,7 +820,7 @@ const uni_ops = Set{Symbol}([:(+), :(-),
 const expr_infix_wide = Set{Symbol}([
     :(=), :(+=), :(-=), :(*=), :(/=), :(\=), :(^=), :(&=), :(|=), :(÷=), :(%=), :(>>>=), :(>>=), :(<<=),
     :(.=), :(.+=), :(.-=), :(.*=), :(./=), :(.\=), :(.^=), :(.&=), :(.|=), :(.÷=), :(.%=), :(.>>>=), :(.>>=), :(.<<=),
-    :(&&), :(||), :(<:), :($=), :(⊻=)])
+    :(&&), :(||), :(<:), :($=), :(⊻=), :(>:)])
 const expr_infix = Set{Symbol}([:(:), :(->), Symbol("::")])
 const expr_infix_any = union(expr_infix, expr_infix_wide)
 const expr_calls  = Dict(:call => ('(',')'), :calldecl => ('(',')'),
@@ -777,6 +835,7 @@ is_id_start_char(c::AbstractChar) = ccal
 is_id_char(c::AbstractChar) = ccall(:jl_id_char, Cint, (UInt32,), c) != 0
 function isidentifier(s::AbstractString)
     isempty(s) && return false
+    (s == "true" || s == "false") && return false
     c, rest = Iterators.peel(s)
     is_id_start_char(c) || return false
     return all(is_id_char, rest)
@@ -833,7 +892,7 @@ operators. Return `0` if `s` is not a va
 # Examples
 ```jldoctest
 julia> Base.operator_precedence(:+), Base.operator_precedence(:*), Base.operator_precedence(:.)
-(11, 13, 17)
+(11, 12, 17)
 
 julia> Base.operator_precedence(:sin), Base.operator_precedence(:+=), Base.operator_precedence(:(=))  # (Note the necessary parens on `:(=)`)
 (0, 1, 1)
@@ -875,8 +934,8 @@ function operator_associativity(s::Symbo
     return :left
 end
 
-is_expr(ex, head::Symbol)         = (isa(ex, Expr) && (ex.head == head))
-is_expr(ex, head::Symbol, n::Int) = is_expr(ex, head) && length(ex.args) == n
+is_expr(@nospecialize(ex), head::Symbol)         = isa(ex, Expr) && (ex.head === head)
+is_expr(@nospecialize(ex), head::Symbol, n::Int) = is_expr(ex, head) && length(ex.args) == n
 
 is_quoted(ex)            = false
 is_quoted(ex::QuoteNode) = true
@@ -903,36 +962,37 @@ show_linenumber(io::IO, line, file) = pr
 show_linenumber(io::IO, line, file::Nothing) = show_linenumber(io, line)
 
 # show a block, e g if/for/etc
-function show_block(io::IO, head, args::Vector, body, indent::Int)
+function show_block(io::IO, head, args::Vector, body, indent::Int, quote_level::Int)
     print(io, head)
     if !isempty(args)
         print(io, ' ')
         if head === :elseif
-            show_list(io, args, " ", indent)
+            show_list(io, args, " ", indent, 0, quote_level)
         else
-            show_list(io, args, ", ", indent)
+            show_list(io, args, ", ", indent, 0, quote_level)
         end
     end
 
     ind = head === :module || head === :baremodule ? indent : indent + indent_width
-    exs = is_expr(body, :block) ? body.args : Any[body]
+    exs = (is_expr(body, :block) || is_expr(body, :quote)) ? body.args : Any[body]
     for ex in exs
         print(io, '\n', " "^ind)
-        show_unquoted(io, ex, ind, -1)
+        show_unquoted(io, ex, ind, -1, quote_level)
     end
     print(io, '\n', " "^indent)
 end
-show_block(io::IO,head,    block,i::Int) = show_block(io,head, [], block,i)
-function show_block(io::IO, head, arg, block, i::Int)
-    if is_expr(arg, :block)
-        show_block(io, head, arg.args, block, i)
+show_block(io::IO,head,    block,i::Int, quote_level::Int) = show_block(io,head, [], block,i, quote_level)
+function show_block(io::IO, head, arg, block, i::Int, quote_level::Int)
+    if is_expr(arg, :block) || is_expr(arg, :quote)
+        show_block(io, head, arg.args, block, i, quote_level)
     else
-        show_block(io, head, Any[arg], block, i)
+        show_block(io, head, Any[arg], block, i, quote_level)
     end
 end
 
 # show an indented list
-function show_list(io::IO, items, sep, indent::Int, prec::Int=0, enclose_operators::Bool=false)
+function show_list(io::IO, items, sep, indent::Int, prec::Int=0, quote_level::Int=0, enclose_operators::Bool=false,
+                   kw::Bool=false)
     n = length(items)
     n == 0 && return
     indent += indent_width
@@ -945,28 +1005,35 @@ function show_list(io::IO, items, sep, i
               (item isa Real && item < 0))) ||
               (enclose_operators && item isa Symbol && isoperator(item))
         parens && print(io, '(')
-        show_unquoted(io, item, indent, parens ? 0 : prec)
+        if kw && is_expr(item, :kw, 2)
+            show_unquoted(io, Expr(:(=), item.args[1], item.args[2]), indent, parens ? 0 : prec, quote_level)
+        elseif kw && is_expr(item, :(=), 2)
+            show_unquoted_expr_fallback(io, item, indent, quote_level)
+        else
+            show_unquoted(io, item, indent, parens ? 0 : prec, quote_level)
+        end
         parens && print(io, ')')
         first = false
     end
 end
 # show an indented list inside the parens (op, cl)
-function show_enclosed_list(io::IO, op, items, sep, cl, indent, prec=0, encl_ops=false)
+function show_enclosed_list(io::IO, op, items, sep, cl, indent, prec=0, quote_level=0, encl_ops=false, kw::Bool=false)
     print(io, op)
-    show_list(io, items, sep, indent, prec, encl_ops)
+    show_list(io, items, sep, indent, prec, quote_level, encl_ops, kw)
     print(io, cl)
 end
 
 # show a normal (non-operator) function call, e.g. f(x, y) or A[z]
-function show_call(io::IO, head, func, func_args, indent)
+# kw: `=` expressions are parsed with head `kw` in this context
+function show_call(io::IO, head, func, func_args, indent, quote_level, kw::Bool)
     op, cl = expr_calls[head]
     if (isa(func, Symbol) && func !== :(:) && !(head === :. && isoperator(func))) ||
             (isa(func, Expr) && (func.head === :. || func.head === :curly || func.head === :macroname)) ||
             isa(func, GlobalRef)
-        show_unquoted(io, func, indent)
+        show_unquoted(io, func, indent, 0, quote_level)
     else
         print(io, '(')
-        show_unquoted(io, func, indent)
+        show_unquoted(io, func, indent, 0, quote_level)
         print(io, ')')
     end
     if head === :(.)
@@ -974,12 +1041,12 @@ function show_call(io::IO, head, func, f
     end
     if !isempty(func_args) && isa(func_args[1], Expr) && func_args[1].head === :parameters
         print(io, op)
-        show_list(io, func_args[2:end], ", ", indent)
+        show_list(io, func_args[2:end], ", ", indent, 0, quote_level, false, kw)
         print(io, "; ")
-        show_list(io, func_args[1].args, ", ", indent)
+        show_list(io, func_args[1].args, ", ", indent, 0, quote_level, false, kw)
         print(io, cl)
     else
-        show_enclosed_list(io, op, func_args, ", ", cl, indent)
+        show_enclosed_list(io, op, func_args, ", ", cl, indent, 0, quote_level, false, kw)
     end
 end
 
@@ -987,7 +1054,7 @@ end
 # * Print valid identifiers & operators literally; also macros names if allow_macroname=true
 # * Escape invalid identifiers with var"" syntax
 function show_sym(io::IO, sym; allow_macroname=false)
-    if isidentifier(sym) || isoperator(sym)
+    if isidentifier(sym) || (isoperator(sym) && sym !== Symbol("'"))
         print(io, sym)
     elseif allow_macroname && (sym_str = string(sym); startswith(sym_str, '@'))
         print(io, '@')
@@ -1000,17 +1067,19 @@ end
 ## AST printing ##
 
 show_unquoted(io::IO, val::SSAValue, ::Int, ::Int)      = print(io, "%", val.id)
-show_unquoted(io::IO, sym::Symbol, ::Int, ::Int)        = show_sym(io, sym)
+show_unquoted(io::IO, sym::Symbol, ::Int, ::Int)        = show_sym(io, sym, allow_macroname=false)
 show_unquoted(io::IO, ex::LineNumberNode, ::Int, ::Int) = show_linenumber(io, ex.line, ex.file)
 show_unquoted(io::IO, ex::GotoNode, ::Int, ::Int)       = print(io, "goto %", ex.label)
-function show_unquoted(io::IO, ex::GlobalRef, ::Int, ::Int)
+show_unquoted(io::IO, ex::GlobalRef, ::Int, ::Int)      = show_globalref(io, ex)
+
+function show_globalref(io::IO, ex::GlobalRef; allow_macroname=false)
     print(io, ex.mod)
     print(io, '.')
     quoted = !isidentifier(ex.name) && !startswith(string(ex.name), "@")
     parens = quoted && (!isoperator(ex.name) || (ex.name in quoted_syms))
     quoted && print(io, ':')
     parens && print(io, '(')
-    show_sym(io, ex.name, allow_macroname=true)
+    show_sym(io, ex.name, allow_macroname=allow_macroname)
     parens && print(io, ')')
     nothing
 end
@@ -1032,18 +1101,21 @@ end
 
 function show_unquoted(io::IO, ex::QuoteNode, indent::Int, prec::Int)
     if isa(ex.value, Symbol)
-        show_unquoted_quote_expr(io, ex.value, indent, prec)
+        show_unquoted_quote_expr(io, ex.value, indent, prec, 0)
     else
         print(io, "\$(QuoteNode(")
+        # QuoteNode does not allows for interpolation, so if ex.value is an
+        # Expr it should be shown with quote_level equal to zero.
+        # Calling show(io, ex.value) like this implicitly enforce that.
         show(io, ex.value)
         print(io, "))")
     end
 end
 
-function show_unquoted_quote_expr(io::IO, @nospecialize(value), indent::Int, prec::Int)
+function show_unquoted_quote_expr(io::IO, @nospecialize(value), indent::Int, prec::Int, quote_level::Int)
     if isa(value, Symbol) && !(value in quoted_syms)
         s = string(value)
-        if isidentifier(s) || isoperator(value)
+        if isidentifier(s) || (isoperator(value) && value !== Symbol("'"))
             print(io, ":")
             print(io, value)
         else
@@ -1051,17 +1123,17 @@ function show_unquoted_quote_expr(io::IO
         end
     else
         if isa(value,Expr) && value.head === :block
-            show_block(io, "quote", value, indent)
+            show_block(IOContext(io, beginsym=>false), "quote", value, indent, quote_level)
             print(io, "end")
         else
             print(io, ":(")
-            show_unquoted(io, value, indent+2, -1)  # +2 for `:(`
+            show_unquoted(io, value, indent+2, -1, quote_level)  # +2 for `:(`
             print(io, ")")
         end
     end
 end
 
-function show_generator(io, ex, indent)
+function show_generator(io, ex, indent, quote_level)
     if ex.head === :flatten
         fg = ex
         ranges = Any[]
@@ -1070,33 +1142,33 @@ function show_generator(io, ex, indent)
             fg = fg.args[1].args[1]
         end
         push!(ranges, fg.args[2:end])
-        show_unquoted(io, fg.args[1], indent)
+        show_unquoted(io, fg.args[1], indent, 0, quote_level)
         for r in ranges
             print(io, " for ")
-            show_list(io, r, ", ", indent)
+            show_list(io, r, ", ", indent, 0, quote_level)
         end
     else
-        show_unquoted(io, ex.args[1], indent)
+        show_unquoted(io, ex.args[1], indent, 0, quote_level)
         print(io, " for ")
-        show_list(io, ex.args[2:end], ", ", indent)
+        show_list(io, ex.args[2:end], ", ", indent, 0, quote_level)
     end
 end
 
 function valid_import_path(@nospecialize ex)
-    return Meta.isexpr(ex, :(.)) && length((ex::Expr).args) > 0 && all(a->isa(a,Symbol), (ex::Expr).args)
+    return is_expr(ex, :(.)) && length((ex::Expr).args) > 0 && all(a->isa(a,Symbol), (ex::Expr).args)
 end
 
-function show_import_path(io::IO, ex)
+function show_import_path(io::IO, ex, quote_level)
     if !isa(ex, Expr)
         show_unquoted(io, ex)
     elseif ex.head === :(:)
-        show_import_path(io, ex.args[1])
+        show_import_path(io, ex.args[1], quote_level)
         print(io, ": ")
         for i = 2:length(ex.args)
             if i > 2
                 print(io, ", ")
             end
-            show_import_path(io, ex.args[i])
+            show_import_path(io, ex.args[i], quote_level)
         end
     elseif ex.head === :(.)
         for i = 1:length(ex.args)
@@ -1106,16 +1178,48 @@ function show_import_path(io::IO, ex)
             show_sym(io, ex.args[i], allow_macroname=(i==length(ex.args)))
         end
     else
-        show_unquoted(io, ex)
+        show_unquoted(io, ex, 0, 0, quote_level)
     end
 end
 
 # Wrap symbols for macro names to allow them to be printed literally
-allow_macroname(ex) = ex isa Symbol && first(string(ex)) == '@' ?
-                      Expr(:macroname, ex) : ex
+function allow_macroname(ex)
+    if (ex isa Symbol && first(string(ex)) == '@') ||
+       ex isa GlobalRef ||
+       (is_expr(ex, :(.)) && length(ex.args) == 2 &&
+        (is_expr(ex.args[2], :quote) || ex.args[2] isa QuoteNode))
+       return Expr(:macroname, ex)
+    else
+        ex
+    end
+end
+
+function is_core_macro(arg, macro_name::AbstractString)
+    arg === GlobalRef(Core, Symbol(macro_name))
+end
+
+# symbol for IOContext flag signaling whether "begin" is treated
+# as an ordinary symbol, which is true in indexing expressions.
+const beginsym = gensym(:beginsym)
+
+function show_unquoted_expr_fallback(io::IO, ex::Expr, indent::Int, quote_level::Int)
+    print(io, "\$(Expr(")
+    show(io, ex.head)
+    for arg in ex.args
+        print(io, ", ")
+        if isa(arg, Expr)
+            print(io, ":(")
+            show_unquoted(io, arg, indent, 0, quote_level+1)
+            print(io, ")")
+        else
+            show(io, arg)
+        end
+    end
+    print(io, "))")
+end
 
 # TODO: implement interpolated strings
-function show_unquoted(io::IO, ex::Expr, indent::Int, prec::Int)
+function show_unquoted(io::IO, ex::Expr, indent::Int, prec::Int, quote_level::Int = 0)
     head, args, nargs = ex.head, ex.args, length(ex.args)
     unhandled = false
     # dot (i.e. "x.y"), but not compact broadcast exps
@@ -1124,9 +1228,9 @@ function show_unquoted(io::IO, ex::Expr,
             item = args[1]
             # field
             field = unquoted(args[2])
-            parens = !is_quoted(item) && !(item isa Symbol && isidentifier(item)) && !Meta.isexpr(item, :(.))
+            parens = !is_quoted(item) && !(item isa Symbol && isidentifier(item)) && !is_expr(item, :(.))
             parens && print(io, '(')
-            show_unquoted(io, item, indent)
+            show_unquoted(io, item, indent, 0, quote_level)
             parens && print(io, ')')
             # .
             print(io, '.')
@@ -1135,7 +1239,7 @@ function show_unquoted(io::IO, ex::Expr,
             quoted = parens || isoperator(field)
             quoted && print(io, ':')
             parens && print(io, '(')
-            show_unquoted(io, field, indent)
+            show_unquoted(io, field, indent, 0, quote_level)
             parens && print(io, ')')
         else
             unhandled = true
@@ -1146,13 +1250,44 @@ function show_unquoted(io::IO, ex::Expr,
         func_prec = operator_precedence(head)
         head_ = head in expr_infix_wide ? " $head " : head
         if func_prec <= prec
-            show_enclosed_list(io, '(', args, head_, ')', indent, func_prec, true)
+            show_enclosed_list(io, '(', args, head_, ')', indent, func_prec, quote_level, true)
         else
-            show_list(io, args, head_, indent, func_prec, true)
+            show_list(io, args, head_, indent, func_prec, quote_level, true)
         end
 
-    # list (i.e. "(1, 2, 3)" or "[1, 2, 3]")
-    elseif haskey(expr_parens, head)               # :tuple/:vcat
+    elseif head === :tuple
+        print(io, "(")
+        if nargs > 0 && is_expr(args[1], :parameters)
+            if nargs == 1 && isempty(args[1].args)
+                # TODO: for now avoid printing (;)
+                show_unquoted_expr_fallback(io, args[1], indent, quote_level)
+                print(io, ',')
+            else
+                show_list(io, args[2:end], ", ", indent, 0, quote_level)
+                nargs == 2 && print(io, ',')
+                print(io, "; ")
+                show_list(io, args[1].args, ", ", indent, 0, quote_level, false, true)
+            end
+        else
+            show_list(io, args, ", ", indent, 0, quote_level)
+            nargs == 1 && print(io, ',')
+        end
+        print(io, ")")
+
+    # list-like forms, e.g. "[1, 2, 3]"
+    elseif haskey(expr_parens, head) ||                          # :vcat etc.
+        head === :typed_vcat || head === :typed_hcat
+        # print the type and defer to the untyped case
+        if head === :typed_vcat || head === :typed_hcat
+            show_unquoted(io, args[1], indent, prec, quote_level)
+            if head === :typed_vcat
+                head = :vcat
+            else
+                head = :hcat
+            end
+            args = args[2:end]
+            nargs = nargs - 1
+        end
         op, cl = expr_parens[head]
         if head === :vcat || head === :bracescat
             sep = "; "
@@ -1162,13 +1297,9 @@ function show_unquoted(io::IO, ex::Expr,
             sep = ", "
         end
         head !== :row && print(io, op)
-        show_list(io, args, sep, indent)
-        if nargs == 1
-            if head === :tuple
-                print(io, ',')
-            elseif head === :vcat
-                print(io, ';')
-            end
+        show_list(io, args, sep, indent, 0, quote_level)
+        if nargs == 1 && head === :vcat
+            print(io, ';')
         end
         head !== :row && print(io, cl)
 
@@ -1182,23 +1313,27 @@ function show_unquoted(io::IO, ex::Expr,
         end
         func_args = args[2:end]
 
+        # :kw exprs are only parsed inside parenthesized calls
+        if any(a->is_expr(a, :kw), func_args)
+            show_call(io, head, func, func_args, indent, quote_level, true)
+
         # scalar multiplication (i.e. "100x")
-        if (func === :* &&
+        elseif (func === :* &&
             length(func_args)==2 && isa(func_args[1], Real) && isa(func_args[2], Symbol))
             if func_prec <= prec
-                show_enclosed_list(io, '(', func_args, "", ')', indent, func_prec)
+                show_enclosed_list(io, '(', func_args, "", ')', indent, func_prec, quote_level)
             else
-                show_list(io, func_args, "", indent, func_prec)
+                show_list(io, func_args, "", indent, func_prec, quote_level)
             end
 
         # unary operator (i.e. "!z")
         elseif isa(func,Symbol) && func in uni_ops && length(func_args) == 1
-            show_unquoted(io, func, indent)
+            show_unquoted(io, func, indent, 0, quote_level)
             arg1 = func_args[1]
             if isa(arg1, Expr) || (isa(arg1, Symbol) && isoperator(arg1))
                 show_enclosed_list(io, '(', func_args, ", ", ')', indent, func_prec)
             else
-                show_unquoted(io, arg1, indent, func_prec)
+                show_unquoted(io, arg1, indent, func_prec, quote_level)
             end
 
         # binary operator (i.e. "x + y")
@@ -1209,119 +1344,125 @@ function show_unquoted(io::IO, ex::Expr,
                 sep = func === :(:) ? "$func" : " $func "
 
                 if func_prec <= prec
-                    show_enclosed_list(io, '(', func_args, sep, ')', indent, func_prec, true)
+                    show_enclosed_list(io, '(', func_args, sep, ')', indent, func_prec, quote_level, true)
                 else
-                    show_list(io, func_args, sep, indent, func_prec, true)
+                    show_list(io, func_args, sep, indent, func_prec, quote_level, true)
                 end
             elseif na == 1
                 # 1-argument call to normally-binary operator
                 op, cl = expr_calls[head]
                 print(io, "(")
-                show_unquoted(io, func, indent)
+                show_unquoted(io, func, indent, 0, quote_level)
                 print(io, ")")
-                show_enclosed_list(io, op, func_args, ", ", cl, indent)
+                show_enclosed_list(io, op, func_args, ", ", cl, indent, 0, quote_level)
             else
-                show_call(io, head, func, func_args, indent)
+                show_call(io, head, func, func_args, indent, quote_level, true)
             end
 
         # normal function (i.e. "f(x,y)")
         else
-            show_call(io, head, func, func_args, indent)
+            show_call(io, head, func, func_args, indent, quote_level, true)
         end
 
     # new expr
     elseif head === :new || head === :splatnew
-        show_enclosed_list(io, "%$head(", args, ", ", ")", indent)
+        show_enclosed_list(io, "%$head(", args, ", ", ")", indent, 0, quote_level)
 
     # other call-like expressions ("A[1,2]", "T{X,Y}", "f.(X,Y)")
     elseif haskey(expr_calls, head) && nargs >= 1  # :ref/:curly/:calldecl/:(.)
         funcargslike = head === :(.) ? args[2].args : args[2:end]
-        show_call(io, head, args[1], funcargslike, indent)
+        show_call(head == :ref ? IOContext(io, beginsym=>true) : io, head, args[1], funcargslike, indent, quote_level, head !== :curly)
 
     # comprehensions
     elseif head === :typed_comprehension && nargs == 2
-        show_unquoted(io, args[1], indent)
+        show_unquoted(io, args[1], indent, 0, quote_level)
         print(io, '[')
-        show_generator(io, args[2], indent)
+        show_generator(io, args[2], indent, quote_level)
         print(io, ']')
 
     elseif head === :comprehension && nargs == 1
         print(io, '[')
-        show_generator(io, args[1], indent)
+        show_generator(io, args[1], indent, quote_level)
         print(io, ']')
 
     elseif (head === :generator && nargs >= 2) || (head === :flatten && nargs == 1)
         print(io, '(')
-        show_generator(io, ex, indent)
+        show_generator(io, ex, indent, quote_level)
         print(io, ')')
 
     elseif head === :filter && nargs == 2
-        show_unquoted(io, args[2], indent)
+        show_unquoted(io, args[2], indent, 0, quote_level)
         print(io, " if ")
-        show_unquoted(io, args[1], indent)
+        show_unquoted(io, args[1], indent, 0, quote_level)
 
     # comparison (i.e. "x < y < z")
     elseif head === :comparison && nargs >= 3 && (nargs&1==1)
         comp_prec = minimum(operator_precedence, args[2:2:end])
         if comp_prec <= prec
-            show_enclosed_list(io, '(', args, " ", ')', indent, comp_prec)
+            show_enclosed_list(io, '(', args, " ", ')', indent, comp_prec, quote_level)
         else
-            show_list(io, args, " ", indent, comp_prec)
+            show_list(io, args, " ", indent, comp_prec, quote_level)
         end
 
     # function calls need to transform the function from :call to :calldecl
     # so that operators are printed correctly
     elseif head === :function && nargs==2 && is_expr(args[1], :call)
-        show_block(io, head, Expr(:calldecl, args[1].args...), args[2], indent)
+        show_block(IOContext(io, beginsym=>false), head, Expr(:calldecl, args[1].args...), args[2], indent, quote_level)
         print(io, "end")
 
     elseif (head === :function || head === :macro) && nargs == 1
         print(io, head, ' ')
-        show_unquoted(io, args[1])
+        show_unquoted(IOContext(io, beginsym=>false), args[1])
         print(io, " end")
 
     elseif head === :do && nargs == 2
-        show_unquoted(io, args[1], indent, -1)
+        iob = IOContext(io, beginsym=>false)
+        show_unquoted(iob, args[1], indent, -1, quote_level)
         print(io, " do ")
-        show_list(io, args[2].args[1].args, ", ", 0)
+        show_list(iob, args[2].args[1].args, ", ", 0, 0, quote_level)
         for stmt in args[2].args[2].args
             print(io, '\n', " "^(indent + indent_width))
-            show_unquoted(io, stmt, indent + indent_width, -1)
+            show_unquoted(iob, stmt, indent + indent_width, -1, quote_level)
         end
         print(io, '\n', " "^indent)
         print(io, "end")
 
     # block with argument
     elseif head in (:for,:while,:function,:macro,:if,:elseif,:let) && nargs==2
-        show_block(io, head, args[1], args[2], indent)
+        if is_expr(args[2], :block)
+            show_block(IOContext(io, beginsym=>false), head, args[1], args[2], indent, quote_level)
+        else
+            show_block(IOContext(io, beginsym=>false), head, args[1], Expr(:block, args[2]), indent, quote_level)
+        end
         print(io, "end")
 
     elseif (head === :if || head === :elseif) && nargs == 3
-        show_block(io, head, args[1], args[2], indent)
+        iob = IOContext(io, beginsym=>false)
+        show_block(iob, head, args[1], args[2], indent, quote_level)
         if isa(args[3],Expr) && args[3].head === :elseif
-            show_unquoted(io, args[3], indent, prec)
+            show_unquoted(iob, args[3], indent, prec, quote_level)
         else
-            show_block(io, "else", args[3], indent)
+            show_block(iob, "else", args[3], indent, quote_level)
             print(io, "end")
         end
 
     elseif head === :module && nargs==3 && isa(args[1],Bool)
-        show_block(io, args[1] ? :module : :baremodule, args[2], args[3], indent)
+        show_block(IOContext(io, beginsym=>false), args[1] ? :module : :baremodule, args[2], args[3], indent, quote_level)
         print(io, "end")
 
     # type declaration
     elseif head === :struct && nargs==3
-        show_block(io, args[1] ? Symbol("mutable struct") : Symbol("struct"), args[2], args[3], indent)
+        show_block(IOContext(io, beginsym=>false), args[1] ? Symbol("mutable struct") : Symbol("struct"), args[2], args[3], indent, quote_level)
         print(io, "end")
 
     elseif head === :primitive && nargs == 2
         print(io, "primitive type ")
-        show_list(io, args, ' ', indent)
+        show_list(io, args, ' ', indent, 0, quote_level)
         print(io, " end")
 
     elseif head === :abstract && nargs == 1
         print(io, "abstract type ")
-        show_list(io, args, ' ', indent)
+        show_list(IOContext(io, beginsym=>false), args, ' ', indent, 0, quote_level)
         print(io, " end")
 
     # empty return (i.e. "function f() return end")
@@ -1331,12 +1472,12 @@ function show_unquoted(io::IO, ex::Expr,
     # type annotation (i.e. "::Int")
     elseif head in uni_syms && nargs == 1
         print(io, head)
-        show_unquoted(io, args[1], indent)
+        show_unquoted(io, args[1], indent, 0, quote_level)
 
     # var-arg declaration or expansion
     # (i.e. "function f(L...) end" or "f(B...)")
     elseif head === :(...) && nargs == 1
-        show_unquoted(io, args[1], indent)
+        show_unquoted(io, args[1], indent, 0, quote_level)
         print(io, "...")
 
     elseif (nargs == 0 && head in (:break, :continue))
@@ -1345,33 +1486,76 @@ function show_unquoted(io::IO, ex::Expr,
     elseif (nargs == 1 && head in (:return, :const)) ||
                           head in (:local,  :global)
         print(io, head, ' ')
-        show_list(io, args, ", ", indent)
+        show_list(io, args, ", ", indent, 0, quote_level)
 
     elseif head === :export
         print(io, head, ' ')
         show_list(io, allow_macroname.(args), ", ", indent)
 
     elseif head === :macrocall && nargs >= 2
-        # first show the line number argument as a comment
-        if isa(args[2], LineNumberNode) || is_expr(args[2], :line)
-            print(io, args[2], ' ')
-        end
-        # Use the functional syntax unless specifically designated with prec=-1
-        # and hide the line number argument from the argument list
-        mname = allow_macroname(args[1])
-        if prec >= 0
-            show_call(io, :call, mname, args[3:end], indent)
-        else
-            show_args = Vector{Any}(undef, nargs - 1)
-            show_args[1] = mname
-            show_args[2:end] = args[3:end]
-            show_list(io, show_args, ' ', indent)
+        # handle some special syntaxes
+        # `a b c`
+        if is_core_macro(args[1], "@cmd")
+            print(io, "`", args[3], "`")
+        # 11111111111111111111, 0xfffffffffffffffff, 1111...many digits...
+        elseif is_core_macro(args[1], "@int128_str") ||
+               is_core_macro(args[1], "@uint128_str") ||
+               is_core_macro(args[1], "@big_str")
+            print(io, args[3])
+        # x"y" and x"y"z
+        elseif isa(args[1], Symbol) &&
+               startswith(string(args[1]::Symbol), "@") &&
+               endswith(string(args[1]::Symbol), "_str")
+            s = string(args[1]::Symbol)
+            print(io, s[2:prevind(s,end,4)], "\"", args[3], "\"")
+            if nargs == 4
+                print(io, args[4])
+            end
+        # general case
+        else
+            # first show the line number argument as a comment
+            if isa(args[2], LineNumberNode) || is_expr(args[2], :line)
+                print(io, args[2], ' ')
+            end
+            # Use the functional syntax unless specifically designated with
+            # prec=-1 and hide the line number argument from the argument list
+            mname = allow_macroname(args[1])
+            if prec >= 0
+                show_call(io, :call, mname, args[3:end], indent, quote_level, false)
+            else
+                show_args = Vector{Any}(undef, nargs - 1)
+                show_args[1] = mname
+                show_args[2:end] = args[3:end]
+                show_list(io, show_args, ' ', indent, 0, quote_level)
+            end
         end
 
     elseif head === :macroname && nargs == 1
         arg1 = args[1]
         if arg1 isa Symbol
             show_sym(io, arg1, allow_macroname=true)
+        elseif arg1 isa GlobalRef
+            show_globalref(io, arg1, allow_macroname=true)
+        elseif is_expr(arg1, :(.)) && length(arg1.args) == 2
+            m = arg1.args[1]
+            if m isa Symbol || m isa GlobalRef || is_expr(m, :(.), 2)
+                show_unquoted(io, m)
+            else
+                print(io, "(")
+                show_unquoted(io, m)
+                print(io, ")")
+            end
+            print(io, '.')
+            if is_expr(arg1.args[2], :quote)
+                mname = arg1.args[2].args[1]
+            else
+                mname = arg1.args[2].value
+            end
+            if mname isa Symbol
+                show_sym(io, mname, allow_macroname=true)
+            else
+                show_unquoted(io, mname)
+            end
         else
             show_unquoted(io, arg1)
         end
@@ -1380,25 +1564,58 @@ function show_unquoted(io::IO, ex::Expr,
         show_linenumber(io, args...)
 
     elseif head === :try && 3 <= nargs <= 4
-        show_block(io, "try", args[1], indent)
+        iob = IOContext(io, beginsym=>false)
+        show_block(iob, "try", args[1], indent, quote_level)
         if is_expr(args[3], :block)
-            show_block(io, "catch", args[2] === false ? Any[] : args[2], args[3], indent)
+            show_block(iob, "catch", args[2] === false ? Any[] : args[2], args[3], indent, quote_level)
         end
         if nargs >= 4 && is_expr(args[4], :block)
-            show_block(io, "finally", Any[], args[4], indent)
+            show_block(iob, "finally", Any[], args[4], indent, quote_level)
         end
         print(io, "end")
 
     elseif head === :block
-        show_block(io, "begin", ex, indent)
-        print(io, "end")
+        # print as (...; ...; ...;) inside indexing expression
+        if get(io, beginsym, false)
+            print(io, '(')
+            ind = indent + indent_width
+            for i = 1:length(ex.args)
+                if i > 1
+                    # if there was only a comment before the first semicolon, the expression would get parsed as a NamedTuple
+                    if !(i == 2 && ex.args[1] isa LineNumberNode)
+                        print(io, ';')
+                    end
+                    print(io, "\n", ' '^ind)
+                end
+                show_unquoted(io, ex.args[i], ind, -1, quote_level)
+            end
+            if length(ex.args) < 2
+                print(io, isempty(ex.args) ? "nothing;)" : ";)")
+            else
+                print(io, ')')
+            end
+        else
+            show_block(io, "begin", ex, indent, quote_level)
+            print(io, "end")
+        end
 
     elseif head === :quote && nargs == 1 && isa(args[1], Symbol)
-        show_unquoted_quote_expr(io, args[1]::Symbol, indent, 0)
+        show_unquoted_quote_expr(IOContext(io, beginsym=>false), args[1]::Symbol, indent, 0, quote_level+1)
+    elseif head === :quote && nargs == 1 && is_expr(args[1], :block)
+        show_block(IOContext(io, beginsym=>false), "quote", Expr(:quote, args[1].args...), indent,
+                   quote_level+1)
+        print(io, "end")
+    elseif head === :quote && nargs == 1
+        print(io, ":(")
+        show_unquoted(IOContext(io, beginsym=>false), args[1], indent+2, 0, quote_level+1)
+        print(io, ")")
+    elseif head === :quote
+        show_block(IOContext(io, beginsym=>false), "quote", ex, indent, quote_level+1)
+        print(io, "end")
 
     elseif head === :gotoifnot && nargs == 2 && isa(args[2], Int)
         print(io, "unless ")
-        show_unquoted(io, args[1], indent, 0)
+        show_unquoted(io, args[1], indent, 0, quote_level)
         print(io, " goto %")
         print(io, args[2]::Int)
 
@@ -1408,17 +1625,16 @@ function show_unquoted(io::IO, ex::Expr,
     elseif head === :null
         print(io, "nothing")
 
-    elseif head === :kw && nargs == 2
-        show_unquoted(io, args[1], indent+indent_width)
-        print(io, '=')
-        show_unquoted(io, args[2], indent+indent_width)
-
     elseif head === :string
         print(io, '"')
         for x in args
             if !isa(x,AbstractString)
                 print(io, "\$(")
-                show_unquoted(io, x)
+                if isa(x,Symbol) && !(x in quoted_syms)
+                    show_sym(io, x)
+                else
+                    show_unquoted(io, x, 0, 0, quote_level)
+                end
                 print(io, ")")
             else
                 escape_string(io, x, "\"\$")
@@ -1426,21 +1642,29 @@ function show_unquoted(io::IO, ex::Expr,
         end
         print(io, '"')
 
-    elseif (head === :&#= || head === :$=#) && nargs == 1
-        print(io, head)
-        a1 = args[1]
-        parens = (isa(a1,Expr) && a1.head !== :tuple) || (isa(a1,Symbol) && isoperator(a1))
-        parens && print(io, "(")
-        show_unquoted(io, a1)
-        parens && print(io, ")")
+    elseif (head === :& || head === :$) && nargs == 1
+        if head === :$
+            quote_level -= 1
+        end
+        if head === :$ && quote_level < 0 && get(io, :unquote_fallback, true)
+            unhandled = true
+        else
+            print(io, head)
+            a1 = args[1]
+            parens = (isa(a1,Expr) && (a1.head !== :tuple && a1.head !== :$)) ||
+                     (isa(a1,Symbol) && isoperator(a1))
+            parens && print(io, "(")
+            show_unquoted(io, a1, 0, 0, quote_level)
+            parens && print(io, ")")
+        end
 
     # transpose
     elseif head === Symbol('\'') && nargs == 1
         if isa(args[1], Symbol)
-            show_unquoted(io, args[1])
+            show_unquoted(io, args[1], 0, 0, quote_level)
         else
             print(io, "(")
-            show_unquoted(io, args[1])
+            show_unquoted(io, args[1], 0, 0, quote_level)
             print(io, ")")
         end
         print(io, head)
@@ -1449,20 +1673,23 @@ function show_unquoted(io::IO, ex::Expr,
     elseif head === :where && nargs > 1
         parens = 1 <= prec
         parens && print(io, "(")
-        show_unquoted(io, args[1], indent, operator_precedence(:(::)))
+        show_unquoted(io, args[1], indent, operator_precedence(:(::)), quote_level)
         print(io, " where ")
         if nargs == 2
-            show_unquoted(io, args[2], indent, 1)
+            show_unquoted(io, args[2], indent, 1, quote_level)
         else
             print(io, "{")
-            show_list(io, args[2:end], ", ", indent)
+            show_list(io, args[2:end], ", ", indent, 0, quote_level)
             print(io, "}")
         end
         parens && print(io, ")")
 
-    elseif (head === :import || head === :using) && nargs == 1 &&
-            (valid_import_path(args[1]) ||
-             (Meta.isexpr(args[1], :(:)) && length((args[1]::Expr).args) > 1 && all(valid_import_path, (args[1]::Expr).args)))
+    elseif (head === :import || head === :using) &&
+           ((nargs == 1 && (valid_import_path(args[1]) ||
+                           (is_expr(args[1], :(:)) &&
+                            length((args[1]::Expr).args) > 1 &&
+                            all(valid_import_path, (args[1]::Expr).args)))) ||
+             all(valid_import_path, args))
         print(io, head)
         print(io, ' ')
         first = true
@@ -1471,7 +1698,7 @@ function show_unquoted(io::IO, ex::Expr,
                 print(io, ", ")
             end
             first = false
-            show_import_path(io, a)
+            show_import_path(io, a, quote_level)
         end
     elseif head === :meta && nargs >= 2 && args[1] === :push_loc
         print(io, "# meta: location ", join(args[2:end], " "))
@@ -1484,32 +1711,43 @@ function show_unquoted(io::IO, ex::Expr,
         unhandled = true
     end
     if unhandled
-        print(io, "\$(Expr(")
-        show(io, ex.head)
-        for arg in args
-            print(io, ", ")
-            show(io, arg)
-        end
-        print(io, "))")
+        show_unquoted_expr_fallback(io, ex, indent, quote_level)
     end
     nothing
 end
 
-function show_tuple_as_call(io::IO, name::Symbol, sig::Type)
+demangle_function_name(name::Symbol) = Symbol(demangle_function_name(string(name)))
+function demangle_function_name(name::AbstractString)
+    demangle = split(name, '#')
+    # kw sorters and impl methods use the name scheme `f#...`
+    if length(demangle) >= 2 && demangle[1] != ""
+        return demangle[1]
+    end
+    return name
+end
+
+function show_tuple_as_call(io::IO, name::Symbol, sig::Type, demangle=false, kwargs=nothing)
     # print a method signature tuple for a lambda definition
     color = get(io, :color, false) && get(io, :backtrace, false) ? stackframe_function_color() : :nothing
     if sig === Tuple
-        printstyled(io, name, "(...)", color=color)
+        printstyled(io, demangle ? demangle_function_name(name) : name, "(...)", color=color)
         return
     end
-    sig = unwrap_unionall(sig).parameters
-    with_output_color(color, io) do io
+    tv = Any[]
+    env_io = io
+    while isa(sig, UnionAll)
+        push!(tv, sig.var)
+        env_io = IOContext(env_io, :unionall_env => sig.var)
+        sig = sig.body
+    end
+    sig = sig.parameters
+    with_output_color(color, env_io) do io
         ft = sig[1]
         uw = unwrap_unionall(ft)
         if ft <: Function && isa(uw,DataType) && isempty(uw.parameters) &&
                 isdefined(uw.name.module, uw.name.mt.name) &&
                 ft == typeof(getfield(uw.name.module, uw.name.mt.name))
-            print(io, uw.name.mt.name)
+            print(io, (demangle ? demangle_function_name : identity)(uw.name.mt.name))
         elseif isa(ft, DataType) && ft.name === Type.body.name && !Core.Compiler.has_free_typevars(ft)
             f = ft.parameters[1]
             print(io, f)
@@ -1523,9 +1761,20 @@ function show_tuple_as_call(io::IO, name
     for i = 2:length(sig)  # fixme (iter): `eachindex` with offset?
         first || print(io, ", ")
         first = false
-        print(io, "::", sig[i])
+        print(env_io, "::", sig[i])
+    end
+    if kwargs !== nothing
+        print(io, "; ")
+        first = true
+        for (k, t) in kwargs
+            first || print(io, ", ")
+            first = false
+            print(io, k, "::")
+            show(io, t)
+        end
     end
     printstyled(io, ")", color=print_style)
+    show_method_params(io, tv)
     nothing
 end
 
@@ -1655,6 +1904,10 @@ function dump(io::IOContext, x::SimpleVe
 end
 
 function dump(io::IOContext, @nospecialize(x), n::Int, indent)
+    if x === Union{}
+        show(io, x)
+        return
+    end
     T = typeof(x)
     if isa(x, Function)
         print(io, x, " (function of type ", T, ")")
@@ -1741,6 +1994,10 @@ function dump(io::IOContext, x::DataType
                 tvar_io = IOContext(tvar_io, :unionall_env => tparam)
             end
         end
+        if x.name === NamedTuple_typename && !(x.parameters[1] isa Tuple)
+            # named tuple type with unknown field names
+            return
+        end
         fields = fieldnames(x)
         fieldtypes = datatype_fieldtypes(x)
         for idx in 1:length(fields)
@@ -1804,13 +2061,13 @@ alignment(io::IO, x::Number) = (length(s
 alignment(io::IO, x::Integer) = (length(sprint(show, x, context=io, sizehint=0)), 0)
 "`alignment(4.23)` yields (1,3) for `4` and `.23`"
 function alignment(io::IO, x::Real)
-    m = match(r"^(.*?)((?:[\.eE].*)?)$", sprint(show, x, context=io, sizehint=0))
+    m = match(r"^(.*?)((?:[\.eEfF].*)?)$", sprint(show, x, context=io, sizehint=0))
     m === nothing ? (length(sprint(show, x, context=io, sizehint=0)), 0) :
                    (length(m.captures[1]), length(m.captures[2]))
 end
 "`alignment(1 + 10im)` yields (3,5) for `1 +` and `_10im` (plus sign on left, space on right)"
 function alignment(io::IO, x::Complex)
-    m = match(r"^(.*[^e][\+\-])(.*)$", sprint(show, x, context=io, sizehint=0))
+    m = match(r"^(.*[^ef][\+\-])(.*)$", sprint(show, x, context=io, sizehint=0))
     m === nothing ? (length(sprint(show, x, context=io, sizehint=0)), 0) :
                    (length(m.captures[1]), length(m.captures[2]))
 end
diff -pruN 1.3.1+dfsg-1/base/some.jl 1.4.0+dfsg-1/base/some.jl
--- 1.3.1+dfsg-1/base/some.jl	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/base/some.jl	2020-03-21 16:36:32.000000000 +0000
@@ -72,6 +72,8 @@ Return the first value in the arguments
 if any. Otherwise throw an error.
 Arguments of type [`Some`](@ref) are unwrapped.
 
+See also [`coalesce`](@ref).
+
 # Examples
 ```jldoctest
 julia> something(nothing, 1)
diff -pruN 1.3.1+dfsg-1/base/sort.jl 1.4.0+dfsg-1/base/sort.jl
--- 1.3.1+dfsg-1/base/sort.jl	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/base/sort.jl	2020-03-21 16:36:32.000000000 +0000
@@ -91,7 +91,7 @@ issorted(itr;
     lt=isless, by=identity, rev::Union{Bool,Nothing}=nothing, order::Ordering=Forward) =
     issorted(itr, ord(lt,by,rev,order))
 
-function partialsort!(v::AbstractVector, k::Union{Int,OrdinalRange}, o::Ordering)
+function partialsort!(v::AbstractVector, k::Union{Integer,OrdinalRange}, o::Ordering)
     inds = axes(v, 1)
     sort!(v, first(inds), last(inds), PartialQuickSort(k), o)
     maybeview(v, k)
@@ -151,7 +151,7 @@ julia> a
  1
 ```
 """
-partialsort!(v::AbstractVector, k::Union{Int,OrdinalRange};
+partialsort!(v::AbstractVector, k::Union{Integer,OrdinalRange};
              lt=isless, by=identity, rev::Union{Bool,Nothing}=nothing, order::Ordering=Forward) =
     partialsort!(v, k, ord(lt,by,rev,order))
 
@@ -161,9 +161,13 @@ partialsort!(v::AbstractVector, k::Union
 Variant of [`partialsort!`](@ref) which copies `v` before partially sorting it, thereby returning the
 same thing as `partialsort!` but leaving `v` unmodified.
 """
-partialsort(v::AbstractVector, k::Union{Int,OrdinalRange}; kws...) =
+partialsort(v::AbstractVector, k::Union{Integer,OrdinalRange}; kws...) =
     partialsort!(copymutable(v), k; kws...)
 
+# This implementation of `midpoint` is performance-optimized but safe
+# only if `lo <= hi`.
+midpoint(lo::T, hi::T) where T<:Integer = lo + ((hi - lo) >>> 0x01)
+midpoint(lo::Integer, hi::Integer) = midpoint(promote(lo, hi)...)
 
 # reference on sorted binary search:
 #   http://www.tbray.org/ongoing/When/200x/2003/03/22/Binary
@@ -175,7 +179,7 @@ function searchsortedfirst(v::AbstractVe
     lo = lo - u
     hi = hi + u
     @inbounds while lo < hi - u
-        m = (lo + hi) >>> 1
+        m = midpoint(lo, hi)
         if lt(o, v[m], x)
             lo = m
         else
@@ -192,7 +196,7 @@ function searchsortedlast(v::AbstractVec
     lo = lo - u
     hi = hi + u
     @inbounds while lo < hi - u
-        m = (lo + hi) >>> 1
+        m = midpoint(lo, hi)
         if lt(o, x, v[m])
             hi = m
         else
@@ -210,7 +214,7 @@ function searchsorted(v::AbstractVector,
     lo = ilo - u
     hi = ihi + u
     @inbounds while lo < hi - u
-        m = (lo + hi) >>> 1
+        m = midpoint(lo, hi)
         if lt(o, v[m], x)
             lo = m
         elseif lt(o, x, v[m])
@@ -387,7 +391,7 @@ struct QuickSortAlg     <: Algorithm end
 struct MergeSortAlg     <: Algorithm end
 
 """
-    PartialQuickSort{T <: Union{Int,OrdinalRange}}
+    PartialQuickSort{T <: Union{Integer,OrdinalRange}}
 
 Indicate that a sorting function should use the partial quick sort
 algorithm. Partial quick sort returns the smallest `k` elements sorted from smallest
@@ -400,7 +404,7 @@ Characteristics:
   * *in-place* in memory.
   * *divide-and-conquer*: sort strategy similar to [`MergeSort`](@ref).
 """
-struct PartialQuickSort{T <: Union{Int,OrdinalRange}} <: Algorithm
+struct PartialQuickSort{T <: Union{Integer,OrdinalRange}} <: Algorithm
     k::T
 end
 
@@ -460,7 +464,7 @@ const DEFAULT_STABLE   = MergeSort
 const SMALL_ALGORITHM  = InsertionSort
 const SMALL_THRESHOLD  = 20
 
-function sort!(v::AbstractVector, lo::Int, hi::Int, ::InsertionSortAlg, o::Ordering)
+function sort!(v::AbstractVector, lo::Integer, hi::Integer, ::InsertionSortAlg, o::Ordering)
     @inbounds for i = lo+1:hi
         j = i
         x = v[i]
@@ -485,9 +489,9 @@ end
 # Upon return, the pivot is in v[lo], and v[hi] is guaranteed to be
 # greater than the pivot
 
-@inline function selectpivot!(v::AbstractVector, lo::Int, hi::Int, o::Ordering)
+@inline function selectpivot!(v::AbstractVector, lo::Integer, hi::Integer, o::Ordering)
     @inbounds begin
-        mi = (lo+hi)>>>1
+        mi = midpoint(lo, hi)
 
         # sort v[mi] <= v[lo] <= v[hi] such that the pivot is immediately in place
         if lt(o, v[lo], v[mi])
@@ -511,7 +515,7 @@ end
 #
 # select a pivot, and partition v according to the pivot
 
-function partition!(v::AbstractVector, lo::Int, hi::Int, o::Ordering)
+function partition!(v::AbstractVector, lo::Integer, hi::Integer, o::Ordering)
     pivot = selectpivot!(v, lo, hi, o)
     # pivot == v[lo], v[hi] > pivot
     i, j = lo, hi
@@ -530,7 +534,7 @@ function partition!(v::AbstractVector, l
     return j
 end
 
-function sort!(v::AbstractVector, lo::Int, hi::Int, a::QuickSortAlg, o::Ordering)
+function sort!(v::AbstractVector, lo::Integer, hi::Integer, a::QuickSortAlg, o::Ordering)
     @inbounds while lo < hi
         hi-lo <= SMALL_THRESHOLD && return sort!(v, lo, hi, SMALL_ALGORITHM, o)
         j = partition!(v, lo, hi, o)
@@ -548,11 +552,11 @@ function sort!(v::AbstractVector, lo::In
     return v
 end
 
-function sort!(v::AbstractVector, lo::Int, hi::Int, a::MergeSortAlg, o::Ordering, t=similar(v,0))
+function sort!(v::AbstractVector, lo::Integer, hi::Integer, a::MergeSortAlg, o::Ordering, t=similar(v,0))
     @inbounds if lo < hi
         hi-lo <= SMALL_THRESHOLD && return sort!(v, lo, hi, SMALL_ALGORITHM, o)
 
-        m = (lo+hi)>>>1
+        m = midpoint(lo, hi)
         (length(t) < m-lo+1) && resize!(t, m-lo+1)
 
         sort!(v, lo,  m,  a, o, t)
@@ -586,7 +590,7 @@ function sort!(v::AbstractVector, lo::In
     return v
 end
 
-function sort!(v::AbstractVector, lo::Int, hi::Int, a::PartialQuickSort{Int},
+function sort!(v::AbstractVector, lo::Integer, hi::Integer, a::PartialQuickSort{<:Integer},
                o::Ordering)
     @inbounds while lo < hi
         hi-lo <= SMALL_THRESHOLD && return sort!(v, lo, hi, SMALL_ALGORITHM, o)
@@ -609,7 +613,7 @@ function sort!(v::AbstractVector, lo::In
 end
 
 
-function sort!(v::AbstractVector, lo::Int, hi::Int, a::PartialQuickSort{T},
+function sort!(v::AbstractVector, lo::Integer, hi::Integer, a::PartialQuickSort{T},
                o::Ordering) where T<:OrdinalRange
     @inbounds while lo < hi
         hi-lo <= SMALL_THRESHOLD && return sort!(v, lo, hi, SMALL_ALGORITHM, o)
@@ -646,9 +650,9 @@ end
 """
     sort!(v; alg::Algorithm=defalg(v), lt=isless, by=identity, rev::Bool=false, order::Ordering=Forward)
 
-Sort the vector `v` in place. `QuickSort` is used by default for numeric arrays while
-`MergeSort` is used for other arrays. You can specify an algorithm to use via the `alg`
-keyword (see Sorting Algorithms for available algorithms). The `by` keyword lets you provide
+Sort the vector `v` in place. [`QuickSort`](@ref) is used by default for numeric arrays while
+[`MergeSort`](@ref) is used for other arrays. You can specify an algorithm to use via the `alg`
+keyword (see [Sorting Algorithms](@ref) for available algorithms). The `by` keyword lets you provide
 a function that will be applied to each element before comparison; the `lt` keyword allows
 providing a custom "less than" function; use `rev=true` to reverse the sorting order. These
 options are independent and can be used together in all possible combinations: if both `by`
@@ -789,16 +793,59 @@ partialsortperm(v::AbstractVector, k::Un
 """
     partialsortperm!(ix, v, k; by=<transform>, lt=<comparison>, rev=false, initialized=false)
 
-Like [`partialsortperm`](@ref), but accepts a preallocated index vector `ix`. If `initialized` is `false`
-(the default), `ix` is initialized to contain the values `1:length(ix)`.
-"""
+Like [`partialsortperm`](@ref), but accepts a preallocated index vector `ix` the same size as
+`v`, which is used to store (a permutation of) the indices of `v`.
+
+If the index vector `ix` is initialized with the indices of `v` (or a permutation thereof), `initialized` should be set to
+`true`.
+
+If `initialized` is `false` (the default), then `ix` is initialized to contain the indices of `v`.
+
+If `initialized` is `true`, but `ix` does not contain (a permutation of) the indices of `v`, the behavior of
+`partialsortperm!` is undefined.
+
+(Typically, the indices of `v` will be `1:length(v)`, although if `v` has an alternative array type
+with non-one-based indices, such as an `OffsetArray`, `ix` must also be an `OffsetArray` with the same
+indices, and must contain as values (a permutation of) these same indices.)
+
+Upon return, `ix` is guaranteed to have the indices `k` in their sorted positions, such that
+
+```julia
+partialsortperm!(ix, v, k);
+v[ix[k]] == partialsort(v, k)
+```
+
+The return value is the `k`th element of `ix` if `k` is an integer, or view into `ix` if `k` is
+a range.
+
+# Examples
+```jldoctest
+julia> v = [3, 1, 2, 1];
+
+julia> ix = Vector{Int}(undef, 4);
+
+julia> partialsortperm!(ix, v, 1)
+2
+
+julia> ix = [1:4;];
+
+julia> partialsortperm!(ix, v, 2:3, initialized=true)
+2-element view(::Array{Int64,1}, 2:3) with eltype Int64:
+ 4
+ 3
+```
+ """
 function partialsortperm!(ix::AbstractVector{<:Integer}, v::AbstractVector,
-                          k::Union{Int, OrdinalRange};
+                          k::Union{Integer, OrdinalRange};
                           lt::Function=isless,
                           by::Function=identity,
                           rev::Union{Bool,Nothing}=nothing,
                           order::Ordering=Forward,
                           initialized::Bool=false)
+    if axes(ix,1) != axes(v,1)
+        throw(ArgumentError("The index vector is used as a workspace and must have the " *
+                            "same length/indices as the source vector, $(axes(ix,1)) != $(axes(v,1))"))
+    end
     if !initialized
         @inbounds for i = axes(ix,1)
             ix[i] = i
@@ -858,8 +905,9 @@ function sortperm(v::AbstractVector;
             end
         end
     end
-    p = similar(Vector{Int}, axes(v, 1))
-    for (i,ind) in zip(eachindex(p), axes(v, 1))
+    ax = axes(v, 1)
+    p = similar(Vector{eltype(ax)}, ax)
+    for (i,ind) in zip(eachindex(p), ax)
         p[i] = ind
     end
     sort!(p, alg, Perm(ordr,v))
@@ -897,7 +945,7 @@ function sortperm!(x::AbstractVector{<:I
                    order::Ordering=Forward,
                    initialized::Bool=false)
     if axes(x,1) != axes(v,1)
-        throw(ArgumentError("index vector must have the same indices as the source vector, $(axes(x,1)) != $(axes(v,1))"))
+        throw(ArgumentError("index vector must have the same length/indices as the source vector, $(axes(x,1)) != $(axes(v,1))"))
     end
     if !initialized
         @inbounds for i = axes(v,1)
@@ -1069,9 +1117,9 @@ lt(::Left, x::T, y::T) where {T<:Floats}
 lt(::Right, x::T, y::T) where {T<:Floats} = slt_int(x, y)
 
 isnan(o::DirectOrdering, x::Floats) = (x!=x)
-isnan(o::Perm, i::Int) = isnan(o.order,o.data[i])
+isnan(o::Perm, i::Integer) = isnan(o.order,o.data[i])
 
-function nans2left!(v::AbstractVector, o::Ordering, lo::Int=first(axes(v,1)), hi::Int=last(axes(v,1)))
+function nans2left!(v::AbstractVector, o::Ordering, lo::Integer=first(axes(v,1)), hi::Integer=last(axes(v,1)))
     i = lo
     @inbounds while i <= hi && isnan(o,v[i])
         i += 1
@@ -1086,7 +1134,7 @@ function nans2left!(v::AbstractVector, o
     end
     return i, hi
 end
-function nans2right!(v::AbstractVector, o::Ordering, lo::Int=first(axes(v,1)), hi::Int=last(axes(v,1)))
+function nans2right!(v::AbstractVector, o::Ordering, lo::Integer=first(axes(v,1)), hi::Integer=last(axes(v,1)))
     i = hi
     @inbounds while lo <= i && isnan(o,v[i])
         i -= 1
@@ -1104,12 +1152,12 @@ end
 
 nans2end!(v::AbstractVector, o::ForwardOrdering) = nans2right!(v,o)
 nans2end!(v::AbstractVector, o::ReverseOrdering) = nans2left!(v,o)
-nans2end!(v::AbstractVector{Int}, o::Perm{<:ForwardOrdering}) = nans2right!(v,o)
-nans2end!(v::AbstractVector{Int}, o::Perm{<:ReverseOrdering}) = nans2left!(v,o)
+nans2end!(v::AbstractVector{<:Integer}, o::Perm{<:ForwardOrdering}) = nans2right!(v,o)
+nans2end!(v::AbstractVector{<:Integer}, o::Perm{<:ReverseOrdering}) = nans2left!(v,o)
 
 issignleft(o::ForwardOrdering, x::Floats) = lt(o, x, zero(x))
 issignleft(o::ReverseOrdering, x::Floats) = lt(o, x, -zero(x))
-issignleft(o::Perm, i::Int) = issignleft(o.order, o.data[i])
+issignleft(o::Perm, i::Integer) = issignleft(o.order, o.data[i])
 
 function fpsort!(v::AbstractVector, a::Algorithm, o::Ordering)
     i, j = lo, hi = nans2end!(v,o)
diff -pruN 1.3.1+dfsg-1/base/special/cbrt.jl 1.4.0+dfsg-1/base/special/cbrt.jl
--- 1.3.1+dfsg-1/base/special/cbrt.jl	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/base/special/cbrt.jl	2020-03-21 16:36:32.000000000 +0000
@@ -52,7 +52,7 @@ Adding a bias of -0.03306235651 to the `
 32.
 
 With the IEEE floating point representation, for finite positive normal values, ordinary
-integer divison of the value in bits magically gives almost exactly the RHS of the above
+integer division of the value in bits magically gives almost exactly the RHS of the above
 provided we first subtract the exponent bias and later add it back.  We do the
 subtraction virtually to keep e >= 0 so that ordinary integer division rounds towards
 minus infinity; this is also efficient. All operations can be done in 32-bit.
diff -pruN 1.3.1+dfsg-1/base/stacktraces.jl 1.4.0+dfsg-1/base/stacktraces.jl
--- 1.3.1+dfsg-1/base/stacktraces.jl	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/base/stacktraces.jl	2020-03-21 16:36:32.000000000 +0000
@@ -7,8 +7,7 @@ module StackTraces
 
 
 import Base: hash, ==, show
-using Base.Printf: @printf
-using Base: something
+import Core: CodeInfo, MethodInstance
 
 export StackTrace, StackFrame, stacktrace
 
@@ -54,7 +53,7 @@ struct StackFrame # this type should be
     "the line number in the file containing the execution context"
     line::Int
     "the MethodInstance or CodeInfo containing the execution context (if it could be found)"
-    linfo::Union{Core.MethodInstance, Core.CodeInfo, Nothing}
+    linfo::Union{MethodInstance, CodeInfo, Nothing}
     "true if the code is from C"
     from_c::Bool
     "true if the code is from an inlined frame"
@@ -98,32 +97,29 @@ end
 
 
 """
-    lookup(pointer::Union{Ptr{Cvoid}, UInt}) -> Vector{StackFrame}
+    lookup(pointer::Ptr{Cvoid}) -> Vector{StackFrame}
 
 Given a pointer to an execution context (usually generated by a call to `backtrace`), looks
 up stack frame context information. Returns an array of frame information for all functions
 inlined at that point, innermost function first.
 """
 function lookup(pointer::Ptr{Cvoid})
-    infos = ccall(:jl_lookup_code_address, Any, (Ptr{Cvoid}, Cint), pointer - 1, false)
-    isempty(infos) && return [StackFrame(empty_sym, empty_sym, -1, nothing, true, false, convert(UInt64, pointer))]
+    infos = ccall(:jl_lookup_code_address, Any, (Ptr{Cvoid}, Cint), pointer, false)
+    pointer = convert(UInt64, pointer)
+    isempty(infos) && return [StackFrame(empty_sym, empty_sym, -1, nothing, true, false, pointer)] # this is equal to UNKNOWN
     res = Vector{StackFrame}(undef, length(infos))
     for i in 1:length(infos)
         info = infos[i]
-        @assert(length(info) == 7)
-        res[i] = StackFrame(info[1], info[2], info[3], info[4], info[5], info[6], info[7])
+        @assert(length(info) == 6)
+        res[i] = StackFrame(info[1], info[2], info[3], info[4], info[5], info[6], pointer)
     end
     return res
 end
 
-lookup(pointer::UInt) = lookup(convert(Ptr{Cvoid}, pointer))
-
 const top_level_scope_sym = Symbol("top-level scope")
 
-using Base.Meta
-is_loc_meta(expr, kind) = isexpr(expr, :meta) && length(expr.args) >= 1 && expr.args[1] === kind
 function lookup(ip::Base.InterpreterIP)
-    if ip.code isa Core.MethodInstance && ip.code.def isa Method
+    if ip.code isa MethodInstance && ip.code.def isa Method
         codeinfo = ip.code.uninferred
         func = ip.code.def.name
         file = ip.code.def.file
@@ -132,7 +128,7 @@ function lookup(ip::Base.InterpreterIP)
         # interpreted top-level expression with no CodeInfo
         return [StackFrame(top_level_scope_sym, empty_sym, 0, nothing, false, false, 0)]
     else
-        @assert ip.code isa Core.CodeInfo
+        @assert ip.code isa CodeInfo
         codeinfo = ip.code
         func = top_level_scope_sym
         file = empty_sym
@@ -154,39 +150,6 @@ function lookup(ip::Base.InterpreterIP)
     return scopes
 end
 
-# allow lookup on already-looked-up data for easier handling of pre-processed frames
-lookup(s::StackFrame) = StackFrame[s]
-lookup(s::Tuple{StackFrame,Int}) = StackFrame[s[1]]
-
-"""
-    backtrace()
-
-Get a backtrace object for the current program point.
-"""
-function Base.backtrace()
-    bt, bt2 = ccall(:jl_backtrace_from_here, Any, (Int32,), false)
-    if length(bt) > 2
-        # remove frames for jl_backtrace_from_here and backtrace()
-        if bt[2] == Ptr{Cvoid}(-1%UInt)
-            # backtrace() is interpreted
-            # Note: win32 is missing the top frame (see https://bugs.chromium.org/p/crashpad/issues/detail?id=53)
-            @static if Base.Sys.iswindows() && Int === Int32
-                deleteat!(bt, 1:2)
-            else
-                deleteat!(bt, 1:3)
-            end
-            pushfirst!(bt2)
-        else
-            @static if Base.Sys.iswindows() && Int === Int32
-                deleteat!(bt, 1)
-            else
-                deleteat!(bt, 1:2)
-            end
-        end
-    end
-    return Base._reformat_bt(bt, bt2)
-end
-
 """
     stacktrace([trace::Vector{Ptr{Cvoid}},] [c_funcs::Bool=false]) -> StackTrace
 
@@ -195,26 +158,27 @@ doesn't return C functions, but this can
 trace, `stacktrace` first calls `backtrace`.
 """
 function stacktrace(trace::Vector{<:Union{Base.InterpreterIP,Ptr{Cvoid}}}, c_funcs::Bool=false)
-    stack = vcat(StackTrace(), map(lookup, trace)...)::StackTrace
-
-    # Remove frames that come from C calls.
-    if !c_funcs
-        filter!(frame -> !frame.from_c, stack)
+    stack = StackTrace()
+    for ip in trace
+        for frame in lookup(ip)
+            # Skip frames that come from C calls.
+            if c_funcs || !frame.from_c
+                push!(stack, frame)
+            end
+        end
     end
+    return stack
+end
 
+function stacktrace(c_funcs::Bool=false)
+    stack = stacktrace(backtrace(), c_funcs)
     # Remove frame for this function (and any functions called by this function).
     remove_frames!(stack, :stacktrace)
-
-    # is there a better way?  the func symbol has a number suffix which changes.
-    # it's possible that no test is needed and we could just popfirst! all the time.
-    # this line was added to PR #16213 because otherwise stacktrace() != stacktrace(false).
-    # not sure why.  possibly b/c of re-ordering of base/sysimg.jl
-    !isempty(stack) && startswith(string(stack[1].func),"jlcall_stacktrace") && popfirst!(stack)
-    stack
+    # also remove all of the non-Julia functions that led up to this point (if that list is non-empty)
+    c_funcs && deleteat!(stack, 1:(something(findfirst(frame -> !frame.from_c, stack), 1) - 1))
+    return stack
 end
 
-stacktrace(c_funcs::Bool=false) = stacktrace(backtrace(), c_funcs)
-
 """
     remove_frames!(stack::StackTrace, name::Symbol)
 
@@ -224,12 +188,12 @@ all frames above the specified function)
 from the `StackTrace` prior to returning it.
 """
 function remove_frames!(stack::StackTrace, name::Symbol)
-    splice!(stack, 1:something(findlast(frame -> frame.func == name, stack), 0))
+    deleteat!(stack, 1:something(findlast(frame -> frame.func == name, stack), 0))
     return stack
 end
 
 function remove_frames!(stack::StackTrace, names::Vector{Symbol})
-    splice!(stack, 1:something(findlast(frame -> frame.func in names, stack), 0))
+    deleteat!(stack, 1:something(findlast(frame -> frame.func in names, stack), 0))
     return stack
 end
 
@@ -243,27 +207,44 @@ function remove_frames!(stack::StackTrac
     return stack
 end
 
-is_top_level_frame(f::StackFrame) = f.linfo isa Core.CodeInfo || (f.linfo === nothing && f.func === top_level_scope_sym)
+is_top_level_frame(f::StackFrame) = f.linfo isa CodeInfo || (f.linfo === nothing && f.func === top_level_scope_sym)
 
 function show_spec_linfo(io::IO, frame::StackFrame)
     if frame.linfo === nothing
         if frame.func === empty_sym
-            @printf(io, "ip:%#x", frame.pointer)
+            print(io, "ip:0x", string(frame.pointer, base=16))
         elseif frame.func === top_level_scope_sym
             print(io, "top-level scope")
         else
             color = get(io, :color, false) && get(io, :backtrace, false) ?
                         Base.stackframe_function_color() :
                         :nothing
-            printstyled(io, string(frame.func), color=color)
+            printstyled(io, Base.demangle_function_name(string(frame.func)), color=color)
         end
-    elseif frame.linfo isa Core.MethodInstance
-        if isa(frame.linfo.def, Method)
-            Base.show_tuple_as_call(io, frame.linfo.def.name, frame.linfo.specTypes)
+    elseif frame.linfo isa MethodInstance
+        def = frame.linfo.def
+        if isa(def, Method)
+            sig = frame.linfo.specTypes
+            if def.nkw > 0
+                # rearrange call kw_impl(kw_args..., func, pos_args...) to func(pos_args...)
+                kwarg_types = Any[ fieldtype(sig, i) for i = 2:(1+def.nkw) ]
+                uw = Base.unwrap_unionall(sig)
+                pos_sig = Base.rewrap_unionall(Tuple{uw.parameters[(def.nkw+2):end]...}, sig)
+                kwnames = Base.method_argnames(def)[2:(def.nkw+1)]
+                for i = 1:length(kwnames)
+                    str = string(kwnames[i])
+                    if endswith(str, "...")
+                        kwnames[i] = Symbol(str[1:end-3])
+                    end
+                end
+                Base.show_tuple_as_call(io, def.name, pos_sig, true, zip(kwnames, kwarg_types))
+            else
+                Base.show_tuple_as_call(io, def.name, sig, true)
+            end
         else
             Base.show(io, frame.linfo)
         end
-    elseif frame.linfo isa Core.CodeInfo
+    elseif frame.linfo isa CodeInfo
         print(io, "top-level scope")
     end
 end
@@ -296,7 +277,7 @@ function from(frame::StackFrame, m::Modu
     finfo = frame.linfo
     result = false
 
-    if finfo isa Core.MethodInstance
+    if finfo isa MethodInstance
         frame_m = finfo.def
         isa(frame_m, Method) && (frame_m = frame_m.module)
         result = nameof(frame_m) === nameof(m)
diff -pruN 1.3.1+dfsg-1/base/stream.jl 1.4.0+dfsg-1/base/stream.jl
--- 1.3.1+dfsg-1/base/stream.jl	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/base/stream.jl	2020-03-21 16:36:32.000000000 +0000
@@ -51,7 +51,7 @@ function eof(s::LibuvStream)
     # and that we won't return true if there's a readerror pending (it'll instead get thrown).
     # This requires some careful ordering here (TODO: atomic loads)
     bytesavailable(s) > 0 && return false
-    open = isopen(s) # must preceed readerror check
+    open = isopen(s) # must precede readerror check
     s.readerror === nothing || throw(s.readerror)
     return !open
 end
@@ -332,7 +332,7 @@ end
 function wait_readnb(x::LibuvStream, nb::Int)
     # fast path before iolock acquire
     bytesavailable(x.buffer) >= nb && return
-    open = isopen(x) # must preceed readerror check
+    open = isopen(x) # must precede readerror check
     x.readerror === nothing || throw(x.readerror)
     open || return
     iolock_begin()
diff -pruN 1.3.1+dfsg-1/base/strings/basic.jl 1.4.0+dfsg-1/base/strings/basic.jl
--- 1.3.1+dfsg-1/base/strings/basic.jl	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/base/strings/basic.jl	2020-03-21 16:36:32.000000000 +0000
@@ -107,7 +107,7 @@ julia> isvalid(str, 1)
 true
 
 julia> str[1]
-'α': Unicode U+03b1 (category Ll: Letter, lowercase)
+'α': Unicode U+03B1 (category Ll: Letter, lowercase)
 
 julia> isvalid(str, 2)
 false
@@ -157,6 +157,7 @@ julia> sizeof("∀")
 sizeof(s::AbstractString) = ncodeunits(s) * sizeof(codeunit(s))
 firstindex(s::AbstractString) = 1
 lastindex(s::AbstractString) = thisind(s, ncodeunits(s))
+isempty(s::AbstractString) = iszero(ncodeunits(s))
 
 function getindex(s::AbstractString, i::Integer)
     @boundscheck checkbounds(s, i)
@@ -564,17 +565,22 @@ isascii(c::Char) = bswap(reinterpret(UIn
 isascii(s::AbstractString) = all(isascii, s)
 isascii(c::AbstractChar) = UInt32(c) < 0x80
 
-## string map, filter, has ##
+## string map, filter ##
 
 function map(f, s::AbstractString)
-    out = IOBuffer(sizehint=sizeof(s))
+    out = StringVector(max(4, sizeof(s)÷sizeof(codeunit(s))))
+    index = UInt(1)
     for c in s
         c′ = f(c)
         isa(c′, AbstractChar) || throw(ArgumentError(
-            "map(f, s::AbstractString) requires f to return AbstractChar; try map(f, collect(s)) or a comprehension instead"))
-        write(out, c′::AbstractChar)
+            "map(f, s::AbstractString) requires f to return AbstractChar; " *
+            "try map(f, collect(s)) or a comprehension instead"))
+        index + 3 > length(out) && resize!(out, unsigned(2 * length(out)))
+        index += __unsafe_string!(out, convert(Char, c′), index)
     end
-    String(take!(out))
+    resize!(out, index-1)
+    sizehint!(out, index-1)
+    return String(out)
 end
 
 function filter(f, s::AbstractString)
diff -pruN 1.3.1+dfsg-1/base/strings/io.jl 1.4.0+dfsg-1/base/strings/io.jl
--- 1.3.1+dfsg-1/base/strings/io.jl	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/base/strings/io.jl	2020-03-21 16:36:32.000000000 +0000
@@ -107,9 +107,6 @@ function sprint(f::Function, args...; co
     String(resize!(s.data, s.size))
 end
 
-# CategoricalArrays extends this
-function tostr_sizehint end
-
 function _str_sizehint(x)
     if x isa Float64
         return 20
@@ -393,7 +390,8 @@ The following escape sequences are recog
  - Escaped backslash (`\\\\`)
  - Escaped double-quote (`\\\"`)
  - Standard C escape sequences (`\\a`, `\\b`, `\\t`, `\\n`, `\\v`, `\\f`, `\\r`, `\\e`)
- - Unicode code points (`\\u` or `\\U` prefixes with 1-4 trailing hex digits)
+ - Unicode BMP code points (`\\u` with 1-4 trailing hex digits)
+ - All Unicode code points (`\\U` with 1-8 trailing hex digits; max value = 0010ffff)
  - Hex bytes (`\\x` with 1-2 trailing hex digits)
  - Octal bytes (`\\` with 1-3 trailing octal digits)
 
diff -pruN 1.3.1+dfsg-1/base/strings/string.jl 1.4.0+dfsg-1/base/strings/string.jl
--- 1.3.1+dfsg-1/base/strings/string.jl	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/base/strings/string.jl	2020-03-21 16:36:32.000000000 +0000
@@ -66,7 +66,7 @@ Convert a string to a contiguous byte ar
 This representation is often appropriate for passing strings to C.
 """
 String(s::AbstractString) = print_to_string(s)
-String(s::Symbol) = unsafe_string(unsafe_convert(Ptr{UInt8}, s))
+@pure String(s::Symbol) = unsafe_string(unsafe_convert(Ptr{UInt8}, s))
 
 unsafe_wrap(::Type{Vector{UInt8}}, s::String) = ccall(:jl_string_to_array, Ref{Vector{UInt8}}, (Any,), s)
 
@@ -81,8 +81,8 @@ String(s::CodeUnits{UInt8,String}) = s.s
 pointer(s::String) = unsafe_convert(Ptr{UInt8}, s)
 pointer(s::String, i::Integer) = pointer(s)+(i-1)
 
-ncodeunits(s::String) = Core.sizeof(s)
-sizeof(s::String) = Core.sizeof(s)
+@pure ncodeunits(s::String) = Core.sizeof(s)
+@pure sizeof(s::String) = Core.sizeof(s)
 codeunit(s::String) = UInt8
 
 @inline function codeunit(s::String, i::Integer)
diff -pruN 1.3.1+dfsg-1/base/strings/util.jl 1.4.0+dfsg-1/base/strings/util.jl
--- 1.3.1+dfsg-1/base/strings/util.jl	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/base/strings/util.jl	2020-03-21 16:36:32.000000000 +0000
@@ -104,7 +104,7 @@ end
 # chop(s::AbstractString) = SubString(s, firstindex(s), prevind(s, lastindex(s)))
 
 """
-    chomp(s::AbstractString)
+    chomp(s::AbstractString) -> SubString
 
 Remove a single trailing newline from a string.
 
@@ -133,8 +133,8 @@ function chomp(s::String)
 end
 
 """
-    lstrip([pred=isspace,] str::AbstractString)
-    lstrip(str::AbstractString, chars)
+    lstrip([pred=isspace,] str::AbstractString) -> SubString
+    lstrip(str::AbstractString, chars) -> SubString
 
 Remove leading characters from `str`, either those specified by `chars` or those for
 which the function `pred` returns `true`.
@@ -165,8 +165,8 @@ lstrip(s::AbstractString) = lstrip(isspa
 lstrip(s::AbstractString, chars::Chars) = lstrip(in(chars), s)
 
 """
-    rstrip([pred=isspace,] str::AbstractString)
-    rstrip(str::AbstractString, chars)
+    rstrip([pred=isspace,] str::AbstractString) -> SubString
+    rstrip(str::AbstractString, chars) -> SubString
 
 Remove trailing characters from `str`, either those specified by `chars` or those for
 which the function `pred` returns `true`.
@@ -196,8 +196,8 @@ rstrip(s::AbstractString) = rstrip(isspa
 rstrip(s::AbstractString, chars::Chars) = rstrip(in(chars), s)
 
 """
-    strip([pred=isspace,] str::AbstractString)
-    strip(str::AbstractString, chars)
+    strip([pred=isspace,] str::AbstractString) -> SubString
+    strip(str::AbstractString, chars) -> SubString
 
 Remove leading and trailing characters from `str`, either those specified by `chars` or
 those for which the function `pred` returns `true`.
@@ -470,7 +470,7 @@ If `count` is provided, replace at most
 `pat` may be a single character, a vector or a set of characters, a string,
 or a regular expression.
 If `r` is a function, each occurrence is replaced with `r(s)`
-where `s` is the matched substring (when `pat`is a `Regex` or `AbstractString`) or
+where `s` is the matched substring (when `pat` is a `Regex` or `AbstractString`) or
 character (when `pat` is an `AbstractChar` or a collection of `AbstractChar`).
 If `pat` is a regular expression and `r` is a [`SubstitutionString`](@ref), then capture group
 references in `r` are replaced with the corresponding matched text.
diff -pruN 1.3.1+dfsg-1/base/subarray.jl 1.4.0+dfsg-1/base/subarray.jl
--- 1.3.1+dfsg-1/base/subarray.jl	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/base/subarray.jl	2020-03-21 16:36:32.000000000 +0000
@@ -4,7 +4,13 @@ abstract type AbstractCartesianIndex{N}
 const ViewIndex = Union{Real, AbstractArray}
 const ScalarIndex = Real
 
-# L is true if the view itself supports fast linear indexing
+"""
+    SubArray{T,N,P,I,L} <: AbstractArray{T,N}
+
+`N`-dimensional view into a parent array (of type `P`) with an element type `T`, restricted by a tuple of indices (of type `I`). `L` is true for types that support fast linear indexing, and `false` otherwise.
+
+Construct `SubArray`s using the [`view`](@ref) function.
+"""
 struct SubArray{T,N,P,I,L} <: AbstractArray{T,N}
     parent::P
     indices::I
diff -pruN 1.3.1+dfsg-1/base/sysimg.jl 1.4.0+dfsg-1/base/sysimg.jl
--- 1.3.1+dfsg-1/base/sysimg.jl	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/base/sysimg.jl	2020-03-21 16:36:32.000000000 +0000
@@ -27,11 +27,11 @@ let
             :Mmap,
             :Serialization,
             :Libdl,
+            :Printf,
             :Markdown,
             :LibGit2,
             :Logging,
             :Sockets,
-            :Printf,
             :Profile,
             :Dates,
             :DelimitedFiles,
diff -pruN 1.3.1+dfsg-1/base/sysinfo.jl 1.4.0+dfsg-1/base/sysinfo.jl
--- 1.3.1+dfsg-1/base/sysinfo.jl	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/base/sysinfo.jl	2020-03-21 16:36:32.000000000 +0000
@@ -49,6 +49,9 @@ A string containing the full path to the
 A string containing the full path to the directory containing the `stdlib` packages.
 """
 STDLIB = "$BINDIR/../share/julia/stdlib/v$(VERSION.major).$(VERSION.minor)" # for bootstrap
+# In case STDLIB change after julia is built, the variable below can be used
+# to update cached method locations to updated ones.
+const BUILD_STDLIB_PATH = STDLIB
 
 # helper to avoid triggering precompile warnings
 
diff -pruN 1.3.1+dfsg-1/base/task.jl 1.4.0+dfsg-1/base/task.jl
--- 1.3.1+dfsg-1/base/task.jl	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/base/task.jl	2020-03-21 16:36:32.000000000 +0000
@@ -244,6 +244,22 @@ function _wait(t::Task)
     nothing
 end
 
+# have `waiter` wait for `t`
+function _wait2(t::Task, waiter::Task)
+    if !istaskdone(t)
+        lock(t.donenotify)
+        if !istaskdone(t)
+            push!(t.donenotify.waitq, waiter)
+            unlock(t.donenotify)
+            return nothing
+        else
+            unlock(t.donenotify)
+        end
+    end
+    schedule(waiter)
+    nothing
+end
+
 function wait(t::Task)
     t === current_task() && error("deadlock detected: cannot wait on current task")
     _wait(t)
@@ -328,20 +344,60 @@ end
     @async
 
 Wrap an expression in a [`Task`](@ref) and add it to the local machine's scheduler queue.
+
+Values can be interpolated into `@async` via `\$`, which copies the value directly into the
+constructed underlying closure. This allows you to insert the _value_ of a variable,
+isolating the aysnchronous code from changes to the variable's value in the current task.
+
+!!! compat "Julia 1.4"
+    Interpolating values via `\$` is available as of Julia 1.4.
 """
 macro async(expr)
+    letargs = Base._lift_one_interp!(expr)
+
     thunk = esc(:(()->($expr)))
     var = esc(sync_varname)
     quote
-        local task = Task($thunk)
-        if $(Expr(:isdefined, var))
-            push!($var, task)
+        let $(letargs...)
+            local task = Task($thunk)
+            if $(Expr(:islocal, var))
+                push!($var, task)
+            end
+            schedule(task)
+            task
+        end
+    end
+end
+
+# Capture interpolated variables in $() and move them to let-block
+function _lift_one_interp!(e)
+    letargs = Any[]  # store the new gensymed arguments
+    _lift_one_interp_helper(e, false, letargs) # Start out _not_ in a quote context (false)
+    letargs
+end
+_lift_one_interp_helper(v, _, _) = v
+function _lift_one_interp_helper(expr::Expr, in_quote_context, letargs)
+    if expr.head === :$
+        if in_quote_context  # This $ is simply interpolating out of the quote
+            # Now, we're out of the quote, so any _further_ $ is ours.
+            in_quote_context = false
+        else
+            newarg = gensym()
+            push!(letargs, :($(esc(newarg)) = $(esc(expr.args[1]))))
+            return newarg  # Don't recurse into the lifted $() exprs
         end
-        schedule(task)
-        task
+    elseif expr.head === :quote
+        in_quote_context = true   # Don't try to lift $ directly out of quotes
+    elseif expr.head === :macrocall
+        return expr  # Don't recur into macro calls, since some other macros use $
+    end
+    for (i,e) in enumerate(expr.args)
+        expr.args[i] = _lift_one_interp_helper(e, in_quote_context, letargs)
     end
+    expr
 end
 
+
 # add a wait-able object to the sync pool
 macro sync_add(expr)
     var = esc(sync_varname)
@@ -352,12 +408,6 @@ macro sync_add(expr)
     end
 end
 
-function register_taskdone_hook(t::Task, hook)
-    tls = get_task_tls(t)
-    push!(get!(tls, :TASKDONE_HOOKS, []), hook)
-    return t
-end
-
 # runtime system hook called when a task finishes
 function task_done_hook(t::Task)
     # `finish_task` sets `sigatomic` before entering this function
@@ -381,13 +431,6 @@ function task_done_hook(t::Task)
         end
     end
 
-    # Execute any other hooks registered in the TLS
-    if isa(t.storage, IdDict) && haskey(t.storage, :TASKDONE_HOOKS)
-        foreach(hook -> hook(t), t.storage[:TASKDONE_HOOKS])
-        delete!(t.storage, :TASKDONE_HOOKS)
-        handled = true
-    end
-
     if err && !handled && Threads.threadid() == 1
         if isa(result, InterruptException) && isdefined(Base, :active_repl_backend) &&
             active_repl_backend.backend_task.state === :runnable && isempty(Workqueue) &&
@@ -656,8 +699,7 @@ end
 @noinline function poptaskref(W::StickyWorkqueue)
     task = trypoptask(W)
     if !(task isa Task)
-        gettask = () -> trypoptask(W)
-        task = ccall(:jl_task_get_next, Any, (Any,), gettask)::Task
+        task = ccall(:jl_task_get_next, Ref{Task}, (Any, Any), trypoptask, W)
     end
     return Ref(task)
 end
diff -pruN 1.3.1+dfsg-1/base/threadingconstructs.jl 1.4.0+dfsg-1/base/threadingconstructs.jl
--- 1.3.1+dfsg-1/base/threadingconstructs.jl	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/base/threadingconstructs.jl	2020-03-21 16:36:32.000000000 +0000
@@ -43,7 +43,7 @@ function _threadsfor(iter,lbody)
                 len, rem = 1, 0
             end
             # compute this thread's iterations
-            f = 1 + ((tid-1) * len)
+            f = firstindex(r) + ((tid-1) * len)
             l = f + len - 1
             # distribute remaining iterations evenly
             if rem > 0
@@ -57,7 +57,7 @@ function _threadsfor(iter,lbody)
             end
             # run this thread's iterations
             for i = f:l
-                local $(esc(lidx)) = Base.unsafe_getindex(r,i)
+                local $(esc(lidx)) = @inbounds r[i]
                 $(esc(lbody))
             end
         end
@@ -90,7 +90,11 @@ macro threads(args...)
         throw(ArgumentError("need an expression argument to @threads"))
     end
     if ex.head === :for
-        return _threadsfor(ex.args[1], ex.args[2])
+        if ex.args[1] isa Expr && ex.args[1].head === :(=)
+            return _threadsfor(ex.args[1], ex.args[2])
+        else
+            throw(ArgumentError("nested outer loops are not currently supported by @threads"))
+        end
     else
         throw(ArgumentError("unrecognized argument to @threads"))
     end
@@ -103,22 +107,33 @@ Create and run a [`Task`](@ref) on any a
 finish, call [`wait`](@ref) on the result of this macro, or call [`fetch`](@ref)
 to wait and then obtain its return value.
 
+Values can be interpolated into `@spawn` via `\$`, which copies the value directly into the
+constructed underlying closure. This allows you to insert the _value_ of a variable,
+isolating the aysnchronous code from changes to the variable's value in the current task.
+
 !!! note
     This feature is currently considered experimental.
 
 !!! compat "Julia 1.3"
     This macro is available as of Julia 1.3.
+
+!!! compat "Julia 1.4"
+    Interpolating values via `\$` is available as of Julia 1.4.
 """
 macro spawn(expr)
+    letargs = Base._lift_one_interp!(expr)
+
     thunk = esc(:(()->($expr)))
     var = esc(Base.sync_varname)
     quote
-        local task = Task($thunk)
-        task.sticky = false
-        if $(Expr(:isdefined, var))
-            push!($var, task)
+        let $(letargs...)
+            local task = Task($thunk)
+            task.sticky = false
+            if $(Expr(:islocal, var))
+                push!($var, task)
+            end
+            schedule(task)
+            task
         end
-        schedule(task)
-        task
     end
 end
diff -pruN 1.3.1+dfsg-1/base/tuple.jl 1.4.0+dfsg-1/base/tuple.jl
--- 1.3.1+dfsg-1/base/tuple.jl	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/base/tuple.jl	2020-03-21 16:36:32.000000000 +0000
@@ -28,7 +28,25 @@ getindex(t::Tuple, b::AbstractArray{Bool
 getindex(t::Tuple, c::Colon) = t
 
 # returns new tuple; N.B.: becomes no-op if i is out-of-bounds
-setindex(x::Tuple, v, i::Integer) = (@_inline_meta; _setindex(v, i, x...))
+
+"""
+    setindex(c::Tuple, v, i::Integer)
+
+Creates a new tuple similar to `x` with the value at index `i` set to `v`.
+Throws a `BoundsError` when out of bounds.
+
+# Examples
+```jldoctest
+julia> Base.setindex((1, 2, 6), 2, 3) == (1, 2, 2)
+true
+```
+"""
+function setindex(x::Tuple, v, i::Integer)
+    @boundscheck 1 <= i <= length(x) || throw(BoundsError(x, i))
+    @_inline_meta
+    _setindex(v, i, x...)
+end
+
 function _setindex(v, i::Integer, first, tail...)
     @_inline_meta
     return (ifelse(i == 1, v, first), _setindex(v, i - 1, tail...)...)
@@ -186,18 +204,7 @@ function map(f, t1::Any16, t2::Any16, ts
     (A...,)
 end
 
-# mapafoldl, based on afold in operators.jl
-mapafoldl(F,op,a) = a
-mapafoldl(F,op,a,b) = op(a,F(b))
-mapafoldl(F,op,a,b,c...) = mapafoldl(F, op, op(a,F(b)), c...)
-function mapafoldl(F,op,a,b,c,d,e,f,g,h,i,j,k,l,m,n,o,p,qs...)
-    y = op(op(op(op(op(op(op(op(op(op(op(op(op(op(op(a,F(b)),F(c)),F(d)),F(e)),F(f)),F(g)),F(h)),F(i)),F(j)),F(k)),F(l)),F(m)),F(n)),F(o)),F(p))
-    for x in qs; y = op(y,F(x)); end
-    y
-end
-mapfoldl_impl(f, op, nt::NamedTuple{(:init,)}, t::Tuple) = mapafoldl(f, op, nt.init, t...)
-mapfoldl_impl(f, op, nt::NamedTuple{()}, t::Tuple) = mapafoldl(f, op, f(t[1]), tail(t)...)
-mapfoldl_impl(f, op, nt::NamedTuple{()}, t::Tuple{}) = mapreduce_empty_iter(f, op, t, IteratorEltype(t))
+_foldl_impl(op, init, itr::Tuple) = afoldl(op, init, itr...)
 
 # type-stable padding
 fill_to_length(t::NTuple{N,Any}, val, ::Val{N}) where {N} = t
@@ -217,6 +224,9 @@ if nameof(@__MODULE__) === :Base
 
 (::Type{T})(x::Tuple) where {T<:Tuple} = convert(T, x)  # still use `convert` for tuples
 
+Tuple(x::Ref) = tuple(getindex(x))  # faster than iterator for one element
+Tuple(x::Array{T,0}) where {T} = tuple(getindex(x))
+
 (::Type{T})(itr) where {T<:Tuple} = _totuple(T, itr)
 
 _totuple(::Type{Tuple{}}, itr, s...) = ()
@@ -249,6 +259,13 @@ _totuple(::Type{Tuple}, itr, s...) = (co
 
 end
 
+## filter ##
+
+filter(f, xs::Tuple) = afoldl((ys, x) -> f(x) ? (ys..., x) : ys, (), xs...)
+
+# use Array for long tuples
+filter(f, t::Any16) = Tuple(filter(f, collect(t)))
+
 ## comparison ##
 
 isequal(t1::Tuple, t2::Tuple) = (length(t1) == length(t2)) && _isequal(t1, t2)
diff -pruN 1.3.1+dfsg-1/base/util.jl 1.4.0+dfsg-1/base/util.jl
--- 1.3.1+dfsg-1/base/util.jl	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/base/util.jl	2020-03-21 16:36:32.000000000 +0000
@@ -3,20 +3,20 @@
 
 # This type must be kept in sync with the C struct in src/gc.h
 struct GC_Num
-    allocd      ::Int64 # GC internal
-    deferred_alloc::Int64 # GC internal
-    freed       ::Int64 # GC internal
-    malloc      ::UInt64
-    realloc     ::UInt64
-    poolalloc   ::UInt64
-    bigalloc    ::UInt64
-    freecall    ::UInt64
-    total_time  ::UInt64
-    total_allocd::UInt64 # GC internal
-    since_sweep ::UInt64 # GC internal
-    collect     ::Csize_t # GC internal
-    pause       ::Cint
-    full_sweep  ::Cint
+    allocd          ::Int64 # GC internal
+    deferred_alloc  ::Int64 # GC internal
+    freed           ::Int64 # GC internal
+    malloc          ::Int64
+    realloc         ::Int64
+    poolalloc       ::Int64
+    bigalloc        ::Int64
+    freecall        ::Int64
+    total_time      ::Int64
+    total_allocd    ::Int64 # GC internal
+    since_sweep     ::Int64 # GC internal
+    collect         ::Csize_t # GC internal
+    pause           ::Cint
+    full_sweep      ::Cint
 end
 
 gc_num() = ccall(:jl_gc_num, GC_Num, ())
@@ -35,21 +35,21 @@ struct GC_Diff
 end
 
 gc_total_bytes(gc_num::GC_Num) =
-    (gc_num.allocd + gc_num.deferred_alloc + Int64(gc_num.total_allocd))
+    gc_num.allocd + gc_num.deferred_alloc + gc_num.total_allocd
 
 function GC_Diff(new::GC_Num, old::GC_Num)
     # logic from `src/gc.c:jl_gc_total_bytes`
     old_allocd = gc_total_bytes(old)
     new_allocd = gc_total_bytes(new)
     return GC_Diff(new_allocd - old_allocd,
-                   Int64(new.malloc       - old.malloc),
-                   Int64(new.realloc      - old.realloc),
-                   Int64(new.poolalloc    - old.poolalloc),
-                   Int64(new.bigalloc     - old.bigalloc),
-                   Int64(new.freecall     - old.freecall),
-                   Int64(new.total_time   - old.total_time),
-                   new.pause              - old.pause,
-                   new.full_sweep         - old.full_sweep)
+                   new.malloc       - old.malloc,
+                   new.realloc      - old.realloc,
+                   new.poolalloc    - old.poolalloc,
+                   new.bigalloc     - old.bigalloc,
+                   new.freecall     - old.freecall,
+                   new.total_time   - old.total_time,
+                   new.pause        - old.pause,
+                   new.full_sweep   - old.full_sweep)
 end
 
 function gc_alloc_count(diff::GC_Diff)
@@ -60,8 +60,18 @@ end
 # total time spend in garbage collection, in nanoseconds
 gc_time_ns() = ccall(:jl_gc_total_hrtime, UInt64, ())
 
-# total number of bytes allocated so far
-gc_bytes() = ccall(:jl_gc_total_bytes, Int64, ())
+"""
+    Base.gc_live_bytes()
+
+Return the total size (in bytes) of objects currently in memory.
+This is computed as the total size of live objects after
+the last garbage collection, plus the number of bytes allocated
+since then.
+"""
+function gc_live_bytes()
+    num = gc_num()
+    Int(ccall(:jl_gc_live_bytes, Int64, ())) + num.allocd + num.deferred_alloc
+end
 
 # print elapsed time, return expression value
 const _mem_units = ["byte", "KiB", "MiB", "GiB", "TiB", "PiB"]
@@ -76,39 +86,43 @@ function prettyprint_getunits(value, num
     return number, unit
 end
 
-function padded_nonzero_print(value,str)
+function padded_nonzero_print(value, str)
     if value != 0
-        blanks = "                "[1:18-length(str)]
-        println("$str:$blanks$value")
+        blanks = "                "[1:(18 - length(str))]
+        println(str, ":", blanks, value)
     end
 end
 
-function format_bytes(bytes)
+
+function format_bytes(bytes) # also used by InteractiveUtils
     bytes, mb = prettyprint_getunits(bytes, length(_mem_units), Int64(1024))
     if mb == 1
-        Printf.@sprintf("%d %s%s", bytes, _mem_units[mb], bytes==1 ? "" : "s")
+        return string(Int(bytes), " ", _mem_units[mb], bytes==1 ? "" : "s")
     else
-        Printf.@sprintf("%.3f %s", bytes, _mem_units[mb])
+        return string(Ryu.writefixed(Float64(bytes), 3), " ", _mem_units[mb])
     end
 end
 
 function time_print(elapsedtime, bytes=0, gctime=0, allocs=0)
-    Printf.@printf("%10.6f seconds", elapsedtime/1e9)
+    timestr = Ryu.writefixed(Float64(elapsedtime/1e9), 6)
+    length(timestr) < 10 && print(" "^(10 - length(timestr)))
+    print(timestr, " seconds")
     if bytes != 0 || allocs != 0
         allocs, ma = prettyprint_getunits(allocs, length(_cnt_units), Int64(1000))
         if ma == 1
-            Printf.@printf(" (%d%s allocation%s: ", allocs, _cnt_units[ma], allocs==1 ? "" : "s")
+            print(" (", Int(allocs), _cnt_units[ma], allocs==1 ? " allocation: " : " allocations: ")
         else
-            Printf.@printf(" (%.2f%s allocations: ", allocs, _cnt_units[ma])
+            print(" (", Ryu.writefixed(Float64(allocs), 2), _cnt_units[ma], " allocations: ")
         end
         print(format_bytes(bytes))
-        if gctime > 0
-            Printf.@printf(", %.2f%% gc time", 100*gctime/elapsedtime)
-        end
+    end
+    if gctime > 0
+        print(", ", Ryu.writefixed(Float64(100*gctime/elapsedtime), 2), "% gc time")
+    end
+    if bytes != 0 || allocs != 0
         print(")")
-    elseif gctime > 0
-        Printf.@printf(", %.2f%% gc time", 100*gctime/elapsedtime)
     end
+    nothing
 end
 
 function timev_print(elapsedtime, diff::GC_Diff)
@@ -136,6 +150,11 @@ returning the value of the expression.
 See also [`@timev`](@ref), [`@timed`](@ref), [`@elapsed`](@ref), and
 [`@allocated`](@ref).
 
+!!! note
+    For more serious benchmarking, consider the `@btime` macro from the BenchmarkTools.jl
+    package which among other things evaluates the function multiple times in order to
+    reduce noise.
+
 ```julia-repl
 julia> @time rand(10^6);
   0.001525 seconds (7 allocations: 7.630 MiB)
@@ -150,6 +169,7 @@ julia> @time begin
 """
 macro time(ex)
     quote
+        while false; end # compiler heuristic: compile this block (alter this if the heuristic changes)
         local stats = gc_num()
         local elapsedtime = time_ns()
         local val = $(esc(ex))
@@ -183,6 +203,7 @@ malloc() calls:    1
 """
 macro timev(ex)
     quote
+        while false; end # compiler heuristic: compile this block (alter this if the heuristic changes)
         local stats = gc_num()
         local elapsedtime = time_ns()
         local val = $(esc(ex))
@@ -208,27 +229,27 @@ julia> @elapsed sleep(0.3)
 """
 macro elapsed(ex)
     quote
+        while false; end # compiler heuristic: compile this block (alter this if the heuristic changes)
         local t0 = time_ns()
-        local val = $(esc(ex))
-        (time_ns()-t0)/1e9
+        $(esc(ex))
+        (time_ns() - t0) / 1e9
     end
 end
 
-# measure bytes allocated without *most* contamination from compilation
-# Note: This reports a different value from the @time macros, because
-# it wraps the call in a function, however, this means that things
-# like:  @allocated y = foo()
-# will not work correctly, because it will set y in the context of
-# the local function made by the macro, not the current function
+# total number of bytes allocated so far
+gc_bytes(b::Ref{Int64}) = ccall(:jl_gc_get_total_bytes, Cvoid, (Ptr{Int64},), b)
+# NOTE: gc_bytes() is deprecated
+function gc_bytes()
+    b = Ref{Int64}()
+    gc_bytes(b)
+    b[]
+end
+
 """
     @allocated
 
 A macro to evaluate an expression, discarding the resulting value, instead returning the
-total number of bytes allocated during evaluation of the expression. Note: the expression is
-evaluated inside a local function, instead of the current context, in order to eliminate the
-effects of compilation, however, there still may be some allocations due to JIT compilation.
-This also makes the results inconsistent with the `@time` macros, which do not try to adjust
-for the effects of compilation.
+total number of bytes allocated during evaluation of the expression.
 
 See also [`@time`](@ref), [`@timev`](@ref), [`@timed`](@ref),
 and [`@elapsed`](@ref).
@@ -240,15 +261,13 @@ julia> @allocated rand(10^6)
 """
 macro allocated(ex)
     quote
-        let
-            local f
-            function f()
-                b0 = gc_bytes()
-                $(esc(ex))
-                gc_bytes() - b0
-            end
-            f()
-        end
+        while false; end # compiler heuristic: compile this block (alter this if the heuristic changes)
+        local b0 = Ref{Int64}(0)
+        local b1 = Ref{Int64}(0)
+        gc_bytes(b0)
+        $(esc(ex))
+        gc_bytes(b1)
+        b1[] - b0[]
     end
 end
 
@@ -283,6 +302,7 @@ julia> memallocs.total_time
 """
 macro timed(ex)
     quote
+        while false; end # compiler heuristic: compile this block (alter this if the heuristic changes)
         local stats = gc_num()
         local elapsedtime = time_ns()
         local val = $(esc(ex))
@@ -812,6 +832,7 @@ function runtests(tests = ["all"]; ncore
     try
         run(setenv(`$(julia_cmd()) $(joinpath(Sys.BINDIR::String,
             Base.DATAROOTDIR, "julia", "test", "runtests.jl")) $tests`, ENV2))
+        nothing
     catch
         buf = PipeBuffer()
         Base.require(Base, :InteractiveUtils).versioninfo(buf)
diff -pruN 1.3.1+dfsg-1/base/version.jl 1.4.0+dfsg-1/base/version.jl
--- 1.3.1+dfsg-1/base/version.jl	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/base/version.jl	2020-03-21 16:36:32.000000000 +0000
@@ -237,7 +237,13 @@ catch e
     VersionNumber(0)
 end
 
-const libllvm_version = VersionNumber(libllvm_version_string)
+const libllvm_version = if endswith(libllvm_version_string, "jl")
+    # strip the "jl" SONAME suffix (JuliaLang/julia#33058)
+    # (LLVM does never report a prerelease version anyway)
+    VersionNumber(libllvm_version_string[1:end-2])
+else
+    VersionNumber(libllvm_version_string)
+end
 
 function banner(io::IO = stdout)
     if GIT_VERSION_INFO.tagged_commit
diff -pruN 1.3.1+dfsg-1/base/views.jl 1.4.0+dfsg-1/base/views.jl
--- 1.3.1+dfsg-1/base/views.jl	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/base/views.jl	2020-03-21 16:36:32.000000000 +0000
@@ -186,7 +186,7 @@ end
 Convert every array-slicing operation in the given expression
 (which may be a `begin`/`end` block, loop, function, etc.)
 to return a view. Scalar indices, non-array types, and
-explicit `getindex` calls (as opposed to `array[...]`) are
+explicit [`getindex`](@ref) calls (as opposed to `array[...]`) are
 unaffected.
 
 !!! note
diff -pruN 1.3.1+dfsg-1/base/weakkeydict.jl 1.4.0+dfsg-1/base/weakkeydict.jl
--- 1.3.1+dfsg-1/base/weakkeydict.jl	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/base/weakkeydict.jl	2020-03-21 16:36:32.000000000 +0000
@@ -105,7 +105,7 @@ function get!(default::Callable, wkh::We
 end
 pop!(wkh::WeakKeyDict{K}, key) where {K} = lock(() -> pop!(wkh.ht, key), wkh)
 pop!(wkh::WeakKeyDict{K}, key, default) where {K} = lock(() -> pop!(wkh.ht, key, default), wkh)
-delete!(wkh::WeakKeyDict, key) = lock(() -> delete!(wkh.ht, key), wkh)
+delete!(wkh::WeakKeyDict, key) = (lock(() -> delete!(wkh.ht, key), wkh); wkh)
 empty!(wkh::WeakKeyDict) = (lock(() -> empty!(wkh.ht), wkh); wkh)
 haskey(wkh::WeakKeyDict{K}, key) where {K} = lock(() -> haskey(wkh.ht, key), wkh)
 getindex(wkh::WeakKeyDict{K}, key) where {K} = lock(() -> getindex(wkh.ht, key), wkh)
diff -pruN 1.3.1+dfsg-1/contrib/add_license_to_files.jl 1.4.0+dfsg-1/contrib/add_license_to_files.jl
--- 1.3.1+dfsg-1/contrib/add_license_to_files.jl	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/contrib/add_license_to_files.jl	2020-03-21 16:36:32.000000000 +0000
@@ -25,6 +25,7 @@ const rootdirs = [
 const excludedirs = [
     # see: https://github.com/JuliaLang/julia/pull/11073#issuecomment-98090053
     "../base/grisu",
+    "../base/ryu",
     "../src/flisp",
 ]
 
diff -pruN 1.3.1+dfsg-1/contrib/generate_precompile.jl 1.4.0+dfsg-1/contrib/generate_precompile.jl
--- 1.3.1+dfsg-1/contrib/generate_precompile.jl	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/contrib/generate_precompile.jl	2020-03-21 16:36:32.000000000 +0000
@@ -35,6 +35,19 @@ julia_exepath() = joinpath(Sys.BINDIR, B
 
 have_repl =  haskey(Base.loaded_modules,
                     Base.PkgId(Base.UUID("3fa0cd96-eef1-5676-8a61-b3b8758bbffb"), "REPL"))
+
+Distributed = get(Base.loaded_modules,
+          Base.PkgId(Base.UUID("8ba89e20-285c-5b6f-9357-94700520ee1b"), "Distributed"),
+          nothing)
+if Distributed !== nothing
+    precompile_script *= """
+    using Distributed
+    addprocs(2)
+    pmap(x->iseven(x) ? 1 : 0, 1:4)
+    @distributed (+) for i = 1:100 Int(rand(Bool)) end
+    """
+end
+
 Pkg = get(Base.loaded_modules,
           Base.PkgId(Base.UUID("44cfe95a-1eb2-52ea-b672-e2afdf69b78f"), "Pkg"),
           nothing)
@@ -131,7 +144,7 @@ function generate_precompile_statements(
         close(pty_master)
         write(debug_output, "\n#### FINISHED ####\n")
 
-        # Extract the precompile statements from stderr
+        # Extract the precompile statements from the precompile file
         statements = Set{String}()
         for statement in eachline(precompile_file_h)
             # Main should be completely clean
diff -pruN 1.3.1+dfsg-1/contrib/mac/app/Entitlements.plist 1.4.0+dfsg-1/contrib/mac/app/Entitlements.plist
--- 1.3.1+dfsg-1/contrib/mac/app/Entitlements.plist	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/contrib/mac/app/Entitlements.plist	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1,8 @@
+<?xml version="1.0" encoding="UTF-8"?>
+<!DOCTYPE plist PUBLIC "-//Apple//DTD PLIST 1.0//EN" "http://www.apple.com/DTDs/PropertyList-1.0.dtd">
+<plist version="1.0">
+<dict>
+	<key>com.apple.security.automation.apple-events</key>
+	<true/>
+</dict>
+</plist>
diff -pruN 1.3.1+dfsg-1/contrib/mac/app/.gitignore 1.4.0+dfsg-1/contrib/mac/app/.gitignore
--- 1.3.1+dfsg-1/contrib/mac/app/.gitignore	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/contrib/mac/app/.gitignore	2020-03-21 16:36:32.000000000 +0000
@@ -1,3 +1,4 @@
 julia/
 dmg/
 *.dmg
+notarize-*.xml
diff -pruN 1.3.1+dfsg-1/contrib/mac/app/Makefile 1.4.0+dfsg-1/contrib/mac/app/Makefile
--- 1.3.1+dfsg-1/contrib/mac/app/Makefile	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/contrib/mac/app/Makefile	2020-03-21 16:36:32.000000000 +0000
@@ -17,7 +17,7 @@ APP_NAME:=Julia-$(JULIA_VERSION_MAJOR_MI
 VOL_NAME:=Julia-$(JULIA_VERSION_OPT_COMMIT)
 
 APP_ID:=org.julialang.launcherapp
-APP_COPYRIGHT:=© 2016 The Julia Project
+APP_COPYRIGHT:=© $(shell date '+%Y') The Julia Project
 
 
 all: clean $(DMG_NAME)
@@ -51,7 +51,7 @@ dmg/$(APP_NAME): startup.applescript jul
 	tar zxf $(JULIAHOME)/$(JULIA_BINARYDIST_FILENAME).tar.gz -C $@/Contents/Resources/julia --strip-components 1
 	if [ -n "$$MACOS_CODESIGN_IDENTITY" ]; then \
 	    echo "Codesigning with identity $$MACOS_CODESIGN_IDENTITY"; \
-		codesign -s "$$MACOS_CODESIGN_IDENTITY" -v --deep $@; \
+		codesign -s "$$MACOS_CODESIGN_IDENTITY" --option=runtime --entitlements Entitlements.plist -v --deep $@; \
 	else \
 		true; \
 	fi
@@ -60,9 +60,35 @@ ROOTFILES := $(shell ls -ld dmg/*.app *.
 clean:
 ifneq ($(filter root,$(ROOTFILES)),)
 	@echo "We have to use sudo here to clean out folders owned by root.  You may be asked for your password"
-	sudo rm -rf dmg *.dmg
+	sudo rm -rf dmg *.dmg notarize-*.xml
 else
 	rm -rf dmg *.dmg
 endif
 
-.PHONY: clean all
+notarize-upload-$(DMG_NAME).xml: $(DMG_NAME)
+	@# Upload the `.dmg` for notarization
+	xcrun altool --notarize-app --primary-bundle-id org.julialang.launcherapp --username "$$APPLEID" --password "$$APPLEID_PASSWORD" -itc_provider A427R7F42H --file "$(DMG_NAME)" --output-format xml > "$@"
+	@# Sleep for a few seconds so that we don't immediately error out when we request the UUID from Apple
+	@sleep 5
+
+
+notarize-check: notarize-upload-$(DMG_NAME).xml
+	@# We wait in a while loop for notarization to complete
+	./notarize_check.sh "$<"
+
+# This is the top-level notarization target.  Note that this is still a somewhat manual
+# process; things can go wrong, and so if it fails, you may need to inspect the `.xml`
+# files to see what went wrong, but in general you can just run `make notarize` and it
+# should upload, notarize, staple, and re-package the .dmg for you.
+# Note that for this to work, you need to have exported `APPLEID`, `APPLEID_PASSWORD`
+# and `MACOS_CODESIGN_IDENTITY` to have signed the `.app` in the first place.
+notarize: notarize-check
+	@# Delete old .dmg file
+	rm -f $(DMG_NAME)
+	@# Staple the .app
+	xcrun stapler staple dmg/$(APP_NAME)
+	@# re-build the .dmg
+	$(MAKE) $(DMG_NAME)
+
+
+.PHONY: clean all notarize-upload notarize-check
diff -pruN 1.3.1+dfsg-1/contrib/mac/app/notarize_check.sh 1.4.0+dfsg-1/contrib/mac/app/notarize_check.sh
--- 1.3.1+dfsg-1/contrib/mac/app/notarize_check.sh	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/contrib/mac/app/notarize_check.sh	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1,61 @@
+#!/bin/bash
+
+# Note that you need to have exported `APPLEID` and `APPLEID_PASSWORD` for this to work.
+
+# Get the UUID from a notarization-upload*.xml file
+function extract_uuid()
+{
+    PLIST_FILE="$1"
+
+    SED_PATTERN='.*([[:xdigit:]]{8}-[[:xdigit:]]{4}-[[:xdigit:]]{4}-[[:xdigit:]]{4}-[[:xdigit:]]{12}).*'
+    /usr/libexec/PlistBuddy -c "print notarization-upload:RequestUUID" "${PLIST_FILE}" 2>/dev/null
+    if [[ $? != 0 ]]; then
+        sed -n -E "s/${SED_PATTERN}/\1/p" "${PLIST_FILE}" 2>/dev/null | head -1
+    fi
+}
+
+# Continually probe and ask if Apple is done notarizing our precious binary bits
+function wait_until_completed()
+{
+    UUID="$1"
+    PLIST_FILE="$2"
+    echo "Waiting until UUID ${UUID} is done processing...."
+
+    while true; do
+        xcrun altool --notarization-info "${UUID}" --username "${APPLEID}" --password "${APPLEID_PASSWORD}" --output-format xml > "${PLIST_FILE}"
+        STATUS=$(/usr/libexec/PlistBuddy -c "print notarization-info:Status" "${PLIST_FILE}" 2>/dev/null)
+
+        # Process loop exit conditions
+        if [[ ${STATUS} == "success" ]]; then
+            echo "Notarization finished"
+            return 0
+        elif [[ ${STATUS} == "in progress" ]]; then
+            echo -n "."
+            sleep 10
+            continue
+        else
+            echo "Notarization failed with status ${STATUS}"
+            exit 1
+        fi
+    done
+}
+
+if [[ "$#" != 1 ]]; then
+    echo "Usage: $0 notarize-upload-<suffix>.xml"
+    exit 1
+fi
+
+# Get input parameters
+UPLOAD_PLIST_FILE="$1"
+SUFFIX="${UPLOAD_PLIST_FILE#"notarize-upload-"}"
+SUFFIX="${SUFFIX%".xml"}"
+
+# Extract UUID from uploaded plist file
+UUID=$(extract_uuid "${UPLOAD_PLIST_FILE}")
+if [[ -z "${UUID}" ]]; then
+    echo "ERROR: Could not extract UUID value from ${UPLOAD_PLIST_FILE}" >&2
+    exit 1
+fi
+
+# Wait until the UUID is done processing
+wait_until_completed "${UUID}" "notarize-check-${SUFFIX}.xml"
diff -pruN 1.3.1+dfsg-1/contrib/mac/frameworkapp/ExecSandbox/ExecSandboxProtocol.h 1.4.0+dfsg-1/contrib/mac/frameworkapp/ExecSandbox/ExecSandboxProtocol.h
--- 1.3.1+dfsg-1/contrib/mac/frameworkapp/ExecSandbox/ExecSandboxProtocol.h	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/contrib/mac/frameworkapp/ExecSandbox/ExecSandboxProtocol.h	2020-03-21 16:36:32.000000000 +0000
@@ -17,7 +17,7 @@
  @param executableBookmark NSURL file bookmark for the julia executable to run.
  @param args Arguments to pass to julia.
  @param reply Async result with task and standard in, out, and error. An error
- occured if task is nil.
+ occurred if task is nil.
  */
 - (void)eval:(NSString *_Nonnull)juliaProgram
     withJulia:(NSData *_Nonnull)executableBookmark
diff -pruN 1.3.1+dfsg-1/contrib/normalize_triplet.py 1.4.0+dfsg-1/contrib/normalize_triplet.py
--- 1.3.1+dfsg-1/contrib/normalize_triplet.py	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/contrib/normalize_triplet.py	2020-03-21 16:36:32.000000000 +0000
@@ -6,7 +6,7 @@ import re, sys
 # a method `platform_key_abi()` to parse uname-like output into something standarized.
 
 if len(sys.argv) < 2:
-    print("Usage: %s <host triplet> [<gcc version>] [<cxxabi11>]")
+    print("Usage: {} <host triplet> [<gcc version>] [<cxxabi11>]".format(sys.argv[0]))
     sys.exit(1)
 
 arch_mapping = {
diff -pruN 1.3.1+dfsg-1/contrib/refresh_bb_tarballs.sh 1.4.0+dfsg-1/contrib/refresh_bb_tarballs.sh
--- 1.3.1+dfsg-1/contrib/refresh_bb_tarballs.sh	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/contrib/refresh_bb_tarballs.sh	2020-03-21 16:36:32.000000000 +0000
@@ -12,8 +12,9 @@
 TRIPLETS="i686-linux-gnu x86_64-linux-gnu aarch64-linux-gnu arm-linux-gnueabihf powerpc64le-linux-gnu i686-linux-musl x86_64-linux-musl aarch64-linux-musl arm-linux-musleabihf x86_64-apple-darwin14 x86_64-unknown-freebsd11.1 i686-w64-mingw32 x86_64-w64-mingw32"
 
 # These are the projects currently using BinaryBuilder; both GCC-expanded and non-GCC-expanded:
-BB_PROJECTS="gmp mbedtls libssh2 mpfr curl libgit2 pcre libuv unwind osxunwind dsfmt objconv p7zip zlib"
-BB_GCC_EXPANDED_PROJECTS="llvm openblas suitesparse openlibm"
+BB_PROJECTS="gmp mbedtls libssh2 mpfr curl libgit2 pcre libuv unwind osxunwind dsfmt objconv p7zip zlib suitesparse"
+BB_GCC_EXPANDED_PROJECTS="openblas openlibm"
+BB_CXX_EXPANDED_PROJECTS="llvm"
 
 # If we've been given a project name, filter down to that one:
 if [ -n "${1}" ]; then
@@ -25,6 +26,10 @@ if [ -n "${1}" ]; then
         *${1}*) BB_GCC_EXPANDED_PROJECTS="${1}" ;;
         *) BB_GCC_EXPANDED_PROJECTS="" ;;
     esac
+    case "${BB_CXX_EXPANDED_PROJECTS}" in
+        *${1}*) BB_CXX_EXPANDED_PROJECTS="${1}" ;;
+        *) BB_CXX_EXPANDED_PROJECTS="" ;;
+    esac
 fi
 
 # Get "contrib/" directory path
@@ -45,4 +50,12 @@ for triplet in ${TRIPLETS}; do
 		    make -C "${CONTRIB_DIR}/../deps" USE_BINARYBUILDER_${PROJ}=1 ${PROJ}_BB_TRIPLET=${triplet}-${gcc} BB_TRIPLET_CXXABI=${triplet} install-${proj}
         done
     done
+
+    for proj in ${BB_CXX_EXPANDED_PROJECTS}; do
+		PROJ="$(echo ${proj} | tr [a-z] [A-Z])"
+        for cxx in cxx03 cxx11; do
+		    make -C "${CONTRIB_DIR}/../deps" BINARYBUILDER_LLVM_ASSERTS=1 USE_BINARYBUILDER_${PROJ}=1 ${PROJ}_BB_TRIPLET=${triplet}-${cxx} BB_TRIPLET_CXXABI=${triplet} distclean-${proj}
+		    make -C "${CONTRIB_DIR}/../deps" BINARYBUILDER_LLVM_ASSERTS=1 USE_BINARYBUILDER_${PROJ}=1 ${PROJ}_BB_TRIPLET=${triplet}-${cxx} BB_TRIPLET_CXXABI=${triplet} install-${proj}
+        done
+    done
 done
diff -pruN 1.3.1+dfsg-1/CONTRIBUTING.md 1.4.0+dfsg-1/CONTRIBUTING.md
--- 1.3.1+dfsg-1/CONTRIBUTING.md	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/CONTRIBUTING.md	2020-03-21 16:36:32.000000000 +0000
@@ -6,7 +6,7 @@ If you are already familiar with Julia i
 
 ## Learning Julia
 
-[The learning page](https://julialang.org/learning) has a great list of resources for new and experienced users alike. [This tutorial video](https://www.youtube.com/watch?v=vWkgEddb4-A) is one recommended starting point, as is the "[Invitation to Julia](https://www.youtube.com/watch?v=gQ1y5NUD_RI)" workshop video from JuliaCon 2015  ([slide materials here](https://github.com/dpsanders/invitation_to_julia)). The [Julia documentation](https://docs.julialang.org/en/latest) covers the language and core library features, and is searchable.
+[The learning page](https://julialang.org/learning) has a great list of resources for new and experienced users alike. [This tutorial video](https://www.youtube.com/watch?v=vWkgEddb4-A) is one recommended starting point, as is the "[Invitation to Julia](https://www.youtube.com/watch?v=gQ1y5NUD_RI)" workshop video from JuliaCon 2015  ([slide materials here](https://github.com/dpsanders/invitation_to_julia)). The [Julia documentation](https://docs.julialang.org) covers the language and core library features, and is searchable.
 
 ## Before filing an issue
 
@@ -43,7 +43,7 @@ A useful bug report filed as a GitHub is
   - Try some simple debugging techniques to help isolate the problem.
     - Try running the code with the debug build of Julia with `make debug`, which produces the `usr/bin/julia-debug`.
     - Consider running `julia-debug` with a debugger such as `gdb` or `lldb`. Obtaining even a simple [backtrace](http://www.unknownroad.com/rtfm/gdbtut/gdbsegfault.html) is very useful.
-    - If Julia segfaults, try following [these debugging tips](https://docs.julialang.org/en/latest/devdocs/backtraces#Reporting-and-analyzing-crashes-(segfaults)-1) to help track down the specific origin of the bug.
+    - If Julia segfaults, try following [these debugging tips](https://docs.julialang.org/en/v1/devdocs/backtraces/) to help track down the specific origin of the bug.
 
 2. If the problem is caused by a Julia package rather than core Julia, file a bug report with the relevant package author rather than here.
 
@@ -86,7 +86,7 @@ There are never enough tests. Track [cod
 
 2. Browse through the source files and find some untested functionality (highlighted in red) that you think you might be able to write a test for.
 
-3. Write a test that exercises this functionality---you can add your test to one of the existing files, or start a new one, whichever seems most appropriate to you. If you're adding a new test file, make sure you include it in the list of tests in `test/choosetests.jl`. https://docs.julialang.org/en/latest/stdlib/Test/ may be helpful in explaining how the testing infrastructure works.
+3. Write a test that exercises this functionality---you can add your test to one of the existing files, or start a new one, whichever seems most appropriate to you. If you're adding a new test file, make sure you include it in the list of tests in `test/choosetests.jl`. https://docs.julialang.org/en/v1/stdlib/Test/ may be helpful in explaining how the testing infrastructure works.
 
 4. Run `make test-all` to rebuild Julia and run your new test(s). If you had to fix a bug or add functionality in `base`, this will ensure that your test passes and that you have not introduced extraneous whitespace.
 
@@ -264,6 +264,12 @@ If you need to restart your Julia sessio
 built and incorporate them automatically. You only need to rebuild
 Julia if you made code-changes that Revise cannot handle.
 
+For convenience, there are also `test-revise-*` targets for every `test-*`
+target that use Revise to load any modifications to Base into the current
+process before running the corresponding test. This can be useful as a shortcut
+on the command line (since tests aren't always designed to be run outside the
+runtest harness).
+
 ### Code Formatting Guidelines
 
 #### General Formatting Guidelines for Julia code contributions
diff -pruN 1.3.1+dfsg-1/debian/changelog 1.4.0+dfsg-1/debian/changelog
--- 1.3.1+dfsg-1/debian/changelog	2019-12-31 08:30:40.000000000 +0000
+++ 1.4.0+dfsg-1/debian/changelog	2020-04-17 08:17:56.000000000 +0000
@@ -1,3 +1,20 @@
+julia (1.4.0+dfsg-1) unstable; urgency=medium
+
+  [ Mo Zhou ]
+  * New upstream version 1.4.0+dfsg
+
+  [ Graham Inggs ]
+  * Add build-dependency on python3-minimal
+  * Only link libquadmath on architectures where it is available
+  * Drop unused debian/source/include-binaries
+  * Drop unused Lintian overrides
+  * Add Build-Depends-Package to libjulia1.symbols
+  * Switch to debhelper 12
+  * Set Rules-Requires-Root: no
+  * Bump Standards-Version to 4.5.0, no changes
+
+ -- Graham Inggs <ginggs@debian.org>  Fri, 17 Apr 2020 08:17:56 +0000
+
 julia (1.3.1+dfsg-1) unstable; urgency=medium
 
   * New upstream version 1.3.1+dfsg
diff -pruN 1.3.1+dfsg-1/debian/compat 1.4.0+dfsg-1/debian/compat
--- 1.3.1+dfsg-1/debian/compat	2019-11-28 04:21:05.000000000 +0000
+++ 1.4.0+dfsg-1/debian/compat	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-11
diff -pruN 1.3.1+dfsg-1/debian/control 1.4.0+dfsg-1/debian/control
--- 1.3.1+dfsg-1/debian/control	2019-12-31 08:29:34.000000000 +0000
+++ 1.4.0+dfsg-1/debian/control	2020-04-16 16:04:12.000000000 +0000
@@ -2,7 +2,8 @@ Source: julia
 Section: science
 Homepage: https://julialang.org
 Priority: optional
-Standards-Version: 4.4.0
+Standards-Version: 4.5.0
+Rules-Requires-Root: no
 Vcs-Git: https://salsa.debian.org/julia-team/julia.git
 Vcs-Browser: https://salsa.debian.org/julia-team/julia
 Maintainer: Debian Julia Team <pkg-julia-devel@lists.alioth.debian.org>
@@ -10,7 +11,7 @@ Uploaders: Peter Colberg <peter@colberg.
            Graham Inggs <ginggs@debian.org>,
            Mo Zhou <lumin@debian.org>
 Build-Depends: curl,
-               debhelper (>= 11~),
+               debhelper-compat (= 12),
                dpkg-dev (>= 1.16.2~),
                libcurl4-gnutls-dev | libcurl-dev,
                libdsfmt-dev (>= 2.2.3),
@@ -25,6 +26,7 @@ Build-Depends: curl,
                llvm-8-dev,
                openssl,
                p7zip,
+               python3-minimal:native,
                unicode-data,
                gfortran,
                libblas-dev | libblas.so,
diff -pruN 1.3.1+dfsg-1/debian/copyright 1.4.0+dfsg-1/debian/copyright
--- 1.3.1+dfsg-1/debian/copyright	2019-12-31 08:30:12.000000000 +0000
+++ 1.4.0+dfsg-1/debian/copyright	2020-04-02 09:46:58.000000000 +0000
@@ -133,6 +133,7 @@ Copyright: 2012-2015 Sébastien Villemot
 License: Expat
 
 Files: debian/embedded/Pkg*
+       debian/embedded/Statistics*
 Copyright: 2017 Stefan Karpinski
            2017 SimonDanisch
            2016 Art Wild
Binary files 1.3.1+dfsg-1/debian/embedded/9419c70af69153cd5c4276bff90fbb135e0aa3f1 and 1.4.0+dfsg-1/debian/embedded/9419c70af69153cd5c4276bff90fbb135e0aa3f1 differ
Binary files 1.3.1+dfsg-1/debian/embedded/a2203d3b67f7413701be5de251622cb85c9cc69d and 1.4.0+dfsg-1/debian/embedded/a2203d3b67f7413701be5de251622cb85c9cc69d differ
diff -pruN 1.3.1+dfsg-1/debian/embedded/Documenter/.appveyor.yml 1.4.0+dfsg-1/debian/embedded/Documenter/.appveyor.yml
--- 1.3.1+dfsg-1/debian/embedded/Documenter/.appveyor.yml	2019-11-28 04:21:05.000000000 +0000
+++ 1.4.0+dfsg-1/debian/embedded/Documenter/.appveyor.yml	2020-03-30 16:16:04.000000000 +0000
@@ -1,18 +1,18 @@
 environment:
   matrix:
   - julia_version: 1.0
-  - julia_version: 1.1
-  - julia_version: latest
+  - julia_version: 1.3
+  - julia_version: nightly
 
 platform:
   - x86 # 32-bit
   - x64 # 64-bit
 
-## uncomment the following lines to allow failures on nightly julia
-## (tests will run but not make your overall status red)
-#matrix:
-#  allow_failures:
-#  - julia_version: latest
+# Uncomment the following lines to allow failures on nightly julia
+# (tests will run but not make your overall status red)
+matrix:
+  allow_failures:
+  - julia_version: nightly
 
 branches:
   only:
diff -pruN 1.3.1+dfsg-1/debian/embedded/Documenter/assets/html/arrow.svg 1.4.0+dfsg-1/debian/embedded/Documenter/assets/html/arrow.svg
--- 1.3.1+dfsg-1/debian/embedded/Documenter/assets/html/arrow.svg	2019-11-28 04:21:05.000000000 +0000
+++ 1.4.0+dfsg-1/debian/embedded/Documenter/assets/html/arrow.svg	1970-01-01 00:00:00.000000000 +0000
@@ -1,63 +0,0 @@
-<?xml version="1.0" encoding="UTF-8" standalone="no"?>
-<!-- Created with Inkscape (http://www.inkscape.org/) -->
-
-<svg
-   xmlns:dc="http://purl.org/dc/elements/1.1/"
-   xmlns:cc="http://creativecommons.org/ns#"
-   xmlns:rdf="http://www.w3.org/1999/02/22-rdf-syntax-ns#"
-   xmlns:svg="http://www.w3.org/2000/svg"
-   xmlns="http://www.w3.org/2000/svg"
-   xmlns:sodipodi="http://sodipodi.sourceforge.net/DTD/sodipodi-0.dtd"
-   xmlns:inkscape="http://www.inkscape.org/namespaces/inkscape"
-   width="16.5mm"
-   height="8.6603003mm"
-   viewBox="0 0 58.464567 30.686103"
-   id="svg2"
-   version="1.1"
-   inkscape:version="0.91 r13725"
-   sodipodi:docname="arrow.svg">
-  <defs
-     id="defs4" />
-  <sodipodi:namedview
-     id="base"
-     pagecolor="#ffffff"
-     bordercolor="#666666"
-     borderopacity="1.0"
-     inkscape:pageopacity="0.0"
-     inkscape:pageshadow="2"
-     inkscape:zoom="11.2"
-     inkscape:cx="14.209234"
-     inkscape:cy="29.780479"
-     inkscape:document-units="px"
-     inkscape:current-layer="layer1"
-     showgrid="false"
-     inkscape:window-width="1920"
-     inkscape:window-height="1053"
-     inkscape:window-x="0"
-     inkscape:window-y="27"
-     inkscape:window-maximized="1" />
-  <metadata
-     id="metadata7">
-    <rdf:RDF>
-      <cc:Work
-         rdf:about="">
-        <dc:format>image/svg+xml</dc:format>
-        <dc:type
-           rdf:resource="http://purl.org/dc/dcmitype/StillImage" />
-        <dc:title></dc:title>
-      </cc:Work>
-    </rdf:RDF>
-  </metadata>
-  <g
-     inkscape:label="Layer 1"
-     inkscape:groupmode="layer"
-     id="layer1"
-     transform="translate(0,-1021.6761)">
-    <path
-       style="fill:#000000;fill-opacity:1;fill-rule:evenodd;stroke:#000000;stroke-width:0;stroke-linecap:butt;stroke-linejoin:miter;stroke-miterlimit:4;stroke-dasharray:none;stroke-opacity:1"
-       d="m 0,1021.6761 35.433071,0 -17.716536,30.6861 z"
-       id="path4140"
-       inkscape:connector-curvature="0"
-       sodipodi:nodetypes="cccc" />
-  </g>
-</svg>
diff -pruN 1.3.1+dfsg-1/debian/embedded/Documenter/assets/html/documenter.css 1.4.0+dfsg-1/debian/embedded/Documenter/assets/html/documenter.css
--- 1.3.1+dfsg-1/debian/embedded/Documenter/assets/html/documenter.css	2019-11-28 04:21:05.000000000 +0000
+++ 1.4.0+dfsg-1/debian/embedded/Documenter/assets/html/documenter.css	1970-01-01 00:00:00.000000000 +0000
@@ -1,605 +0,0 @@
-/*
- * The default CSS style for Documenter.jl generated sites
- *
- * Heavily inspired by the Julia Sphinx theme
- *     https://github.com/JuliaLang/JuliaDoc
- * which extends the sphinx_rtd_theme
- *     https://github.com/snide/sphinx_rtd_theme
- *
- * Part of Documenter.jl
- *     https://github.com/JuliaDocs/Documenter.jl
- *
- * License: MIT
- */
-
-/* fonts */
-body, input {
-  font-family: 'Lato', 'Helvetica Neue', Arial, sans-serif;
-  font-size: 16px;
-  color: #222;
-  text-rendering: optimizeLegibility;
-}
-
-pre, code, kbd {
-  font-family: Inconsolata, Monaco, courier, monospace;
-  font-size: 0.90em;
-}
-
-pre code {
-  font-size: 1em;
-}
-
-a {
-    color: #2980b9;
-    text-decoration: none;
-}
-
-a:hover {
-    color: #3091d1;
-}
-
-a:visited {
-    color: #9b59b6;
-}
-
-body {
-    line-height: 1.5;
-}
-
-h1 {
-    font-size: 1.75em;
-}
-
-/* Unless the <h1> the is very first thing on the page (i.e. the second element
- * in the <article>, * after the <header>, we add some additional styling to it
- * to make it stand out a bit more. This way we get a reasonable fallback if CSS3
- * selectors are not supported in the browser.
- */
-article > h1:not(:nth-child(2)) {
-    margin: 2.5em 0 0;
-    padding-bottom: 0.30em;
-    border-bottom: 1px solid #e5e5e5;
-}
-h2 {
-    font-size: 1.50em;
-    margin: 2.3em 0 0;
-    padding-bottom: 0.25em;
-    border-bottom: 1px solid #e5e5e5;
-}
-h3 {
-    font-size: 1.25em;
-    margin: 2.0em 0 0;
-}
-h4 { font-size: 1.15em; }
-h5 { font-size: 1.10em; }
-h6 { font-size: 1em; }
-
-h4, h5, h6 {
-    margin-top: 1.5em;
-    margin-bottom: 1em;
-}
-
-img {
-    max-width: 100%;
-}
-
-video {
-    max-width: 100%;
-}
-
-table {
-    border-collapse: collapse;
-    margin: 1em 0;
-}
-
-th, td {
-    border: 1px solid #e1e4e5;
-    padding: 0.5em 1em;
-}
-
-th {
-    border-bottom-width: 2px;
-}
-
-tr:nth-child(even) {
-    background-color: #f3f6f6;
-}
-
-hr {
-    border: 0;
-    border-top: 1px solid #e5e5e5;
-}
-
-/* Inline code and code blocks */
-
-code {
-    padding: 0.1em;
-    background-color: rgba(0,0,0,.04);
-    border-radius: 3px;
-}
-
-pre {
-    background-color: #f5f5f5;
-    border: 1px solid #dddddd;
-    border-radius: 3px;
-    padding: 0.5em;
-    overflow: auto;
-}
-
-pre code {
-    padding: 0;
-    background-color: initial;
-}
-
-kbd {
-    font-size: 0.70em;
-    display: inline-block;
-    padding: 0.1em 0.5em 0.4em 0.5em;
-    line-height: 1.0em;
-    color: #444d56;
-    vertical-align: middle;
-    background-color: #fafbfc;
-    border: solid 1px #c6cbd1;
-    border-bottom-color: #959da5;
-    border-radius: 3px;
-    box-shadow: inset 0 -1px 0 #959da5;
-}
-
-/* Headers in admonitions and docstrings */
-.admonition h1,
-article section.docstring h1 {
-    font-size: 1.25em;
-}
-
-.admonition h2,
-article section.docstring h2 {
-    font-size: 1.10em;
-}
-
-.admonition h3,
-.admonition h4,
-.admonition h5,
-.admonition h6,
-article section.docstring h3,
-article section.docstring h4,
-article section.docstring h5,
-article section.docstring h6 {
-    font-size: 1em;
-}
-
-/* Navigation */
-nav.toc {
-    position: fixed;
-    top: 0;
-    left: 0;
-    bottom: 0;
-    width: 20em;
-    display: flex;
-    flex-flow: column nowrap;
-    overflow-y: auto;
-    padding: 1em 0 0 0;
-    background-color: #fcfcfc;
-    box-shadow: inset -14px 0px 5px -12px rgb(210,210,210);
-}
-
-nav.toc .logo {
-    margin: 0 auto;
-    display: block;
-    max-height: 6em;
-    max-width: 18em;
-}
-
-nav.toc h1 {
-    text-align: center;
-    margin-top: .57em;
-    margin-bottom: 0;
-}
-
-nav.toc select {
-    display: block;
-    height: 2em;
-    flex-shrink: 0;
-    padding: 0 1.6em 0 1em;
-    min-width: 7em;
-    max-width: 90%;
-    max-width: calc(100% - 5em);
-    margin: 0 auto;
-    font-size: .83em;
-    border: 1px solid #c9c9c9;
-    border-radius: 1em;
-
-    /* TODO: doesn't seem to be centered on Safari */
-    text-align: center;
-    text-align-last: center;
-
-    appearance: none;
-    -moz-appearance: none;
-    -webkit-appearance: none;
-
-    background: white url("arrow.svg");
-    background-size: 1.155em;
-    background-repeat: no-repeat;
-    background-position: right;
-}
-
-nav.toc select:hover {
-    border: 1px solid #a0a0a0;
-}
-
-nav.toc select option {
-    text-align: center;
-}
-
-nav.toc input {
-    display: block;
-    height: 2em;
-    width: 90%;
-    width: calc(100% - 5em);
-    margin: 1.2em auto;
-    padding: 0 1em;
-    border: 1px solid #c9c9c9;
-    border-radius: 1em;
-    font-size: .83em;
-}
-
-nav.toc > ul * {
-    margin: 0;
-}
-
-nav.toc > ul {
-    min-height: 2em;
-    overflow-y: auto;
-    margin: 0;
-}
-
-nav.toc > ul > li:last-child {
-    padding-bottom: 1em;
-}
-
-nav.toc ul {
-    color: #404040;
-    padding: 0;
-    list-style: none;
-}
-
-nav.toc ul .toctext {
-    color: inherit;
-    display: block;
-}
-
-nav.toc ul a:hover {
-    color: #fcfcfc;
-    background-color: #4e4a4a;
-}
-
-nav.toc ul.internal a {
-    color: inherit;
-    display: block;
-}
-
-nav.toc ul.internal a:hover {
-    background-color: #d6d6d6;
-}
-
-nav.toc ul.internal {
-    background-color: #e3e3e3;
-    box-shadow: inset -14px 0px 5px -12px rgb(210,210,210);
-    list-style: none;
-}
-
-nav.toc ul.internal li.toplevel {
-    border-top: 1px solid #909090;
-    font-weight: bold;
-}
-
-nav.toc ul.internal li.toplevel:first-child {
-    border-top: none;
-}
-
-nav.toc .toctext {
-    padding-top: 0.3em;
-    padding-bottom: 0.3em;
-    padding-right: 1em;
-}
-
-nav.toc ul .toctext {
-    padding-left: 1em;
-}
-
-nav.toc ul ul .toctext {
-    padding-left: 2em;
-}
-
-nav.toc ul ul ul .toctext {
-    padding-left: 3em;
-}
-
-nav.toc li.current > .toctext {
-    border-top: 1px solid #c9c9c9;
-    border-bottom: 1px solid #c9c9c9;
-    color: #404040;
-    font-weight: bold;
-    background-color: white;
-}
-
-nav.toc ul::-webkit-scrollbar {
-    width: .4em;
-    background: none;
-}
-
-nav.toc ul::-webkit-scrollbar-thumb {
-    border-radius: 5px;
-    background: #c9c9c9;
-}
-
-nav.toc ul::-webkit-scrollbar-thumb:hover {
-    border-radius: 5px;
-    background: #aaaaaa;
-}
-
-article {
-    margin-left: 20em;
-    min-width: 20em;
-    max-width: 48em;
-    padding: 2em;
-}
-
-article > header {}
-
-article > header div#topbar {
-    display: none;
-}
-
-article > header nav ul {
-    display: inline-block;
-    list-style: none;
-    margin: 0;
-    padding: 0;
-}
-
-article > header nav li {
-    display: inline-block;
-    padding-right: 0.2em;
-}
-
-article > header nav li:before {
-    content: "»";
-    padding-right: 0.2em;
-}
-
-article > header .edit-page {
-    float: right;
-}
-
-article > footer {}
-
-article > footer a.prev {
-    float: left;
-}
-article > footer a.next {
-    float: right;
-}
-
-article > footer a .direction:after {
-    content: ": ";
-}
-
-article hr {
-    margin: 1em 0;
-}
-
-article section.docstring {
-    border: 1px solid #ddd;
-    margin: 0.5em 0;
-    padding: 0.5em;
-    border-radius: 3px;
-}
-
-article section.docstring .docstring-header {
-    margin-bottom: 1em;
-}
-
-article section.docstring .docstring-binding {
-    color: #333;
-    font-weight: bold;
-}
-
-article section.docstring .docstring-category {
-    font-style: italic;
-}
-
-article section.docstring a.source-link {
-    display: block;
-    font-weight: bold;
-}
-
-.nav-anchor,
-.nav-anchor:hover,
-.nav-anchor:visited {
-    color: #333;
-}
-
-/*
- * Admonitions
- *
- * Colors (title, body)
- * warning: #f0b37e #ffedcc (orange)
- * note:    #6ab0de #e7f2fa (blue)
- * tip:     #1abc9c #dbfaf4 (green)
-*/
-.admonition {
-    border-radius: 3px;
-    background-color: #eeeeee;
-    margin: 1em 0;
-}
-
-.admonition-title {
-    border-radius: 3px 3px 0 0;
-    background-color: #9b9b9b;
-    padding: 0.15em 0.5em;
-}
-
-.admonition-text {
-    padding: 0.5em;
-}
-
-.admonition-text > :first-child {
-    margin-top: 0;
-}
-
-.admonition-text > :last-child {
-    margin-bottom: 0;
-}
-
-.admonition > .admonition-title:before {
-    font-family: "FontAwesome";
-    margin-right: 5px;
-    content: "\f06a";
-}
-
-.admonition.warning > .admonition-title {
-    background-color: #f0b37e;
-}
-
-.admonition.warning {
-    background-color: #ffedcc;
-}
-
-.admonition.note > .admonition-title {
-    background-color: #6ab0de;
-}
-
-.admonition.note {
-    background-color: #e7f2fa;
-}
-
-.admonition.tip > .admonition-title {
-    background-color: #1abc9c;
-}
-
-.admonition.tip {
-    background-color: #dbfaf4;
-}
-
-
-/* footnotes */
-.footnote {
-    padding-left: 0.8em;
-    border-left: 2px solid #ccc;
-}
-
-/* Search page */
-#search-results .category {
-    font-size: smaller;
-}
-
-/* Overriding the <code> block style of highligh.js.
- * We have to override the padding and the background-color, since we style this
- * part ourselves. Specifically, we style the <pre> surrounding the <code>, while
- * highlight.js applies the .hljs style directly to the <code> tag.
- */
-.hljs {
-    background-color: transparent;
-    padding: 0;
-}
-
-@media only screen and (max-width: 768px) {
-    nav.toc {
-        position: fixed;
-        width: 16em;
-        left: -16em;
-        -webkit-overflow-scrolling: touch;
-        -webkit-transition-property: left; /* Safari */
-        -webkit-transition-duration: 0.3s; /* Safari */
-        transition-property: left;
-        transition-duration: 0.3s;
-        -webkit-transition-timing-function: ease-out; /* Safari */
-        transition-timing-function: ease-out;
-        z-index: 2;
-        box-shadow: 5px 0px 5px 0px rgb(210,210,210);
-    }
-
-    nav.toc.show {
-        left: 0;
-    }
-
-    article {
-        margin-left: 0;
-        padding: 3em 0.9em 0 0.9em; /* top right bottom left */
-        overflow-wrap: break-word;
-    }
-
-    article > header {
-        position: fixed;
-        left: 0;
-        z-index: 1;
-    }
-
-    article > header nav, hr {
-        display: none;
-    }
-
-    article > header div#topbar {
-        display: block; /* is mobile */
-        position: fixed;
-        width: 100%;
-        height: 1.5em;
-        padding-top: 1em;
-        padding-bottom: 1em;
-        background-color: #fcfcfc;
-        box-shadow: 0 1px 3px rgba(0,0,0,.26);
-        top: 0;
-        -webkit-transition-property: top; /* Safari */
-        -webkit-transition-duration: 0.3s; /* Safari */
-        transition-property: top;
-        transition-duration: 0.3s;
-    }
-
-    article > header div#topbar.headroom--unpinned.headroom--not-top.headroom--not-bottom {
-        top: -4em;
-        -webkit-transition-property: top; /* Safari */
-        -webkit-transition-duration: 0.7s; /* Safari */
-        transition-property: top;
-        transition-duration: 0.7s;
-    }
-
-    article > header div#topbar span {
-        width: 80%;
-        height: 1.5em;
-        margin-top: -0.1em;
-        margin-left: 0.9em;
-        font-size: 1.2em;
-        overflow: hidden;
-    }
-
-    article > header div#topbar a.fa-bars {
-        float: right;
-        padding: 0.6em;
-        margin-top: -0.6em;
-        margin-right: 0.3em;
-        font-size: 1.5em;
-    }
-
-    article > header div#topbar a.fa-bars:visited {
-        color: #3091d1;
-    }
-
-    article table {
-        overflow-x: auto;
-        display: block;
-    }
-
-    article div.MathJax_Display {
-        overflow: scroll;
-    }
-
-    article span.MathJax {
-        overflow: hidden;
-    }
-}
-
-@media only screen and (max-width: 320px) {
-    body {
-        font-size: 15px;
-    }
-}
diff -pruN 1.3.1+dfsg-1/debian/embedded/Documenter/assets/html/documenter.js 1.4.0+dfsg-1/debian/embedded/Documenter/assets/html/documenter.js
--- 1.3.1+dfsg-1/debian/embedded/Documenter/assets/html/documenter.js	2019-11-28 04:21:05.000000000 +0000
+++ 1.4.0+dfsg-1/debian/embedded/Documenter/assets/html/documenter.js	1970-01-01 00:00:00.000000000 +0000
@@ -1,133 +0,0 @@
-/*
- * Part of Documenter.jl
- *     https://github.com/JuliaDocs/Documenter.jl
- *
- * License: MIT
- */
-
-requirejs.config({
-    paths: {
-        'jquery': 'file:///usr/share/javascript/jquery/jquery.min.js',
-        'jqueryui': 'file:///usr/share/javascript/jquery-ui/jquery-ui.min.js',
-		//'headroom': 'https://cdnjs.cloudflare.com/ajax/libs/headroom/0.9.3/headroom.min',
-		'headroom': 'http://localhost',
-        'mathjax': 'file:///usr/share/javascript/mathjax/MathJax.js?config=TeX-AMS_HTML',
-        'highlight': 'file:///usr/lib/nodejs/highlight.js/highlight.js',
-        'highlight-julia': 'file:////usr/lib/nodejs/highlight.js/languages/julia.js',
-        'highlight-julia-repl': 'file:////usr/lib/nodejs/highlight.js/languages/julia-repl.js',
-    },
-    shim: {
-        'mathjax' : {
-            exports: "MathJax"
-        },
-        'highlight-julia': ['highlight'],
-        'highlight-julia-repl': ['highlight'],
-    }
-});
-
-// Load MathJax
-require(['mathjax'], function(MathJax) {
-    MathJax.Hub.Config({
-      "tex2jax": {
-        inlineMath: [['$','$'], ['\\(','\\)']],
-        processEscapes: true
-      }
-    });
-    MathJax.Hub.Config({
-      config: ["MMLorHTML.js"],
-      jax: [
-        "input/TeX",
-        "output/HTML-CSS",
-        "output/NativeMML"
-      ],
-      extensions: [
-        "MathMenu.js",
-        "MathZoom.js",
-        "TeX/AMSmath.js",
-        "TeX/AMSsymbols.js",
-        "TeX/autobold.js",
-        "TeX/autoload-all.js"
-      ]
-    });
-    MathJax.Hub.Config({
-      TeX: { equationNumbers: { autoNumber: "AMS" } }
-    });
-})
-
-require(['jquery', 'highlight', 'highlight-julia', 'highlight-julia-repl'], function($, hljs) {
-    $(document).ready(function() {
-        hljs.initHighlighting();
-    })
-
-})
-
-// update the version selector with info from the siteinfo.js and ../versions.js files
-require(['jquery'], function($) {
-    $(document).ready(function() {
-        var version_selector = $("#version-selector");
-
-        // add the current version to the selector based on siteinfo.js, but only if the selector is empty
-        if (typeof DOCUMENTER_CURRENT_VERSION !== 'undefined' && $('#version-selector > option').length == 0) {
-            var option = $("<option value='#' selected='selected'>" + DOCUMENTER_CURRENT_VERSION + "</option>");
-            version_selector.append(option);
-        }
-
-        if (typeof DOC_VERSIONS !== 'undefined') {
-            var existing_versions = $('#version-selector > option');
-            var existing_versions_texts = existing_versions.map(function(i,x){return x.text});
-            DOC_VERSIONS.forEach(function(each) {
-                var version_url = documenterBaseURL + "/../" + each;
-                var existing_id = $.inArray(each, existing_versions_texts);
-                // if not already in the version selector, add it as a new option,
-                // otherwise update the old option with the URL and enable it
-                if (existing_id == -1) {
-                    var option = $("<option value='" + version_url + "'>" + each + "</option>");
-                    version_selector.append(option);
-                } else {
-                    var option = existing_versions[existing_id];
-                    option.value = version_url;
-                    option.disabled = false;
-                }
-            });
-        }
-
-        // only show the version selector if the selector has been populated
-        if ($('#version-selector > option').length > 0) {
-            version_selector.css("visibility", "visible");
-        }
-
-        // Scroll the navigation bar to the currently selected menu item
-        $("nav.toc > ul").get(0).scrollTop = $(".current").get(0).offsetTop - $("nav.toc > ul").get(0).offsetTop;
-    })
-
-})
-
-// mobile
-require(['jquery', 'headroom'], function($, Headroom) {
-    $(document).ready(function() {
-        var navtoc = $("nav.toc");
-        $("nav.toc li.current a.toctext").click(function() {
-            navtoc.toggleClass('show');
-        });
-        $("article > header div#topbar a.fa-bars").click(function(ev) {
-            ev.preventDefault();
-            navtoc.toggleClass('show');
-            if (navtoc.hasClass('show')) {
-                var title = $("article > header div#topbar span").text();
-                $("nav.toc ul li a:contains('" + title + "')").focus();
-            }
-        });
-        $("article#docs").bind('click', function(ev) {
-            if ($(ev.target).is('div#topbar a.fa-bars')) {
-                return;
-            }
-            if (navtoc.hasClass('show')) {
-                navtoc.removeClass('show');
-            }
-        });
-        if ($("article > header div#topbar").css('display') == 'block') {
-            var headroom = new Headroom(document.querySelector("article > header div#topbar"), {"tolerance": {"up": 10, "down": 10}});
-            headroom.init();
-        }
-    })
-})
diff -pruN 1.3.1+dfsg-1/debian/embedded/Documenter/assets/html/js/headroom.js 1.4.0+dfsg-1/debian/embedded/Documenter/assets/html/js/headroom.js
--- 1.3.1+dfsg-1/debian/embedded/Documenter/assets/html/js/headroom.js	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/debian/embedded/Documenter/assets/html/js/headroom.js	2020-03-30 16:16:04.000000000 +0000
@@ -0,0 +1,11 @@
+// libraries: jquery, headroom, headroom-jquery
+// arguments: $, Headroom
+
+// Manages the top navigation bar (hides it when the user starts scrolling down on the
+// mobile).
+window.Headroom = Headroom; // work around buggy module loading?
+$(document).ready(function() {
+  $('#documenter .docs-navbar').headroom({
+    "tolerance": {"up": 10, "down": 10},
+  });
+})
diff -pruN 1.3.1+dfsg-1/debian/embedded/Documenter/assets/html/js/settings.js 1.4.0+dfsg-1/debian/embedded/Documenter/assets/html/js/settings.js
--- 1.3.1+dfsg-1/debian/embedded/Documenter/assets/html/js/settings.js	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/debian/embedded/Documenter/assets/html/js/settings.js	2020-03-30 16:16:04.000000000 +0000
@@ -0,0 +1,18 @@
+// libraries: jquery
+// arguments: $
+
+// Modal settings dialog
+$(document).ready(function() {
+  var settings = $('#documenter-settings');
+  $('#documenter-settings-button').click(function(){
+    settings.toggleClass('is-active');
+  });
+  // Close the dialog if X is clicked
+  $('#documenter-settings button.delete').click(function(){
+    settings.removeClass('is-active');
+  });
+  // Close dialog if ESC is pressed
+  $(document).keyup(function(e) {
+    if (e.keyCode == 27) settings.removeClass('is-active');
+  });
+});
diff -pruN 1.3.1+dfsg-1/debian/embedded/Documenter/assets/html/js/sidebar.js 1.4.0+dfsg-1/debian/embedded/Documenter/assets/html/js/sidebar.js
--- 1.3.1+dfsg-1/debian/embedded/Documenter/assets/html/js/sidebar.js	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/debian/embedded/Documenter/assets/html/js/sidebar.js	2020-03-30 16:16:04.000000000 +0000
@@ -0,0 +1,52 @@
+// libraries: jquery
+// arguments: $
+
+// Manages the showing and hiding of the sidebar.
+$(document).ready(function() {
+  var sidebar = $("#documenter > .docs-sidebar");
+  var sidebar_button = $("#documenter-sidebar-button")
+  sidebar_button.click(function(ev) {
+    ev.preventDefault();
+    sidebar.toggleClass('visible');
+    if (sidebar.hasClass('visible')) {
+      // Makes sure that the current menu item is visible in the sidebar.
+      $("#documenter .docs-menu a.is-active").focus();
+    }
+  });
+  $("#documenter > .docs-main").bind('click', function(ev) {
+    if ($(ev.target).is(sidebar_button)) {
+      return;
+    }
+    if (sidebar.hasClass('visible')) {
+      sidebar.removeClass('visible');
+    }
+  });
+})
+
+// Resizes the package name / sitename in the sidebar if it is too wide.
+// Inspired by: https://github.com/davatron5000/FitText.js
+$(document).ready(function() {
+  e = $("#documenter .docs-autofit");
+  function resize() {
+    var L = parseInt(e.css('max-width'), 10);
+    var L0 = e.width();
+    if(L0 > L) {
+      var h0 = parseInt(e.css('font-size'), 10);
+      e.css('font-size', L * h0 / L0);
+      // TODO: make sure it survives resizes?
+    }
+  }
+  // call once and then register events
+  resize();
+  $(window).resize(resize);
+  $(window).on('orientationchange', resize);
+});
+
+// Scroll the navigation bar to the currently selected menu item
+$(document).ready(function() {
+  var sidebar = $("#documenter .docs-menu").get(0);
+  var active = $("#documenter .docs-menu .is-active").get(0);
+  if(typeof active !== 'undefined') {
+    sidebar.scrollTop = active.offsetTop - sidebar.offsetTop - 15;
+  }
+})
diff -pruN 1.3.1+dfsg-1/debian/embedded/Documenter/assets/html/js/themes.js 1.4.0+dfsg-1/debian/embedded/Documenter/assets/html/js/themes.js
--- 1.3.1+dfsg-1/debian/embedded/Documenter/assets/html/js/themes.js	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/debian/embedded/Documenter/assets/html/js/themes.js	2020-03-30 16:16:04.000000000 +0000
@@ -0,0 +1,53 @@
+// libraries: jquery
+// arguments: $
+
+function set_theme(theme) {
+  var active = null;
+  var disabled = [];
+  for (var i = 0; i < document.styleSheets.length; i++) {
+    var ss = document.styleSheets[i];
+    var themename = ss.ownerNode.getAttribute("data-theme-name");
+    if(themename === null) continue; // ignore non-theme stylesheets
+    // Find the active theme
+    if(themename === theme) active = ss;
+    else disabled.push(ss);
+  }
+  if(active !== null) {
+    active.disabled = false;
+    if(active.ownerNode.getAttribute("data-theme-primary") === null) {
+      document.getElementsByTagName('html')[0].className = "theme--" + theme;
+    } else {
+      document.getElementsByTagName('html')[0].className = "";
+    }
+    disabled.forEach(function(ss){
+      ss.disabled = true;
+    });
+  }
+
+  // Store the theme in localStorage
+  if(typeof(window.localStorage) !== "undefined") {
+    window.localStorage.setItem("documenter-theme", theme);
+  } else {
+    console.error("Browser does not support window.localStorage");
+  }
+}
+
+// Theme picker setup
+$(document).ready(function() {
+  // onchange callback
+  $('#documenter-themepicker').change(function themepick_callback(ev){
+    var themename = $('#documenter-themepicker option:selected').attr('value');
+    set_theme(themename);
+  });
+
+  // Make sure that the themepicker displays the correct theme when the theme is retrieved
+  // from localStorage
+  if(typeof(window.localStorage) !== "undefined") {
+    var theme =  window.localStorage.getItem("documenter-theme");
+    if(theme !== null) {
+      $('#documenter-themepicker option').each(function(i,e) {
+        e.selected = (e.value === theme);
+      })
+    }
+  }
+})
diff -pruN 1.3.1+dfsg-1/debian/embedded/Documenter/assets/html/js/versions.js 1.4.0+dfsg-1/debian/embedded/Documenter/assets/html/js/versions.js
--- 1.3.1+dfsg-1/debian/embedded/Documenter/assets/html/js/versions.js	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/debian/embedded/Documenter/assets/html/js/versions.js	2020-03-30 16:16:04.000000000 +0000
@@ -0,0 +1,43 @@
+// libraries: jquery
+// arguments: $
+
+// update the version selector with info from the siteinfo.js and ../versions.js files
+$(document).ready(function() {
+  var version_selector = $("#documenter .docs-version-selector");
+  var version_selector_select = $("#documenter .docs-version-selector select");
+
+  version_selector_select.change(function(x) {
+    target_href = version_selector_select.children("option:selected").get(0).value;
+    window.location.href = target_href;
+  });
+
+  // add the current version to the selector based on siteinfo.js, but only if the selector is empty
+  if (typeof DOCUMENTER_CURRENT_VERSION !== 'undefined' && $('#version-selector > option').length == 0) {
+    var option = $("<option value='#' selected='selected'>" + DOCUMENTER_CURRENT_VERSION + "</option>");
+    version_selector_select.append(option);
+  }
+
+  if (typeof DOC_VERSIONS !== 'undefined') {
+    var existing_versions = version_selector_select.children("option");
+    var existing_versions_texts = existing_versions.map(function(i,x){return x.text});
+    DOC_VERSIONS.forEach(function(each) {
+      var version_url = documenterBaseURL + "/../" + each;
+      var existing_id = $.inArray(each, existing_versions_texts);
+      // if not already in the version selector, add it as a new option,
+      // otherwise update the old option with the URL and enable it
+      if (existing_id == -1) {
+        var option = $("<option value='" + version_url + "'>" + each + "</option>");
+        version_selector_select.append(option);
+      } else {
+        var option = existing_versions[existing_id];
+        option.value = version_url;
+        option.disabled = false;
+      }
+    });
+  }
+
+  // only show the version selector if the selector has been populated
+  if (version_selector_select.children("option").length > 0) {
+    version_selector.toggleClass("visible");
+  }
+})
diff -pruN 1.3.1+dfsg-1/debian/embedded/Documenter/assets/html/README.md 1.4.0+dfsg-1/debian/embedded/Documenter/assets/html/README.md
--- 1.3.1+dfsg-1/debian/embedded/Documenter/assets/html/README.md	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/debian/embedded/Documenter/assets/html/README.md	2020-03-30 16:16:04.000000000 +0000
@@ -0,0 +1,11 @@
+# Non-Julia Assets for `HTMLWriter`
+
+Themes / CSS:
+
+* `scss/`: contains the SCSS and Sass files
+  * `scss/bulma/`: Sass sources of the [Bulma CSS framework](https://bulma.io/), v0.7.5
+    (MIT license, [GitHub](https://github.com/jgthms/bulma))
+  * `darkly/`: [Darkly Bulmaswatch theme](https://jenil.github.io/bulmaswatch/darkly/) (MIT license, [GitHub](https://github.com/jenil/bulmaswatch/))
+  * `documenter/`: Documenter-specific overrides, components etc.
+  * `documenter.scss` and `darkly.scss`: Documenter default themes
+* `themes/`: contains the compiled `.css` files of the default themes
diff -pruN 1.3.1+dfsg-1/debian/embedded/Documenter/assets/html/scss/bulma/base/_all.sass 1.4.0+dfsg-1/debian/embedded/Documenter/assets/html/scss/bulma/base/_all.sass
--- 1.3.1+dfsg-1/debian/embedded/Documenter/assets/html/scss/bulma/base/_all.sass	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/debian/embedded/Documenter/assets/html/scss/bulma/base/_all.sass	2020-03-30 16:16:04.000000000 +0000
@@ -0,0 +1,5 @@
+@charset "utf-8"
+
+@import "minireset.sass"
+@import "generic.sass"
+@import "helpers.sass"
diff -pruN 1.3.1+dfsg-1/debian/embedded/Documenter/assets/html/scss/bulma/base/generic.sass 1.4.0+dfsg-1/debian/embedded/Documenter/assets/html/scss/bulma/base/generic.sass
--- 1.3.1+dfsg-1/debian/embedded/Documenter/assets/html/scss/bulma/base/generic.sass	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/debian/embedded/Documenter/assets/html/scss/bulma/base/generic.sass	2020-03-30 16:16:04.000000000 +0000
@@ -0,0 +1,142 @@
+$body-background-color: $white !default
+$body-size: 16px !default
+$body-min-width: 300px !default
+$body-rendering: optimizeLegibility !default
+$body-family: $family-primary !default
+$body-overflow-x: hidden !default
+$body-overflow-y: scroll !default
+
+$body-color: $text !default
+$body-font-size: 1em !default
+$body-weight: $weight-normal !default
+$body-line-height: 1.5 !default
+
+$code-family: $family-code !default
+$code-padding: 0.25em 0.5em 0.25em !default
+$code-weight: normal !default
+$code-size: 0.875em !default
+
+$small-font-size: 0.875em !default
+
+$hr-background-color: $background !default
+$hr-height: 2px !default
+$hr-margin: 1.5rem 0 !default
+
+$strong-color: $text-strong !default
+$strong-weight: $weight-bold !default
+
+$pre-font-size: 0.875em !default
+$pre-padding: 1.25rem 1.5rem !default
+$pre-code-font-size: 1em !default
+
+html
+  background-color: $body-background-color
+  font-size: $body-size
+  -moz-osx-font-smoothing: grayscale
+  -webkit-font-smoothing: antialiased
+  min-width: $body-min-width
+  overflow-x: $body-overflow-x
+  overflow-y: $body-overflow-y
+  text-rendering: $body-rendering
+  text-size-adjust: 100%
+
+article,
+aside,
+figure,
+footer,
+header,
+hgroup,
+section
+  display: block
+
+body,
+button,
+input,
+select,
+textarea
+  font-family: $body-family
+
+code,
+pre
+  -moz-osx-font-smoothing: auto
+  -webkit-font-smoothing: auto
+  font-family: $code-family
+
+body
+  color: $body-color
+  font-size: $body-font-size
+  font-weight: $body-weight
+  line-height: $body-line-height
+
+// Inline
+
+a
+  color: $link
+  cursor: pointer
+  text-decoration: none
+  strong
+    color: currentColor
+  &:hover
+    color: $link-hover
+
+code
+  background-color: $code-background
+  color: $code
+  font-size: $code-size
+  font-weight: $code-weight
+  padding: $code-padding
+
+hr
+  background-color: $hr-background-color
+  border: none
+  display: block
+  height: $hr-height
+  margin: $hr-margin
+
+img
+  height: auto
+  max-width: 100%
+
+input[type="checkbox"],
+input[type="radio"]
+  vertical-align: baseline
+
+small
+  font-size: $small-font-size
+
+span
+  font-style: inherit
+  font-weight: inherit
+
+strong
+  color: $strong-color
+  font-weight: $strong-weight
+
+// Block
+
+fieldset
+  border: none
+
+pre
+  +overflow-touch
+  background-color: $pre-background
+  color: $pre
+  font-size: $pre-font-size
+  overflow-x: auto
+  padding: $pre-padding
+  white-space: pre
+  word-wrap: normal
+  code
+    background-color: transparent
+    color: currentColor
+    font-size: $pre-code-font-size
+    padding: 0
+
+table
+  td,
+  th
+    vertical-align: top
+    &:not([align])
+      text-align: left
+  th
+    color: $text-strong
diff -pruN 1.3.1+dfsg-1/debian/embedded/Documenter/assets/html/scss/bulma/base/helpers.sass 1.4.0+dfsg-1/debian/embedded/Documenter/assets/html/scss/bulma/base/helpers.sass
--- 1.3.1+dfsg-1/debian/embedded/Documenter/assets/html/scss/bulma/base/helpers.sass	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/debian/embedded/Documenter/assets/html/scss/bulma/base/helpers.sass	2020-03-30 16:16:04.000000000 +0000
@@ -0,0 +1,281 @@
+// Float
+
+.is-clearfix
+  +clearfix
+
+.is-pulled-left
+  float: left !important
+
+.is-pulled-right
+  float: right !important
+
+// Overflow
+
+.is-clipped
+  overflow: hidden !important
+
+// Overlay
+
+.is-overlay
+  @extend %overlay
+
+// Typography
+
+=typography-size($target:'')
+  @each $size in $sizes
+    $i: index($sizes, $size)
+    .is-size-#{$i}#{if($target == '', '', '-' + $target)}
+      font-size: $size !important
+
++typography-size()
+
++mobile
+  +typography-size('mobile')
+
++tablet
+  +typography-size('tablet')
+
++touch
+  +typography-size('touch')
+
++desktop
+  +typography-size('desktop')
+
++widescreen
+  +typography-size('widescreen')
+
++fullhd
+  +typography-size('fullhd')
+
+$alignments: ('centered': 'center', 'justified': 'justify', 'left': 'left', 'right': 'right')
+
+@each $alignment, $text-align in $alignments
+  .has-text-#{$alignment}
+    text-align: #{$text-align} !important
+
+@each $alignment, $text-align in $alignments
+  +mobile
+    .has-text-#{$alignment}-mobile
+      text-align: #{$text-align} !important
+  +tablet
+    .has-text-#{$alignment}-tablet
+      text-align: #{$text-align} !important
+  +tablet-only
+    .has-text-#{$alignment}-tablet-only
+      text-align: #{$text-align} !important
+  +touch
+    .has-text-#{$alignment}-touch
+      text-align: #{$text-align} !important
+  +desktop
+    .has-text-#{$alignment}-desktop
+      text-align: #{$text-align} !important
+  +desktop-only
+    .has-text-#{$alignment}-desktop-only
+      text-align: #{$text-align} !important
+  +widescreen
+    .has-text-#{$alignment}-widescreen
+      text-align: #{$text-align} !important
+  +widescreen-only
+    .has-text-#{$alignment}-widescreen-only
+      text-align: #{$text-align} !important
+  +fullhd
+    .has-text-#{$alignment}-fullhd
+      text-align: #{$text-align} !important
+
+.is-capitalized
+  text-transform: capitalize !important
+
+.is-lowercase
+  text-transform: lowercase !important
+
+.is-uppercase
+  text-transform: uppercase !important
+
+.is-italic
+  font-style: italic !important
+
+@each $name, $pair in $colors
+  $color: nth($pair, 1)
+  .has-text-#{$name}
+    color: $color !important
+  a.has-text-#{$name}
+    &:hover,
+    &:focus
+      color: darken($color, 10%) !important
+  .has-background-#{$name}
+    background-color: $color !important
+
+@each $name, $shade in $shades
+  .has-text-#{$name}
+    color: $shade !important
+  .has-background-#{$name}
+    background-color: $shade !important
+
+.has-text-weight-light
+  font-weight: $weight-light !important
+.has-text-weight-normal
+  font-weight: $weight-normal !important
+.has-text-weight-medium
+  font-weight: $weight-medium !important
+.has-text-weight-semibold
+  font-weight: $weight-semibold !important
+.has-text-weight-bold
+  font-weight: $weight-bold !important
+
+.is-family-primary
+  font-family: $family-primary !important
+
+.is-family-secondary
+  font-family: $family-secondary !important
+
+.is-family-sans-serif
+  font-family: $family-sans-serif !important
+
+.is-family-monospace
+  font-family: $family-monospace !important
+
+.is-family-code
+  font-family: $family-code !important
+
+// Visibility
+
+$displays: 'block' 'flex' 'inline' 'inline-block' 'inline-flex'
+
+@each $display in $displays
+  .is-#{$display}
+    display: #{$display} !important
+  +mobile
+    .is-#{$display}-mobile
+      display: #{$display} !important
+  +tablet
+    .is-#{$display}-tablet
+      display: #{$display} !important
+  +tablet-only
+    .is-#{$display}-tablet-only
+      display: #{$display} !important
+  +touch
+    .is-#{$display}-touch
+      display: #{$display} !important
+  +desktop
+    .is-#{$display}-desktop
+      display: #{$display} !important
+  +desktop-only
+    .is-#{$display}-desktop-only
+      display: #{$display} !important
+  +widescreen
+    .is-#{$display}-widescreen
+      display: #{$display} !important
+  +widescreen-only
+    .is-#{$display}-widescreen-only
+      display: #{$display} !important
+  +fullhd
+    .is-#{$display}-fullhd
+      display: #{$display} !important
+
+.is-hidden
+  display: none !important
+
+.is-sr-only
+  border: none !important
+  clip: rect(0, 0, 0, 0) !important
+  height: 0.01em !important
+  overflow: hidden !important
+  padding: 0 !important
+  position: absolute !important
+  white-space: nowrap !important
+  width: 0.01em !important
+
++mobile
+  .is-hidden-mobile
+    display: none !important
+
++tablet
+  .is-hidden-tablet
+    display: none !important
+
++tablet-only
+  .is-hidden-tablet-only
+    display: none !important
+
++touch
+  .is-hidden-touch
+    display: none !important
+
++desktop
+  .is-hidden-desktop
+    display: none !important
+
++desktop-only
+  .is-hidden-desktop-only
+    display: none !important
+
++widescreen
+  .is-hidden-widescreen
+    display: none !important
+
++widescreen-only
+  .is-hidden-widescreen-only
+    display: none !important
+
++fullhd
+  .is-hidden-fullhd
+    display: none !important
+
+.is-invisible
+  visibility: hidden !important
+
++mobile
+  .is-invisible-mobile
+    visibility: hidden !important
+
++tablet
+  .is-invisible-tablet
+    visibility: hidden !important
+
++tablet-only
+  .is-invisible-tablet-only
+    visibility: hidden !important
+
++touch
+  .is-invisible-touch
+    visibility: hidden !important
+
++desktop
+  .is-invisible-desktop
+    visibility: hidden !important
+
++desktop-only
+  .is-invisible-desktop-only
+    visibility: hidden !important
+
++widescreen
+  .is-invisible-widescreen
+    visibility: hidden !important
+
++widescreen-only
+  .is-invisible-widescreen-only
+    visibility: hidden !important
+
++fullhd
+  .is-invisible-fullhd
+    visibility: hidden !important
+
+// Other
+
+.is-marginless
+  margin: 0 !important
+
+.is-paddingless
+  padding: 0 !important
+
+.is-radiusless
+  border-radius: 0 !important
+
+.is-shadowless
+  box-shadow: none !important
+
+.is-unselectable
+  @extend %unselectable
+
+.is-relative
+  position: relative !important
diff -pruN 1.3.1+dfsg-1/debian/embedded/Documenter/assets/html/scss/bulma/base/minireset.sass 1.4.0+dfsg-1/debian/embedded/Documenter/assets/html/scss/bulma/base/minireset.sass
--- 1.3.1+dfsg-1/debian/embedded/Documenter/assets/html/scss/bulma/base/minireset.sass	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/debian/embedded/Documenter/assets/html/scss/bulma/base/minireset.sass	2020-03-30 16:16:04.000000000 +0000
@@ -0,0 +1,85 @@
+/*! minireset.css v0.0.4 | MIT License | github.com/jgthms/minireset.css */
+// Blocks
+html,
+body,
+p,
+ol,
+ul,
+li,
+dl,
+dt,
+dd,
+blockquote,
+figure,
+fieldset,
+legend,
+textarea,
+pre,
+iframe,
+hr,
+h1,
+h2,
+h3,
+h4,
+h5,
+h6
+  margin: 0
+  padding: 0
+
+// Headings
+h1,
+h2,
+h3,
+h4,
+h5,
+h6
+  font-size: 100%
+  font-weight: normal
+
+// List
+ul
+  list-style: none
+
+// Form
+button,
+input,
+select,
+textarea
+  margin: 0
+
+// Box sizing
+html
+  box-sizing: border-box
+
+*
+  &,
+  &::before,
+  &::after
+    box-sizing: inherit
+
+// Media
+img,
+embed,
+iframe,
+object,
+video
+  height: auto
+  max-width: 100%
+
+audio
+  max-width: 100%
+
+// Iframe
+iframe
+  border: 0
+
+// Table
+table
+  border-collapse: collapse
+  border-spacing: 0
+
+td,
+th
+  padding: 0
+  &:not([align])
+    text-align: left
diff -pruN 1.3.1+dfsg-1/debian/embedded/Documenter/assets/html/scss/bulma/components/_all.sass 1.4.0+dfsg-1/debian/embedded/Documenter/assets/html/scss/bulma/components/_all.sass
--- 1.3.1+dfsg-1/debian/embedded/Documenter/assets/html/scss/bulma/components/_all.sass	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/debian/embedded/Documenter/assets/html/scss/bulma/components/_all.sass	2020-03-30 16:16:04.000000000 +0000
@@ -0,0 +1,15 @@
+@charset "utf-8"
+
+@import "breadcrumb.sass"
+@import "card.sass"
+@import "dropdown.sass"
+@import "level.sass"
+@import "list.sass"
+@import "media.sass"
+@import "menu.sass"
+@import "message.sass"
+@import "modal.sass"
+@import "navbar.sass"
+@import "pagination.sass"
+@import "panel.sass"
+@import "tabs.sass"
diff -pruN 1.3.1+dfsg-1/debian/embedded/Documenter/assets/html/scss/bulma/components/breadcrumb.sass 1.4.0+dfsg-1/debian/embedded/Documenter/assets/html/scss/bulma/components/breadcrumb.sass
--- 1.3.1+dfsg-1/debian/embedded/Documenter/assets/html/scss/bulma/components/breadcrumb.sass	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/debian/embedded/Documenter/assets/html/scss/bulma/components/breadcrumb.sass	2020-03-30 16:16:04.000000000 +0000
@@ -0,0 +1,75 @@
+$breadcrumb-item-color: $link !default
+$breadcrumb-item-hover-color: $link-hover !default
+$breadcrumb-item-active-color: $text-strong !default
+
+$breadcrumb-item-padding-vertical: 0 !default
+$breadcrumb-item-padding-horizontal: 0.75em !default
+
+$breadcrumb-item-separator-color: $grey-light !default
+
+.breadcrumb
+  @extend %block
+  @extend %unselectable
+  font-size: $size-normal
+  white-space: nowrap
+  a
+    align-items: center
+    color: $breadcrumb-item-color
+    display: flex
+    justify-content: center
+    padding: $breadcrumb-item-padding-vertical $breadcrumb-item-padding-horizontal
+    &:hover
+      color: $breadcrumb-item-hover-color
+  li
+    align-items: center
+    display: flex
+    &:first-child a
+      padding-left: 0
+    &.is-active
+      a
+        color: $breadcrumb-item-active-color
+        cursor: default
+        pointer-events: none
+    & + li::before
+      color: $breadcrumb-item-separator-color
+      content: "\0002f"
+  ul,
+  ol
+    align-items: flex-start
+    display: flex
+    flex-wrap: wrap
+    justify-content: flex-start
+  .icon
+    &:first-child
+      margin-right: 0.5em
+    &:last-child
+      margin-left: 0.5em
+  // Alignment
+  &.is-centered
+    ol,
+    ul
+      justify-content: center
+  &.is-right
+    ol,
+    ul
+      justify-content: flex-end
+  // Sizes
+  &.is-small
+    font-size: $size-small
+  &.is-medium
+    font-size: $size-medium
+  &.is-large
+    font-size: $size-large
+  // Styles
+  &.has-arrow-separator
+    li + li::before
+      content: "\02192"
+  &.has-bullet-separator
+    li + li::before
+      content: "\02022"
+  &.has-dot-separator
+    li + li::before
+      content: "\000b7"
+  &.has-succeeds-separator
+    li + li::before
+      content: "\0227B"
diff -pruN 1.3.1+dfsg-1/debian/embedded/Documenter/assets/html/scss/bulma/components/card.sass 1.4.0+dfsg-1/debian/embedded/Documenter/assets/html/scss/bulma/components/card.sass
--- 1.3.1+dfsg-1/debian/embedded/Documenter/assets/html/scss/bulma/components/card.sass	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/debian/embedded/Documenter/assets/html/scss/bulma/components/card.sass	2020-03-30 16:16:04.000000000 +0000
@@ -0,0 +1,79 @@
+$card-color: $text !default
+$card-background-color: $white !default
+$card-shadow: 0 2px 3px rgba($black, 0.1), 0 0 0 1px rgba($black, 0.1) !default
+
+$card-header-background-color: transparent !default
+$card-header-color: $text-strong !default
+$card-header-padding: 0.75rem !default
+$card-header-shadow: 0 1px 2px rgba($black, 0.1) !default
+$card-header-weight: $weight-bold !default
+
+$card-content-background-color: transparent !default
+$card-content-padding: 1.5rem !default
+
+$card-footer-background-color: transparent !default
+$card-footer-border-top: 1px solid $border !default
+$card-footer-padding: 0.75rem !default
+
+$card-media-margin: $block-spacing !default
+
+.card
+  background-color: $card-background-color
+  box-shadow: $card-shadow
+  color: $card-color
+  max-width: 100%
+  position: relative
+
+.card-header
+  background-color: $card-header-background-color
+  align-items: stretch
+  box-shadow: $card-header-shadow
+  display: flex
+
+.card-header-title
+  align-items: center
+  color: $card-header-color
+  display: flex
+  flex-grow: 1
+  font-weight: $card-header-weight
+  padding: $card-header-padding
+  &.is-centered
+    justify-content: center
+
+.card-header-icon
+  align-items: center
+  cursor: pointer
+  display: flex
+  justify-content: center
+  padding: $card-header-padding
+
+.card-image
+  display: block
+  position: relative
+
+.card-content
+  background-color: $card-content-background-color
+  padding: $card-content-padding
+
+.card-footer
+  background-color: $card-footer-background-color
+  border-top: $card-footer-border-top
+  align-items: stretch
+  display: flex
+
+.card-footer-item
+  align-items: center
+  display: flex
+  flex-basis: 0
+  flex-grow: 1
+  flex-shrink: 0
+  justify-content: center
+  padding: $card-footer-padding
+  &:not(:last-child)
+    border-right: $card-footer-border-top
+
+// Combinations
+
+.card
+  .media:not(:last-child)
+    margin-bottom: $card-media-margin
diff -pruN 1.3.1+dfsg-1/debian/embedded/Documenter/assets/html/scss/bulma/components/dropdown.sass 1.4.0+dfsg-1/debian/embedded/Documenter/assets/html/scss/bulma/components/dropdown.sass
--- 1.3.1+dfsg-1/debian/embedded/Documenter/assets/html/scss/bulma/components/dropdown.sass	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/debian/embedded/Documenter/assets/html/scss/bulma/components/dropdown.sass	2020-03-30 16:16:04.000000000 +0000
@@ -0,0 +1,81 @@
+$dropdown-menu-min-width: 12rem !default
+
+$dropdown-content-background-color: $white !default
+$dropdown-content-arrow: $link !default
+$dropdown-content-offset: 4px !default
+$dropdown-content-padding-bottom: 0.5rem !default
+$dropdown-content-padding-top: 0.5rem !default
+$dropdown-content-radius: $radius !default
+$dropdown-content-shadow: 0 2px 3px rgba($black, 0.1), 0 0 0 1px rgba($black, 0.1) !default
+$dropdown-content-z: 20 !default
+
+$dropdown-item-color: $grey-dark !default
+$dropdown-item-hover-color: $black !default
+$dropdown-item-hover-background-color: $background !default
+$dropdown-item-active-color: $link-invert !default
+$dropdown-item-active-background-color: $link !default
+
+$dropdown-divider-background-color: $border !default
+
+.dropdown
+  display: inline-flex
+  position: relative
+  vertical-align: top
+  &.is-active,
+  &.is-hoverable:hover
+    .dropdown-menu
+      display: block
+  &.is-right
+    .dropdown-menu
+      left: auto
+      right: 0
+  &.is-up
+    .dropdown-menu
+      bottom: 100%
+      padding-bottom: $dropdown-content-offset
+      padding-top: initial
+      top: auto
+
+.dropdown-menu
+  display: none
+  left: 0
+  min-width: $dropdown-menu-min-width
+  padding-top: $dropdown-content-offset
+  position: absolute
+  top: 100%
+  z-index: $dropdown-content-z
+
+.dropdown-content
+  background-color: $dropdown-content-background-color
+  border-radius: $dropdown-content-radius
+  box-shadow: $dropdown-content-shadow
+  padding-bottom: $dropdown-content-padding-bottom
+  padding-top: $dropdown-content-padding-top
+
+.dropdown-item
+  color: $dropdown-item-color
+  display: block
+  font-size: 0.875rem
+  line-height: 1.5
+  padding: 0.375rem 1rem
+  position: relative
+
+a.dropdown-item,
+button.dropdown-item
+  padding-right: 3rem
+  text-align: left
+  white-space: nowrap
+  width: 100%
+  &:hover
+    background-color: $dropdown-item-hover-background-color
+    color: $dropdown-item-hover-color
+  &.is-active
+    background-color: $dropdown-item-active-background-color
+    color: $dropdown-item-active-color
+
+.dropdown-divider
+  background-color: $dropdown-divider-background-color
+  border: none
+  display: block
+  height: 1px
+  margin: 0.5rem 0
diff -pruN 1.3.1+dfsg-1/debian/embedded/Documenter/assets/html/scss/bulma/components/level.sass 1.4.0+dfsg-1/debian/embedded/Documenter/assets/html/scss/bulma/components/level.sass
--- 1.3.1+dfsg-1/debian/embedded/Documenter/assets/html/scss/bulma/components/level.sass	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/debian/embedded/Documenter/assets/html/scss/bulma/components/level.sass	2020-03-30 16:16:04.000000000 +0000
@@ -0,0 +1,77 @@
+$level-item-spacing: ($block-spacing / 2) !default
+
+.level
+  @extend %block
+  align-items: center
+  justify-content: space-between
+  code
+    border-radius: $radius
+  img
+    display: inline-block
+    vertical-align: top
+  // Modifiers
+  &.is-mobile
+    display: flex
+    .level-left,
+    .level-right
+      display: flex
+    .level-left + .level-right
+      margin-top: 0
+    .level-item
+      &:not(:last-child)
+        margin-bottom: 0
+        margin-right: $level-item-spacing
+      &:not(.is-narrow)
+        flex-grow: 1
+  // Responsiveness
+  +tablet
+    display: flex
+    & > .level-item
+      &:not(.is-narrow)
+        flex-grow: 1
+
+.level-item
+  align-items: center
+  display: flex
+  flex-basis: auto
+  flex-grow: 0
+  flex-shrink: 0
+  justify-content: center
+  .title,
+  .subtitle
+    margin-bottom: 0
+  // Responsiveness
+  +mobile
+    &:not(:last-child)
+      margin-bottom: $level-item-spacing
+
+.level-left,
+.level-right
+  flex-basis: auto
+  flex-grow: 0
+  flex-shrink: 0
+  .level-item
+    // Modifiers
+    &.is-flexible
+      flex-grow: 1
+    // Responsiveness
+    +tablet
+      &:not(:last-child)
+        margin-right: $level-item-spacing
+
+.level-left
+  align-items: center
+  justify-content: flex-start
+  // Responsiveness
+  +mobile
+    & + .level-right
+      margin-top: 1.5rem
+  +tablet
+    display: flex
+
+.level-right
+  align-items: center
+  justify-content: flex-end
+  // Responsiveness
+  +tablet
+    display: flex
diff -pruN 1.3.1+dfsg-1/debian/embedded/Documenter/assets/html/scss/bulma/components/list.sass 1.4.0+dfsg-1/debian/embedded/Documenter/assets/html/scss/bulma/components/list.sass
--- 1.3.1+dfsg-1/debian/embedded/Documenter/assets/html/scss/bulma/components/list.sass	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/debian/embedded/Documenter/assets/html/scss/bulma/components/list.sass	2020-03-30 16:16:04.000000000 +0000
@@ -0,0 +1,39 @@
+$list-background-color: $white !default
+$list-shadow: 0 2px 3px rgba($black, 0.1), 0 0 0 1px rgba($black, 0.1) !default
+$list-radius: $radius !default
+
+$list-item-border: 1px solid $border !default
+$list-item-color: $text !default
+$list-item-active-background-color: $link !default
+$list-item-active-color: $link-invert !default
+$list-item-hover-background-color: $background !default
+
+.list
+  @extend %block
+  background-color: $list-background-color
+  border-radius: $list-radius
+  box-shadow: $list-shadow
+  // &.is-hoverable > .list-item:hover:not(.is-active)
+  //   background-color: $list-item-hover-background-color
+  //   cursor: pointer
+
+.list-item
+  display: block
+  padding: 0.5em 1em
+  &:not(a)
+    color: $list-item-color
+  &:first-child
+    border-top-left-radius: $list-radius
+    border-top-right-radius: $list-radius
+  &:last-child
+    border-bottom-left-radius: $list-radius
+    border-bottom-right-radius: $list-radius
+  &:not(:last-child)
+    border-bottom: $list-item-border
+  &.is-active
+    background-color: $list-item-active-background-color
+    color: $list-item-active-color
+
+a.list-item
+  background-color: $list-item-hover-background-color
+  cursor: pointer
diff -pruN 1.3.1+dfsg-1/debian/embedded/Documenter/assets/html/scss/bulma/components/media.sass 1.4.0+dfsg-1/debian/embedded/Documenter/assets/html/scss/bulma/components/media.sass
--- 1.3.1+dfsg-1/debian/embedded/Documenter/assets/html/scss/bulma/components/media.sass	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/debian/embedded/Documenter/assets/html/scss/bulma/components/media.sass	2020-03-30 16:16:04.000000000 +0000
@@ -0,0 +1,48 @@
+.media
+  align-items: flex-start
+  display: flex
+  text-align: left
+  .content:not(:last-child)
+    margin-bottom: 0.75rem
+  .media
+    border-top: 1px solid rgba($border, 0.5)
+    display: flex
+    padding-top: 0.75rem
+    .content:not(:last-child),
+    .control:not(:last-child)
+      margin-bottom: 0.5rem
+    .media
+      padding-top: 0.5rem
+      & + .media
+        margin-top: 0.5rem
+  & + .media
+    border-top: 1px solid rgba($border, 0.5)
+    margin-top: 1rem
+    padding-top: 1rem
+  // Sizes
+  &.is-large
+    & + .media
+      margin-top: 1.5rem
+      padding-top: 1.5rem
+
+.media-left,
+.media-right
+  flex-basis: auto
+  flex-grow: 0
+  flex-shrink: 0
+
+.media-left
+  margin-right: 1rem
+
+.media-right
+  margin-left: 1rem
+
+.media-content
+  flex-basis: auto
+  flex-grow: 1
+  flex-shrink: 1
+  text-align: left
+
++mobile
+  .media-content
+    overflow-x: auto
diff -pruN 1.3.1+dfsg-1/debian/embedded/Documenter/assets/html/scss/bulma/components/menu.sass 1.4.0+dfsg-1/debian/embedded/Documenter/assets/html/scss/bulma/components/menu.sass
--- 1.3.1+dfsg-1/debian/embedded/Documenter/assets/html/scss/bulma/components/menu.sass	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/debian/embedded/Documenter/assets/html/scss/bulma/components/menu.sass	2020-03-30 16:16:04.000000000 +0000
@@ -0,0 +1,57 @@
+$menu-item-color: $text !default
+$menu-item-radius: $radius-small !default
+$menu-item-hover-color: $text-strong !default
+$menu-item-hover-background-color: $background !default
+$menu-item-active-color: $link-invert !default
+$menu-item-active-background-color: $link !default
+
+$menu-list-border-left: 1px solid $border !default
+$menu-list-line-height: 1.25 !default
+$menu-list-link-padding: 0.5em 0.75em !default
+$menu-nested-list-margin: 0.75em !default
+$menu-nested-list-padding-left: 0.75em !default
+
+$menu-label-color: $text-light !default
+$menu-label-font-size: 0.75em !default
+$menu-label-letter-spacing: 0.1em !default
+$menu-label-spacing: 1em !default
+
+.menu
+  font-size: $size-normal
+  // Sizes
+  &.is-small
+    font-size: $size-small
+  &.is-medium
+    font-size: $size-medium
+  &.is-large
+    font-size: $size-large
+
+.menu-list
+  line-height: $menu-list-line-height
+  a
+    border-radius: $menu-item-radius
+    color: $menu-item-color
+    display: block
+    padding: $menu-list-link-padding
+    &:hover
+      background-color: $menu-item-hover-background-color
+      color: $menu-item-hover-color
+    // Modifiers
+    &.is-active
+      background-color: $menu-item-active-background-color
+      color: $menu-item-active-color
+  li
+    ul
+      border-left: $menu-list-border-left
+      margin: $menu-nested-list-margin
+      padding-left: $menu-nested-list-padding-left
+
+.menu-label
+  color: $menu-label-color
+  font-size: $menu-label-font-size
+  letter-spacing: $menu-label-letter-spacing
+  text-transform: uppercase
+  &:not(:first-child)
+    margin-top: $menu-label-spacing
+  &:not(:last-child)
+    margin-bottom: $menu-label-spacing
diff -pruN 1.3.1+dfsg-1/debian/embedded/Documenter/assets/html/scss/bulma/components/message.sass 1.4.0+dfsg-1/debian/embedded/Documenter/assets/html/scss/bulma/components/message.sass
--- 1.3.1+dfsg-1/debian/embedded/Documenter/assets/html/scss/bulma/components/message.sass	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/debian/embedded/Documenter/assets/html/scss/bulma/components/message.sass	2020-03-30 16:16:04.000000000 +0000
@@ -0,0 +1,87 @@
+$message-background-color: $background !default
+$message-radius: $radius !default
+
+$message-header-background-color: $text !default
+$message-header-color: $text-invert !default
+$message-header-weight: $weight-bold !default
+$message-header-padding: 0.75em 1em !default
+$message-header-radius: $radius !default
+
+$message-body-border-color: $border !default
+$message-body-border-width: 0 0 0 4px !default
+$message-body-color: $text !default
+$message-body-padding: 1.25em 1.5em !default
+$message-body-radius: $radius !default
+
+$message-body-pre-background-color: $white !default
+$message-body-pre-code-background-color: transparent !default
+
+$message-header-body-border-width: 0 !default
+$message-colors: $colors !default
+
+.message
+  @extend %block
+  background-color: $message-background-color
+  border-radius: $message-radius
+  font-size: $size-normal
+  strong
+    color: currentColor
+  a:not(.button):not(.tag):not(.dropdown-item)
+    color: currentColor
+    text-decoration: underline
+  // Sizes
+  &.is-small
+    font-size: $size-small
+  &.is-medium
+    font-size: $size-medium
+  &.is-large
+    font-size: $size-large
+  // Colors
+  @each $name, $pair in $message-colors
+    $color: nth($pair, 1)
+    $color-invert: nth($pair, 2)
+    $color-lightning: max((100% - lightness($color)) - 2%, 0%)
+    $color-luminance: colorLuminance($color)
+    $darken-percentage: $color-luminance * 70%
+    $desaturate-percentage: $color-luminance * 30%
+    &.is-#{$name}
+      background-color: lighten($color, $color-lightning)
+      .message-header
+        background-color: $color
+        color: $color-invert
+      .message-body
+        border-color: $color
+        color: desaturate(darken($color, $darken-percentage), $desaturate-percentage)
+
+.message-header
+  align-items: center
+  background-color: $message-header-background-color
+  border-radius: $message-header-radius $message-header-radius 0 0
+  color: $message-header-color
+  display: flex
+  font-weight: $message-header-weight
+  justify-content: space-between
+  line-height: 1.25
+  padding: $message-header-padding
+  position: relative
+  .delete
+    flex-grow: 0
+    flex-shrink: 0
+    margin-left: 0.75em
+  & + .message-body
+    border-width: $message-header-body-border-width
+    border-top-left-radius: 0
+    border-top-right-radius: 0
+
+.message-body
+  border-color: $message-body-border-color
+  border-radius: $message-body-radius
+  border-style: solid
+  border-width: $message-body-border-width
+  color: $message-body-color
+  padding: $message-body-padding
+  code,
+  pre
+    background-color: $message-body-pre-background-color
+  pre code
+    background-color: $message-body-pre-code-background-color
diff -pruN 1.3.1+dfsg-1/debian/embedded/Documenter/assets/html/scss/bulma/components/modal.sass 1.4.0+dfsg-1/debian/embedded/Documenter/assets/html/scss/bulma/components/modal.sass
--- 1.3.1+dfsg-1/debian/embedded/Documenter/assets/html/scss/bulma/components/modal.sass	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/debian/embedded/Documenter/assets/html/scss/bulma/components/modal.sass	2020-03-30 16:16:04.000000000 +0000
@@ -0,0 +1,113 @@
+$modal-z: 40 !default
+
+$modal-background-background-color: rgba($black, 0.86) !default
+
+$modal-content-width: 640px !default
+$modal-content-margin-mobile: 20px !default
+$modal-content-spacing-mobile: 160px !default
+$modal-content-spacing-tablet: 40px !default
+
+$modal-close-dimensions: 40px !default
+$modal-close-right: 20px !default
+$modal-close-top: 20px !default
+
+$modal-card-spacing: 40px !default
+
+$modal-card-head-background-color: $background !default
+$modal-card-head-border-bottom: 1px solid $border !default
+$modal-card-head-padding: 20px !default
+$modal-card-head-radius: $radius-large !default
+
+$modal-card-title-color: $text-strong !default
+$modal-card-title-line-height: 1 !default
+$modal-card-title-size: $size-4 !default
+
+$modal-card-foot-radius: $radius-large !default
+$modal-card-foot-border-top: 1px solid $border !default
+
+$modal-card-body-background-color: $white !default
+$modal-card-body-padding: 20px !default
+
+.modal
+  @extend %overlay
+  align-items: center
+  display: none
+  flex-direction: column
+  justify-content: center
+  overflow: hidden
+  position: fixed
+  z-index: $modal-z
+  // Modifiers
+  &.is-active
+    display: flex
+
+.modal-background
+  @extend %overlay
+  background-color: $modal-background-background-color
+
+.modal-content,
+.modal-card
+  margin: 0 $modal-content-margin-mobile
+  max-height: calc(100vh - #{$modal-content-spacing-mobile})
+  overflow: auto
+  position: relative
+  width: 100%
+  // Responsiveness
+  +tablet
+    margin: 0 auto
+    max-height: calc(100vh - #{$modal-content-spacing-tablet})
+    width: $modal-content-width
+
+.modal-close
+  @extend %delete
+  background: none
+  height: $modal-close-dimensions
+  position: fixed
+  right: $modal-close-right
+  top: $modal-close-top
+  width: $modal-close-dimensions
+
+.modal-card
+  display: flex
+  flex-direction: column
+  max-height: calc(100vh - #{$modal-card-spacing})
+  overflow: hidden
+  -ms-overflow-y: visible
+
+.modal-card-head,
+.modal-card-foot
+  align-items: center
+  background-color: $modal-card-head-background-color
+  display: flex
+  flex-shrink: 0
+  justify-content: flex-start
+  padding: $modal-card-head-padding
+  position: relative
+
+.modal-card-head
+  border-bottom: $modal-card-head-border-bottom
+  border-top-left-radius: $modal-card-head-radius
+  border-top-right-radius: $modal-card-head-radius
+
+.modal-card-title
+  color: $modal-card-title-color
+  flex-grow: 1
+  flex-shrink: 0
+  font-size: $modal-card-title-size
+  line-height: $modal-card-title-line-height
+
+.modal-card-foot
+  border-bottom-left-radius: $modal-card-foot-radius
+  border-bottom-right-radius: $modal-card-foot-radius
+  border-top: $modal-card-foot-border-top
+  .button
+    &:not(:last-child)
+      margin-right: 0.5em
+
+.modal-card-body
+  +overflow-touch
+  background-color: $modal-card-body-background-color
+  flex-grow: 1
+  flex-shrink: 1
+  overflow: auto
+  padding: $modal-card-body-padding
diff -pruN 1.3.1+dfsg-1/debian/embedded/Documenter/assets/html/scss/bulma/components/navbar.sass 1.4.0+dfsg-1/debian/embedded/Documenter/assets/html/scss/bulma/components/navbar.sass
--- 1.3.1+dfsg-1/debian/embedded/Documenter/assets/html/scss/bulma/components/navbar.sass	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/debian/embedded/Documenter/assets/html/scss/bulma/components/navbar.sass	2020-03-30 16:16:04.000000000 +0000
@@ -0,0 +1,443 @@
+$navbar-background-color: $white !default
+$navbar-box-shadow-size: 0 2px 0 0 !default
+$navbar-box-shadow-color: $background !default
+$navbar-height: 3.25rem !default
+$navbar-padding-vertical: 1rem !default
+$navbar-padding-horizontal: 2rem !default
+$navbar-z: 30 !default
+$navbar-fixed-z: 30 !default
+
+$navbar-item-color: $grey-dark !default
+$navbar-item-hover-color: $link !default
+$navbar-item-hover-background-color: $white-bis !default
+$navbar-item-active-color: $black !default
+$navbar-item-active-background-color: transparent !default
+$navbar-item-img-max-height: 1.75rem !default
+
+$navbar-burger-color: $navbar-item-color !default
+
+$navbar-tab-hover-background-color: transparent !default
+$navbar-tab-hover-border-bottom-color: $link !default
+$navbar-tab-active-color: $link !default
+$navbar-tab-active-background-color: transparent !default
+$navbar-tab-active-border-bottom-color: $link !default
+$navbar-tab-active-border-bottom-style: solid !default
+$navbar-tab-active-border-bottom-width: 3px !default
+
+$navbar-dropdown-background-color: $white !default
+$navbar-dropdown-border-top: 2px solid $border !default
+$navbar-dropdown-offset: -4px !default
+$navbar-dropdown-arrow: $link !default
+$navbar-dropdown-radius: $radius-large !default
+$navbar-dropdown-z: 20 !default
+
+$navbar-dropdown-boxed-radius: $radius-large !default
+$navbar-dropdown-boxed-shadow: 0 8px 8px rgba($black, 0.1), 0 0 0 1px rgba($black, 0.1) !default
+
+$navbar-dropdown-item-hover-color: $black !default
+$navbar-dropdown-item-hover-background-color: $background !default
+$navbar-dropdown-item-active-color: $link !default
+$navbar-dropdown-item-active-background-color: $background !default
+
+$navbar-divider-background-color: $background !default
+$navbar-divider-height: 2px !default
+
+$navbar-bottom-box-shadow-size: 0 -2px 0 0 !default
+
+$navbar-breakpoint: $desktop !default
+
+=navbar-fixed
+  left: 0
+  position: fixed
+  right: 0
+  z-index: $navbar-fixed-z
+
+.navbar
+  background-color: $navbar-background-color
+  min-height: $navbar-height
+  position: relative
+  z-index: $navbar-z
+  @each $name, $pair in $colors
+    $color: nth($pair, 1)
+    $color-invert: nth($pair, 2)
+    &.is-#{$name}
+      background-color: $color
+      color: $color-invert
+      .navbar-brand
+        & > .navbar-item,
+        .navbar-link
+          color: $color-invert
+        & > a.navbar-item,
+        .navbar-link
+          &:focus,
+          &:hover,
+          &.is-active
+            background-color: darken($color, 5%)
+            color: $color-invert
+        .navbar-link
+          &::after
+            border-color: $color-invert
+      .navbar-burger
+        color: $color-invert
+      +from($navbar-breakpoint)
+        .navbar-start,
+        .navbar-end
+          & > .navbar-item,
+          .navbar-link
+            color: $color-invert
+          & > a.navbar-item,
+          .navbar-link
+            &:focus,
+            &:hover,
+            &.is-active
+              background-color: darken($color, 5%)
+              color: $color-invert
+          .navbar-link
+            &::after
+              border-color: $color-invert
+        .navbar-item.has-dropdown:focus .navbar-link,
+        .navbar-item.has-dropdown:hover .navbar-link,
+        .navbar-item.has-dropdown.is-active .navbar-link
+          background-color: darken($color, 5%)
+          color: $color-invert
+        .navbar-dropdown
+          a.navbar-item
+            &.is-active
+              background-color: $color
+              color: $color-invert
+  & > .container
+    align-items: stretch
+    display: flex
+    min-height: $navbar-height
+    width: 100%
+  &.has-shadow
+    box-shadow: $navbar-box-shadow-size $navbar-box-shadow-color
+  &.is-fixed-bottom,
+  &.is-fixed-top
+    +navbar-fixed
+  &.is-fixed-bottom
+    bottom: 0
+    &.has-shadow
+      box-shadow: $navbar-bottom-box-shadow-size $navbar-box-shadow-color
+  &.is-fixed-top
+    top: 0
+
+html,
+body
+  &.has-navbar-fixed-top
+    padding-top: $navbar-height
+  &.has-navbar-fixed-bottom
+    padding-bottom: $navbar-height
+
+.navbar-brand,
+.navbar-tabs
+  align-items: stretch
+  display: flex
+  flex-shrink: 0
+  min-height: $navbar-height
+
+.navbar-brand
+  a.navbar-item
+    &:focus,
+    &:hover
+      background-color: transparent
+
+.navbar-tabs
+  +overflow-touch
+  max-width: 100vw
+  overflow-x: auto
+  overflow-y: hidden
+
+.navbar-burger
+  color: $navbar-burger-color
+  +hamburger($navbar-height)
+  margin-left: auto
+
+.navbar-menu
+  display: none
+
+.navbar-item,
+.navbar-link
+  color: $navbar-item-color
+  display: block
+  line-height: 1.5
+  padding: 0.5rem 0.75rem
+  position: relative
+  .icon
+    &:only-child
+      margin-left: -0.25rem
+      margin-right: -0.25rem
+
+a.navbar-item,
+.navbar-link
+  cursor: pointer
+  &:focus,
+  &:focus-within,
+  &:hover,
+  &.is-active
+    background-color: $navbar-item-hover-background-color
+    color: $navbar-item-hover-color
+
+.navbar-item
+  display: block
+  flex-grow: 0
+  flex-shrink: 0
+  img
+    max-height: $navbar-item-img-max-height
+  &.has-dropdown
+    padding: 0
+  &.is-expanded
+    flex-grow: 1
+    flex-shrink: 1
+  &.is-tab
+    border-bottom: 1px solid transparent
+    min-height: $navbar-height
+    padding-bottom: calc(0.5rem - 1px)
+    &:focus,
+    &:hover
+      background-color: $navbar-tab-hover-background-color
+      border-bottom-color: $navbar-tab-hover-border-bottom-color
+    &.is-active
+      background-color: $navbar-tab-active-background-color
+      border-bottom-color: $navbar-tab-active-border-bottom-color
+      border-bottom-style: $navbar-tab-active-border-bottom-style
+      border-bottom-width: $navbar-tab-active-border-bottom-width
+      color: $navbar-tab-active-color
+      padding-bottom: calc(0.5rem - #{$navbar-tab-active-border-bottom-width})
+
+.navbar-content
+  flex-grow: 1
+  flex-shrink: 1
+
+.navbar-link:not(.is-arrowless)
+  padding-right: 2.5em
+  &::after
+    @extend %arrow
+    border-color: $navbar-dropdown-arrow
+    margin-top: -0.375em
+    right: 1.125em
+
+.navbar-dropdown
+  font-size: 0.875rem
+  padding-bottom: 0.5rem
+  padding-top: 0.5rem
+  .navbar-item
+    padding-left: 1.5rem
+    padding-right: 1.5rem
+
+.navbar-divider
+  background-color: $navbar-divider-background-color
+  border: none
+  display: none
+  height: $navbar-divider-height
+  margin: 0.5rem 0
+
++until($navbar-breakpoint)
+  .navbar > .container
+    display: block
+  .navbar-brand,
+  .navbar-tabs
+    .navbar-item
+      align-items: center
+      display: flex
+  .navbar-link
+    &::after
+      display: none
+  .navbar-menu
+    background-color: $navbar-background-color
+    box-shadow: 0 8px 16px rgba($black, 0.1)
+    padding: 0.5rem 0
+    &.is-active
+      display: block
+  // Fixed navbar
+  .navbar
+    &.is-fixed-bottom-touch,
+    &.is-fixed-top-touch
+      +navbar-fixed
+    &.is-fixed-bottom-touch
+      bottom: 0
+      &.has-shadow
+        box-shadow: 0 -2px 3px rgba($black, 0.1)
+    &.is-fixed-top-touch
+      top: 0
+    &.is-fixed-top,
+    &.is-fixed-top-touch
+      .navbar-menu
+        +overflow-touch
+        max-height: calc(100vh - #{$navbar-height})
+        overflow: auto
+  html,
+  body
+    &.has-navbar-fixed-top-touch
+      padding-top: $navbar-height
+    &.has-navbar-fixed-bottom-touch
+      padding-bottom: $navbar-height
+
++from($navbar-breakpoint)
+  .navbar,
+  .navbar-menu,
+  .navbar-start,
+  .navbar-end
+    align-items: stretch
+    display: flex
+  .navbar
+    min-height: $navbar-height
+    &.is-spaced
+      padding: $navbar-padding-vertical $navbar-padding-horizontal
+      .navbar-start,
+      .navbar-end
+        align-items: center
+      a.navbar-item,
+      .navbar-link
+        border-radius: $radius
+    &.is-transparent
+      a.navbar-item,
+      .navbar-link
+        &:focus,
+        &:hover,
+        &.is-active
+          background-color: transparent !important
+      .navbar-item.has-dropdown
+        &.is-active,
+        &.is-hoverable:focus,
+        &.is-hoverable:focus-within,
+        &.is-hoverable:hover
+          .navbar-link
+            background-color: transparent !important
+      .navbar-dropdown
+        a.navbar-item
+          &:focus,
+          &:hover
+            background-color: $navbar-dropdown-item-hover-background-color
+            color: $navbar-dropdown-item-hover-color
+          &.is-active
+            background-color: $navbar-dropdown-item-active-background-color
+            color: $navbar-dropdown-item-active-color
+  .navbar-burger
+    display: none
+  .navbar-item,
+  .navbar-link
+    align-items: center
+    display: flex
+  .navbar-item
+    display: flex
+    &.has-dropdown
+      align-items: stretch
+    &.has-dropdown-up
+      .navbar-link::after
+        transform: rotate(135deg) translate(0.25em, -0.25em)
+      .navbar-dropdown
+        border-bottom: $navbar-dropdown-border-top
+        border-radius: $navbar-dropdown-radius $navbar-dropdown-radius 0 0
+        border-top: none
+        bottom: 100%
+        box-shadow: 0 -8px 8px rgba($black, 0.1)
+        top: auto
+    &.is-active,
+    &.is-hoverable:focus,
+    &.is-hoverable:focus-within,
+    &.is-hoverable:hover
+      .navbar-dropdown
+        display: block
+        .navbar.is-spaced &,
+        &.is-boxed
+          opacity: 1
+          pointer-events: auto
+          transform: translateY(0)
+  .navbar-menu
+    flex-grow: 1
+    flex-shrink: 0
+  .navbar-start
+    justify-content: flex-start
+    margin-right: auto
+  .navbar-end
+    justify-content: flex-end
+    margin-left: auto
+  .navbar-dropdown
+    background-color: $navbar-dropdown-background-color
+    border-bottom-left-radius: $navbar-dropdown-radius
+    border-bottom-right-radius: $navbar-dropdown-radius
+    border-top: $navbar-dropdown-border-top
+    box-shadow: 0 8px 8px rgba($black, 0.1)
+    display: none
+    font-size: 0.875rem
+    left: 0
+    min-width: 100%
+    position: absolute
+    top: 100%
+    z-index: $navbar-dropdown-z
+    .navbar-item
+      padding: 0.375rem 1rem
+      white-space: nowrap
+    a.navbar-item
+      padding-right: 3rem
+      &:focus,
+      &:hover
+        background-color: $navbar-dropdown-item-hover-background-color
+        color: $navbar-dropdown-item-hover-color
+      &.is-active
+        background-color: $navbar-dropdown-item-active-background-color
+        color: $navbar-dropdown-item-active-color
+    .navbar.is-spaced &,
+    &.is-boxed
+      border-radius: $navbar-dropdown-boxed-radius
+      border-top: none
+      box-shadow: $navbar-dropdown-boxed-shadow
+      display: block
+      opacity: 0
+      pointer-events: none
+      top: calc(100% + (#{$navbar-dropdown-offset}))
+      transform: translateY(-5px)
+      transition-duration: $speed
+      transition-property: opacity, transform
+    &.is-right
+      left: auto
+      right: 0
+  .navbar-divider
+    display: block
+  .navbar > .container,
+  .container > .navbar
+    .navbar-brand
+      margin-left: -.75rem
+    .navbar-menu
+      margin-right: -.75rem
+  // Fixed navbar
+  .navbar
+    &.is-fixed-bottom-desktop,
+    &.is-fixed-top-desktop
+      +navbar-fixed
+    &.is-fixed-bottom-desktop
+      bottom: 0
+      &.has-shadow
+        box-shadow: 0 -2px 3px rgba($black, 0.1)
+    &.is-fixed-top-desktop
+      top: 0
+  html,
+  body
+    &.has-navbar-fixed-top-desktop
+      padding-top: $navbar-height
+    &.has-navbar-fixed-bottom-desktop
+      padding-bottom: $navbar-height
+    &.has-spaced-navbar-fixed-top
+      padding-top: $navbar-height + ($navbar-padding-vertical * 2)
+    &.has-spaced-navbar-fixed-bottom
+      padding-bottom: $navbar-height + ($navbar-padding-vertical * 2)
+  // Hover/Active states
+  a.navbar-item,
+  .navbar-link
+    &.is-active
+      color: $navbar-item-active-color
+    &.is-active:not(:focus):not(:hover)
+      background-color: $navbar-item-active-background-color
+  .navbar-item.has-dropdown
+    &:focus,
+    &:hover,
+    &.is-active
+      .navbar-link
+        background-color: $navbar-item-hover-background-color
+
+// Combination
+
+.hero
+  &.is-fullheight-with-navbar
+    min-height: calc(100vh - #{$navbar-height})
diff -pruN 1.3.1+dfsg-1/debian/embedded/Documenter/assets/html/scss/bulma/components/pagination.sass 1.4.0+dfsg-1/debian/embedded/Documenter/assets/html/scss/bulma/components/pagination.sass
--- 1.3.1+dfsg-1/debian/embedded/Documenter/assets/html/scss/bulma/components/pagination.sass	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/debian/embedded/Documenter/assets/html/scss/bulma/components/pagination.sass	2020-03-30 16:16:04.000000000 +0000
@@ -0,0 +1,149 @@
+$pagination-color: $grey-darker !default
+$pagination-border-color: $grey-lighter !default
+$pagination-margin: -0.25rem !default
+$pagination-min-width: $control-height !default
+
+$pagination-item-font-size: 1em !default
+$pagination-item-margin: 0.25rem !default
+$pagination-item-padding-left: 0.5em !default
+$pagination-item-padding-right: 0.5em !default
+
+$pagination-hover-color: $link-hover !default
+$pagination-hover-border-color: $link-hover-border !default
+
+$pagination-focus-color: $link-focus !default
+$pagination-focus-border-color: $link-focus-border !default
+
+$pagination-active-color: $link-active !default
+$pagination-active-border-color: $link-active-border !default
+
+$pagination-disabled-color: $grey !default
+$pagination-disabled-background-color: $grey-lighter !default
+$pagination-disabled-border-color: $grey-lighter !default
+
+$pagination-current-color: $link-invert !default
+$pagination-current-background-color: $link !default
+$pagination-current-border-color: $link !default
+
+$pagination-ellipsis-color: $grey-light !default
+
+$pagination-shadow-inset: inset 0 1px 2px rgba($black, 0.2)
+
+.pagination
+  font-size: $size-normal
+  margin: $pagination-margin
+  // Sizes
+  &.is-small
+    font-size: $size-small
+  &.is-medium
+    font-size: $size-medium
+  &.is-large
+    font-size: $size-large
+  &.is-rounded
+    .pagination-previous,
+    .pagination-next
+      padding-left: 1em
+      padding-right: 1em
+      border-radius: $radius-rounded
+    .pagination-link
+      border-radius: $radius-rounded
+
+.pagination,
+.pagination-list
+  align-items: center
+  display: flex
+  justify-content: center
+  text-align: center
+
+.pagination-previous,
+.pagination-next,
+.pagination-link,
+.pagination-ellipsis
+  @extend %control
+  @extend %unselectable
+  font-size: $pagination-item-font-size
+  justify-content: center
+  margin: $pagination-item-margin
+  padding-left: $pagination-item-padding-left
+  padding-right: $pagination-item-padding-right
+  text-align: center
+
+.pagination-previous,
+.pagination-next,
+.pagination-link
+  border-color: $pagination-border-color
+  color: $pagination-color
+  min-width: $pagination-min-width
+  &:hover
+    border-color: $pagination-hover-border-color
+    color: $pagination-hover-color
+  &:focus
+    border-color: $pagination-focus-border-color
+  &:active
+    box-shadow: $pagination-shadow-inset
+  &[disabled]
+    background-color: $pagination-disabled-background-color
+    border-color: $pagination-disabled-border-color
+    box-shadow: none
+    color: $pagination-disabled-color
+    opacity: 0.5
+
+.pagination-previous,
+.pagination-next
+  padding-left: 0.75em
+  padding-right: 0.75em
+  white-space: nowrap
+
+.pagination-link
+  &.is-current
+    background-color: $pagination-current-background-color
+    border-color: $pagination-current-border-color
+    color: $pagination-current-color
+
+.pagination-ellipsis
+  color: $pagination-ellipsis-color
+  pointer-events: none
+
+.pagination-list
+  flex-wrap: wrap
+
++mobile
+  .pagination
+    flex-wrap: wrap
+  .pagination-previous,
+  .pagination-next
+    flex-grow: 1
+    flex-shrink: 1
+  .pagination-list
+    li
+      flex-grow: 1
+      flex-shrink: 1
+
++tablet
+  .pagination-list
+    flex-grow: 1
+    flex-shrink: 1
+    justify-content: flex-start
+    order: 1
+  .pagination-previous
+    order: 2
+  .pagination-next
+    order: 3
+  .pagination
+    justify-content: space-between
+    &.is-centered
+      .pagination-previous
+        order: 1
+      .pagination-list
+        justify-content: center
+        order: 2
+      .pagination-next
+        order: 3
+    &.is-right
+      .pagination-previous
+        order: 1
+      .pagination-next
+        order: 2
+      .pagination-list
+        justify-content: flex-end
+        order: 3
diff -pruN 1.3.1+dfsg-1/debian/embedded/Documenter/assets/html/scss/bulma/components/panel.sass 1.4.0+dfsg-1/debian/embedded/Documenter/assets/html/scss/bulma/components/panel.sass
--- 1.3.1+dfsg-1/debian/embedded/Documenter/assets/html/scss/bulma/components/panel.sass	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/debian/embedded/Documenter/assets/html/scss/bulma/components/panel.sass	2020-03-30 16:16:04.000000000 +0000
@@ -0,0 +1,103 @@
+$panel-margin: $block-spacing !default
+$panel-item-border: 1px solid $border !default
+
+$panel-heading-background-color: $background !default
+$panel-heading-color: $text-strong !default
+$panel-heading-line-height: 1.25 !default
+$panel-heading-padding: 0.5em 0.75em !default
+$panel-heading-radius: $radius !default
+$panel-heading-size: 1.25em !default
+$panel-heading-weight: $weight-light !default
+
+$panel-tabs-font-size: 0.875em !default
+$panel-tab-border-bottom: 1px solid $border !default
+$panel-tab-active-border-bottom-color: $link-active-border !default
+$panel-tab-active-color: $link-active !default
+
+$panel-list-item-color: $text !default
+$panel-list-item-hover-color: $link !default
+
+$panel-block-color: $text-strong !default
+$panel-block-hover-background-color: $background !default
+$panel-block-active-border-left-color: $link !default
+$panel-block-active-color: $link-active !default
+$panel-block-active-icon-color: $link !default
+
+$panel-icon-color: $text-light !default
+
+.panel
+  font-size: $size-normal
+  &:not(:last-child)
+    margin-bottom: $panel-margin
+
+.panel-heading,
+.panel-tabs,
+.panel-block
+  border-bottom: $panel-item-border
+  border-left: $panel-item-border
+  border-right: $panel-item-border
+  &:first-child
+    border-top: $panel-item-border
+
+.panel-heading
+  background-color: $panel-heading-background-color
+  border-radius: $panel-heading-radius $panel-heading-radius 0 0
+  color: $panel-heading-color
+  font-size: $panel-heading-size
+  font-weight: $panel-heading-weight
+  line-height: $panel-heading-line-height
+  padding: $panel-heading-padding
+
+.panel-tabs
+  align-items: flex-end
+  display: flex
+  font-size: $panel-tabs-font-size
+  justify-content: center
+  a
+    border-bottom: $panel-tab-border-bottom
+    margin-bottom: -1px
+    padding: 0.5em
+    // Modifiers
+    &.is-active
+      border-bottom-color: $panel-tab-active-border-bottom-color
+      color: $panel-tab-active-color
+
+.panel-list
+  a
+    color: $panel-list-item-color
+    &:hover
+      color: $panel-list-item-hover-color
+
+.panel-block
+  align-items: center
+  color: $panel-block-color
+  display: flex
+  justify-content: flex-start
+  padding: 0.5em 0.75em
+  input[type="checkbox"]
+    margin-right: 0.75em
+  & > .control
+    flex-grow: 1
+    flex-shrink: 1
+    width: 100%
+  &.is-wrapped
+    flex-wrap: wrap
+  &.is-active
+    border-left-color: $panel-block-active-border-left-color
+    color: $panel-block-active-color
+    .panel-icon
+      color: $panel-block-active-icon-color
+
+a.panel-block,
+label.panel-block
+  cursor: pointer
+  &:hover
+    background-color: $panel-block-hover-background-color
+
+.panel-icon
+  +fa(14px, 1em)
+  color: $panel-icon-color
+  margin-right: 0.75em
+  .fa
+    font-size: inherit
+    line-height: inherit
diff -pruN 1.3.1+dfsg-1/debian/embedded/Documenter/assets/html/scss/bulma/components/tabs.sass 1.4.0+dfsg-1/debian/embedded/Documenter/assets/html/scss/bulma/components/tabs.sass
--- 1.3.1+dfsg-1/debian/embedded/Documenter/assets/html/scss/bulma/components/tabs.sass	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/debian/embedded/Documenter/assets/html/scss/bulma/components/tabs.sass	2020-03-30 16:16:04.000000000 +0000
@@ -0,0 +1,151 @@
+$tabs-border-bottom-color: $border !default
+$tabs-border-bottom-style: solid !default
+$tabs-border-bottom-width: 1px !default
+$tabs-link-color: $text !default
+$tabs-link-hover-border-bottom-color: $text-strong !default
+$tabs-link-hover-color: $text-strong !default
+$tabs-link-active-border-bottom-color: $link !default
+$tabs-link-active-color: $link !default
+$tabs-link-padding: 0.5em 1em !default
+
+$tabs-boxed-link-radius: $radius !default
+$tabs-boxed-link-hover-background-color: $background !default
+$tabs-boxed-link-hover-border-bottom-color: $border !default
+
+$tabs-boxed-link-active-background-color: $white !default
+$tabs-boxed-link-active-border-color: $border !default
+$tabs-boxed-link-active-border-bottom-color: transparent !default
+
+$tabs-toggle-link-border-color: $border !default
+$tabs-toggle-link-border-style: solid !default
+$tabs-toggle-link-border-width: 1px !default
+$tabs-toggle-link-hover-background-color: $background !default
+$tabs-toggle-link-hover-border-color: $border-hover !default
+$tabs-toggle-link-radius: $radius !default
+$tabs-toggle-link-active-background-color: $link !default
+$tabs-toggle-link-active-border-color: $link !default
+$tabs-toggle-link-active-color: $link-invert !default
+
+.tabs
+  @extend %block
+  +overflow-touch
+  @extend %unselectable
+  align-items: stretch
+  display: flex
+  font-size: $size-normal
+  justify-content: space-between
+  overflow: hidden
+  overflow-x: auto
+  white-space: nowrap
+  a
+    align-items: center
+    border-bottom-color: $tabs-border-bottom-color
+    border-bottom-style: $tabs-border-bottom-style
+    border-bottom-width: $tabs-border-bottom-width
+    color: $tabs-link-color
+    display: flex
+    justify-content: center
+    margin-bottom: -#{$tabs-border-bottom-width}
+    padding: $tabs-link-padding
+    vertical-align: top
+    &:hover
+      border-bottom-color: $tabs-link-hover-border-bottom-color
+      color: $tabs-link-hover-color
+  li
+    display: block
+    &.is-active
+      a
+        border-bottom-color: $tabs-link-active-border-bottom-color
+        color: $tabs-link-active-color
+  ul
+    align-items: center
+    border-bottom-color: $tabs-border-bottom-color
+    border-bottom-style: $tabs-border-bottom-style
+    border-bottom-width: $tabs-border-bottom-width
+    display: flex
+    flex-grow: 1
+    flex-shrink: 0
+    justify-content: flex-start
+    &.is-left
+      padding-right: 0.75em
+    &.is-center
+      flex: none
+      justify-content: center
+      padding-left: 0.75em
+      padding-right: 0.75em
+    &.is-right
+      justify-content: flex-end
+      padding-left: 0.75em
+  .icon
+    &:first-child
+      margin-right: 0.5em
+    &:last-child
+      margin-left: 0.5em
+  // Alignment
+  &.is-centered
+    ul
+      justify-content: center
+  &.is-right
+    ul
+      justify-content: flex-end
+  // Styles
+  &.is-boxed
+    a
+      border: 1px solid transparent
+      border-radius: $tabs-boxed-link-radius $tabs-boxed-link-radius 0 0
+      &:hover
+        background-color: $tabs-boxed-link-hover-background-color
+        border-bottom-color: $tabs-boxed-link-hover-border-bottom-color
+    li
+      &.is-active
+        a
+          background-color: $tabs-boxed-link-active-background-color
+          border-color: $tabs-boxed-link-active-border-color
+          border-bottom-color: $tabs-boxed-link-active-border-bottom-color !important
+  &.is-fullwidth
+    li
+      flex-grow: 1
+      flex-shrink: 0
+  &.is-toggle
+    a
+      border-color: $tabs-toggle-link-border-color
+      border-style: $tabs-toggle-link-border-style
+      border-width: $tabs-toggle-link-border-width
+      margin-bottom: 0
+      position: relative
+      &:hover
+        background-color: $tabs-toggle-link-hover-background-color
+        border-color: $tabs-toggle-link-hover-border-color
+        z-index: 2
+    li
+      & + li
+        margin-left: -#{$tabs-toggle-link-border-width}
+      &:first-child a
+        border-radius: $tabs-toggle-link-radius 0 0 $tabs-toggle-link-radius
+      &:last-child a
+        border-radius: 0 $tabs-toggle-link-radius $tabs-toggle-link-radius 0
+      &.is-active
+        a
+          background-color: $tabs-toggle-link-active-background-color
+          border-color: $tabs-toggle-link-active-border-color
+          color: $tabs-toggle-link-active-color
+          z-index: 1
+    ul
+      border-bottom: none
+    &.is-toggle-rounded
+      li
+        &:first-child a
+          border-bottom-left-radius: $radius-rounded
+          border-top-left-radius: $radius-rounded
+          padding-left: 1.25em
+        &:last-child a
+          border-bottom-right-radius: $radius-rounded
+          border-top-right-radius: $radius-rounded
+          padding-right: 1.25em
+  // Sizes
+  &.is-small
+    font-size: $size-small
+  &.is-medium
+    font-size: $size-medium
+  &.is-large
+    font-size: $size-large
diff -pruN 1.3.1+dfsg-1/debian/embedded/Documenter/assets/html/scss/bulma/elements/_all.sass 1.4.0+dfsg-1/debian/embedded/Documenter/assets/html/scss/bulma/elements/_all.sass
--- 1.3.1+dfsg-1/debian/embedded/Documenter/assets/html/scss/bulma/elements/_all.sass	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/debian/embedded/Documenter/assets/html/scss/bulma/elements/_all.sass	2020-03-30 16:16:04.000000000 +0000
@@ -0,0 +1,15 @@
+@charset "utf-8"
+
+@import "box.sass"
+@import "button.sass"
+@import "container.sass"
+@import "content.sass"
+@import "icon.sass"
+@import "image.sass"
+@import "notification.sass"
+@import "progress.sass"
+@import "table.sass"
+@import "tag.sass"
+@import "title.sass"
+
+@import "other.sass"
diff -pruN 1.3.1+dfsg-1/debian/embedded/Documenter/assets/html/scss/bulma/elements/box.sass 1.4.0+dfsg-1/debian/embedded/Documenter/assets/html/scss/bulma/elements/box.sass
--- 1.3.1+dfsg-1/debian/embedded/Documenter/assets/html/scss/bulma/elements/box.sass	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/debian/embedded/Documenter/assets/html/scss/bulma/elements/box.sass	2020-03-30 16:16:04.000000000 +0000
@@ -0,0 +1,24 @@
+$box-color: $text !default
+$box-background-color: $white !default
+$box-radius: $radius-large !default
+$box-shadow: 0 2px 3px rgba($black, 0.1), 0 0 0 1px rgba($black, 0.1) !default
+$box-padding: 1.25rem !default
+
+$box-link-hover-shadow: 0 2px 3px rgba($black, 0.1), 0 0 0 1px $link !default
+$box-link-active-shadow: inset 0 1px 2px rgba($black, 0.2), 0 0 0 1px $link !default
+
+.box
+  @extend %block
+  background-color: $box-background-color
+  border-radius: $box-radius
+  box-shadow: $box-shadow
+  color: $box-color
+  display: block
+  padding: $box-padding
+
+a.box
+  &:hover,
+  &:focus
+    box-shadow: $box-link-hover-shadow
+  &:active
+    box-shadow: $box-link-active-shadow
diff -pruN 1.3.1+dfsg-1/debian/embedded/Documenter/assets/html/scss/bulma/elements/button.sass 1.4.0+dfsg-1/debian/embedded/Documenter/assets/html/scss/bulma/elements/button.sass
--- 1.3.1+dfsg-1/debian/embedded/Documenter/assets/html/scss/bulma/elements/button.sass	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/debian/embedded/Documenter/assets/html/scss/bulma/elements/button.sass	2020-03-30 16:16:04.000000000 +0000
@@ -0,0 +1,305 @@
+$button-color: $grey-darker !default
+$button-background-color: $white !default
+$button-family: false !default
+
+$button-border-color: $grey-lighter !default
+$button-border-width: $control-border-width !default
+
+$button-padding-vertical: calc(0.375em - #{$button-border-width}) !default
+$button-padding-horizontal: 0.75em !default
+
+$button-hover-color: $link-hover !default
+$button-hover-border-color: $link-hover-border !default
+
+$button-focus-color: $link-focus !default
+$button-focus-border-color: $link-focus-border !default
+$button-focus-box-shadow-size: 0 0 0 0.125em !default
+$button-focus-box-shadow-color: rgba($link, 0.25) !default
+
+$button-active-color: $link-active !default
+$button-active-border-color: $link-active-border !default
+
+$button-text-color: $text !default
+$button-text-hover-background-color: $background !default
+$button-text-hover-color: $text-strong !default
+
+$button-disabled-background-color: $white !default
+$button-disabled-border-color: $grey-lighter !default
+$button-disabled-shadow: none !default
+$button-disabled-opacity: 0.5 !default
+
+$button-static-color: $grey !default
+$button-static-background-color: $white-ter !default
+$button-static-border-color: $grey-lighter !default
+
+// The button sizes use mixins so they can be used at different breakpoints
+=button-small
+  border-radius: $radius-small
+  font-size: $size-small
+=button-normal
+  font-size: $size-normal
+=button-medium
+  font-size: $size-medium
+=button-large
+  font-size: $size-large
+
+.button
+  @extend %control
+  @extend %unselectable
+  background-color: $button-background-color
+  border-color: $button-border-color
+  border-width: $button-border-width
+  color: $button-color
+  cursor: pointer
+  @if $button-family
+    font-family: $button-family
+  justify-content: center
+  padding-bottom: $button-padding-vertical
+  padding-left: $button-padding-horizontal
+  padding-right: $button-padding-horizontal
+  padding-top: $button-padding-vertical
+  text-align: center
+  white-space: nowrap
+  strong
+    color: inherit
+  .icon
+    &,
+    &.is-small,
+    &.is-medium,
+    &.is-large
+      height: 1.5em
+      width: 1.5em
+    &:first-child:not(:last-child)
+      margin-left: calc(-0.375em - #{$button-border-width})
+      margin-right: 0.1875em
+    &:last-child:not(:first-child)
+      margin-left: 0.1875em
+      margin-right: calc(-0.375em - #{$button-border-width})
+    &:first-child:last-child
+      margin-left: calc(-0.375em - #{$button-border-width})
+      margin-right: calc(-0.375em - #{$button-border-width})
+  // States
+  &:hover,
+  &.is-hovered
+    border-color: $button-hover-border-color
+    color: $button-hover-color
+  &:focus,
+  &.is-focused
+    border-color: $button-focus-border-color
+    color: $button-focus-color
+    &:not(:active)
+      box-shadow: $button-focus-box-shadow-size $button-focus-box-shadow-color
+  &:active,
+  &.is-active
+    border-color: $button-active-border-color
+    color: $button-active-color
+  // Colors
+  &.is-text
+    background-color: transparent
+    border-color: transparent
+    color: $button-text-color
+    text-decoration: underline
+    &:hover,
+    &.is-hovered,
+    &:focus,
+    &.is-focused
+      background-color: $button-text-hover-background-color
+      color: $button-text-hover-color
+    &:active,
+    &.is-active
+      background-color: darken($button-text-hover-background-color, 5%)
+      color: $button-text-hover-color
+    &[disabled],
+    fieldset[disabled] &
+      background-color: transparent
+      border-color: transparent
+      box-shadow: none
+  @each $name, $pair in $colors
+    $color: nth($pair, 1)
+    $color-invert: nth($pair, 2)
+    &.is-#{$name}
+      background-color: $color
+      border-color: transparent
+      color: $color-invert
+      &:hover,
+      &.is-hovered
+        background-color: darken($color, 2.5%)
+        border-color: transparent
+        color: $color-invert
+      &:focus,
+      &.is-focused
+        border-color: transparent
+        color: $color-invert
+        &:not(:active)
+          box-shadow: $button-focus-box-shadow-size rgba($color, 0.25)
+      &:active,
+      &.is-active
+        background-color: darken($color, 5%)
+        border-color: transparent
+        color: $color-invert
+      &[disabled],
+      fieldset[disabled] &
+        background-color: $color
+        border-color: transparent
+        box-shadow: none
+      &.is-inverted
+        background-color: $color-invert
+        color: $color
+        &:hover,
+        &.is-hovered
+          background-color: darken($color-invert, 5%)
+        &[disabled],
+        fieldset[disabled] &
+          background-color: $color-invert
+          border-color: transparent
+          box-shadow: none
+          color: $color
+      &.is-loading
+        &::after
+          border-color: transparent transparent $color-invert $color-invert !important
+      &.is-outlined
+        background-color: transparent
+        border-color: $color
+        color: $color
+        &:hover,
+        &.is-hovered,
+        &:focus,
+        &.is-focused
+          background-color: $color
+          border-color: $color
+          color: $color-invert
+        &.is-loading
+          &::after
+            border-color: transparent transparent $color $color !important
+          &:hover,
+          &.is-hovered,
+          &:focus,
+          &.is-focused
+            &::after
+              border-color: transparent transparent $color-invert $color-invert !important
+        &[disabled],
+        fieldset[disabled] &
+          background-color: transparent
+          border-color: $color
+          box-shadow: none
+          color: $color
+      &.is-inverted.is-outlined
+        background-color: transparent
+        border-color: $color-invert
+        color: $color-invert
+        &:hover,
+        &.is-hovered,
+        &:focus,
+        &.is-focused
+          background-color: $color-invert
+          color: $color
+        &.is-loading
+          &:hover,
+          &.is-hovered,
+          &:focus,
+          &.is-focused
+            &::after
+              border-color: transparent transparent $color $color !important
+        &[disabled],
+        fieldset[disabled] &
+          background-color: transparent
+          border-color: $color-invert
+          box-shadow: none
+          color: $color-invert
+  // Sizes
+  &.is-small
+    +button-small
+  &.is-normal
+    +button-normal
+  &.is-medium
+    +button-medium
+  &.is-large
+    +button-large
+  // Modifiers
+  &[disabled],
+  fieldset[disabled] &
+    background-color: $button-disabled-background-color
+    border-color: $button-disabled-border-color
+    box-shadow: $button-disabled-shadow
+    opacity: $button-disabled-opacity
+  &.is-fullwidth
+    display: flex
+    width: 100%
+  &.is-loading
+    color: transparent !important
+    pointer-events: none
+    &::after
+      @extend %loader
+      +center(1em)
+      position: absolute !important
+  &.is-static
+    background-color: $button-static-background-color
+    border-color: $button-static-border-color
+    color: $button-static-color
+    box-shadow: none
+    pointer-events: none
+  &.is-rounded
+    border-radius: $radius-rounded
+    padding-left: 1em
+    padding-right: 1em
+
+.buttons
+  align-items: center
+  display: flex
+  flex-wrap: wrap
+  justify-content: flex-start
+  .button
+    margin-bottom: 0.5rem
+    &:not(:last-child):not(.is-fullwidth)
+      margin-right: 0.5rem
+  &:last-child
+    margin-bottom: -0.5rem
+  &:not(:last-child)
+    margin-bottom: 1rem
+  // Sizes
+  &.are-small
+    .button:not(.is-normal):not(.is-medium):not(.is-large)
+      +button-small
+  &.are-medium
+    .button:not(.is-small):not(.is-normal):not(.is-large)
+      +button-medium
+  &.are-large
+    .button:not(.is-small):not(.is-normal):not(.is-medium)
+      +button-large
+  &.has-addons
+    .button
+      &:not(:first-child)
+        border-bottom-left-radius: 0
+        border-top-left-radius: 0
+      &:not(:last-child)
+        border-bottom-right-radius: 0
+        border-top-right-radius: 0
+        margin-right: -1px
+      &:last-child
+        margin-right: 0
+      &:hover,
+      &.is-hovered
+        z-index: 2
+      &:focus,
+      &.is-focused,
+      &:active,
+      &.is-active,
+      &.is-selected
+        z-index: 3
+        &:hover
+          z-index: 4
+      &.is-expanded
+        flex-grow: 1
+        flex-shrink: 1
+  &.is-centered
+    justify-content: center
+    &:not(.has-addons)
+      .button:not(.is-fullwidth)
+        margin-left: 0.25rem
+        margin-right: 0.25rem
+  &.is-right
+    justify-content: flex-end
+    &:not(.has-addons)
+      .button:not(.is-fullwidth)
+        margin-left: 0.25rem
+        margin-right: 0.25rem
diff -pruN 1.3.1+dfsg-1/debian/embedded/Documenter/assets/html/scss/bulma/elements/container.sass 1.4.0+dfsg-1/debian/embedded/Documenter/assets/html/scss/bulma/elements/container.sass
--- 1.3.1+dfsg-1/debian/embedded/Documenter/assets/html/scss/bulma/elements/container.sass	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/debian/embedded/Documenter/assets/html/scss/bulma/elements/container.sass	2020-03-30 16:16:04.000000000 +0000
@@ -0,0 +1,23 @@
+$container-offset: (2 * $gap) !default
+
+.container
+  flex-grow: 1
+  margin: 0 auto
+  position: relative
+  width: auto
+  +desktop
+    max-width: $desktop - $container-offset
+    &.is-fluid
+      margin-left: $gap
+      margin-right: $gap
+      max-width: none
+  +until-widescreen
+    &.is-widescreen
+      max-width: $widescreen - $container-offset
+  +until-fullhd
+    &.is-fullhd
+      max-width: $fullhd - $container-offset
+  +widescreen
+    max-width: $widescreen - $container-offset
+  +fullhd
+    max-width: $fullhd - $container-offset
diff -pruN 1.3.1+dfsg-1/debian/embedded/Documenter/assets/html/scss/bulma/elements/content.sass 1.4.0+dfsg-1/debian/embedded/Documenter/assets/html/scss/bulma/elements/content.sass
--- 1.3.1+dfsg-1/debian/embedded/Documenter/assets/html/scss/bulma/elements/content.sass	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/debian/embedded/Documenter/assets/html/scss/bulma/elements/content.sass	2020-03-30 16:16:04.000000000 +0000
@@ -0,0 +1,155 @@
+$content-heading-color: $text-strong !default
+$content-heading-weight: $weight-semibold !default
+$content-heading-line-height: 1.125 !default
+
+$content-blockquote-background-color: $background !default
+$content-blockquote-border-left: 5px solid $border !default
+$content-blockquote-padding: 1.25em 1.5em !default
+
+$content-pre-padding: 1.25em 1.5em !default
+
+$content-table-cell-border: 1px solid $border !default
+$content-table-cell-border-width: 0 0 1px !default
+$content-table-cell-padding: 0.5em 0.75em !default
+$content-table-cell-heading-color: $text-strong !default
+$content-table-head-cell-border-width: 0 0 2px !default
+$content-table-head-cell-color: $text-strong !default
+$content-table-foot-cell-border-width: 2px 0 0 !default
+$content-table-foot-cell-color: $text-strong !default
+
+.content
+  @extend %block
+  // Inline
+  li + li
+    margin-top: 0.25em
+  // Block
+  p,
+  dl,
+  ol,
+  ul,
+  blockquote,
+  pre,
+  table
+    &:not(:last-child)
+      margin-bottom: 1em
+  h1,
+  h2,
+  h3,
+  h4,
+  h5,
+  h6
+    color: $content-heading-color
+    font-weight: $content-heading-weight
+    line-height: $content-heading-line-height
+  h1
+    font-size: 2em
+    margin-bottom: 0.5em
+    &:not(:first-child)
+      margin-top: 1em
+  h2
+    font-size: 1.75em
+    margin-bottom: 0.5714em
+    &:not(:first-child)
+      margin-top: 1.1428em
+  h3
+    font-size: 1.5em
+    margin-bottom: 0.6666em
+    &:not(:first-child)
+      margin-top: 1.3333em
+  h4
+    font-size: 1.25em
+    margin-bottom: 0.8em
+  h5
+    font-size: 1.125em
+    margin-bottom: 0.8888em
+  h6
+    font-size: 1em
+    margin-bottom: 1em
+  blockquote
+    background-color: $content-blockquote-background-color
+    border-left: $content-blockquote-border-left
+    padding: $content-blockquote-padding
+  ol
+    list-style-position: outside
+    margin-left: 2em
+    margin-top: 1em
+    &:not([type])
+      list-style-type: decimal
+      &.is-lower-alpha
+        list-style-type: lower-alpha
+      &.is-lower-roman
+        list-style-type: lower-roman
+      &.is-upper-alpha
+        list-style-type: upper-alpha
+      &.is-upper-roman
+        list-style-type: upper-roman
+  ul
+    list-style: disc outside
+    margin-left: 2em
+    margin-top: 1em
+    ul
+      list-style-type: circle
+      margin-top: 0.5em
+      ul
+        list-style-type: square
+  dd
+    margin-left: 2em
+  figure
+    margin-left: 2em
+    margin-right: 2em
+    text-align: center
+    &:not(:first-child)
+      margin-top: 2em
+    &:not(:last-child)
+      margin-bottom: 2em
+    img
+      display: inline-block
+    figcaption
+      font-style: italic
+  pre
+    +overflow-touch
+    overflow-x: auto
+    padding: $content-pre-padding
+    white-space: pre
+    word-wrap: normal
+  sup,
+  sub
+    font-size: 75%
+  table
+    width: 100%
+    td,
+    th
+      border: $content-table-cell-border
+      border-width: $content-table-cell-border-width
+      padding: $content-table-cell-padding
+      vertical-align: top
+    th
+      color: $content-table-cell-heading-color
+      &:not([align])
+        text-align: left
+    thead
+      td,
+      th
+        border-width: $content-table-head-cell-border-width
+        color: $content-table-head-cell-color
+    tfoot
+      td,
+      th
+        border-width: $content-table-foot-cell-border-width
+        color: $content-table-foot-cell-color
+    tbody
+      tr
+        &:last-child
+          td,
+          th
+            border-bottom-width: 0
+  .tabs
+    li + li
+      margin-top: 0
+  // Sizes
+  &.is-small
+    font-size: $size-small
+  &.is-medium
+    font-size: $size-medium
+  &.is-large
+    font-size: $size-large
diff -pruN 1.3.1+dfsg-1/debian/embedded/Documenter/assets/html/scss/bulma/elements/form.sass 1.4.0+dfsg-1/debian/embedded/Documenter/assets/html/scss/bulma/elements/form.sass
--- 1.3.1+dfsg-1/debian/embedded/Documenter/assets/html/scss/bulma/elements/form.sass	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/debian/embedded/Documenter/assets/html/scss/bulma/elements/form.sass	2020-03-30 16:16:04.000000000 +0000
@@ -0,0 +1 @@
+@warn "The form.sass file is DEPRECATED. It has moved into its own /form folder. Please import sass/form/_all instead."
diff -pruN 1.3.1+dfsg-1/debian/embedded/Documenter/assets/html/scss/bulma/elements/icon.sass 1.4.0+dfsg-1/debian/embedded/Documenter/assets/html/scss/bulma/elements/icon.sass
--- 1.3.1+dfsg-1/debian/embedded/Documenter/assets/html/scss/bulma/elements/icon.sass	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/debian/embedded/Documenter/assets/html/scss/bulma/elements/icon.sass	2020-03-30 16:16:04.000000000 +0000
@@ -0,0 +1,21 @@
+$icon-dimensions: 1.5rem !default
+$icon-dimensions-small: 1rem !default
+$icon-dimensions-medium: 2rem !default
+$icon-dimensions-large: 3rem !default
+
+.icon
+  align-items: center
+  display: inline-flex
+  justify-content: center
+  height: $icon-dimensions
+  width: $icon-dimensions
+  // Sizes
+  &.is-small
+    height: $icon-dimensions-small
+    width: $icon-dimensions-small
+  &.is-medium
+    height: $icon-dimensions-medium
+    width: $icon-dimensions-medium
+  &.is-large
+    height: $icon-dimensions-large
+    width: $icon-dimensions-large
diff -pruN 1.3.1+dfsg-1/debian/embedded/Documenter/assets/html/scss/bulma/elements/image.sass 1.4.0+dfsg-1/debian/embedded/Documenter/assets/html/scss/bulma/elements/image.sass
--- 1.3.1+dfsg-1/debian/embedded/Documenter/assets/html/scss/bulma/elements/image.sass	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/debian/embedded/Documenter/assets/html/scss/bulma/elements/image.sass	2020-03-30 16:16:04.000000000 +0000
@@ -0,0 +1,69 @@
+$dimensions: 16 24 32 48 64 96 128 !default
+
+.image
+  display: block
+  position: relative
+  img
+    display: block
+    height: auto
+    width: 100%
+    &.is-rounded
+      border-radius: $radius-rounded
+  // Ratio
+  &.is-square,
+  &.is-1by1,
+  &.is-5by4,
+  &.is-4by3,
+  &.is-3by2,
+  &.is-5by3,
+  &.is-16by9,
+  &.is-2by1,
+  &.is-3by1,
+  &.is-4by5,
+  &.is-3by4,
+  &.is-2by3,
+  &.is-3by5,
+  &.is-9by16,
+  &.is-1by2,
+  &.is-1by3
+    img,
+    .has-ratio
+      @extend %overlay
+      height: 100%
+      width: 100%
+  &.is-square,
+  &.is-1by1
+    padding-top: 100%
+  &.is-5by4
+    padding-top: 80%
+  &.is-4by3
+    padding-top: 75%
+  &.is-3by2
+    padding-top: 66.6666%
+  &.is-5by3
+    padding-top: 60%
+  &.is-16by9
+    padding-top: 56.25%
+  &.is-2by1
+    padding-top: 50%
+  &.is-3by1
+    padding-top: 33.3333%
+  &.is-4by5
+    padding-top: 125%
+  &.is-3by4
+    padding-top: 133.3333%
+  &.is-2by3
+    padding-top: 150%
+  &.is-3by5
+    padding-top: 166.6666%
+  &.is-9by16
+    padding-top: 177.7777%
+  &.is-1by2
+    padding-top: 200%
+  &.is-1by3
+    padding-top: 300%
+  // Sizes
+  @each $dimension in $dimensions
+    &.is-#{$dimension}x#{$dimension}
+      height: $dimension * 1px
+      width: $dimension * 1px
diff -pruN 1.3.1+dfsg-1/debian/embedded/Documenter/assets/html/scss/bulma/elements/notification.sass 1.4.0+dfsg-1/debian/embedded/Documenter/assets/html/scss/bulma/elements/notification.sass
--- 1.3.1+dfsg-1/debian/embedded/Documenter/assets/html/scss/bulma/elements/notification.sass	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/debian/embedded/Documenter/assets/html/scss/bulma/elements/notification.sass	2020-03-30 16:16:04.000000000 +0000
@@ -0,0 +1,35 @@
+$notification-background-color: $background !default
+$notification-radius: $radius !default
+$notification-padding: 1.25rem 2.5rem 1.25rem 1.5rem !default
+
+.notification
+  @extend %block
+  background-color: $notification-background-color
+  border-radius: $notification-radius
+  padding: $notification-padding
+  position: relative
+  a:not(.button):not(.dropdown-item)
+    color: currentColor
+    text-decoration: underline
+  strong
+    color: currentColor
+  code,
+  pre
+    background: $white
+  pre code
+    background: transparent
+  & > .delete
+    position: absolute
+    right: 0.5rem
+    top: 0.5rem
+  .title,
+  .subtitle,
+  .content
+    color: currentColor
+  // Colors
+  @each $name, $pair in $colors
+    $color: nth($pair, 1)
+    $color-invert: nth($pair, 2)
+    &.is-#{$name}
+      background-color: $color
+      color: $color-invert
diff -pruN 1.3.1+dfsg-1/debian/embedded/Documenter/assets/html/scss/bulma/elements/other.sass 1.4.0+dfsg-1/debian/embedded/Documenter/assets/html/scss/bulma/elements/other.sass
--- 1.3.1+dfsg-1/debian/embedded/Documenter/assets/html/scss/bulma/elements/other.sass	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/debian/embedded/Documenter/assets/html/scss/bulma/elements/other.sass	2020-03-30 16:16:04.000000000 +0000
@@ -0,0 +1,39 @@
+.block
+  @extend %block
+
+.delete
+  @extend %delete
+
+.heading
+  display: block
+  font-size: 11px
+  letter-spacing: 1px
+  margin-bottom: 5px
+  text-transform: uppercase
+
+.highlight
+  @extend %block
+  font-weight: $weight-normal
+  max-width: 100%
+  overflow: hidden
+  padding: 0
+  pre
+    overflow: auto
+    max-width: 100%
+
+.loader
+  @extend %loader
+
+.number
+  align-items: center
+  background-color: $background
+  border-radius: $radius-rounded
+  display: inline-flex
+  font-size: $size-medium
+  height: 2em
+  justify-content: center
+  margin-right: 1.5rem
+  min-width: 2.5em
+  padding: 0.25rem 0.5rem
+  text-align: center
+  vertical-align: top
diff -pruN 1.3.1+dfsg-1/debian/embedded/Documenter/assets/html/scss/bulma/elements/progress.sass 1.4.0+dfsg-1/debian/embedded/Documenter/assets/html/scss/bulma/elements/progress.sass
--- 1.3.1+dfsg-1/debian/embedded/Documenter/assets/html/scss/bulma/elements/progress.sass	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/debian/embedded/Documenter/assets/html/scss/bulma/elements/progress.sass	2020-03-30 16:16:04.000000000 +0000
@@ -0,0 +1,67 @@
+$progress-bar-background-color: $border !default
+$progress-value-background-color: $text !default
+$progress-border-radius: $radius-rounded !default
+
+$progress-indeterminate-duration: 1.5s !default
+
+.progress
+  @extend %block
+  -moz-appearance: none
+  -webkit-appearance: none
+  border: none
+  border-radius: $progress-border-radius
+  display: block
+  height: $size-normal
+  overflow: hidden
+  padding: 0
+  width: 100%
+  &::-webkit-progress-bar
+    background-color: $progress-bar-background-color
+  &::-webkit-progress-value
+    background-color: $progress-value-background-color
+  &::-moz-progress-bar
+    background-color: $progress-value-background-color
+  &::-ms-fill
+    background-color: $progress-value-background-color
+    border: none
+  // Colors
+  @each $name, $pair in $colors
+    $color: nth($pair, 1)
+    &.is-#{$name}
+      &::-webkit-progress-value
+        background-color: $color
+      &::-moz-progress-bar
+        background-color: $color
+      &::-ms-fill
+        background-color: $color
+      &:indeterminate
+        background-image: linear-gradient(to right, $color 30%, $progress-bar-background-color 30%)
+
+  &:indeterminate
+    animation-duration: $progress-indeterminate-duration
+    animation-iteration-count: infinite
+    animation-name: moveIndeterminate
+    animation-timing-function: linear
+    background-color: $progress-bar-background-color
+    background-image: linear-gradient(to right, $text 30%, $progress-bar-background-color 30%)
+    background-position: top left
+    background-repeat: no-repeat
+    background-size: 150% 150%
+    &::-webkit-progress-bar
+      background-color: transparent
+    &::-moz-progress-bar
+      background-color: transparent
+
+  // Sizes
+  &.is-small
+    height: $size-small
+  &.is-medium
+    height: $size-medium
+  &.is-large
+    height: $size-large
+
+@keyframes moveIndeterminate
+  from
+    background-position: 200% 0
+  to
+    background-position: -200% 0
diff -pruN 1.3.1+dfsg-1/debian/embedded/Documenter/assets/html/scss/bulma/elements/table.sass 1.4.0+dfsg-1/debian/embedded/Documenter/assets/html/scss/bulma/elements/table.sass
--- 1.3.1+dfsg-1/debian/embedded/Documenter/assets/html/scss/bulma/elements/table.sass	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/debian/embedded/Documenter/assets/html/scss/bulma/elements/table.sass	2020-03-30 16:16:04.000000000 +0000
@@ -0,0 +1,127 @@
+$table-color: $grey-darker !default
+$table-background-color: $white !default
+
+$table-cell-border: 1px solid $grey-lighter !default
+$table-cell-border-width: 0 0 1px !default
+$table-cell-padding: 0.5em 0.75em !default
+$table-cell-heading-color: $text-strong !default
+
+$table-head-cell-border-width: 0 0 2px !default
+$table-head-cell-color: $text-strong !default
+$table-foot-cell-border-width: 2px 0 0 !default
+$table-foot-cell-color: $text-strong !default
+
+$table-head-background-color: transparent !default
+$table-body-background-color: transparent !default
+$table-foot-background-color: transparent !default
+
+$table-row-hover-background-color: $white-bis !default
+
+$table-row-active-background-color: $primary !default
+$table-row-active-color: $primary-invert !default
+
+$table-striped-row-even-background-color: $white-bis !default
+$table-striped-row-even-hover-background-color: $white-ter !default
+
+.table
+  @extend %block
+  background-color: $table-background-color
+  color: $table-color
+  td,
+  th
+    border: $table-cell-border
+    border-width: $table-cell-border-width
+    padding: $table-cell-padding
+    vertical-align: top
+    // Colors
+    @each $name, $pair in $colors
+      $color: nth($pair, 1)
+      $color-invert: nth($pair, 2)
+      &.is-#{$name}
+        background-color: $color
+        border-color: $color
+        color: $color-invert
+    // Modifiers
+    &.is-narrow
+      white-space: nowrap
+      width: 1%
+    &.is-selected
+      background-color: $table-row-active-background-color
+      color: $table-row-active-color
+      a,
+      strong
+        color: currentColor
+  th
+    color: $table-cell-heading-color
+    &:not([align])
+      text-align: left
+  tr
+    &.is-selected
+      background-color: $table-row-active-background-color
+      color: $table-row-active-color
+      a,
+      strong
+        color: currentColor
+      td,
+      th
+        border-color: $table-row-active-color
+        color: currentColor
+  thead
+    background-color: $table-head-background-color
+    td,
+    th
+      border-width: $table-head-cell-border-width
+      color: $table-head-cell-color
+  tfoot
+    background-color: $table-foot-background-color
+    td,
+    th
+      border-width: $table-foot-cell-border-width
+      color: $table-foot-cell-color
+  tbody
+    background-color: $table-body-background-color
+    tr
+      &:last-child
+        td,
+        th
+          border-bottom-width: 0
+  // Modifiers
+  &.is-bordered
+    td,
+    th
+      border-width: 1px
+    tr
+      &:last-child
+        td,
+        th
+          border-bottom-width: 1px
+  &.is-fullwidth
+    width: 100%
+  &.is-hoverable
+    tbody
+      tr:not(.is-selected)
+        &:hover
+          background-color: $table-row-hover-background-color
+    &.is-striped
+      tbody
+        tr:not(.is-selected)
+          &:hover
+            background-color: $table-row-hover-background-color
+            &:nth-child(even)
+              background-color: $table-striped-row-even-hover-background-color
+  &.is-narrow
+    td,
+    th
+      padding: 0.25em 0.5em
+  &.is-striped
+    tbody
+      tr:not(.is-selected)
+        &:nth-child(even)
+          background-color: $table-striped-row-even-background-color
+
+.table-container
+  @extend %block
+  +overflow-touch
+  overflow: auto
+  overflow-y: hidden
+  max-width: 100%
diff -pruN 1.3.1+dfsg-1/debian/embedded/Documenter/assets/html/scss/bulma/elements/tag.sass 1.4.0+dfsg-1/debian/embedded/Documenter/assets/html/scss/bulma/elements/tag.sass
--- 1.3.1+dfsg-1/debian/embedded/Documenter/assets/html/scss/bulma/elements/tag.sass	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/debian/embedded/Documenter/assets/html/scss/bulma/elements/tag.sass	2020-03-30 16:16:04.000000000 +0000
@@ -0,0 +1,121 @@
+$tag-background-color: $background !default
+$tag-color: $text !default
+$tag-radius: $radius !default
+$tag-delete-margin: 1px !default
+
+.tags
+  align-items: center
+  display: flex
+  flex-wrap: wrap
+  justify-content: flex-start
+  .tag
+    margin-bottom: 0.5rem
+    &:not(:last-child)
+      margin-right: 0.5rem
+  &:last-child
+    margin-bottom: -0.5rem
+  &:not(:last-child)
+    margin-bottom: 1rem
+  // Sizes
+  &.are-medium
+    .tag:not(.is-normal):not(.is-large)
+      font-size: $size-normal
+  &.are-large
+    .tag:not(.is-normal):not(.is-medium)
+      font-size: $size-medium
+  &.is-centered
+    justify-content: center
+    .tag
+      margin-right: 0.25rem
+      margin-left: 0.25rem
+  &.is-right
+    justify-content: flex-end
+    .tag
+      &:not(:first-child)
+        margin-left: 0.5rem
+      &:not(:last-child)
+        margin-right: 0
+  &.has-addons
+    .tag
+      margin-right: 0
+      &:not(:first-child)
+        margin-left: 0
+        border-bottom-left-radius: 0
+        border-top-left-radius: 0
+      &:not(:last-child)
+        border-bottom-right-radius: 0
+        border-top-right-radius: 0
+
+.tag:not(body)
+  align-items: center
+  background-color: $tag-background-color
+  border-radius: $tag-radius
+  color: $tag-color
+  display: inline-flex
+  font-size: $size-small
+  height: 2em
+  justify-content: center
+  line-height: 1.5
+  padding-left: 0.75em
+  padding-right: 0.75em
+  white-space: nowrap
+  .delete
+    margin-left: 0.25rem
+    margin-right: -0.375rem
+  // Colors
+  @each $name, $pair in $colors
+    $color: nth($pair, 1)
+    $color-invert: nth($pair, 2)
+    &.is-#{$name}
+      background-color: $color
+      color: $color-invert
+  // Sizes
+  &.is-normal
+    font-size: $size-small
+  &.is-medium
+    font-size: $size-normal
+  &.is-large
+    font-size: $size-medium
+  .icon
+    &:first-child:not(:last-child)
+      margin-left: -0.375em
+      margin-right: 0.1875em
+    &:last-child:not(:first-child)
+      margin-left: 0.1875em
+      margin-right: -0.375em
+    &:first-child:last-child
+      margin-left: -0.375em
+      margin-right: -0.375em
+  // Modifiers
+  &.is-delete
+    margin-left: $tag-delete-margin
+    padding: 0
+    position: relative
+    width: 2em
+    &::before,
+    &::after
+      background-color: currentColor
+      content: ""
+      display: block
+      left: 50%
+      position: absolute
+      top: 50%
+      transform: translateX(-50%) translateY(-50%) rotate(45deg)
+      transform-origin: center center
+    &::before
+      height: 1px
+      width: 50%
+    &::after
+      height: 50%
+      width: 1px
+    &:hover,
+    &:focus
+      background-color: darken($tag-background-color, 5%)
+    &:active
+      background-color: darken($tag-background-color, 10%)
+  &.is-rounded
+    border-radius: $radius-rounded
+
+a.tag
+  &:hover
+    text-decoration: underline
diff -pruN 1.3.1+dfsg-1/debian/embedded/Documenter/assets/html/scss/bulma/elements/title.sass 1.4.0+dfsg-1/debian/embedded/Documenter/assets/html/scss/bulma/elements/title.sass
--- 1.3.1+dfsg-1/debian/embedded/Documenter/assets/html/scss/bulma/elements/title.sass	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/debian/embedded/Documenter/assets/html/scss/bulma/elements/title.sass	2020-03-30 16:16:04.000000000 +0000
@@ -0,0 +1,70 @@
+$title-color: $grey-darker !default
+$title-family: false !default
+$title-size: $size-3 !default
+$title-weight: $weight-semibold !default
+$title-line-height: 1.125 !default
+$title-strong-color: inherit !default
+$title-strong-weight: inherit !default
+$title-sub-size: 0.75em !default
+$title-sup-size: 0.75em !default
+
+$subtitle-color: $grey-dark !default
+$subtitle-family: false !default
+$subtitle-size: $size-5 !default
+$subtitle-weight: $weight-normal !default
+$subtitle-line-height: 1.25 !default
+$subtitle-strong-color: $grey-darker !default
+$subtitle-strong-weight: $weight-semibold !default
+$subtitle-negative-margin: -1.25rem !default
+
+.title,
+.subtitle
+  @extend %block
+  word-break: break-word
+  em,
+  span
+    font-weight: inherit
+  sub
+    font-size: $title-sub-size
+  sup
+    font-size: $title-sup-size
+  .tag
+    vertical-align: middle
+
+.title
+  color: $title-color
+  @if $title-family
+    font-family: $title-family
+  font-size: $title-size
+  font-weight: $title-weight
+  line-height: $title-line-height
+  strong
+    color: $title-strong-color
+    font-weight: $title-strong-weight
+  & + .highlight
+    margin-top: -0.75rem
+  &:not(.is-spaced) + .subtitle
+    margin-top: $subtitle-negative-margin
+  // Sizes
+  @each $size in $sizes
+    $i: index($sizes, $size)
+    &.is-#{$i}
+      font-size: $size
+
+.subtitle
+  color: $subtitle-color
+  @if $subtitle-family
+    font-family: $subtitle-family
+  font-size: $subtitle-size
+  font-weight: $subtitle-weight
+  line-height: $subtitle-line-height
+  strong
+    color: $subtitle-strong-color
+    font-weight: $subtitle-strong-weight
+  &:not(.is-spaced) + .title
+    margin-top: $subtitle-negative-margin
+  // Sizes
+  @each $size in $sizes
+    $i: index($sizes, $size)
+    &.is-#{$i}
+      font-size: $size
diff -pruN 1.3.1+dfsg-1/debian/embedded/Documenter/assets/html/scss/bulma/form/_all.sass 1.4.0+dfsg-1/debian/embedded/Documenter/assets/html/scss/bulma/form/_all.sass
--- 1.3.1+dfsg-1/debian/embedded/Documenter/assets/html/scss/bulma/form/_all.sass	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/debian/embedded/Documenter/assets/html/scss/bulma/form/_all.sass	2020-03-30 16:16:04.000000000 +0000
@@ -0,0 +1,8 @@
+@charset "utf-8"
+
+@import "shared.sass"
+@import "input-textarea.sass"
+@import "checkbox-radio.sass"
+@import "select.sass"
+@import "file.sass"
+@import "tools.sass"
diff -pruN 1.3.1+dfsg-1/debian/embedded/Documenter/assets/html/scss/bulma/form/checkbox-radio.sass 1.4.0+dfsg-1/debian/embedded/Documenter/assets/html/scss/bulma/form/checkbox-radio.sass
--- 1.3.1+dfsg-1/debian/embedded/Documenter/assets/html/scss/bulma/form/checkbox-radio.sass	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/debian/embedded/Documenter/assets/html/scss/bulma/form/checkbox-radio.sass	2020-03-30 16:16:04.000000000 +0000
@@ -0,0 +1,21 @@
+%checkbox-radio
+  cursor: pointer
+  display: inline-block
+  line-height: 1.25
+  position: relative
+  input
+    cursor: pointer
+  &:hover
+    color: $input-hover-color
+  &[disabled],
+  fieldset[disabled] &
+    color: $input-disabled-color
+    cursor: not-allowed
+
+.checkbox
+  @extend %checkbox-radio
+
+.radio
+  @extend %checkbox-radio
+  & + .radio
+    margin-left: 0.5em
diff -pruN 1.3.1+dfsg-1/debian/embedded/Documenter/assets/html/scss/bulma/form/file.sass 1.4.0+dfsg-1/debian/embedded/Documenter/assets/html/scss/bulma/form/file.sass
--- 1.3.1+dfsg-1/debian/embedded/Documenter/assets/html/scss/bulma/form/file.sass	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/debian/embedded/Documenter/assets/html/scss/bulma/form/file.sass	2020-03-30 16:16:04.000000000 +0000
@@ -0,0 +1,180 @@
+$file-border-color: $border !default
+$file-radius: $radius !default
+
+$file-cta-background-color: $white-ter !default
+$file-cta-color: $grey-dark !default
+$file-cta-hover-color: $grey-darker !default
+$file-cta-active-color: $grey-darker !default
+
+$file-name-border-color: $border !default
+$file-name-border-style: solid !default
+$file-name-border-width: 1px 1px 1px 0 !default
+$file-name-max-width: 16em !default
+
+.file
+  @extend %unselectable
+  align-items: stretch
+  display: flex
+  justify-content: flex-start
+  position: relative
+  // Colors
+  @each $name, $pair in $colors
+    $color: nth($pair, 1)
+    $color-invert: nth($pair, 2)
+    &.is-#{$name}
+      .file-cta
+        background-color: $color
+        border-color: transparent
+        color: $color-invert
+      &:hover,
+      &.is-hovered
+        .file-cta
+          background-color: darken($color, 2.5%)
+          border-color: transparent
+          color: $color-invert
+      &:focus,
+      &.is-focused
+        .file-cta
+          border-color: transparent
+          box-shadow: 0 0 0.5em rgba($color, 0.25)
+          color: $color-invert
+      &:active,
+      &.is-active
+        .file-cta
+          background-color: darken($color, 5%)
+          border-color: transparent
+          color: $color-invert
+  // Sizes
+  &.is-small
+    font-size: $size-small
+  &.is-medium
+    font-size: $size-medium
+    .file-icon
+      .fa
+        font-size: 21px
+  &.is-large
+    font-size: $size-large
+    .file-icon
+      .fa
+        font-size: 28px
+  // Modifiers
+  &.has-name
+    .file-cta
+      border-bottom-right-radius: 0
+      border-top-right-radius: 0
+    .file-name
+      border-bottom-left-radius: 0
+      border-top-left-radius: 0
+    &.is-empty
+      .file-cta
+        border-radius: $file-radius
+      .file-name
+        display: none
+  &.is-boxed
+    .file-label
+      flex-direction: column
+    .file-cta
+      flex-direction: column
+      height: auto
+      padding: 1em 3em
+    .file-name
+      border-width: 0 1px 1px
+    .file-icon
+      height: 1.5em
+      width: 1.5em
+      .fa
+        font-size: 21px
+    &.is-small
+      .file-icon .fa
+        font-size: 14px
+    &.is-medium
+      .file-icon .fa
+        font-size: 28px
+    &.is-large
+      .file-icon .fa
+        font-size: 35px
+    &.has-name
+      .file-cta
+        border-radius: $file-radius $file-radius 0 0
+      .file-name
+        border-radius: 0 0 $file-radius $file-radius
+        border-width: 0 1px 1px
+  &.is-centered
+    justify-content: center
+  &.is-fullwidth
+    .file-label
+      width: 100%
+    .file-name
+      flex-grow: 1
+      max-width: none
+  &.is-right
+    justify-content: flex-end
+    .file-cta
+      border-radius: 0 $file-radius $file-radius 0
+    .file-name
+      border-radius: $file-radius 0 0 $file-radius
+      border-width: 1px 0 1px 1px
+      order: -1
+
+.file-label
+  align-items: stretch
+  display: flex
+  cursor: pointer
+  justify-content: flex-start
+  overflow: hidden
+  position: relative
+  &:hover
+    .file-cta
+      background-color: darken($file-cta-background-color, 2.5%)
+      color: $file-cta-hover-color
+    .file-name
+      border-color: darken($file-name-border-color, 2.5%)
+  &:active
+    .file-cta
+      background-color: darken($file-cta-background-color, 5%)
+      color: $file-cta-active-color
+    .file-name
+      border-color: darken($file-name-border-color, 5%)
+
+.file-input
+  height: 100%
+  left: 0
+  opacity: 0
+  outline: none
+  position: absolute
+  top: 0
+  width: 100%
+
+.file-cta,
+.file-name
+  @extend %control
+  border-color: $file-border-color
+  border-radius: $file-radius
+  font-size: 1em
+  padding-left: 1em
+  padding-right: 1em
+  white-space: nowrap
+
+.file-cta
+  background-color: $file-cta-background-color
+  color: $file-cta-color
+
+.file-name
+  border-color: $file-name-border-color
+  border-style: $file-name-border-style
+  border-width: $file-name-border-width
+  display: block
+  max-width: $file-name-max-width
+  overflow: hidden
+  text-align: left
+  text-overflow: ellipsis
+
+.file-icon
+  align-items: center
+  display: flex
+  height: 1em
+  justify-content: center
+  margin-right: 0.5em
+  width: 1em
+  .fa
+    font-size: 14px
diff -pruN 1.3.1+dfsg-1/debian/embedded/Documenter/assets/html/scss/bulma/form/input-textarea.sass 1.4.0+dfsg-1/debian/embedded/Documenter/assets/html/scss/bulma/form/input-textarea.sass
--- 1.3.1+dfsg-1/debian/embedded/Documenter/assets/html/scss/bulma/form/input-textarea.sass	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/debian/embedded/Documenter/assets/html/scss/bulma/form/input-textarea.sass	2020-03-30 16:16:04.000000000 +0000
@@ -0,0 +1,60 @@
+%input-textarea
+  @extend %input
+  box-shadow: $input-shadow
+  max-width: 100%
+  width: 100%
+  &[readonly]
+    box-shadow: none
+  // Colors
+  @each $name, $pair in $colors
+    $color: nth($pair, 1)
+    &.is-#{$name}
+      border-color: $color
+      &:focus,
+      &.is-focused,
+      &:active,
+      &.is-active
+        box-shadow: $input-focus-box-shadow-size rgba($color, 0.25)
+  // Sizes
+  &.is-small
+    +control-small
+  &.is-medium
+    +control-medium
+  &.is-large
+    +control-large
+  // Modifiers
+  &.is-fullwidth
+    display: block
+    width: 100%
+  &.is-inline
+    display: inline
+    width: auto
+
+.input
+  @extend %input-textarea
+  &.is-rounded
+    border-radius: $radius-rounded
+    padding-left: 1em
+    padding-right: 1em
+  &.is-static
+    background-color: transparent
+    border-color: transparent
+    box-shadow: none
+    padding-left: 0
+    padding-right: 0
+
+.textarea
+  @extend %input-textarea
+  display: block
+  max-width: 100%
+  min-width: 100%
+  padding: 0.625em
+  resize: vertical
+  &:not([rows])
+    max-height: 600px
+    min-height: 120px
+  &[rows]
+    height: initial
+  // Modifiers
+  &.has-fixed-size
+    resize: none
diff -pruN 1.3.1+dfsg-1/debian/embedded/Documenter/assets/html/scss/bulma/form/select.sass 1.4.0+dfsg-1/debian/embedded/Documenter/assets/html/scss/bulma/form/select.sass
--- 1.3.1+dfsg-1/debian/embedded/Documenter/assets/html/scss/bulma/form/select.sass	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/debian/embedded/Documenter/assets/html/scss/bulma/form/select.sass	2020-03-30 16:16:04.000000000 +0000
@@ -0,0 +1,85 @@
+.select
+  display: inline-block
+  max-width: 100%
+  position: relative
+  vertical-align: top
+  &:not(.is-multiple)
+    height: $input-height
+  &:not(.is-multiple):not(.is-loading)
+    &::after
+      @extend %arrow
+      border-color: $input-arrow
+      right: 1.125em
+      z-index: 4
+  &.is-rounded
+    select
+      border-radius: $radius-rounded
+      padding-left: 1em
+  select
+    @extend %input
+    cursor: pointer
+    display: block
+    font-size: 1em
+    max-width: 100%
+    outline: none
+    &::-ms-expand
+      display: none
+    &[disabled]:hover,
+    fieldset[disabled] &:hover
+      border-color: $input-disabled-border-color
+    &:not([multiple])
+      padding-right: 2.5em
+    &[multiple]
+      height: auto
+      padding: 0
+      option
+        padding: 0.5em 1em
+  // States
+  &:not(.is-multiple):not(.is-loading):hover
+    &::after
+      border-color: $input-hover-color
+  // Colors
+  @each $name, $pair in $colors
+    $color: nth($pair, 1)
+    &.is-#{$name}
+      &:not(:hover)::after
+        border-color: $color
+      select
+        border-color: $color
+        &:hover,
+        &.is-hovered
+          border-color: darken($color, 5%)
+        &:focus,
+        &.is-focused,
+        &:active,
+        &.is-active
+          box-shadow: $input-focus-box-shadow-size rgba($color, 0.25)
+  // Sizes
+  &.is-small
+    +control-small
+  &.is-medium
+    +control-medium
+  &.is-large
+    +control-large
+  // Modifiers
+  &.is-disabled
+    &::after
+      border-color: $input-disabled-color
+  &.is-fullwidth
+    width: 100%
+    select
+      width: 100%
+  &.is-loading
+    &::after
+      @extend %loader
+      margin-top: 0
+      position: absolute
+      right: 0.625em
+      top: 0.625em
+      transform: none
+    &.is-small:after
+      font-size: $size-small
+    &.is-medium:after
+      font-size: $size-medium
+    &.is-large:after
+      font-size: $size-large
diff -pruN 1.3.1+dfsg-1/debian/embedded/Documenter/assets/html/scss/bulma/form/shared.sass 1.4.0+dfsg-1/debian/embedded/Documenter/assets/html/scss/bulma/form/shared.sass
--- 1.3.1+dfsg-1/debian/embedded/Documenter/assets/html/scss/bulma/form/shared.sass	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/debian/embedded/Documenter/assets/html/scss/bulma/form/shared.sass	2020-03-30 16:16:04.000000000 +0000
@@ -0,0 +1,55 @@
+$input-color: $grey-darker !default
+$input-background-color: $white !default
+$input-border-color: $grey-lighter !default
+$input-height: $control-height !default
+$input-shadow: inset 0 1px 2px rgba($black, 0.1) !default
+$input-placeholder-color: rgba($input-color, 0.3) !default
+
+$input-hover-color: $grey-darker !default
+$input-hover-border-color: $grey-light !default
+
+$input-focus-color: $grey-darker !default
+$input-focus-border-color: $link !default
+$input-focus-box-shadow-size: 0 0 0 0.125em !default
+$input-focus-box-shadow-color: rgba($link, 0.25) !default
+
+$input-disabled-color: $text-light !default
+$input-disabled-background-color: $background !default
+$input-disabled-border-color: $background !default
+$input-disabled-placeholder-color: rgba($input-disabled-color, 0.3) !default
+
+$input-arrow: $link !default
+
+$input-icon-color: $grey-lighter !default
+$input-icon-active-color: $grey !default
+
+$input-radius: $radius !default
+
+=input
+  @extend %control
+  background-color: $input-background-color
+  border-color: $input-border-color
+  border-radius: $input-radius
+  color: $input-color
+  +placeholder
+    color: $input-placeholder-color
+  &:hover,
+  &.is-hovered
+    border-color: $input-hover-border-color
+  &:focus,
+  &.is-focused,
+  &:active,
+  &.is-active
+    border-color: $input-focus-border-color
+    box-shadow: $input-focus-box-shadow-size $input-focus-box-shadow-color
+  &[disabled],
+  fieldset[disabled] &
+    background-color: $input-disabled-background-color
+    border-color: $input-disabled-border-color
+    box-shadow: none
+    color: $input-disabled-color
+    +placeholder
+      color: $input-disabled-placeholder-color
+
+%input
+  +input
diff -pruN 1.3.1+dfsg-1/debian/embedded/Documenter/assets/html/scss/bulma/form/tools.sass 1.4.0+dfsg-1/debian/embedded/Documenter/assets/html/scss/bulma/form/tools.sass
--- 1.3.1+dfsg-1/debian/embedded/Documenter/assets/html/scss/bulma/form/tools.sass	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/debian/embedded/Documenter/assets/html/scss/bulma/form/tools.sass	2020-03-30 16:16:04.000000000 +0000
@@ -0,0 +1,205 @@
+$label-color: $grey-darker !default
+$label-weight: $weight-bold !default
+
+$help-size: $size-small !default
+
+.label
+  color: $label-color
+  display: block
+  font-size: $size-normal
+  font-weight: $label-weight
+  &:not(:last-child)
+    margin-bottom: 0.5em
+  // Sizes
+  &.is-small
+    font-size: $size-small
+  &.is-medium
+    font-size: $size-medium
+  &.is-large
+    font-size: $size-large
+
+.help
+  display: block
+  font-size: $help-size
+  margin-top: 0.25rem
+  @each $name, $pair in $colors
+    $color: nth($pair, 1)
+    &.is-#{$name}
+      color: $color
+
+// Containers
+
+.field
+  &:not(:last-child)
+    margin-bottom: 0.75rem
+  // Modifiers
+  &.has-addons
+    display: flex
+    justify-content: flex-start
+    .control
+      &:not(:last-child)
+        margin-right: -1px
+      &:not(:first-child):not(:last-child)
+        .button,
+        .input,
+        .select select
+          border-radius: 0
+      &:first-child:not(:only-child)
+        .button,
+        .input,
+        .select select
+          border-bottom-right-radius: 0
+          border-top-right-radius: 0
+      &:last-child:not(:only-child)
+        .button,
+        .input,
+        .select select
+          border-bottom-left-radius: 0
+          border-top-left-radius: 0
+      .button,
+      .input,
+      .select select
+        &:not([disabled])
+          &:hover,
+          &.is-hovered
+            z-index: 2
+          &:focus,
+          &.is-focused,
+          &:active,
+          &.is-active
+            z-index: 3
+            &:hover
+              z-index: 4
+      &.is-expanded
+        flex-grow: 1
+        flex-shrink: 1
+    &.has-addons-centered
+      justify-content: center
+    &.has-addons-right
+      justify-content: flex-end
+    &.has-addons-fullwidth
+      .control
+        flex-grow: 1
+        flex-shrink: 0
+  &.is-grouped
+    display: flex
+    justify-content: flex-start
+    & > .control
+      flex-shrink: 0
+      &:not(:last-child)
+        margin-bottom: 0
+        margin-right: 0.75rem
+      &.is-expanded
+        flex-grow: 1
+        flex-shrink: 1
+    &.is-grouped-centered
+      justify-content: center
+    &.is-grouped-right
+      justify-content: flex-end
+    &.is-grouped-multiline
+      flex-wrap: wrap
+      & > .control
+        &:last-child,
+        &:not(:last-child)
+          margin-bottom: 0.75rem
+      &:last-child
+        margin-bottom: -0.75rem
+      &:not(:last-child)
+        margin-bottom: 0
+  &.is-horizontal
+    +tablet
+      display: flex
+
+.field-label
+  .label
+    font-size: inherit
+  +mobile
+    margin-bottom: 0.5rem
+  +tablet
+    flex-basis: 0
+    flex-grow: 1
+    flex-shrink: 0
+    margin-right: 1.5rem
+    text-align: right
+    &.is-small
+      font-size: $size-small
+      padding-top: 0.375em
+    &.is-normal
+      padding-top: 0.375em
+    &.is-medium
+      font-size: $size-medium
+      padding-top: 0.375em
+    &.is-large
+      font-size: $size-large
+      padding-top: 0.375em
+
+.field-body
+  .field .field
+    margin-bottom: 0
+  +tablet
+    display: flex
+    flex-basis: 0
+    flex-grow: 5
+    flex-shrink: 1
+    .field
+      margin-bottom: 0
+    & > .field
+      flex-shrink: 1
+      &:not(.is-narrow)
+        flex-grow: 1
+      &:not(:last-child)
+        margin-right: 0.75rem
+
+.control
+  box-sizing: border-box
+  clear: both
+  font-size: $size-normal
+  position: relative
+  text-align: left
+  // Modifiers
+  &.has-icons-left,
+  &.has-icons-right
+    .input,
+    .select
+      &:focus
+        & ~ .icon
+          color: $input-icon-active-color
+      &.is-small ~ .icon
+        font-size: $size-small
+      &.is-medium ~ .icon
+        font-size: $size-medium
+      &.is-large ~ .icon
+        font-size: $size-large
+    .icon
+      color: $input-icon-color
+      height: $input-height
+      pointer-events: none
+      position: absolute
+      top: 0
+      width: $input-height
+      z-index: 4
+  &.has-icons-left
+    .input,
+    .select select
+      padding-left: $input-height
+    .icon.is-left
+      left: 0
+  &.has-icons-right
+    .input,
+    .select select
+      padding-right: $input-height
+    .icon.is-right
+      right: 0
+  &.is-loading
+    &::after
+      @extend %loader
+      position: absolute !important
+      right: 0.625em
+      top: 0.625em
+      z-index: 4
+    &.is-small:after
+      font-size: $size-small
+    &.is-medium:after
+      font-size: $size-medium
+    &.is-large:after
+      font-size: $size-large
diff -pruN 1.3.1+dfsg-1/debian/embedded/Documenter/assets/html/scss/bulma/grid/_all.sass 1.4.0+dfsg-1/debian/embedded/Documenter/assets/html/scss/bulma/grid/_all.sass
--- 1.3.1+dfsg-1/debian/embedded/Documenter/assets/html/scss/bulma/grid/_all.sass	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/debian/embedded/Documenter/assets/html/scss/bulma/grid/_all.sass	2020-03-30 16:16:04.000000000 +0000
@@ -0,0 +1,4 @@
+@charset "utf-8"
+
+@import "columns.sass"
+@import "tiles.sass"
diff -pruN 1.3.1+dfsg-1/debian/embedded/Documenter/assets/html/scss/bulma/grid/columns.sass 1.4.0+dfsg-1/debian/embedded/Documenter/assets/html/scss/bulma/grid/columns.sass
--- 1.3.1+dfsg-1/debian/embedded/Documenter/assets/html/scss/bulma/grid/columns.sass	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/debian/embedded/Documenter/assets/html/scss/bulma/grid/columns.sass	2020-03-30 16:16:04.000000000 +0000
@@ -0,0 +1,504 @@
+$column-gap: 0.75rem !default
+
+.column
+  display: block
+  flex-basis: 0
+  flex-grow: 1
+  flex-shrink: 1
+  padding: $column-gap
+  .columns.is-mobile > &.is-narrow
+    flex: none
+  .columns.is-mobile > &.is-full
+    flex: none
+    width: 100%
+  .columns.is-mobile > &.is-three-quarters
+    flex: none
+    width: 75%
+  .columns.is-mobile > &.is-two-thirds
+    flex: none
+    width: 66.6666%
+  .columns.is-mobile > &.is-half
+    flex: none
+    width: 50%
+  .columns.is-mobile > &.is-one-third
+    flex: none
+    width: 33.3333%
+  .columns.is-mobile > &.is-one-quarter
+    flex: none
+    width: 25%
+  .columns.is-mobile > &.is-one-fifth
+    flex: none
+    width: 20%
+  .columns.is-mobile > &.is-two-fifths
+    flex: none
+    width: 40%
+  .columns.is-mobile > &.is-three-fifths
+    flex: none
+    width: 60%
+  .columns.is-mobile > &.is-four-fifths
+    flex: none
+    width: 80%
+  .columns.is-mobile > &.is-offset-three-quarters
+    margin-left: 75%
+  .columns.is-mobile > &.is-offset-two-thirds
+    margin-left: 66.6666%
+  .columns.is-mobile > &.is-offset-half
+    margin-left: 50%
+  .columns.is-mobile > &.is-offset-one-third
+    margin-left: 33.3333%
+  .columns.is-mobile > &.is-offset-one-quarter
+    margin-left: 25%
+  .columns.is-mobile > &.is-offset-one-fifth
+    margin-left: 20%
+  .columns.is-mobile > &.is-offset-two-fifths
+    margin-left: 40%
+  .columns.is-mobile > &.is-offset-three-fifths
+    margin-left: 60%
+  .columns.is-mobile > &.is-offset-four-fifths
+    margin-left: 80%
+  @for $i from 0 through 12
+    .columns.is-mobile > &.is-#{$i}
+      flex: none
+      width: percentage($i / 12)
+    .columns.is-mobile > &.is-offset-#{$i}
+      margin-left: percentage($i / 12)
+  +mobile
+    &.is-narrow-mobile
+      flex: none
+    &.is-full-mobile
+      flex: none
+      width: 100%
+    &.is-three-quarters-mobile
+      flex: none
+      width: 75%
+    &.is-two-thirds-mobile
+      flex: none
+      width: 66.6666%
+    &.is-half-mobile
+      flex: none
+      width: 50%
+    &.is-one-third-mobile
+      flex: none
+      width: 33.3333%
+    &.is-one-quarter-mobile
+      flex: none
+      width: 25%
+    &.is-one-fifth-mobile
+      flex: none
+      width: 20%
+    &.is-two-fifths-mobile
+      flex: none
+      width: 40%
+    &.is-three-fifths-mobile
+      flex: none
+      width: 60%
+    &.is-four-fifths-mobile
+      flex: none
+      width: 80%
+    &.is-offset-three-quarters-mobile
+      margin-left: 75%
+    &.is-offset-two-thirds-mobile
+      margin-left: 66.6666%
+    &.is-offset-half-mobile
+      margin-left: 50%
+    &.is-offset-one-third-mobile
+      margin-left: 33.3333%
+    &.is-offset-one-quarter-mobile
+      margin-left: 25%
+    &.is-offset-one-fifth-mobile
+      margin-left: 20%
+    &.is-offset-two-fifths-mobile
+      margin-left: 40%
+    &.is-offset-three-fifths-mobile
+      margin-left: 60%
+    &.is-offset-four-fifths-mobile
+      margin-left: 80%
+    @for $i from 0 through 12
+      &.is-#{$i}-mobile
+        flex: none
+        width: percentage($i / 12)
+      &.is-offset-#{$i}-mobile
+        margin-left: percentage($i / 12)
+  +tablet
+    &.is-narrow,
+    &.is-narrow-tablet
+      flex: none
+    &.is-full,
+    &.is-full-tablet
+      flex: none
+      width: 100%
+    &.is-three-quarters,
+    &.is-three-quarters-tablet
+      flex: none
+      width: 75%
+    &.is-two-thirds,
+    &.is-two-thirds-tablet
+      flex: none
+      width: 66.6666%
+    &.is-half,
+    &.is-half-tablet
+      flex: none
+      width: 50%
+    &.is-one-third,
+    &.is-one-third-tablet
+      flex: none
+      width: 33.3333%
+    &.is-one-quarter,
+    &.is-one-quarter-tablet
+      flex: none
+      width: 25%
+    &.is-one-fifth,
+    &.is-one-fifth-tablet
+      flex: none
+      width: 20%
+    &.is-two-fifths,
+    &.is-two-fifths-tablet
+      flex: none
+      width: 40%
+    &.is-three-fifths,
+    &.is-three-fifths-tablet
+      flex: none
+      width: 60%
+    &.is-four-fifths,
+    &.is-four-fifths-tablet
+      flex: none
+      width: 80%
+    &.is-offset-three-quarters,
+    &.is-offset-three-quarters-tablet
+      margin-left: 75%
+    &.is-offset-two-thirds,
+    &.is-offset-two-thirds-tablet
+      margin-left: 66.6666%
+    &.is-offset-half,
+    &.is-offset-half-tablet
+      margin-left: 50%
+    &.is-offset-one-third,
+    &.is-offset-one-third-tablet
+      margin-left: 33.3333%
+    &.is-offset-one-quarter,
+    &.is-offset-one-quarter-tablet
+      margin-left: 25%
+    &.is-offset-one-fifth,
+    &.is-offset-one-fifth-tablet
+      margin-left: 20%
+    &.is-offset-two-fifths,
+    &.is-offset-two-fifths-tablet
+      margin-left: 40%
+    &.is-offset-three-fifths,
+    &.is-offset-three-fifths-tablet
+      margin-left: 60%
+    &.is-offset-four-fifths,
+    &.is-offset-four-fifths-tablet
+      margin-left: 80%
+    @for $i from 0 through 12
+      &.is-#{$i},
+      &.is-#{$i}-tablet
+        flex: none
+        width: percentage($i / 12)
+      &.is-offset-#{$i},
+      &.is-offset-#{$i}-tablet
+        margin-left: percentage($i / 12)
+  +touch
+    &.is-narrow-touch
+      flex: none
+    &.is-full-touch
+      flex: none
+      width: 100%
+    &.is-three-quarters-touch
+      flex: none
+      width: 75%
+    &.is-two-thirds-touch
+      flex: none
+      width: 66.6666%
+    &.is-half-touch
+      flex: none
+      width: 50%
+    &.is-one-third-touch
+      flex: none
+      width: 33.3333%
+    &.is-one-quarter-touch
+      flex: none
+      width: 25%
+    &.is-one-fifth-touch
+      flex: none
+      width: 20%
+    &.is-two-fifths-touch
+      flex: none
+      width: 40%
+    &.is-three-fifths-touch
+      flex: none
+      width: 60%
+    &.is-four-fifths-touch
+      flex: none
+      width: 80%
+    &.is-offset-three-quarters-touch
+      margin-left: 75%
+    &.is-offset-two-thirds-touch
+      margin-left: 66.6666%
+    &.is-offset-half-touch
+      margin-left: 50%
+    &.is-offset-one-third-touch
+      margin-left: 33.3333%
+    &.is-offset-one-quarter-touch
+      margin-left: 25%
+    &.is-offset-one-fifth-touch
+      margin-left: 20%
+    &.is-offset-two-fifths-touch
+      margin-left: 40%
+    &.is-offset-three-fifths-touch
+      margin-left: 60%
+    &.is-offset-four-fifths-touch
+      margin-left: 80%
+    @for $i from 0 through 12
+      &.is-#{$i}-touch
+        flex: none
+        width: percentage($i / 12)
+      &.is-offset-#{$i}-touch
+        margin-left: percentage($i / 12)
+  +desktop
+    &.is-narrow-desktop
+      flex: none
+    &.is-full-desktop
+      flex: none
+      width: 100%
+    &.is-three-quarters-desktop
+      flex: none
+      width: 75%
+    &.is-two-thirds-desktop
+      flex: none
+      width: 66.6666%
+    &.is-half-desktop
+      flex: none
+      width: 50%
+    &.is-one-third-desktop
+      flex: none
+      width: 33.3333%
+    &.is-one-quarter-desktop
+      flex: none
+      width: 25%
+    &.is-one-fifth-desktop
+      flex: none
+      width: 20%
+    &.is-two-fifths-desktop
+      flex: none
+      width: 40%
+    &.is-three-fifths-desktop
+      flex: none
+      width: 60%
+    &.is-four-fifths-desktop
+      flex: none
+      width: 80%
+    &.is-offset-three-quarters-desktop
+      margin-left: 75%
+    &.is-offset-two-thirds-desktop
+      margin-left: 66.6666%
+    &.is-offset-half-desktop
+      margin-left: 50%
+    &.is-offset-one-third-desktop
+      margin-left: 33.3333%
+    &.is-offset-one-quarter-desktop
+      margin-left: 25%
+    &.is-offset-one-fifth-desktop
+      margin-left: 20%
+    &.is-offset-two-fifths-desktop
+      margin-left: 40%
+    &.is-offset-three-fifths-desktop
+      margin-left: 60%
+    &.is-offset-four-fifths-desktop
+      margin-left: 80%
+    @for $i from 0 through 12
+      &.is-#{$i}-desktop
+        flex: none
+        width: percentage($i / 12)
+      &.is-offset-#{$i}-desktop
+        margin-left: percentage($i / 12)
+  +widescreen
+    &.is-narrow-widescreen
+      flex: none
+    &.is-full-widescreen
+      flex: none
+      width: 100%
+    &.is-three-quarters-widescreen
+      flex: none
+      width: 75%
+    &.is-two-thirds-widescreen
+      flex: none
+      width: 66.6666%
+    &.is-half-widescreen
+      flex: none
+      width: 50%
+    &.is-one-third-widescreen
+      flex: none
+      width: 33.3333%
+    &.is-one-quarter-widescreen
+      flex: none
+      width: 25%
+    &.is-one-fifth-widescreen
+      flex: none
+      width: 20%
+    &.is-two-fifths-widescreen
+      flex: none
+      width: 40%
+    &.is-three-fifths-widescreen
+      flex: none
+      width: 60%
+    &.is-four-fifths-widescreen
+      flex: none
+      width: 80%
+    &.is-offset-three-quarters-widescreen
+      margin-left: 75%
+    &.is-offset-two-thirds-widescreen
+      margin-left: 66.6666%
+    &.is-offset-half-widescreen
+      margin-left: 50%
+    &.is-offset-one-third-widescreen
+      margin-left: 33.3333%
+    &.is-offset-one-quarter-widescreen
+      margin-left: 25%
+    &.is-offset-one-fifth-widescreen
+      margin-left: 20%
+    &.is-offset-two-fifths-widescreen
+      margin-left: 40%
+    &.is-offset-three-fifths-widescreen
+      margin-left: 60%
+    &.is-offset-four-fifths-widescreen
+      margin-left: 80%
+    @for $i from 0 through 12
+      &.is-#{$i}-widescreen
+        flex: none
+        width: percentage($i / 12)
+      &.is-offset-#{$i}-widescreen
+        margin-left: percentage($i / 12)
+  +fullhd
+    &.is-narrow-fullhd
+      flex: none
+    &.is-full-fullhd
+      flex: none
+      width: 100%
+    &.is-three-quarters-fullhd
+      flex: none
+      width: 75%
+    &.is-two-thirds-fullhd
+      flex: none
+      width: 66.6666%
+    &.is-half-fullhd
+      flex: none
+      width: 50%
+    &.is-one-third-fullhd
+      flex: none
+      width: 33.3333%
+    &.is-one-quarter-fullhd
+      flex: none
+      width: 25%
+    &.is-one-fifth-fullhd
+      flex: none
+      width: 20%
+    &.is-two-fifths-fullhd
+      flex: none
+      width: 40%
+    &.is-three-fifths-fullhd
+      flex: none
+      width: 60%
+    &.is-four-fifths-fullhd
+      flex: none
+      width: 80%
+    &.is-offset-three-quarters-fullhd
+      margin-left: 75%
+    &.is-offset-two-thirds-fullhd
+      margin-left: 66.6666%
+    &.is-offset-half-fullhd
+      margin-left: 50%
+    &.is-offset-one-third-fullhd
+      margin-left: 33.3333%
+    &.is-offset-one-quarter-fullhd
+      margin-left: 25%
+    &.is-offset-one-fifth-fullhd
+      margin-left: 20%
+    &.is-offset-two-fifths-fullhd
+      margin-left: 40%
+    &.is-offset-three-fifths-fullhd
+      margin-left: 60%
+    &.is-offset-four-fifths-fullhd
+      margin-left: 80%
+    @for $i from 0 through 12
+      &.is-#{$i}-fullhd
+        flex: none
+        width: percentage($i / 12)
+      &.is-offset-#{$i}-fullhd
+        margin-left: percentage($i / 12)
+
+.columns
+  margin-left: (-$column-gap)
+  margin-right: (-$column-gap)
+  margin-top: (-$column-gap)
+  &:last-child
+    margin-bottom: (-$column-gap)
+  &:not(:last-child)
+    margin-bottom: calc(1.5rem - #{$column-gap})
+  // Modifiers
+  &.is-centered
+    justify-content: center
+  &.is-gapless
+    margin-left: 0
+    margin-right: 0
+    margin-top: 0
+    & > .column
+      margin: 0
+      padding: 0 !important
+    &:not(:last-child)
+      margin-bottom: 1.5rem
+    &:last-child
+      margin-bottom: 0
+  &.is-mobile
+    display: flex
+  &.is-multiline
+    flex-wrap: wrap
+  &.is-vcentered
+    align-items: center
+  // Responsiveness
+  +tablet
+    &:not(.is-desktop)
+      display: flex
+  +desktop
+    // Modifiers
+    &.is-desktop
+      display: flex
+
+@if $variable-columns
+  .columns.is-variable
+    --columnGap: 0.75rem
+    margin-left: calc(-1 * var(--columnGap))
+    margin-right: calc(-1 * var(--columnGap))
+    .column
+      padding-left: var(--columnGap)
+      padding-right: var(--columnGap)
+    @for $i from 0 through 8
+      &.is-#{$i}
+        --columnGap: #{$i * 0.25rem}
+      +mobile
+        &.is-#{$i}-mobile
+          --columnGap: #{$i * 0.25rem}
+      +tablet
+        &.is-#{$i}-tablet
+          --columnGap: #{$i * 0.25rem}
+      +tablet-only
+        &.is-#{$i}-tablet-only
+          --columnGap: #{$i * 0.25rem}
+      +touch
+        &.is-#{$i}-touch
+          --columnGap: #{$i * 0.25rem}
+      +desktop
+        &.is-#{$i}-desktop
+          --columnGap: #{$i * 0.25rem}
+      +desktop-only
+        &.is-#{$i}-desktop-only
+          --columnGap: #{$i * 0.25rem}
+      +widescreen
+        &.is-#{$i}-widescreen
+          --columnGap: #{$i * 0.25rem}
+      +widescreen-only
+        &.is-#{$i}-widescreen-only
+          --columnGap: #{$i * 0.25rem}
+      +fullhd
+        &.is-#{$i}-fullhd
+          --columnGap: #{$i * 0.25rem}
diff -pruN 1.3.1+dfsg-1/debian/embedded/Documenter/assets/html/scss/bulma/grid/tiles.sass 1.4.0+dfsg-1/debian/embedded/Documenter/assets/html/scss/bulma/grid/tiles.sass
--- 1.3.1+dfsg-1/debian/embedded/Documenter/assets/html/scss/bulma/grid/tiles.sass	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/debian/embedded/Documenter/assets/html/scss/bulma/grid/tiles.sass	2020-03-30 16:16:04.000000000 +0000
@@ -0,0 +1,34 @@
+$tile-spacing: 0.75rem !default
+
+.tile
+  align-items: stretch
+  display: block
+  flex-basis: 0
+  flex-grow: 1
+  flex-shrink: 1
+  min-height: min-content
+  // Modifiers
+  &.is-ancestor
+    margin-left: $tile-spacing * -1
+    margin-right: $tile-spacing * -1
+    margin-top: $tile-spacing * -1
+    &:last-child
+      margin-bottom: $tile-spacing * -1
+    &:not(:last-child)
+      margin-bottom: $tile-spacing
+  &.is-child
+    margin: 0 !important
+  &.is-parent
+    padding: $tile-spacing
+  &.is-vertical
+    flex-direction: column
+    & > .tile.is-child:not(:last-child)
+      margin-bottom: 1.5rem !important
+  // Responsiveness
+  +tablet
+    &:not(.is-child)
+      display: flex
+    @for $i from 1 through 12
+      &.is-#{$i}
+        flex: none
+        width: ($i / 12) * 100%
diff -pruN 1.3.1+dfsg-1/debian/embedded/Documenter/assets/html/scss/bulma/layout/_all.sass 1.4.0+dfsg-1/debian/embedded/Documenter/assets/html/scss/bulma/layout/_all.sass
--- 1.3.1+dfsg-1/debian/embedded/Documenter/assets/html/scss/bulma/layout/_all.sass	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/debian/embedded/Documenter/assets/html/scss/bulma/layout/_all.sass	2020-03-30 16:16:04.000000000 +0000
@@ -0,0 +1,5 @@
+@charset "utf-8"
+
+@import "hero.sass"
+@import "section.sass"
+@import "footer.sass"
diff -pruN 1.3.1+dfsg-1/debian/embedded/Documenter/assets/html/scss/bulma/layout/footer.sass 1.4.0+dfsg-1/debian/embedded/Documenter/assets/html/scss/bulma/layout/footer.sass
--- 1.3.1+dfsg-1/debian/embedded/Documenter/assets/html/scss/bulma/layout/footer.sass	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/debian/embedded/Documenter/assets/html/scss/bulma/layout/footer.sass	2020-03-30 16:16:04.000000000 +0000
@@ -0,0 +1,9 @@
+$footer-background-color: $white-bis !default
+$footer-color: false !default
+$footer-padding: 3rem 1.5rem 6rem !default
+
+.footer
+  background-color: $footer-background-color
+  padding: $footer-padding
+  @if $footer-color
+    color: $footer-color
diff -pruN 1.3.1+dfsg-1/debian/embedded/Documenter/assets/html/scss/bulma/layout/hero.sass 1.4.0+dfsg-1/debian/embedded/Documenter/assets/html/scss/bulma/layout/hero.sass
--- 1.3.1+dfsg-1/debian/embedded/Documenter/assets/html/scss/bulma/layout/hero.sass	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/debian/embedded/Documenter/assets/html/scss/bulma/layout/hero.sass	2020-03-30 16:16:04.000000000 +0000
@@ -0,0 +1,143 @@
+// Main container
+
+.hero
+  align-items: stretch
+  display: flex
+  flex-direction: column
+  justify-content: space-between
+  .navbar
+    background: none
+  .tabs
+    ul
+      border-bottom: none
+  // Colors
+  @each $name, $pair in $colors
+    $color: nth($pair, 1)
+    $color-invert: nth($pair, 2)
+    &.is-#{$name}
+      background-color: $color
+      color: $color-invert
+      a:not(.button):not(.dropdown-item):not(.tag):not(.pagination-link.is-current),
+      strong
+        color: inherit
+      .title
+        color: $color-invert
+      .subtitle
+        color: rgba($color-invert, 0.9)
+        a:not(.button),
+        strong
+          color: $color-invert
+      .navbar-menu
+        +touch
+          background-color: $color
+      .navbar-item,
+      .navbar-link
+        color: rgba($color-invert, 0.7)
+      a.navbar-item,
+      .navbar-link
+        &:hover,
+        &.is-active
+          background-color: darken($color, 5%)
+          color: $color-invert
+      .tabs
+        a
+          color: $color-invert
+          opacity: 0.9
+          &:hover
+            opacity: 1
+        li
+          &.is-active a
+            opacity: 1
+        &.is-boxed,
+        &.is-toggle
+          a
+            color: $color-invert
+            &:hover
+              background-color: rgba($black, 0.1)
+          li.is-active a
+            &,
+            &:hover
+              background-color: $color-invert
+              border-color: $color-invert
+              color: $color
+      // Modifiers
+      &.is-bold
+        $gradient-top-left: darken(saturate(adjust-hue($color, -10deg), 10%), 10%)
+        $gradient-bottom-right: lighten(saturate(adjust-hue($color, 10deg), 5%), 5%)
+        background-image: linear-gradient(141deg, $gradient-top-left 0%, $color 71%, $gradient-bottom-right 100%)
+        +mobile
+          .navbar-menu
+            background-image: linear-gradient(141deg, $gradient-top-left 0%, $color 71%, $gradient-bottom-right 100%)
+  // Sizes
+  &.is-small
+    .hero-body
+      padding-bottom: 1.5rem
+      padding-top: 1.5rem
+  &.is-medium
+    +tablet
+      .hero-body
+        padding-bottom: 9rem
+        padding-top: 9rem
+  &.is-large
+    +tablet
+      .hero-body
+        padding-bottom: 18rem
+        padding-top: 18rem
+  &.is-halfheight,
+  &.is-fullheight,
+  &.is-fullheight-with-navbar
+    .hero-body
+      align-items: center
+      display: flex
+      & > .container
+        flex-grow: 1
+        flex-shrink: 1
+  &.is-halfheight
+    min-height: 50vh
+  &.is-fullheight
+    min-height: 100vh
+
+// Components
+
+.hero-video
+  @extend %overlay
+  overflow: hidden
+  video
+    left: 50%
+    min-height: 100%
+    min-width: 100%
+    position: absolute
+    top: 50%
+    transform: translate3d(-50%, -50%, 0)
+  // Modifiers
+  &.is-transparent
+    opacity: 0.3
+  // Responsiveness
+  +mobile
+    display: none
+
+.hero-buttons
+  margin-top: 1.5rem
+  // Responsiveness
+  +mobile
+    .button
+      display: flex
+      &:not(:last-child)
+        margin-bottom: 0.75rem
+  +tablet
+    display: flex
+    justify-content: center
+    .button:not(:last-child)
+      margin-right: 1.5rem
+
+// Containers
+
+.hero-head,
+.hero-foot
+  flex-grow: 0
+  flex-shrink: 0
+
+.hero-body
+  flex-grow: 1
+  flex-shrink: 0
+  padding: 3rem 1.5rem
diff -pruN 1.3.1+dfsg-1/debian/embedded/Documenter/assets/html/scss/bulma/layout/section.sass 1.4.0+dfsg-1/debian/embedded/Documenter/assets/html/scss/bulma/layout/section.sass
--- 1.3.1+dfsg-1/debian/embedded/Documenter/assets/html/scss/bulma/layout/section.sass	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/debian/embedded/Documenter/assets/html/scss/bulma/layout/section.sass	2020-03-30 16:16:04.000000000 +0000
@@ -0,0 +1,13 @@
+$section-padding: 3rem 1.5rem !default
+$section-padding-medium: 9rem 1.5rem !default
+$section-padding-large: 18rem 1.5rem !default
+
+.section
+  padding: $section-padding
+  // Responsiveness
+  +desktop
+    // Sizes
+    &.is-medium
+      padding: $section-padding-medium
+    &.is-large
+      padding: $section-padding-large
diff -pruN 1.3.1+dfsg-1/debian/embedded/Documenter/assets/html/scss/bulma/LICENSE 1.4.0+dfsg-1/debian/embedded/Documenter/assets/html/scss/bulma/LICENSE
--- 1.3.1+dfsg-1/debian/embedded/Documenter/assets/html/scss/bulma/LICENSE	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/debian/embedded/Documenter/assets/html/scss/bulma/LICENSE	2020-03-30 16:16:04.000000000 +0000
@@ -0,0 +1,21 @@
+The MIT License (MIT)
+
+Copyright (c) 2019 Jeremy Thomas
+
+Permission is hereby granted, free of charge, to any person obtaining a copy
+of this software and associated documentation files (the "Software"), to deal
+in the Software without restriction, including without limitation the rights
+to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
+copies of the Software, and to permit persons to whom the Software is
+furnished to do so, subject to the following conditions:
+
+The above copyright notice and this permission notice shall be included in
+all copies or substantial portions of the Software.
+
+THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
+IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
+FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
+AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
+LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
+OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
+THE SOFTWARE.
diff -pruN 1.3.1+dfsg-1/debian/embedded/Documenter/assets/html/scss/bulma/utilities/_all.sass 1.4.0+dfsg-1/debian/embedded/Documenter/assets/html/scss/bulma/utilities/_all.sass
--- 1.3.1+dfsg-1/debian/embedded/Documenter/assets/html/scss/bulma/utilities/_all.sass	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/debian/embedded/Documenter/assets/html/scss/bulma/utilities/_all.sass	2020-03-30 16:16:04.000000000 +0000
@@ -0,0 +1,8 @@
+@charset "utf-8"
+
+@import "initial-variables.sass"
+@import "functions.sass"
+@import "derived-variables.sass"
+@import "animations.sass"
+@import "mixins.sass"
+@import "controls.sass"
diff -pruN 1.3.1+dfsg-1/debian/embedded/Documenter/assets/html/scss/bulma/utilities/animations.sass 1.4.0+dfsg-1/debian/embedded/Documenter/assets/html/scss/bulma/utilities/animations.sass
--- 1.3.1+dfsg-1/debian/embedded/Documenter/assets/html/scss/bulma/utilities/animations.sass	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/debian/embedded/Documenter/assets/html/scss/bulma/utilities/animations.sass	2020-03-30 16:16:04.000000000 +0000
@@ -0,0 +1,5 @@
+@keyframes spinAround
+  from
+    transform: rotate(0deg)
+  to
+    transform: rotate(359deg)
diff -pruN 1.3.1+dfsg-1/debian/embedded/Documenter/assets/html/scss/bulma/utilities/controls.sass 1.4.0+dfsg-1/debian/embedded/Documenter/assets/html/scss/bulma/utilities/controls.sass
--- 1.3.1+dfsg-1/debian/embedded/Documenter/assets/html/scss/bulma/utilities/controls.sass	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/debian/embedded/Documenter/assets/html/scss/bulma/utilities/controls.sass	2020-03-30 16:16:04.000000000 +0000
@@ -0,0 +1,50 @@
+$control-radius: $radius !default
+$control-radius-small: $radius-small !default
+
+$control-border-width: 1px !default
+
+$control-height: 2.25em !default
+$control-line-height: 1.5 !default
+
+$control-padding-vertical: calc(0.375em - #{$control-border-width}) !default
+$control-padding-horizontal: calc(0.625em - #{$control-border-width}) !default
+
+=control
+  -moz-appearance: none
+  -webkit-appearance: none
+  align-items: center
+  border: $control-border-width solid transparent
+  border-radius: $control-radius
+  box-shadow: none
+  display: inline-flex
+  font-size: $size-normal
+  height: $control-height
+  justify-content: flex-start
+  line-height: $control-line-height
+  padding-bottom: $control-padding-vertical
+  padding-left: $control-padding-horizontal
+  padding-right: $control-padding-horizontal
+  padding-top: $control-padding-vertical
+  position: relative
+  vertical-align: top
+  // States
+  &:focus,
+  &.is-focused,
+  &:active,
+  &.is-active
+    outline: none
+  &[disabled],
+  fieldset[disabled] &
+    cursor: not-allowed
+
+%control
+  +control
+
+// The controls sizes use mixins so they can be used at different breakpoints
+=control-small
+  border-radius: $control-radius-small
+  font-size: $size-small
+=control-medium
+  font-size: $size-medium
+=control-large
+  font-size: $size-large
diff -pruN 1.3.1+dfsg-1/debian/embedded/Documenter/assets/html/scss/bulma/utilities/derived-variables.sass 1.4.0+dfsg-1/debian/embedded/Documenter/assets/html/scss/bulma/utilities/derived-variables.sass
--- 1.3.1+dfsg-1/debian/embedded/Documenter/assets/html/scss/bulma/utilities/derived-variables.sass	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/debian/embedded/Documenter/assets/html/scss/bulma/utilities/derived-variables.sass	2020-03-30 16:16:04.000000000 +0000
@@ -0,0 +1,85 @@
+$primary: $turquoise !default
+
+$info: $cyan !default
+$success: $green !default
+$warning: $yellow !default
+$danger: $red !default
+
+$light: $white-ter !default
+$dark: $grey-darker !default
+
+// Invert colors
+
+$orange-invert: findColorInvert($orange) !default
+$yellow-invert: findColorInvert($yellow) !default
+$green-invert: findColorInvert($green) !default
+$turquoise-invert: findColorInvert($turquoise) !default
+$cyan-invert: findColorInvert($cyan) !default
+$blue-invert: findColorInvert($blue) !default
+$purple-invert: findColorInvert($purple) !default
+$red-invert: findColorInvert($red) !default
+
+$primary-invert: $turquoise-invert !default
+$info-invert: $cyan-invert !default
+$success-invert: $green-invert !default
+$warning-invert: $yellow-invert !default
+$danger-invert: $red-invert !default
+$light-invert: $dark !default
+$dark-invert: $light !default
+
+// General colors
+
+$background: $white-ter !default
+
+$border: $grey-lighter !default
+$border-hover: $grey-light !default
+
+// Text colors
+
+$text: $grey-dark !default
+$text-invert: findColorInvert($text) !default
+$text-light: $grey !default
+$text-strong: $grey-darker !default
+
+// Code colors
+
+$code: $red !default
+$code-background: $background !default
+
+$pre: $text !default
+$pre-background: $background !default
+
+// Link colors
+
+$link: $blue !default
+$link-invert: $blue-invert !default
+$link-visited: $purple !default
+
+$link-hover: $grey-darker !default
+$link-hover-border: $grey-light !default
+
+$link-focus: $grey-darker !default
+$link-focus-border: $blue !default
+
+$link-active: $grey-darker !default
+$link-active-border: $grey-dark !default
+
+// Typography
+
+$family-primary: $family-sans-serif !default
+$family-secondary: $family-sans-serif !default
+$family-code: $family-monospace !default
+
+$size-small: $size-7 !default
+$size-normal: $size-6 !default
+$size-medium: $size-5 !default
+$size-large: $size-4 !default
+
+// Lists and maps
+$custom-colors: null !default
+$custom-shades: null !default
+
+$colors: mergeColorMaps(("white": ($white, $black), "black": ($black, $white), "light": ($light, $light-invert), "dark": ($dark, $dark-invert), "primary": ($primary, $primary-invert), "link": ($link, $link-invert), "info": ($info, $info-invert), "success": ($success, $success-invert), "warning": ($warning, $warning-invert), "danger": ($danger, $danger-invert)), $custom-colors) !default
+$shades: mergeColorMaps(("black-bis": $black-bis, "black-ter": $black-ter, "grey-darker": $grey-darker, "grey-dark": $grey-dark, "grey": $grey, "grey-light": $grey-light, "grey-lighter": $grey-lighter, "white-ter": $white-ter, "white-bis": $white-bis), $custom-shades) !default
+
+$sizes: $size-1 $size-2 $size-3 $size-4 $size-5 $size-6 $size-7 !default
diff -pruN 1.3.1+dfsg-1/debian/embedded/Documenter/assets/html/scss/bulma/utilities/functions.sass 1.4.0+dfsg-1/debian/embedded/Documenter/assets/html/scss/bulma/utilities/functions.sass
--- 1.3.1+dfsg-1/debian/embedded/Documenter/assets/html/scss/bulma/utilities/functions.sass	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/debian/embedded/Documenter/assets/html/scss/bulma/utilities/functions.sass	2020-03-30 16:16:04.000000000 +0000
@@ -0,0 +1,62 @@
+@function mergeColorMaps($bulma-colors, $custom-colors)
+  // we return at least bulma hardcoded colors
+  $merged-colors: $bulma-colors
+
+  // we want a map as input
+  @if type-of($custom-colors) == 'map'
+    @each $name, $components in $custom-colors
+      // color name should be a string and colors pair a list with at least one element
+      @if type-of($name) == 'string' and (type-of($components) == 'list' or type-of($components) == 'color') and length($components) >= 1
+        $color-base: null
+
+        // the param can either be a single color
+        // or a list of 2 colors
+        @if type-of($components) == 'color'
+          $color-base: $components
+        @else if type-of($components) == 'list'
+          $color-base: nth($components, 1)
+
+        $color-invert: null
+        // is an inverted color provided in the list
+        @if length($components) > 1
+          $color-invert: nth($components, 2)
+
+        // we only want a color as base color
+        @if type-of($color-base) == 'color'
+          // if inverted color is not provided or is not a color we compute it
+          @if type-of($color-invert) != 'color'
+            $color-invert: findColorInvert($color-base)
+
+          // we merge this colors elements as map with bulma colors (we can override them this way, no multiple definition for the same name)
+          $merged-colors: map_merge($merged-colors, ($name: ($color-base, $color-invert)))
+
+  @return $merged-colors
+
+@function powerNumber($number, $exp)
+  $value: 1
+  @if $exp > 0
+    @for $i from 1 through $exp
+      $value: $value * $number
+  @else if $exp < 0
+    @for $i from 1 through -$exp
+      $value: $value / $number
+  @return $value
+
+@function colorLuminance($color)
+  $color-rgb: ('red': red($color),'green': green($color),'blue': blue($color))
+  @each $name, $value in $color-rgb
+    $adjusted: 0
+    $value: $value / 255
+    @if $value < 0.03928
+      $value: $value / 12.92
+    @else
+      $value: ($value + .055) / 1.055
+      $value: powerNumber($value, 2)
+    $color-rgb: map-merge($color-rgb, ($name: $value))
+  @return (map-get($color-rgb, 'red') * .2126) + (map-get($color-rgb, 'green') * .7152) + (map-get($color-rgb, 'blue') * .0722)
+
+@function findColorInvert($color)
+  @if (colorLuminance($color) > 0.55)
+    @return rgba(#000, 0.7)
+  @else
+    @return #fff
diff -pruN 1.3.1+dfsg-1/debian/embedded/Documenter/assets/html/scss/bulma/utilities/initial-variables.sass 1.4.0+dfsg-1/debian/embedded/Documenter/assets/html/scss/bulma/utilities/initial-variables.sass
--- 1.3.1+dfsg-1/debian/embedded/Documenter/assets/html/scss/bulma/utilities/initial-variables.sass	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/debian/embedded/Documenter/assets/html/scss/bulma/utilities/initial-variables.sass	2020-03-30 16:16:04.000000000 +0000
@@ -0,0 +1,76 @@
+// Colors
+
+$black:        hsl(0, 0%, 4%) !default
+$black-bis:    hsl(0, 0%, 7%) !default
+$black-ter:    hsl(0, 0%, 14%) !default
+
+$grey-darker:  hsl(0, 0%, 21%) !default
+$grey-dark:    hsl(0, 0%, 29%) !default
+$grey:         hsl(0, 0%, 48%) !default
+$grey-light:   hsl(0, 0%, 71%) !default
+$grey-lighter: hsl(0, 0%, 86%) !default
+
+$white-ter:    hsl(0, 0%, 96%) !default
+$white-bis:    hsl(0, 0%, 98%) !default
+$white:        hsl(0, 0%, 100%) !default
+
+$orange:       hsl(14,  100%, 53%) !default
+$yellow:       hsl(48,  100%, 67%) !default
+$green:        hsl(141, 71%,  48%) !default
+$turquoise:    hsl(171, 100%, 41%) !default
+$cyan:         hsl(204, 86%,  53%) !default
+$blue:         hsl(217, 71%,  53%) !default
+$purple:       hsl(271, 100%, 71%) !default
+$red:          hsl(348, 100%, 61%) !default
+
+// Typography
+
+$family-sans-serif: BlinkMacSystemFont, -apple-system, "Segoe UI", "Roboto", "Oxygen", "Ubuntu", "Cantarell", "Fira Sans", "Droid Sans", "Helvetica Neue", "Helvetica", "Arial", sans-serif !default
+$family-monospace: monospace !default
+$render-mode: optimizeLegibility !default
+
+$size-1: 3rem !default
+$size-2: 2.5rem !default
+$size-3: 2rem !default
+$size-4: 1.5rem !default
+$size-5: 1.25rem !default
+$size-6: 1rem !default
+$size-7: 0.75rem !default
+
+$weight-light: 300 !default
+$weight-normal: 400 !default
+$weight-medium: 500 !default
+$weight-semibold: 600 !default
+$weight-bold: 700 !default
+
+// Spacing
+
+$block-spacing: 1.5rem !default
+
+// Responsiveness
+
+// The container horizontal gap, which acts as the offset for breakpoints
+$gap: 32px !default
+// 960, 1152, and 1344 have been chosen because they are divisible by both 12 and 16
+$tablet: 769px !default
+// 960px container + 4rem
+$desktop: 960px + (2 * $gap) !default
+// 1152px container + 4rem
+$widescreen: 1152px + (2 * $gap) !default
+$widescreen-enabled: true !default
+// 1344px container + 4rem
+$fullhd: 1344px + (2 * $gap) !default
+$fullhd-enabled: true !default
+
+// Miscellaneous
+
+$easing: ease-out !default
+$radius-small: 2px !default
+$radius: 4px !default
+$radius-large: 6px !default
+$radius-rounded: 290486px !default
+$speed: 86ms !default
+
+// Flags
+
+$variable-columns: true !default
diff -pruN 1.3.1+dfsg-1/debian/embedded/Documenter/assets/html/scss/bulma/utilities/mixins.sass 1.4.0+dfsg-1/debian/embedded/Documenter/assets/html/scss/bulma/utilities/mixins.sass
--- 1.3.1+dfsg-1/debian/embedded/Documenter/assets/html/scss/bulma/utilities/mixins.sass	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/debian/embedded/Documenter/assets/html/scss/bulma/utilities/mixins.sass	2020-03-30 16:16:04.000000000 +0000
@@ -0,0 +1,261 @@
+@import "initial-variables"
+
+=clearfix
+  &::after
+    clear: both
+    content: " "
+    display: table
+
+=center($width, $height: 0)
+  position: absolute
+  @if $height != 0
+    left: calc(50% - (#{$width} / 2))
+    top: calc(50% - (#{$height} / 2))
+  @else
+    left: calc(50% - (#{$width} / 2))
+    top: calc(50% - (#{$width} / 2))
+
+=fa($size, $dimensions)
+  display: inline-block
+  font-size: $size
+  height: $dimensions
+  line-height: $dimensions
+  text-align: center
+  vertical-align: top
+  width: $dimensions
+
+=hamburger($dimensions)
+  cursor: pointer
+  display: block
+  height: $dimensions
+  position: relative
+  width: $dimensions
+  span
+    background-color: currentColor
+    display: block
+    height: 1px
+    left: calc(50% - 8px)
+    position: absolute
+    transform-origin: center
+    transition-duration: $speed
+    transition-property: background-color, opacity, transform
+    transition-timing-function: $easing
+    width: 16px
+    &:nth-child(1)
+      top: calc(50% - 6px)
+    &:nth-child(2)
+      top: calc(50% - 1px)
+    &:nth-child(3)
+      top: calc(50% + 4px)
+  &:hover
+    background-color: rgba(black, 0.05)
+  // Modifers
+  &.is-active
+    span
+      &:nth-child(1)
+        transform: translateY(5px) rotate(45deg)
+      &:nth-child(2)
+        opacity: 0
+      &:nth-child(3)
+        transform: translateY(-5px) rotate(-45deg)
+
+=overflow-touch
+  -webkit-overflow-scrolling: touch
+
+=placeholder
+  $placeholders: ':-moz' ':-webkit-input' '-moz' '-ms-input'
+  @each $placeholder in $placeholders
+    &:#{$placeholder}-placeholder
+      @content
+
+// Responsiveness
+
+=from($device)
+  @media screen and (min-width: $device)
+    @content
+
+=until($device)
+  @media screen and (max-width: $device - 1px)
+    @content
+
+=mobile
+  @media screen and (max-width: $tablet - 1px)
+    @content
+
+=tablet
+  @media screen and (min-width: $tablet), print
+    @content
+
+=tablet-only
+  @media screen and (min-width: $tablet) and (max-width: $desktop - 1px)
+    @content
+
+=touch
+  @media screen and (max-width: $desktop - 1px)
+    @content
+
+=desktop
+  @media screen and (min-width: $desktop)
+    @content
+
+=desktop-only
+  @if $widescreen-enabled
+    @media screen and (min-width: $desktop) and (max-width: $widescreen - 1px)
+      @content
+
+=until-widescreen
+  @if $widescreen-enabled
+    @media screen and (max-width: $widescreen - 1px)
+      @content
+
+=widescreen
+  @if $widescreen-enabled
+    @media screen and (min-width: $widescreen)
+      @content
+
+=widescreen-only
+  @if $widescreen-enabled and $fullhd-enabled
+    @media screen and (min-width: $widescreen) and (max-width: $fullhd - 1px)
+      @content
+
+=until-fullhd
+  @if $fullhd-enabled
+    @media screen and (max-width: $fullhd - 1px)
+      @content
+
+=fullhd
+  @if $fullhd-enabled
+    @media screen and (min-width: $fullhd)
+      @content
+
+// Placeholders
+
+=unselectable
+  -webkit-touch-callout: none
+  -webkit-user-select: none
+  -moz-user-select: none
+  -ms-user-select: none
+  user-select: none
+
+%unselectable
+  +unselectable
+
+=arrow($color: transparent)
+  border: 3px solid $color
+  border-radius: 2px
+  border-right: 0
+  border-top: 0
+  content: " "
+  display: block
+  height: 0.625em
+  margin-top: -0.4375em
+  pointer-events: none
+  position: absolute
+  top: 50%
+  transform: rotate(-45deg)
+  transform-origin: center
+  width: 0.625em
+
+%arrow
+  +arrow
+
+=block($spacing: $block-spacing)
+  &:not(:last-child)
+    margin-bottom: $spacing
+
+%block
+  +block
+
+=delete
+  @extend %unselectable
+  -moz-appearance: none
+  -webkit-appearance: none
+  background-color: rgba($black, 0.2)
+  border: none
+  border-radius: $radius-rounded
+  cursor: pointer
+  pointer-events: auto
+  display: inline-block
+  flex-grow: 0
+  flex-shrink: 0
+  font-size: 0
+  height: 20px
+  max-height: 20px
+  max-width: 20px
+  min-height: 20px
+  min-width: 20px
+  outline: none
+  position: relative
+  vertical-align: top
+  width: 20px
+  &::before,
+  &::after
+    background-color: $white
+    content: ""
+    display: block
+    left: 50%
+    position: absolute
+    top: 50%
+    transform: translateX(-50%) translateY(-50%) rotate(45deg)
+    transform-origin: center center
+  &::before
+    height: 2px
+    width: 50%
+  &::after
+    height: 50%
+    width: 2px
+  &:hover,
+  &:focus
+    background-color: rgba($black, 0.3)
+  &:active
+    background-color: rgba($black, 0.4)
+  // Sizes
+  &.is-small
+    height: 16px
+    max-height: 16px
+    max-width: 16px
+    min-height: 16px
+    min-width: 16px
+    width: 16px
+  &.is-medium
+    height: 24px
+    max-height: 24px
+    max-width: 24px
+    min-height: 24px
+    min-width: 24px
+    width: 24px
+  &.is-large
+    height: 32px
+    max-height: 32px
+    max-width: 32px
+    min-height: 32px
+    min-width: 32px
+    width: 32px
+
+%delete
+  +delete
+
+=loader
+  animation: spinAround 500ms infinite linear
+  border: 2px solid $grey-lighter
+  border-radius: $radius-rounded
+  border-right-color: transparent
+  border-top-color: transparent
+  content: ""
+  display: block
+  height: 1em
+  position: relative
+  width: 1em
+
+%loader
+  +loader
+
+=overlay($offset: 0)
+  bottom: $offset
+  left: $offset
+  position: absolute
+  right: $offset
+  top: $offset
+
+%overlay
+  +overlay
diff -pruN 1.3.1+dfsg-1/debian/embedded/Documenter/assets/html/scss/darkly/LICENSE 1.4.0+dfsg-1/debian/embedded/Documenter/assets/html/scss/darkly/LICENSE
--- 1.3.1+dfsg-1/debian/embedded/Documenter/assets/html/scss/darkly/LICENSE	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/debian/embedded/Documenter/assets/html/scss/darkly/LICENSE	2020-03-30 16:16:04.000000000 +0000
@@ -0,0 +1,26 @@
+Darkly theme from Bulmaswatch
+
+- https://jenil.github.io/bulmaswatch/
+- https://github.com/jenil/bulmaswatch
+
+MIT License
+
+Copyright (c) 2017 - Present Jenil Gogari
+
+Permission is hereby granted, free of charge, to any person obtaining a copy
+of this software and associated documentation files (the "Software"), to deal
+in the Software without restriction, including without limitation the rights
+to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
+copies of the Software, and to permit persons to whom the Software is
+furnished to do so, subject to the following conditions:
+
+The above copyright notice and this permission notice shall be included in all
+copies or substantial portions of the Software.
+
+THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
+IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
+FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
+AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
+LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
+OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
+SOFTWARE.
diff -pruN 1.3.1+dfsg-1/debian/embedded/Documenter/assets/html/scss/darkly/_overrides.scss 1.4.0+dfsg-1/debian/embedded/Documenter/assets/html/scss/darkly/_overrides.scss
--- 1.3.1+dfsg-1/debian/embedded/Documenter/assets/html/scss/darkly/_overrides.scss	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/debian/embedded/Documenter/assets/html/scss/darkly/_overrides.scss	2020-03-30 16:16:04.000000000 +0000
@@ -0,0 +1,300 @@
+// Overrides
+@if $bulmaswatch-import-font {
+    @import url(https://fonts.googleapis.com/css?family=Lato:400,700,400italic);
+}
+
+hr {
+  height: $border-width;
+}
+
+h6 {
+  text-transform: uppercase;
+  letter-spacing: 0.5px;
+}
+
+.hero {
+  background-color: $grey-dark;
+}
+
+a {
+  transition: all 200ms ease;
+}
+
+.button {
+  transition: all 200ms ease;
+  border-width: $border-width;
+  color: $white;
+
+  &.is-active,
+  &.is-focused,
+  &:active,
+  &:focus {
+    box-shadow: 0 0 0 2px rgba($button-focus-border-color, 0.5);
+  }
+  @each $name, $pair in $colors {
+    $color: nth($pair, 1);
+    $color-invert: nth($pair, 2);
+
+    &.is-#{$name} {
+      &.is-hovered,
+      &:hover {
+        background-color: lighten($color, 7.5%);
+      }
+
+      &.is-active,
+      &.is-focused,
+      &:active,
+      &:focus {
+        border-color: $color;
+        box-shadow: 0 0 0 2px rgba($color, 0.5);
+      }
+    }
+  }
+}
+
+.label {
+  color: $grey-lighter;
+}
+
+.button,
+.control.has-icons-left .icon,
+.control.has-icons-right .icon,
+.input,
+.pagination-ellipsis,
+.pagination-link,
+.pagination-next,
+.pagination-previous,
+.select,
+.select select,
+.textarea {
+  height: 2.5em;
+}
+
+.input,
+.textarea {
+  transition: all 200ms ease;
+  box-shadow: none;
+  border-width: $border-width;
+  padding-left: 1em;
+  padding-right: 1em;
+}
+
+.select {
+  &:after,
+  select {
+    border-width: $border-width;
+  }
+}
+
+.control {
+  &.has-addons {
+    .button,
+    .input,
+    .select {
+      margin-right: -$border-width;
+    }
+  }
+}
+
+.notification {
+  background-color: $grey-dark;
+}
+
+.card {
+  $card-border-color: lighten($grey-darker, 5);
+  box-shadow: none;
+  border: $border-width solid $card-border-color;
+  background-color: $grey-darker;
+  border-radius: $radius;
+
+  .card-image {
+    img {
+      border-radius: $radius $radius 0 0;
+    }
+  }
+
+  .card-header {
+    box-shadow: none;
+    background-color: rgba($black-bis, 0.2);
+    border-radius: $radius $radius 0 0;
+  }
+
+  .card-footer {
+    background-color: rgba($black-bis, 0.2);
+  }
+
+  .card-footer,
+  .card-footer-item {
+    border-width: $border-width;
+    border-color: $card-border-color;
+  }
+}
+
+.notification {
+  @each $name, $pair in $colors {
+    $color: nth($pair, 1);
+    $color-invert: nth($pair, 2);
+
+    &.is-#{$name} {
+      a:not(.button) {
+        color: $color-invert;
+        text-decoration: underline;
+      }
+    }
+  }
+}
+
+.tag {
+  border-radius: $radius;
+}
+
+.menu-list {
+  a {
+    transition: all 300ms ease;
+  }
+}
+
+.modal-card-body {
+  background-color: $grey-darker;
+}
+
+.modal-card-foot,
+.modal-card-head {
+  border-color: $grey-dark;
+}
+
+.message-header {
+  font-weight: $weight-bold;
+  background-color: $grey-dark;
+  color: $white;
+}
+
+.message-body {
+  border-width: $border-width;
+  border-color: $grey-dark;
+}
+
+.navbar {
+  border-radius: $radius;
+
+  &.is-transparent {
+    background: none;
+  }
+
+  &.is-primary {
+    .navbar-dropdown {
+      a.navbar-item.is-active {
+        background-color: $link;
+      }
+    }
+  }
+
+  @include touch {
+    .navbar-menu {
+      background-color: $navbar-background-color;
+      border-radius: 0 0 $radius $radius;
+    }
+  }
+}
+
+.hero .navbar,
+body > .navbar {
+  border-radius: 0;
+}
+
+.pagination-link,
+.pagination-next,
+.pagination-previous {
+  border-width: $border-width;
+}
+
+.panel-block,
+.panel-heading,
+.panel-tabs {
+  border-width: $border-width;
+
+  &:first-child {
+    border-top-width: $border-width;
+  }
+}
+
+.panel-heading {
+  font-weight: $weight-bold;
+}
+
+.panel-tabs {
+  a {
+    border-width: $border-width;
+    margin-bottom: -$border-width;
+
+    &.is-active {
+      border-bottom-color: $link-active;
+    }
+  }
+}
+
+.panel-block {
+  &:hover {
+    color: $link-hover;
+
+    .panel-icon {
+      color: $link-hover;
+    }
+  }
+
+  &.is-active {
+    .panel-icon {
+      color: $link-active;
+    }
+  }
+}
+
+.tabs {
+  a {
+    border-bottom-width: $border-width;
+    margin-bottom: -$border-width;
+  }
+
+  ul {
+    border-bottom-width: $border-width;
+  }
+
+  &.is-boxed {
+    a {
+      border-width: $border-width;
+    }
+
+    li.is-active a {
+      background-color: darken($grey-darker, 4);
+    }
+  }
+
+  &.is-toggle {
+    li a {
+      border-width: $border-width;
+      margin-bottom: 0;
+    }
+
+    li + li {
+      margin-left: -$border-width;
+    }
+  }
+}
+
+.hero {
+  // Colors
+  @each $name, $pair in $colors {
+    $color: nth($pair, 1);
+    $color-invert: nth($pair, 2);
+
+    &.is-#{$name} {
+      .navbar {
+        .navbar-dropdown {
+          .navbar-item:hover {
+            background-color: $navbar-dropdown-item-hover-background-color;
+          }
+        }
+      }
+    }
+  }
+}
diff -pruN 1.3.1+dfsg-1/debian/embedded/Documenter/assets/html/scss/darkly/_variables.scss 1.4.0+dfsg-1/debian/embedded/Documenter/assets/html/scss/darkly/_variables.scss
--- 1.3.1+dfsg-1/debian/embedded/Documenter/assets/html/scss/darkly/_variables.scss	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/debian/embedded/Documenter/assets/html/scss/darkly/_variables.scss	2020-03-30 16:16:04.000000000 +0000
@@ -0,0 +1,105 @@
+////////////////////////////////////////////////
+// DARKLY
+////////////////////////////////////////////////
+$grey-lighter: #dbdee0;
+$grey-light:   #8c9b9d;
+$grey:         darken($grey-light, 18);
+$grey-dark:    darken($grey, 18);
+$grey-darker:  darken($grey, 23);
+
+$orange: #e67e22;
+$yellow: #f1b70e;
+$green: #2ecc71;
+$turquoise: #1abc9c;
+$blue: #3498db;
+$purple: #8e44ad;
+$red: #e74c3c;
+$white-ter: #ecf0f1;
+$primary: #375a7f !default;
+$yellow-invert: #fff;
+
+$family-sans-serif: "Lato", -apple-system, BlinkMacSystemFont, "Segoe UI", "Helvetica Neue", "Helvetica", "Arial", sans-serif;
+$family-monospace: "Inconsolata", "Consolas", "Monaco", monospace;
+
+$radius-small: 3px;
+$radius: .4em;
+$radius-large: 8px;
+$size-6: 15px;
+$size-7: .85em;
+$title-weight: 500;
+$subtitle-weight: 400;
+$subtitle-color: $grey-dark;
+
+$border-width: 2px;
+$border: $grey;
+
+$body-background-color: darken($grey-darker, 4);
+$body-size: 15px;
+
+$background: $grey-darker;
+$footer-background-color: $background;
+$button-background-color: $background;
+$button-border-color: lighten($button-background-color, 15);
+
+$title-color: #fff;
+$subtitle-color: $grey-light;
+$subtitle-strong-color: $grey-light;
+
+$text: #fff;
+$text-light: lighten($text, 10);
+$text-strong: darken($text, 5);
+
+$box-color: $text;
+$box-background-color: $grey-dark;
+$box-shadow: none;
+
+$link: $turquoise;
+$link-hover: lighten($link, 5);
+$link-focus: darken($link, 5);
+$link-active: darken($link, 5);
+$link-focus-border: $grey-light;
+
+$button-color: $primary;
+$button-hover-color: darken($text, 5); // text-dark
+$button-focus: darken($text, 5); // text-dark
+$button-active-color: darken($text, 5); // text-dark
+$button-disabled-background-color: $grey-light;
+
+$input-hover-color: $grey-light;
+$input-disabled-background-color: $grey-light;
+$input-disabled-border: $grey-lighter;
+
+$table-color: $text;
+$table-head: $grey-lighter;
+$table-background-color: $grey-dark;
+$table-cell-border: 1px solid $grey;
+
+$table-row-hover-background-color: $grey-darker;
+$table-striped-row-even-background-color: $grey-darker;
+$table-striped-row-even-hover-background-color: lighten($grey-darker, 2);
+
+$pagination-color: $link;
+$pagination-border-color: $border;
+
+$navbar-height: 4rem;
+
+$navbar-background-color: $primary;
+$navbar-item-color: $text;
+$navbar-item-hover-color: $link;
+$navbar-item-hover-background-color: transparent;
+$navbar-item-active-color: $link;
+$navbar-dropdown-arrow: #fff;
+$navbar-divider-background-color: rgba(0, 0, 0, 0.2);
+$navbar-dropdown-border-top: 1px solid $navbar-divider-background-color;
+$navbar-dropdown-background-color: $primary;
+$navbar-dropdown-item-hover-color: $grey-lighter;
+$navbar-dropdown-item-hover-background-color: transparent;
+$navbar-dropdown-item-active-background-color: transparent;
+$navbar-dropdown-item-active-color: $link;
+
+$dropdown-content-background-color: $background;
+$dropdown-item-color: $text;
+
+$progress-value-background-color: $grey-lighter;
+
+$bulmaswatch-import-font: true !default;
diff -pruN 1.3.1+dfsg-1/debian/embedded/Documenter/assets/html/scss/documenter/components/_admonition.scss 1.4.0+dfsg-1/debian/embedded/Documenter/assets/html/scss/documenter/components/_admonition.scss
--- 1.3.1+dfsg-1/debian/embedded/Documenter/assets/html/scss/documenter/components/_admonition.scss	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/debian/embedded/Documenter/assets/html/scss/documenter/components/_admonition.scss	2020-03-30 16:16:04.000000000 +0000
@@ -0,0 +1,105 @@
+// This is a heavily customized version of Bulma's message component
+// Original copyright (c) 2019 Jeremy Thomas, The MIT License (MIT)
+$admonition-colors: (
+  'default': $grey-darker, 'info': $info, 'success': $success, 'warning': $warning,
+  'danger': $danger, 'compat': $turquoise,
+) !default;
+
+$admonition-background: () !default;
+$admonition-body-color: () !default;
+$admonition-header-background: () !default;
+$admonition-header-color: () !default;
+@each $name, $color in $admonition-colors {
+  $bg: lighten-color($color, 4);
+  @if not map-has-key($admonition-header-background, $name) {
+    $admonition-header-background: map-merge($admonition-header-background, ($name: $color)) !global;
+  }
+  @if not map-has-key($admonition-header-color, $name) {
+    $admonition-header-color: map-merge($admonition-header-color, ($name: findColorInvert($color))) !global;
+  }
+  @if not map-has-key($admonition-background, $name) {
+    $admonition-background: map-merge($admonition-background, ($name: $bg)) !global;
+  }
+  @if not map-has-key($admonition-body-color, $name) {
+    $admonition-body-color: map-merge($admonition-body-color, ($name: findColorInvert($bg))) !global;
+  }
+}
+
+.admonition {
+  @extend %block;
+
+  background-color: map-get($admonition-background, 'default');
+  border-style: solid;
+  border-width: 1px;
+  border-color: map-get($admonition-header-background, 'default');
+  border-radius: $message-radius;
+  font-size: $size-normal;
+
+  strong {
+    color: currentColor;
+  }
+
+  // Sizes
+  &.is-small {
+    font-size: $size-small;
+  }
+
+  &.is-medium {
+    font-size: $size-medium;
+  }
+
+  &.is-large {
+    font-size: $size-large;
+  }
+
+  // Colors
+  @each $name, $pair in $admonition-colors {
+    // $text-color: desaturate(darken($color, $darken-percentage), $desaturate-percentage);
+    // $color-lightning: max(100% - lightness($color) - 5%, 0%);
+    // $background: lighten($color, $color-lightning);
+
+    &.is-#{$name} {
+      background-color: map-get($admonition-background, $name);
+      border-color: map-get($admonition-header-background, $name);
+
+      > .admonition-header {
+        background-color: map-get($admonition-header-background, $name);
+        color: map-get($admonition-header-color, $name);
+      }
+
+      > .admonition-body {
+        color: map-get($admonition-body-color, $name);
+      }
+    }
+  }
+}
+
+.admonition-header {
+  color: map-get($admonition-header-color, 'default');
+  background-color: map-get($admonition-header-background, 'default');
+  align-items: center;
+  font-weight: $message-header-weight;
+  justify-content: space-between;
+  line-height: 1.25;
+  padding: $message-header-padding;
+  position: relative;
+
+  &:before {
+    @include font-awesome;
+    margin-right: $message-header-padding;
+    content: "\f06a";
+}
+}
+
+.admonition-body {
+  color: $message-body-color;
+  padding: $message-body-padding;
+
+  pre {
+    background-color: $background;
+  }
+
+  code {
+    background-color: $code-background;
+  }
+}
diff -pruN 1.3.1+dfsg-1/debian/embedded/Documenter/assets/html/scss/documenter/components/_all.scss 1.4.0+dfsg-1/debian/embedded/Documenter/assets/html/scss/documenter/components/_all.scss
--- 1.3.1+dfsg-1/debian/embedded/Documenter/assets/html/scss/documenter/components/_all.scss	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/debian/embedded/Documenter/assets/html/scss/documenter/components/_all.scss	2020-03-30 16:16:04.000000000 +0000
@@ -0,0 +1,2 @@
+@import "admonition";
+@import "docstring";
diff -pruN 1.3.1+dfsg-1/debian/embedded/Documenter/assets/html/scss/documenter/components/_docstring.scss 1.4.0+dfsg-1/debian/embedded/Documenter/assets/html/scss/documenter/components/_docstring.scss
--- 1.3.1+dfsg-1/debian/embedded/Documenter/assets/html/scss/documenter/components/_docstring.scss	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/debian/embedded/Documenter/assets/html/scss/documenter/components/_docstring.scss	2020-03-30 16:16:04.000000000 +0000
@@ -0,0 +1,60 @@
+// The docstring element which reuses parts of the Bulma card component
+.docstring {
+  margin-bottom: 1em;
+  background-color: $documenter-docstring-background;
+  border: 1px solid $border;
+  box-shadow: $documenter-docstring-shadow;
+  max-width: 100%;
+
+  > header {
+    display: flex;
+    flex-grow: 1;
+    align-items: stretch;
+    padding: $card-header-padding;
+
+    background-color: $background;
+    box-shadow: $card-header-shadow;
+    box-shadow: none;
+    border-bottom: 1px solid $border;
+
+    code {
+      background-color: transparent;
+    }
+
+    .docstring-binding {
+      margin-right: 0.3em;
+    }
+    .docstring-category {
+      margin-left: 0.3em;
+    }
+  }
+
+  > section {
+    position: relative;
+    padding: $card-content-padding;
+
+    border-bottom: 1px solid $border;
+    &:last-child {
+      border-bottom: none;
+    }
+
+    > a.docs-sourcelink {
+      transition: opacity 0.3s;
+      opacity: 0;
+      position: absolute;
+      right: $card-content-padding-h / 2;
+      bottom: $card-content-padding-v / 2;
+      @extend .tag;
+      @extend .is-primary;
+      @extend .is-size-7;
+    }
+  }
+
+  &:hover > section > a.docs-sourcelink {
+    opacity: 0.2;
+  }
+
+  & > section:hover a.docs-sourcelink {
+    opacity: 1;
+  }
+}
diff -pruN 1.3.1+dfsg-1/debian/embedded/Documenter/assets/html/scss/documenter/_elements.scss 1.4.0+dfsg-1/debian/embedded/Documenter/assets/html/scss/documenter/_elements.scss
--- 1.3.1+dfsg-1/debian/embedded/Documenter/assets/html/scss/documenter/_elements.scss	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/debian/embedded/Documenter/assets/html/scss/documenter/_elements.scss	2020-03-30 16:16:04.000000000 +0000
@@ -0,0 +1,35 @@
+// Permalinks to page headings
+// Implemented as empty <a> tags inside the <hN> tags, showing up as chain icons
+h1, h2, h3, h4, h5, h6 {
+  .docs-heading-anchor {
+    &, &:hover, &:visited {
+      color: $content-heading-color;
+    }
+  }
+
+  .docs-heading-anchor-permalink {
+    visibility: hidden;
+    vertical-align: middle;
+    margin-left: 0.5em;
+    font-size: 0.7rem;
+
+    &::before {
+      @include font-awesome;
+      content: "\f0c1";
+    }
+  }
+  // the permalinks icon is only shown if the user hovers over the heading
+  &:hover .docs-heading-anchor-permalink {
+    visibility: visible;
+  }
+}
+
+@if $documenter-is-dark-theme {
+  .docs-light-only {
+    display: none !important;
+  }
+} @else {
+  .docs-dark-only {
+    display: none !important;
+  }
+}
diff -pruN 1.3.1+dfsg-1/debian/embedded/Documenter/assets/html/scss/documenter/layout/_all.scss 1.4.0+dfsg-1/debian/embedded/Documenter/assets/html/scss/documenter/layout/_all.scss
--- 1.3.1+dfsg-1/debian/embedded/Documenter/assets/html/scss/documenter/layout/_all.scss	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/debian/embedded/Documenter/assets/html/scss/documenter/layout/_all.scss	2020-03-30 16:16:04.000000000 +0000
@@ -0,0 +1,3 @@
+@import "main";
+@import "sidebar";
+@import "search";
diff -pruN 1.3.1+dfsg-1/debian/embedded/Documenter/assets/html/scss/documenter/layout/_main.scss 1.4.0+dfsg-1/debian/embedded/Documenter/assets/html/scss/documenter/layout/_main.scss
--- 1.3.1+dfsg-1/debian/embedded/Documenter/assets/html/scss/documenter/layout/_main.scss	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/debian/embedded/Documenter/assets/html/scss/documenter/layout/_main.scss	2020-03-30 16:16:04.000000000 +0000
@@ -0,0 +1,130 @@
+/* This file contain the overall layout.
+ *
+ * The main container is <div> that is identified by id #documenter.
+ */
+#documenter {
+  .docs-main {
+    > article {
+      // Long inline words can happen, so we'll break them in case that, instead of letting
+      // go into overflow. Most likely to happen with inline code snippets.
+      overflow-wrap: break-word;
+    }
+
+    @include desktop {
+      max-width: $documenter-max-width + 2*$documenter-main-padding;
+      margin-left: $documenter-sidebar-width + $documenter-sidebar-main-gap;
+      padding-right: $documenter-main-padding-right;
+    }
+
+    @include touch {
+      width: 100%;
+
+      > article {
+        max-width: $documenter-max-width + 2*$documenter-main-padding;
+        margin-left: auto;
+        margin-right: auto;
+        margin-bottom: 1rem;
+        padding: 0 $documenter-main-padding;
+      }
+      > header, > nav {
+        max-width: 100%;
+        width: 100%;
+        margin: 0;
+      }
+    }
+
+    // Navbar is the top bar of the page that contains the breadcrumb,
+    // the "Edit on GitHub" link and the sidebar burger (when on mobile).
+    header.docs-navbar {
+      background-color: $body-background-color;
+      border-bottom: 1px solid $border;
+      z-index: 2;
+
+      min-height: 4rem;
+      margin-bottom: 1rem;
+
+      display: flex;
+      .breadcrumb {
+        flex-grow: 1;
+      }
+
+      .docs-right {
+        display: flex;
+        .docs-icon, .docs-label, .docs-sidebar-button {
+          display: inline-block;
+        }
+        white-space: nowrap;
+        .docs-label {
+          padding: 0;
+          margin-left: 0.3em;
+        }
+        .docs-settings-button {
+          margin: auto 0 auto 1rem;
+        }
+        .docs-sidebar-button {
+          font-size: 1.5rem;
+          margin: auto 0 auto 1rem;
+        }
+      }
+
+      // ensure vertical middle alignment of everything in the navbar
+      > * {
+        margin: auto 0;
+      }
+
+      @include touch {
+        position: sticky;
+        top: 0;
+        padding: 0 1rem;
+
+        /* For Headroom.js */
+        transition-property: top, box-shadow;
+        -webkit-transition-property: top, box-shadow; /* Safari */
+        transition-duration: 0.3s;
+        -webkit-transition-duration: 0.3s; /* Safari */
+        &.headroom--not-top {
+          box-shadow: $shadow-size 0rem $shadow-blur $shadow;
+          transition-duration: 0.7s;
+          -webkit-transition-duration: 0.7s; /* Safari */
+        }
+        &.headroom--unpinned.headroom--not-top.headroom--not-bottom {
+          top: -4.5rem;
+          transition-duration: 0.7s;
+          -webkit-transition-duration: 0.7s; /* Safari */
+        }
+      }
+    }
+
+    // Footnotes
+    section.footnotes {
+      border-top: 1px solid $border;
+      li {
+        .tag:first-child {
+          margin-right: 1em;
+          margin-bottom: 0.4em;
+        }
+      }
+    }
+
+    .docs-footer {
+      display: flex;
+      margin-left: 0;
+      margin-right: 0;
+      border-top: 1px solid $border;
+      padding-top: 1rem;
+      padding-bottom: 1rem;
+
+      @include touch {
+        padding-left: $documenter-main-padding;
+        padding-right: $documenter-main-padding;
+      }
+
+      .docs-footer-nextpage, .docs-footer-prevpage {
+        flex-grow: 1;
+      }
+      .docs-footer-nextpage {
+        text-align: right;
+      }
+    }
+  }
+}
diff -pruN 1.3.1+dfsg-1/debian/embedded/Documenter/assets/html/scss/documenter/layout/_search.scss 1.4.0+dfsg-1/debian/embedded/Documenter/assets/html/scss/documenter/layout/_search.scss
--- 1.3.1+dfsg-1/debian/embedded/Documenter/assets/html/scss/documenter/layout/_search.scss	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/debian/embedded/Documenter/assets/html/scss/documenter/layout/_search.scss	2020-03-30 16:16:04.000000000 +0000
@@ -0,0 +1,27 @@
+// Additional styling for the search page
+#documenter .docs-main {
+  #documenter-search-info {
+    margin-bottom: 1rem;
+  }
+
+  #documenter-search-results {
+    // border: 1px solid $border;
+    // padding: 1rem;
+    list-style-type: circle;
+    list-style-position: outside;
+    // padding-left: 1rem;
+
+    li {
+      margin-left: 2rem;
+      // &::before {
+      //   @include font-awesome;
+      //   content: "";
+      // }
+      > header {
+      }
+    }
+    .docs-highlight {
+      background-color: yellow;
+    }
+  }
+}
diff -pruN 1.3.1+dfsg-1/debian/embedded/Documenter/assets/html/scss/documenter/layout/_sidebar.scss 1.4.0+dfsg-1/debian/embedded/Documenter/assets/html/scss/documenter/layout/_sidebar.scss
--- 1.3.1+dfsg-1/debian/embedded/Documenter/assets/html/scss/documenter/layout/_sidebar.scss	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/debian/embedded/Documenter/assets/html/scss/documenter/layout/_sidebar.scss	2020-03-30 16:16:04.000000000 +0000
@@ -0,0 +1,245 @@
+#documenter .docs-sidebar {
+  display: flex;
+  flex-direction: column;
+
+  color: $documenter-sidebar-color;
+  background-color: $documenter-sidebar-background;
+  border-right: 1px solid $border;
+  padding: 0;
+  flex: 0 0 $documenter-sidebar-width;
+  z-index: 5; // make sure it's on top of the main body and top bar
+
+  // This is mobile-first, so our default state is that the sidebar is hidden away left
+  // of the screen.
+  position: fixed;
+  left: -$documenter-sidebar-width;
+  width: $documenter-sidebar-width;
+  height: 100%;
+  transition: left 0.3s;
+  // Clicking on the hamburger on mobile toggles the .visible class on the sidebar
+  // If enabled, we'll move the sidebar into view. As it is now floating above the
+  // main body content, we apply a shadow.
+  &.visible {
+    left: 0;
+    box-shadow: 2*$shadow-size 0rem 2*$shadow-blur $shadow;
+    @include desktop {
+      // We make sure that the shadow is gone if we've ended up in non-mobile layout
+      // but the .visible class is still toggled.
+      box-shadow: none;
+    }
+  }
+  // In the non-mobile layout, we show the sidebar as a left panel of the dashboard.
+  @include desktop {
+    left: 0;
+    top: 0;
+  }
+
+  // The top bar of the sidebar bar contains:
+  // 1. Logo (optional)
+  .docs-logo {
+    margin-top: 1rem;
+    padding: 0 1rem;
+    > img {
+      @extend .image;
+      max-height: 6rem;
+      margin: auto;
+    }
+  }
+  // 2. The site name, from the sitename keyword (optional)
+  .docs-package-name {
+    flex-shrink: 0;
+    font-size: $documenter-sidebar-title-font-size;
+    font-weight: $weight-bold;
+    text-align: center;
+    white-space: nowrap;
+    overflow: hidden;
+    // The padding works around the problem that when you set overflow: hidden, part
+    // of the container gets hidden.
+    padding: 0.5rem 0;
+    // We don't know how wide the text is (the user can provide a _really_ long string to
+    // sitename). So we wrap the name in a <span> which can be dynamically resized with
+    // JS.
+    .docs-autofit {
+      max-width: $documenter-sidebar-title-width;
+    }
+  }
+
+  // The version selector (optional). It is hidden by default, but can be toggled by JS
+  // if there actually are some versions to display.
+  .docs-version-selector {
+    border-top: 1px solid $border;
+    display: none;
+    padding: 0.5rem;
+    &.visible {
+      display: flex;
+    }
+  }
+
+  // Styling, positioning etc. of the menu items
+  ul.docs-menu {
+    flex-grow: 1;
+
+    // Heavy-handed approach to disable selecting when you double click on an expandable menu
+    // item
+    user-select: none;
+
+    font-size: $size-normal;
+    border-top: 1px solid $border;
+    // background-color: $background;
+
+    padding-bottom: 1.5rem;
+
+    // First level items
+    > li {
+      // padding-left: 0.5em;
+      > .tocitem {
+        font-weight: bold;
+      }
+    }
+
+    // Second and lower
+    > li li {
+      font-size: 0.95*$size-normal;
+      margin-left: 1em;
+      border-left: 1px solid $border;
+
+      &.is-active {
+        // margin-left: 0;
+      }
+    }
+
+    /* Managing collapsible submenus */
+    input.collapse-toggle {
+        display: none;
+    }
+
+    ul.collapsed {
+        display: none;
+    }
+
+    input:checked ~ ul.collapsed {
+        display: block;
+    }
+
+    label.tocitem {
+      display: flex;
+      .docs-label {
+        flex-grow: 2;
+      }
+      .docs-chevron {
+        display: inline-block;
+        font-style: normal;
+        font-variant: normal;
+        text-rendering: auto;
+        line-height: 1;
+
+        font-size: 0.75*$size-normal;
+        margin-left: 1rem;
+        margin-top: auto;
+        margin-bottom: auto;
+        &::before {
+          @include font-awesome;
+          content: "\f054";
+        }
+      }
+    }
+    input:checked ~ label.tocitem .docs-chevron::before {
+      content: "\f078";
+    }
+
+    .tocitem {
+      display: block;
+      padding: 0.5rem 0.5rem;
+
+      &, &:hover {
+        color: $documenter-sidebar-color;
+      }
+    }
+
+    a, label {
+      &.tocitem:hover {
+        background-color: $documenter-sidebar-menu-hover-background;
+      }
+    }
+
+    li.is-active {
+      border-top: 1px solid $documenter-sidebar-menu-border;
+      border-bottom: 1px solid $border;
+      background-color: $documenter-sidebar-menu-active-background;
+
+      > .tocitem {
+        &, &:hover {
+          background-color: $documenter-sidebar-menu-active-background;
+          color: $documenter-sidebar-menu-active-color;
+        }
+      }
+    }
+
+    // The main ul.docs-menu already has a border-top, so we do not want to duplicate it
+    // here with the li border-top.
+    > li.is-active:first-child {
+      border-top: none;
+    }
+
+    // In-page headings
+    ul.internal {
+      margin: 0 0.5rem 0.5rem;
+      border-top: 1px solid $border;
+      li {
+        font-size: 0.85*$size-normal;
+        border-left: none;
+        margin-left: 0;
+        margin-top: 0.5rem;
+      }
+
+      .tocitem {
+        width: 100%;
+        padding: 0;
+
+        &::before {
+          content: "⚬";
+          margin-right: 0.4em;
+        }
+      }
+    }
+  }
+
+  form.docs-search {
+    > input {
+      @extend .input;
+      @extend .is-rounded;
+      @extend .is-small;
+      width: 0.8 * $documenter-sidebar-width;
+    }
+    margin: auto;
+    margin-top: 0.5rem;
+    margin-bottom: 0.5rem;
+  }
+
+  /* Setting up a nicer theme style for the scrollbar */
+  @mixin sidebar-scroll {
+    overflow-y: auto;
+    -webkit-overflow-scroll: touch;
+    &::-webkit-scrollbar {
+        width: .3rem;
+        background: none;
+    }
+
+    &::-webkit-scrollbar-thumb {
+        border-radius: 5px 0px 0px 5px;
+        background: $documenter-sidebar-scrollbar-color;
+    }
+
+    &::-webkit-scrollbar-thumb:hover {
+        background: $documenter-sidebar-scrollbar-color-hover;
+    }
+  }
+  @include desktop {
+    ul.docs-menu {
+      @include sidebar-scroll;
+    }
+  }
+  @include touch {
+    @include sidebar-scroll;
+  }
+}
diff -pruN 1.3.1+dfsg-1/debian/embedded/Documenter/assets/html/scss/documenter/_overrides.scss 1.4.0+dfsg-1/debian/embedded/Documenter/assets/html/scss/documenter/_overrides.scss
--- 1.3.1+dfsg-1/debian/embedded/Documenter/assets/html/scss/documenter/_overrides.scss	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/debian/embedded/Documenter/assets/html/scss/documenter/_overrides.scss	2020-03-30 16:16:04.000000000 +0000
@@ -0,0 +1,30 @@
+// Additional variables and overrides
+
+// While the docs claim that the navbar breakpoint is `mobile`, it actually is `desktop`.
+// Hence the need to override this variable.
+// $navbar-breakpoint: $tablet !default;
+
+$documenter-sidebar-title-width: 0.9 * $documenter-sidebar-width !default;
+$documenter-sidebar-menu-padding: 1rem !default;
+$documenter-sidebar-title-font-size: $size-large !default;
+
+$documenter-sidebar-background: $background !default;
+$documenter-sidebar-color: invert($documenter-sidebar-background) !default;
+
+$documenter-sidebar-scrollbar-color: darken-color($documenter-sidebar-background, 1) !default;
+$documenter-sidebar-scrollbar-color-hover: darken-color($documenter-sidebar-background, 2) !default;
+
+$documenter-sidebar-menu-border: darken-color($border, 1) !default;
+
+$documenter-sidebar-menu-active-background: lighten-color($documenter-sidebar-background, 0.5) !default;
+$documenter-sidebar-menu-active-color: $documenter-sidebar-color !default;
+
+$documenter-sidebar-menu-hover-background: darken-color($documenter-sidebar-background, 0.5) !default;
+
+$breadcrumb-item-disabled-color: $text-strong !default;
+
+$content-pre-padding: 0.7rem 0.5rem !default;
+
+$admonition-background: ('default': $grey-light, 'warning': #fff3c5) !default;
+
+$documenter-docstring-shadow: 2px 2px 3px rgba($black, 0.1) !default;
diff -pruN 1.3.1+dfsg-1/debian/embedded/Documenter/assets/html/scss/documenter/_patches.scss 1.4.0+dfsg-1/debian/embedded/Documenter/assets/html/scss/documenter/_patches.scss
--- 1.3.1+dfsg-1/debian/embedded/Documenter/assets/html/scss/documenter/_patches.scss	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/debian/embedded/Documenter/assets/html/scss/documenter/_patches.scss	2020-03-30 16:16:04.000000000 +0000
@@ -0,0 +1,73 @@
+// We need to override some .content behavior
+.content {
+  pre {
+    border: 1px solid $border;
+  }
+  // Bold code spans
+  code {
+    font-weight: inherit;
+  }
+  a code {
+    color: $link;
+  }
+  h1, h2, h3, h4, h5, h6 {
+    code {
+      color: $content-heading-color;
+    }
+  }
+  // Don't make tables full-width and make sure that overflowing tables are scrollable
+  table {
+    display: block;
+    width: initial;
+    max-width: 100%;
+    overflow-x: auto;
+  }
+  // kbd tags
+  kbd {
+    @extend .tag;
+    @extend .is-dark;
+  }
+  //
+  blockquote, .admonition-body {
+    > ul:first-child, > ol:first-child {
+      margin-top: 0;
+    }
+  }
+}
+
+// We want to be able to disable certain breadcrumb components
+.breadcrumb a.is-disabled {
+  cursor: default;
+  pointer-events: none;
+  &, &:hover{
+    color: $breadcrumb-item-disabled-color;
+  }
+}
+
+// highlight.js background color fix
+.hljs {
+  background: initial !important;
+  padding: initial !important;
+}
+
+// There appears to be a rendering bug in Chrome, where elements with `position: absolute` in
+// an overflow container affect whether the outer container is overflowing / needs
+// scrollbars.
+//
+// In this particular case, KaTeX applies `position: absolute` on the the MathML
+// accessibility span. This breaks the dashboard layout of the equation is somewhere far
+// down in the container.
+//
+// Moving all of these accessbility "pixels" to the top-right seems to take care of the
+// issue. An alternative is also to use `position: fixed`, which does not cause the outer
+// container to scroll.
+.katex .katex-mathml {
+  top: 0;
+  right: 0;
+}
+
+// Set font subpixel rendering to auto on the HTML tag
+html {
+  -moz-osx-font-smoothing: auto;
+  -webkit-font-smoothing: auto;
+}
diff -pruN 1.3.1+dfsg-1/debian/embedded/Documenter/assets/html/scss/documenter/_theme_overrides.scss 1.4.0+dfsg-1/debian/embedded/Documenter/assets/html/scss/documenter/_theme_overrides.scss
--- 1.3.1+dfsg-1/debian/embedded/Documenter/assets/html/scss/documenter/_theme_overrides.scss	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/debian/embedded/Documenter/assets/html/scss/documenter/_theme_overrides.scss	2020-03-30 16:16:04.000000000 +0000
@@ -0,0 +1,9 @@
+& {
+  background-color: $body-background-color;
+  font-size: $body-size;
+  min-width: $body-min-width;
+  overflow-x: $body-overflow-x;
+  overflow-y: $body-overflow-y;
+  text-rendering: $body-rendering;
+  text-size-adjust: 100%;
+}
diff -pruN 1.3.1+dfsg-1/debian/embedded/Documenter/assets/html/scss/documenter/_utilities.scss 1.4.0+dfsg-1/debian/embedded/Documenter/assets/html/scss/documenter/_utilities.scss
--- 1.3.1+dfsg-1/debian/embedded/Documenter/assets/html/scss/documenter/_utilities.scss	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/debian/embedded/Documenter/assets/html/scss/documenter/_utilities.scss	2020-03-30 16:16:04.000000000 +0000
@@ -0,0 +1,5 @@
+/* Font Awesome 5 mixin. Can be included in any rule that should render Font Awesome icons. */
+@mixin font-awesome {
+  font-family: "Font Awesome 5 Free";
+  font-weight: 900;
+}
diff -pruN 1.3.1+dfsg-1/debian/embedded/Documenter/assets/html/scss/documenter/_variables.scss 1.4.0+dfsg-1/debian/embedded/Documenter/assets/html/scss/documenter/_variables.scss
--- 1.3.1+dfsg-1/debian/embedded/Documenter/assets/html/scss/documenter/_variables.scss	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/debian/embedded/Documenter/assets/html/scss/documenter/_variables.scss	2020-03-30 16:16:04.000000000 +0000
@@ -0,0 +1,80 @@
+// Variable definitions. Some are Documenter-specific, others are setting Bulma variables.
+
+
+// Colors
+// ------
+$primary: #4eb5de !default;
+$red: #da0b00 !default;
+$blue: #2e63b8 !default;
+$green: #22c35b !default;
+$turquoise: #1db5c9 !default;
+$text: #222222 !default;
+$text-strong: $text !default;
+$code: #000000 !default;
+// The inline <code> tags get rendered on various different backgrounds. Therefore, in order
+// to make sure it always renders nicely, we'll just use transparent black color to make the
+// background of the <code> elements slightly darker.
+$code-background: rgba(0, 0, 0, 0.05);
+$code-padding: 0.1em;
+
+$documenter-docstring-background: transparent !default;
+
+$documenter-is-dark-theme: false !default;
+
+// Helper functions
+// ----------------
+// Declares the amount of lightness modifier used in the darken-color and lighten-color
+// functions. Setting this to a negative value is useful for dark themes.
+$lightness-unit: 8% !default;
+// Uses adjust-color to create a darker version of $color
+@function darken-color($color, $factor) {
+  @return adjust-color($color, $lightness: -$factor*$lightness-unit);
+}
+// Uses adjust-color to create a lighter version of $color
+@function lighten-color($color, $factor) {
+  @return adjust-color($color, $lightness: $factor*$lightness-unit);
+}
+
+
+// Fonts
+// -----
+// Declares the font family for the main text.
+$family-sans-serif: 'Lato', -apple-system, BlinkMacSystemFont, "Segoe UI", "Helvetica Neue", "Helvetica", "Arial", sans-serif !default;
+$family-monospace: 'Roboto Mono', 'SFMono-Regular', 'Menlo', 'Consolas', 'Liberation Mono', 'DejaVu Sans Mono', monospace !default;
+// Note: declaring a font family here does not necessarily mean that it will be available
+// for the user. For uncommon fonts it is up to the user to also provide the necessary font
+// assets, e.g. via a CDN, in the makedocs() call.
+
+
+// Shadows
+// -------
+// Shadows are used to visually elevate UI elements that are "floating" (e.g. the sidebar
+// on mobile layout).
+$shadow: #bbb !default;
+$shadow-size: 0.2rem !default;
+$shadow-blur: 0.4rem !default;
+
+
+// Layout
+// ------
+$body-overflow-x: auto !default;
+$body-size: 16px !default;
+$documenter-max-width: 50rem !default;
+$documenter-sidebar-width: 18rem !default;
+
+$documenter-sidebar-main-gap: 2rem !default;
+$documenter-main-padding-right: 1rem !default;
+$documenter-main-padding: 1rem !default;
+
+// We'll override the Bulma $tablet width, which is the point at which the
+// layout switches between the mobile and tablet modes. Note: $tablet needs
+// to be in px, hence the unit conversion.
+$desktop: round($body-size * ($documenter-max-width + $documenter-sidebar-width + $documenter-sidebar-main-gap + $documenter-main-padding-right - 5rem)/1rem) !default;
+
+// Admonitions
+$message-header-padding: 0.75em;
+$message-body-padding: 1em 1.25em;
+// Docstrings
+$card-content-padding-v: 1rem;
+$card-content-padding-h: 1.25rem;
+$card-content-padding: $card-content-padding-v $card-content-padding-h;
diff -pruN 1.3.1+dfsg-1/debian/embedded/Documenter/assets/html/scss/documenter-dark.scss 1.4.0+dfsg-1/debian/embedded/Documenter/assets/html/scss/documenter-dark.scss
--- 1.3.1+dfsg-1/debian/embedded/Documenter/assets/html/scss/documenter-dark.scss	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/debian/embedded/Documenter/assets/html/scss/documenter-dark.scss	2020-03-30 16:16:04.000000000 +0000
@@ -0,0 +1,99 @@
+@charset "UTF-8";
+// The Documente dark theme is a modified version of the Darkly theme from Bulmaswatch:
+// https://jenil.github.io/bulmaswatch/, https://github.com/jenil/bulmaswatch
+$themename: "documenter-dark"; // CSS file must be called `$(themename).css`
+
+// Darkly wants to @import the Lato font by default, but we don't need it.
+$bulmaswatch-import-font: false;
+
+@import "darkly/variables";
+
+$documenter-is-dark-theme: true;
+
+$family-sans-serif: 'Lato', -apple-system, BlinkMacSystemFont, "Segoe UI", "Helvetica Neue", "Helvetica", "Arial", sans-serif;
+$family-monospace: 'Roboto Mono', 'SFMono-Regular', 'Menlo', 'Consolas', 'Liberation Mono', 'DejaVu Sans Mono', monospace;
+
+$info: #024c7d;
+$success: #008438;
+$warning: #ad8100;
+$danger: #9e1b0d;
+$turquoise: #137886;
+
+$admonition-background: (
+  'default': $background, 'info': $background, 'success': $background, 'warning': $background,
+  'danger': $background, 'compat': $background
+);
+$admonition-header-background: ('default': $grey);
+
+$body-size: 16px;
+$documenter-sidebar-background: $grey-darker;
+$shadow: #171717;
+$documenter-sidebar-color: $text;
+$lightness-unit: -8%;
+
+// $docstring-pre-background: adjust-color($background, $lightness: 5);
+$border-width: 1px;
+
+@import "documenter/utilities";
+@import "documenter/variables";
+
+$code: $red;
+$code-background: rgba(255, 255, 255, 0.05);
+
+$documenter-docstring-shadow: none;
+
+@import "bulma/utilities/all";
+@import "bulma/base/minireset.sass";
+@import "bulma/base/helpers.sass";
+
+// Search box, version selector etc.
+$input-color: $grey-lighter;
+$input-background-color: $body-background-color;
+$input-border-color: $border;
+$input-placeholder-color: rgba($input-color, 0.3);
+
+$button-static-color: $grey-lighter;
+$button-static-background-color: $background;
+$button-static-border-color: $border;
+
+// All secondary themes have to be nested in a theme--$(themename) class. When Documenter
+// switches themes, it applies this class to <html> and then disables the primary
+// stylesheet.
+html.theme--#{$themename} {
+  @import "bulma/base/generic.sass";
+
+  @import "documenter/overrides";
+
+  @import "bulma/elements/all";
+  @import "bulma/form/all";
+  @import "bulma/components/all";
+  @import "bulma/grid/all";
+  @import "bulma/layout/all";
+
+  @import "darkly/overrides";
+
+  @import "documenter/elements";
+  @import "documenter/components/all";
+  @import "documenter/patches";
+  @import "documenter/layout/all";
+
+  @import "documenter/theme_overrides";
+
+  // .docstring {
+  //   border: $border-width solid $border;
+  //   box-shadow: none;
+  //
+  //   header {
+  //     box-shadow: none;
+  //     background-color: rgba($black-bis, 0.2);
+  //     border-radius: $radius $radius 0 0;
+  //   }
+  // }
+
+  // FIXME: Hack to get a proper theme for highlight.js in the Darkly theme
+  @import "highlightjs/a11y-dark";
+  // Also, a11y-dark does not highlight string interpolation properly.
+  .hljs-subst {
+    color: #f8f8f2;
+  }
+}
diff -pruN 1.3.1+dfsg-1/debian/embedded/Documenter/assets/html/scss/documenter-light.scss 1.4.0+dfsg-1/debian/embedded/Documenter/assets/html/scss/documenter-light.scss
--- 1.3.1+dfsg-1/debian/embedded/Documenter/assets/html/scss/documenter-light.scss	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/debian/embedded/Documenter/assets/html/scss/documenter-light.scss	2020-03-30 16:16:04.000000000 +0000
@@ -0,0 +1,24 @@
+@charset "UTF-8";
+
+@import "documenter/utilities";
+@import "documenter/variables";
+
+@import "bulma/utilities/all";
+@import "bulma/base/all";
+
+@import "documenter/overrides";
+
+@import "bulma/elements/all";
+@import "bulma/form/all";
+@import "bulma/components/all";
+@import "bulma/grid/all";
+@import "bulma/layout/all";
+
+@import "documenter/elements";
+@import "documenter/components/all";
+@import "documenter/patches";
+@import "documenter/layout/all";
+
+// Workaround to compile in highlightjs theme, so that we could have different
+// themes for both
+@import "highlightjs/default"
diff -pruN 1.3.1+dfsg-1/debian/embedded/Documenter/assets/html/scss/highlightjs/a11y-dark.css 1.4.0+dfsg-1/debian/embedded/Documenter/assets/html/scss/highlightjs/a11y-dark.css
--- 1.3.1+dfsg-1/debian/embedded/Documenter/assets/html/scss/highlightjs/a11y-dark.css	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/debian/embedded/Documenter/assets/html/scss/highlightjs/a11y-dark.css	2020-03-30 16:16:04.000000000 +0000
@@ -0,0 +1,99 @@
+/* a11y-dark theme */
+/* Based on the Tomorrow Night Eighties theme: https://github.com/isagalaev/highlight.js/blob/master/src/styles/tomorrow-night-eighties.css */
+/* @author: ericwbailey */
+
+/* Comment */
+.hljs-comment,
+.hljs-quote {
+  color: #d4d0ab;
+}
+
+/* Red */
+.hljs-variable,
+.hljs-template-variable,
+.hljs-tag,
+.hljs-name,
+.hljs-selector-id,
+.hljs-selector-class,
+.hljs-regexp,
+.hljs-deletion {
+  color: #ffa07a;
+}
+
+/* Orange */
+.hljs-number,
+.hljs-built_in,
+.hljs-builtin-name,
+.hljs-literal,
+.hljs-type,
+.hljs-params,
+.hljs-meta,
+.hljs-link {
+  color: #f5ab35;
+}
+
+/* Yellow */
+.hljs-attribute {
+  color: #ffd700;
+}
+
+/* Green */
+.hljs-string,
+.hljs-symbol,
+.hljs-bullet,
+.hljs-addition {
+  color: #abe338;
+}
+
+/* Blue */
+.hljs-title,
+.hljs-section {
+  color: #00e0e0;
+}
+
+/* Purple */
+.hljs-keyword,
+.hljs-selector-tag {
+  color: #dcc6e0;
+}
+
+.hljs {
+  display: block;
+  overflow-x: auto;
+  background: #2b2b2b;
+  color: #f8f8f2;
+  padding: 0.5em;
+}
+
+.hljs-emphasis {
+  font-style: italic;
+}
+
+.hljs-strong {
+  font-weight: bold;
+}
+
+@media screen and (-ms-high-contrast: active) {
+  .hljs-addition,
+  .hljs-attribute,
+  .hljs-built_in,
+  .hljs-builtin-name,
+  .hljs-bullet,
+  .hljs-comment,
+  .hljs-link,
+  .hljs-literal,
+  .hljs-meta,
+  .hljs-number,
+  .hljs-params,
+  .hljs-string,
+  .hljs-symbol,
+  .hljs-type,
+  .hljs-quote {
+        color: highlight;
+    }
+
+    .hljs-keyword,
+    .hljs-selector-tag {
+        font-weight: bold;
+    }
+}
diff -pruN 1.3.1+dfsg-1/debian/embedded/Documenter/assets/html/scss/highlightjs/default.css 1.4.0+dfsg-1/debian/embedded/Documenter/assets/html/scss/highlightjs/default.css
--- 1.3.1+dfsg-1/debian/embedded/Documenter/assets/html/scss/highlightjs/default.css	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/debian/embedded/Documenter/assets/html/scss/highlightjs/default.css	2020-03-30 16:16:04.000000000 +0000
@@ -0,0 +1,99 @@
+/*
+
+Original highlight.js style (c) Ivan Sagalaev <maniac@softwaremaniacs.org>
+
+*/
+
+.hljs {
+  display: block;
+  overflow-x: auto;
+  padding: 0.5em;
+  background: #F0F0F0;
+}
+
+
+/* Base color: saturation 0; */
+
+.hljs,
+.hljs-subst {
+  color: #444;
+}
+
+.hljs-comment {
+  color: #888888;
+}
+
+.hljs-keyword,
+.hljs-attribute,
+.hljs-selector-tag,
+.hljs-meta-keyword,
+.hljs-doctag,
+.hljs-name {
+  font-weight: bold;
+}
+
+
+/* User color: hue: 0 */
+
+.hljs-type,
+.hljs-string,
+.hljs-number,
+.hljs-selector-id,
+.hljs-selector-class,
+.hljs-quote,
+.hljs-template-tag,
+.hljs-deletion {
+  color: #880000;
+}
+
+.hljs-title,
+.hljs-section {
+  color: #880000;
+  font-weight: bold;
+}
+
+.hljs-regexp,
+.hljs-symbol,
+.hljs-variable,
+.hljs-template-variable,
+.hljs-link,
+.hljs-selector-attr,
+.hljs-selector-pseudo {
+  color: #BC6060;
+}
+
+
+/* Language color: hue: 90; */
+
+.hljs-literal {
+  color: #78A960;
+}
+
+.hljs-built_in,
+.hljs-bullet,
+.hljs-code,
+.hljs-addition {
+  color: #397300;
+}
+
+
+/* Meta color: hue: 200 */
+
+.hljs-meta {
+  color: #1f7199;
+}
+
+.hljs-meta-string {
+  color: #4d99bf;
+}
+
+
+/* Misc effects */
+
+.hljs-emphasis {
+  font-style: italic;
+}
+
+.hljs-strong {
+  font-weight: bold;
+}
diff -pruN 1.3.1+dfsg-1/debian/embedded/Documenter/assets/html/search.js 1.4.0+dfsg-1/debian/embedded/Documenter/assets/html/search.js
--- 1.3.1+dfsg-1/debian/embedded/Documenter/assets/html/search.js	2019-11-28 04:21:05.000000000 +0000
+++ 1.4.0+dfsg-1/debian/embedded/Documenter/assets/html/search.js	2020-03-30 16:16:04.000000000 +0000
@@ -1,250 +1,238 @@
-/*
- * Part of Documenter.jl
- *     https://github.com/JuliaDocs/Documenter.jl
- *
- * License: MIT
- */
-
-// parseUri 1.2.2
-// (c) Steven Levithan <stevenlevithan.com>
-// MIT License
-function parseUri (str) {
-	var	o   = parseUri.options,
-		m   = o.parser[o.strictMode ? "strict" : "loose"].exec(str),
-		uri = {},
-		i   = 14;
-
-	while (i--) uri[o.key[i]] = m[i] || "";
-
-	uri[o.q.name] = {};
-	uri[o.key[12]].replace(o.q.parser, function ($0, $1, $2) {
-		if ($1) uri[o.q.name][$1] = $2;
-	});
-
-	return uri;
-};
-parseUri.options = {
-	strictMode: false,
-	key: ["source","protocol","authority","userInfo","user","password","host","port","relative","path","directory","file","query","anchor"],
-	q:   {
-		name:   "queryKey",
-		parser: /(?:^|&)([^&=]*)=?([^&]*)/g
-	},
-	parser: {
-		strict: /^(?:([^:\/?#]+):)?(?:\/\/((?:(([^:@]*)(?::([^:@]*))?)?@)?([^:\/?#]*)(?::(\d*))?))?((((?:[^?#\/]*\/)*)([^?#]*))(?:\?([^#]*))?(?:#(.*))?)/,
-		loose:  /^(?:(?![^:@]+:[^:@\/]*@)([^:\/?#.]+):)?(?:\/\/)?((?:(([^:@]*)(?::([^:@]*))?)?@)?([^:\/?#]*)(?::(\d*))?)(((\/(?:[^?#](?![^?#\/]*\.[^?#\/.]+(?:[?#]|$)))*\/?)?([^?#\/]*))(?:\?([^#]*))?(?:#(.*))?)/
-	}
-};
-
-requirejs.config({
-    paths: {
-        'jquery': 'https://cdnjs.cloudflare.com/ajax/libs/jquery/3.1.1/jquery.min',
-        'lunr': 'https://cdnjs.cloudflare.com/ajax/libs/lunr.js/2.3.5/lunr.min',
-        'lodash': 'https://cdnjs.cloudflare.com/ajax/libs/lodash.js/4.17.11/lodash.min',
-    }
-});
+// libraries: jquery, lunr, lodash
+// arguments: $, lunr, _
 
-var currentScript = document.currentScript;
+$(document).ready(function() {
+  // parseUri 1.2.2
+  // (c) Steven Levithan <stevenlevithan.com>
+  // MIT License
+  function parseUri (str) {
+    var  o   = parseUri.options,
+      m   = o.parser[o.strictMode ? "strict" : "loose"].exec(str),
+      uri = {},
+      i   = 14;
+
+    while (i--) uri[o.key[i]] = m[i] || "";
+
+    uri[o.q.name] = {};
+    uri[o.key[12]].replace(o.q.parser, function ($0, $1, $2) {
+      if ($1) uri[o.q.name][$1] = $2;
+    });
+
+    return uri;
+  };
+  parseUri.options = {
+    strictMode: false,
+    key: ["source","protocol","authority","userInfo","user","password","host","port","relative","path","directory","file","query","anchor"],
+    q:   {
+      name:   "queryKey",
+      parser: /(?:^|&)([^&=]*)=?([^&]*)/g
+    },
+    parser: {
+      strict: /^(?:([^:\/?#]+):)?(?:\/\/((?:(([^:@]*)(?::([^:@]*))?)?@)?([^:\/?#]*)(?::(\d*))?))?((((?:[^?#\/]*\/)*)([^?#]*))(?:\?([^#]*))?(?:#(.*))?)/,
+      loose:  /^(?:(?![^:@]+:[^:@\/]*@)([^:\/?#.]+):)?(?:\/\/)?((?:(([^:@]*)(?::([^:@]*))?)?@)?([^:\/?#]*)(?::(\d*))?)(((\/(?:[^?#](?![^?#\/]*\.[^?#\/.]+(?:[?#]|$)))*\/?)?([^?#\/]*))(?:\?([^#]*))?(?:#(.*))?)/
+    }
+  };
 
-require(["jquery", "lunr", "lodash"], function($, lunr, _) {
-    $("#search-form").submit(function(e) {
-        e.preventDefault()
+  $("#search-form").submit(function(e) {
+    e.preventDefault()
+  })
+
+  // list below is the lunr 2.1.3 list minus the intersect with names(Base)
+  // (all, any, get, in, is, which) and (do, else, for, let, where, while, with)
+  // ideally we'd just filter the original list but it's not available as a variable
+  lunr.stopWordFilter = lunr.generateStopWordFilter([
+    'a',
+    'able',
+    'about',
+    'across',
+    'after',
+    'almost',
+    'also',
+    'am',
+    'among',
+    'an',
+    'and',
+    'are',
+    'as',
+    'at',
+    'be',
+    'because',
+    'been',
+    'but',
+    'by',
+    'can',
+    'cannot',
+    'could',
+    'dear',
+    'did',
+    'does',
+    'either',
+    'ever',
+    'every',
+    'from',
+    'got',
+    'had',
+    'has',
+    'have',
+    'he',
+    'her',
+    'hers',
+    'him',
+    'his',
+    'how',
+    'however',
+    'i',
+    'if',
+    'into',
+    'it',
+    'its',
+    'just',
+    'least',
+    'like',
+    'likely',
+    'may',
+    'me',
+    'might',
+    'most',
+    'must',
+    'my',
+    'neither',
+    'no',
+    'nor',
+    'not',
+    'of',
+    'off',
+    'often',
+    'on',
+    'only',
+    'or',
+    'other',
+    'our',
+    'own',
+    'rather',
+    'said',
+    'say',
+    'says',
+    'she',
+    'should',
+    'since',
+    'so',
+    'some',
+    'than',
+    'that',
+    'the',
+    'their',
+    'them',
+    'then',
+    'there',
+    'these',
+    'they',
+    'this',
+    'tis',
+    'to',
+    'too',
+    'twas',
+    'us',
+    'wants',
+    'was',
+    'we',
+    'were',
+    'what',
+    'when',
+    'who',
+    'whom',
+    'why',
+    'will',
+    'would',
+    'yet',
+    'you',
+    'your'
+  ])
+
+  // add . as a separator, because otherwise "title": "Documenter.Anchors.add!"
+  // would not find anything if searching for "add!", only for the entire qualification
+  lunr.tokenizer.separator = /[\s\-\.]+/
+
+  // custom trimmer that doesn't strip @ and !, which are used in julia macro and function names
+  lunr.trimmer = function (token) {
+    return token.update(function (s) {
+      return s.replace(/^[^a-zA-Z0-9@!]+/, '').replace(/[^a-zA-Z0-9@!]+$/, '')
     })
+  }
+
+  lunr.Pipeline.registerFunction(lunr.stopWordFilter, 'juliaStopWordFilter')
+  lunr.Pipeline.registerFunction(lunr.trimmer, 'juliaTrimmer')
 
-    // list below is the lunr 2.1.3 list minus the intersect with names(Base)
-    // (all, any, get, in, is, which) and (do, else, for, let, where, while, with)
-    // ideally we'd just filter the original list but it's not available as a variable
-    lunr.stopWordFilter = lunr.generateStopWordFilter([
-        'a',
-        'able',
-        'about',
-        'across',
-        'after',
-        'almost',
-        'also',
-        'am',
-        'among',
-        'an',
-        'and',
-        'are',
-        'as',
-        'at',
-        'be',
-        'because',
-        'been',
-        'but',
-        'by',
-        'can',
-        'cannot',
-        'could',
-        'dear',
-        'did',
-        'does',
-        'either',
-        'ever',
-        'every',
-        'from',
-        'got',
-        'had',
-        'has',
-        'have',
-        'he',
-        'her',
-        'hers',
-        'him',
-        'his',
-        'how',
-        'however',
-        'i',
-        'if',
-        'into',
-        'it',
-        'its',
-        'just',
-        'least',
-        'like',
-        'likely',
-        'may',
-        'me',
-        'might',
-        'most',
-        'must',
-        'my',
-        'neither',
-        'no',
-        'nor',
-        'not',
-        'of',
-        'off',
-        'often',
-        'on',
-        'only',
-        'or',
-        'other',
-        'our',
-        'own',
-        'rather',
-        'said',
-        'say',
-        'says',
-        'she',
-        'should',
-        'since',
-        'so',
-        'some',
-        'than',
-        'that',
-        'the',
-        'their',
-        'them',
-        'then',
-        'there',
-        'these',
-        'they',
-        'this',
-        'tis',
-        'to',
-        'too',
-        'twas',
-        'us',
-        'wants',
-        'was',
-        'we',
-        'were',
-        'what',
-        'when',
-        'who',
-        'whom',
-        'why',
-        'will',
-        'would',
-        'yet',
-        'you',
-        'your'
-        ])
-
-    // add . as a separator, because otherwise "title": "Documenter.Anchors.add!"
-    // would not find anything if searching for "add!", only for the entire qualification
-    lunr.tokenizer.separator = /[\s\-\.]+/
-
-    // custom trimmer that doesn't strip @ and !, which are used in julia macro and function names
-    lunr.trimmer = function (token) {
-        return token.update(function (s) {
-            return s.replace(/^[^a-zA-Z0-9@!]+/, '').replace(/[^a-zA-Z0-9@!]+$/, '')
+  var index = lunr(function () {
+    this.ref('location')
+    this.field('title',{boost: 100})
+    this.field('text')
+    documenterSearchIndex['docs'].forEach(function(e) {
+        this.add(e)
+    }, this)
+  })
+  var store = {}
+
+  documenterSearchIndex['docs'].forEach(function(e) {
+      store[e.location] = {title: e.title, category: e.category}
+  })
+
+  $(function(){
+    searchresults = $('#documenter-search-results');
+    searchinfo = $('#documenter-search-info');
+    searchbox = $('#documenter-search-query');
+    function update_search(querystring) {
+      tokens = lunr.tokenizer(querystring)
+      results = index.query(function (q) {
+        tokens.forEach(function (t) {
+          q.term(t.toString(), {
+            fields: ["title"],
+            boost: 100,
+            usePipeline: false,
+            editDistance: 0,
+            wildcard: lunr.Query.wildcard.NONE
+          })
+          q.term(t.toString(), {
+            fields: ["title"],
+            boost: 10,
+            usePipeline: false,
+            editDistance: 2,
+            wildcard: lunr.Query.wildcard.NONE
+          })
+          q.term(t.toString(), {
+            fields: ["text"],
+            boost: 1,
+            usePipeline: true,
+            editDistance: 0,
+            wildcard: lunr.Query.wildcard.NONE
+          })
         })
+      })
+      searchinfo.text("Number of results: " + results.length)
+      searchresults.empty()
+      results.forEach(function(result) {
+        data = store[result.ref]
+        link = $('<a class="docs-label">'+data.title+'</a>')
+        link.attr('href', documenterBaseURL+'/'+result.ref)
+        cat = $('<span class="docs-category">('+data.category+')</span>')
+        li = $('<li>').append(link).append(" ").append(cat)
+        searchresults.append(li)
+      })
     }
 
-    lunr.Pipeline.registerFunction(lunr.stopWordFilter, 'juliaStopWordFilter')
-    lunr.Pipeline.registerFunction(lunr.trimmer, 'juliaTrimmer')
-
-    var index = lunr(function () {
-        this.ref('location')
-        this.field('title')
-        this.field('text')
-        documenterSearchIndex['docs'].forEach(function(e) {
-            this.add(e)
-        }, this)
-    })
-    var store = {}
+    function update_search_box() {
+      querystring = searchbox.val()
+      update_search(querystring)
+    }
 
-    documenterSearchIndex['docs'].forEach(function(e) {
-        store[e.location] = {title: e.title, category: e.category}
-    })
+    searchbox.keyup(_.debounce(update_search_box, 250))
+    searchbox.change(update_search_box)
 
-    $(function(){
-        function update_search(querystring) {
-            tokens = lunr.tokenizer(querystring)
-            results = index.query(function (q) {
-                tokens.forEach(function (t) {
-                    q.term(t.toString(), {
-                        fields: ["title"],
-                        boost: 100,
-                        usePipeline: false,
-                        editDistance: 0,
-                        wildcard: lunr.Query.wildcard.NONE
-                    })
-                    q.term(t.toString(), {
-                        fields: ["title"],
-                        boost: 10,
-                        usePipeline: false,
-                        editDistance: 2,
-                        wildcard: lunr.Query.wildcard.NONE
-                    })
-                    q.term(t.toString(), {
-                        fields: ["text"],
-                        boost: 1,
-                        usePipeline: true,
-                        editDistance: 0,
-                        wildcard: lunr.Query.wildcard.NONE
-                    })
-                })
-            })
-            $('#search-info').text("Number of results: " + results.length)
-            $('#search-results').empty()
-            results.forEach(function(result) {
-                data = store[result.ref]
-                link = $('<a>')
-                link.text(data.title)
-                link.attr('href', documenterBaseURL+'/'+result.ref)
-                cat = $('<span class="category">('+data.category+')</span>')
-                li = $('<li>').append(link).append(" ").append(cat)
-                $('#search-results').append(li)
-            })
-        }
-
-        function update_search_box() {
-            querystring = $('#search-query').val()
-            update_search(querystring)
-        }
-
-        $('#search-query').keyup(_.debounce(update_search_box, 250))
-        $('#search-query').change(update_search_box)
-
-        search_query_uri = parseUri(window.location).queryKey["q"]
-        if(search_query_uri !== undefined) {
-            search_query = decodeURIComponent(search_query_uri.replace(/\+/g, '%20'))
-            $("#search-query").val(search_query)
-        }
-        update_search_box();
-    })
+    search_query_uri = parseUri(window.location).queryKey["q"]
+    if(search_query_uri !== undefined) {
+      search_query = decodeURIComponent(search_query_uri.replace(/\+/g, '%20'))
+      searchbox.val(search_query)
+    }
+    update_search_box();
+  })
 })
diff -pruN 1.3.1+dfsg-1/debian/embedded/Documenter/assets/html/themes/documenter-dark.css 1.4.0+dfsg-1/debian/embedded/Documenter/assets/html/themes/documenter-dark.css
--- 1.3.1+dfsg-1/debian/embedded/Documenter/assets/html/themes/documenter-dark.css	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/debian/embedded/Documenter/assets/html/themes/documenter-dark.css	2020-03-30 16:16:04.000000000 +0000
@@ -0,0 +1,7623 @@
+@charset "UTF-8";
+/* Font Awesome 5 mixin. Can be included in any rule that should render Font Awesome icons. */
+@keyframes spinAround {
+  from {
+    transform: rotate(0deg); }
+  to {
+    transform: rotate(359deg); } }
+
+html.theme--documenter-dark .delete, html.theme--documenter-dark .modal-close, .is-unselectable, html.theme--documenter-dark .button, html.theme--documenter-dark .file, html.theme--documenter-dark .breadcrumb, html.theme--documenter-dark .pagination-previous,
+html.theme--documenter-dark .pagination-next,
+html.theme--documenter-dark .pagination-link,
+html.theme--documenter-dark .pagination-ellipsis, html.theme--documenter-dark .tabs {
+  -webkit-touch-callout: none;
+  -webkit-user-select: none;
+  -moz-user-select: none;
+  -ms-user-select: none;
+  user-select: none; }
+
+html.theme--documenter-dark .select:not(.is-multiple):not(.is-loading)::after, html.theme--documenter-dark .navbar-link:not(.is-arrowless)::after {
+  border: 3px solid transparent;
+  border-radius: 2px;
+  border-right: 0;
+  border-top: 0;
+  content: " ";
+  display: block;
+  height: 0.625em;
+  margin-top: -0.4375em;
+  pointer-events: none;
+  position: absolute;
+  top: 50%;
+  transform: rotate(-45deg);
+  transform-origin: center;
+  width: 0.625em; }
+
+html.theme--documenter-dark .box:not(:last-child), html.theme--documenter-dark .content:not(:last-child), html.theme--documenter-dark .notification:not(:last-child), html.theme--documenter-dark .progress:not(:last-child), html.theme--documenter-dark .table:not(:last-child), html.theme--documenter-dark .table-container:not(:last-child), html.theme--documenter-dark .title:not(:last-child),
+html.theme--documenter-dark .subtitle:not(:last-child), html.theme--documenter-dark .block:not(:last-child), html.theme--documenter-dark .highlight:not(:last-child), html.theme--documenter-dark .breadcrumb:not(:last-child), html.theme--documenter-dark .level:not(:last-child), html.theme--documenter-dark .list:not(:last-child), html.theme--documenter-dark .message:not(:last-child), html.theme--documenter-dark .tabs:not(:last-child), html.theme--documenter-dark .admonition:not(:last-child) {
+  margin-bottom: 1.5rem; }
+
+html.theme--documenter-dark .delete, html.theme--documenter-dark .modal-close {
+  -moz-appearance: none;
+  -webkit-appearance: none;
+  background-color: rgba(10, 10, 10, 0.2);
+  border: none;
+  border-radius: 290486px;
+  cursor: pointer;
+  pointer-events: auto;
+  display: inline-block;
+  flex-grow: 0;
+  flex-shrink: 0;
+  font-size: 0;
+  height: 20px;
+  max-height: 20px;
+  max-width: 20px;
+  min-height: 20px;
+  min-width: 20px;
+  outline: none;
+  position: relative;
+  vertical-align: top;
+  width: 20px; }
+  html.theme--documenter-dark .delete::before, html.theme--documenter-dark .modal-close::before, html.theme--documenter-dark .delete::after, html.theme--documenter-dark .modal-close::after {
+    background-color: white;
+    content: "";
+    display: block;
+    left: 50%;
+    position: absolute;
+    top: 50%;
+    transform: translateX(-50%) translateY(-50%) rotate(45deg);
+    transform-origin: center center; }
+  html.theme--documenter-dark .delete::before, html.theme--documenter-dark .modal-close::before {
+    height: 2px;
+    width: 50%; }
+  html.theme--documenter-dark .delete::after, html.theme--documenter-dark .modal-close::after {
+    height: 50%;
+    width: 2px; }
+  html.theme--documenter-dark .delete:hover, html.theme--documenter-dark .modal-close:hover, html.theme--documenter-dark .delete:focus, html.theme--documenter-dark .modal-close:focus {
+    background-color: rgba(10, 10, 10, 0.3); }
+  html.theme--documenter-dark .delete:active, html.theme--documenter-dark .modal-close:active {
+    background-color: rgba(10, 10, 10, 0.4); }
+  html.theme--documenter-dark .is-small.delete, html.theme--documenter-dark #documenter .docs-sidebar form.docs-search > input.delete, html.theme--documenter-dark .is-small.modal-close, html.theme--documenter-dark #documenter .docs-sidebar form.docs-search > input.modal-close {
+    height: 16px;
+    max-height: 16px;
+    max-width: 16px;
+    min-height: 16px;
+    min-width: 16px;
+    width: 16px; }
+  html.theme--documenter-dark .is-medium.delete, html.theme--documenter-dark .is-medium.modal-close {
+    height: 24px;
+    max-height: 24px;
+    max-width: 24px;
+    min-height: 24px;
+    min-width: 24px;
+    width: 24px; }
+  html.theme--documenter-dark .is-large.delete, html.theme--documenter-dark .is-large.modal-close {
+    height: 32px;
+    max-height: 32px;
+    max-width: 32px;
+    min-height: 32px;
+    min-width: 32px;
+    width: 32px; }
+
+html.theme--documenter-dark .button.is-loading::after, html.theme--documenter-dark .loader, html.theme--documenter-dark .select.is-loading::after, html.theme--documenter-dark .control.is-loading::after {
+  animation: spinAround 500ms infinite linear;
+  border: 2px solid #dbdee0;
+  border-radius: 290486px;
+  border-right-color: transparent;
+  border-top-color: transparent;
+  content: "";
+  display: block;
+  height: 1em;
+  position: relative;
+  width: 1em; }
+
+.is-overlay, html.theme--documenter-dark .image.is-square img, html.theme--documenter-dark #documenter .docs-sidebar .docs-logo > img.is-square img,
+html.theme--documenter-dark .image.is-square .has-ratio,
+html.theme--documenter-dark #documenter .docs-sidebar .docs-logo > img.is-square .has-ratio, html.theme--documenter-dark .image.is-1by1 img, html.theme--documenter-dark #documenter .docs-sidebar .docs-logo > img.is-1by1 img,
+html.theme--documenter-dark .image.is-1by1 .has-ratio,
+html.theme--documenter-dark #documenter .docs-sidebar .docs-logo > img.is-1by1 .has-ratio, html.theme--documenter-dark .image.is-5by4 img, html.theme--documenter-dark #documenter .docs-sidebar .docs-logo > img.is-5by4 img,
+html.theme--documenter-dark .image.is-5by4 .has-ratio,
+html.theme--documenter-dark #documenter .docs-sidebar .docs-logo > img.is-5by4 .has-ratio, html.theme--documenter-dark .image.is-4by3 img, html.theme--documenter-dark #documenter .docs-sidebar .docs-logo > img.is-4by3 img,
+html.theme--documenter-dark .image.is-4by3 .has-ratio,
+html.theme--documenter-dark #documenter .docs-sidebar .docs-logo > img.is-4by3 .has-ratio, html.theme--documenter-dark .image.is-3by2 img, html.theme--documenter-dark #documenter .docs-sidebar .docs-logo > img.is-3by2 img,
+html.theme--documenter-dark .image.is-3by2 .has-ratio,
+html.theme--documenter-dark #documenter .docs-sidebar .docs-logo > img.is-3by2 .has-ratio, html.theme--documenter-dark .image.is-5by3 img, html.theme--documenter-dark #documenter .docs-sidebar .docs-logo > img.is-5by3 img,
+html.theme--documenter-dark .image.is-5by3 .has-ratio,
+html.theme--documenter-dark #documenter .docs-sidebar .docs-logo > img.is-5by3 .has-ratio, html.theme--documenter-dark .image.is-16by9 img, html.theme--documenter-dark #documenter .docs-sidebar .docs-logo > img.is-16by9 img,
+html.theme--documenter-dark .image.is-16by9 .has-ratio,
+html.theme--documenter-dark #documenter .docs-sidebar .docs-logo > img.is-16by9 .has-ratio, html.theme--documenter-dark .image.is-2by1 img, html.theme--documenter-dark #documenter .docs-sidebar .docs-logo > img.is-2by1 img,
+html.theme--documenter-dark .image.is-2by1 .has-ratio,
+html.theme--documenter-dark #documenter .docs-sidebar .docs-logo > img.is-2by1 .has-ratio, html.theme--documenter-dark .image.is-3by1 img, html.theme--documenter-dark #documenter .docs-sidebar .docs-logo > img.is-3by1 img,
+html.theme--documenter-dark .image.is-3by1 .has-ratio,
+html.theme--documenter-dark #documenter .docs-sidebar .docs-logo > img.is-3by1 .has-ratio, html.theme--documenter-dark .image.is-4by5 img, html.theme--documenter-dark #documenter .docs-sidebar .docs-logo > img.is-4by5 img,
+html.theme--documenter-dark .image.is-4by5 .has-ratio,
+html.theme--documenter-dark #documenter .docs-sidebar .docs-logo > img.is-4by5 .has-ratio, html.theme--documenter-dark .image.is-3by4 img, html.theme--documenter-dark #documenter .docs-sidebar .docs-logo > img.is-3by4 img,
+html.theme--documenter-dark .image.is-3by4 .has-ratio,
+html.theme--documenter-dark #documenter .docs-sidebar .docs-logo > img.is-3by4 .has-ratio, html.theme--documenter-dark .image.is-2by3 img, html.theme--documenter-dark #documenter .docs-sidebar .docs-logo > img.is-2by3 img,
+html.theme--documenter-dark .image.is-2by3 .has-ratio,
+html.theme--documenter-dark #documenter .docs-sidebar .docs-logo > img.is-2by3 .has-ratio, html.theme--documenter-dark .image.is-3by5 img, html.theme--documenter-dark #documenter .docs-sidebar .docs-logo > img.is-3by5 img,
+html.theme--documenter-dark .image.is-3by5 .has-ratio,
+html.theme--documenter-dark #documenter .docs-sidebar .docs-logo > img.is-3by5 .has-ratio, html.theme--documenter-dark .image.is-9by16 img, html.theme--documenter-dark #documenter .docs-sidebar .docs-logo > img.is-9by16 img,
+html.theme--documenter-dark .image.is-9by16 .has-ratio,
+html.theme--documenter-dark #documenter .docs-sidebar .docs-logo > img.is-9by16 .has-ratio, html.theme--documenter-dark .image.is-1by2 img, html.theme--documenter-dark #documenter .docs-sidebar .docs-logo > img.is-1by2 img,
+html.theme--documenter-dark .image.is-1by2 .has-ratio,
+html.theme--documenter-dark #documenter .docs-sidebar .docs-logo > img.is-1by2 .has-ratio, html.theme--documenter-dark .image.is-1by3 img, html.theme--documenter-dark #documenter .docs-sidebar .docs-logo > img.is-1by3 img,
+html.theme--documenter-dark .image.is-1by3 .has-ratio,
+html.theme--documenter-dark #documenter .docs-sidebar .docs-logo > img.is-1by3 .has-ratio, html.theme--documenter-dark .modal, html.theme--documenter-dark .modal-background, html.theme--documenter-dark .hero-video {
+  bottom: 0;
+  left: 0;
+  position: absolute;
+  right: 0;
+  top: 0; }
+
+html.theme--documenter-dark .button, html.theme--documenter-dark .input, html.theme--documenter-dark #documenter .docs-sidebar form.docs-search > input, html.theme--documenter-dark .textarea, html.theme--documenter-dark .select select, html.theme--documenter-dark .file-cta,
+html.theme--documenter-dark .file-name, html.theme--documenter-dark .pagination-previous,
+html.theme--documenter-dark .pagination-next,
+html.theme--documenter-dark .pagination-link,
+html.theme--documenter-dark .pagination-ellipsis {
+  -moz-appearance: none;
+  -webkit-appearance: none;
+  align-items: center;
+  border: 1px solid transparent;
+  border-radius: 0.4em;
+  box-shadow: none;
+  display: inline-flex;
+  font-size: 15px;
+  height: 2.25em;
+  justify-content: flex-start;
+  line-height: 1.5;
+  padding-bottom: calc(0.375em - 1px);
+  padding-left: calc(0.625em - 1px);
+  padding-right: calc(0.625em - 1px);
+  padding-top: calc(0.375em - 1px);
+  position: relative;
+  vertical-align: top; }
+  html.theme--documenter-dark .button:focus, html.theme--documenter-dark .input:focus, html.theme--documenter-dark #documenter .docs-sidebar form.docs-search > input:focus, html.theme--documenter-dark .textarea:focus, html.theme--documenter-dark .select select:focus, html.theme--documenter-dark .file-cta:focus,
+  html.theme--documenter-dark .file-name:focus, html.theme--documenter-dark .pagination-previous:focus,
+  html.theme--documenter-dark .pagination-next:focus,
+  html.theme--documenter-dark .pagination-link:focus,
+  html.theme--documenter-dark .pagination-ellipsis:focus, html.theme--documenter-dark .is-focused.button, html.theme--documenter-dark .is-focused.input, html.theme--documenter-dark #documenter .docs-sidebar form.docs-search > input.is-focused, html.theme--documenter-dark .is-focused.textarea, html.theme--documenter-dark .select select.is-focused, html.theme--documenter-dark .is-focused.file-cta,
+  html.theme--documenter-dark .is-focused.file-name, html.theme--documenter-dark .is-focused.pagination-previous,
+  html.theme--documenter-dark .is-focused.pagination-next,
+  html.theme--documenter-dark .is-focused.pagination-link,
+  html.theme--documenter-dark .is-focused.pagination-ellipsis, html.theme--documenter-dark .button:active, html.theme--documenter-dark .input:active, html.theme--documenter-dark #documenter .docs-sidebar form.docs-search > input:active, html.theme--documenter-dark .textarea:active, html.theme--documenter-dark .select select:active, html.theme--documenter-dark .file-cta:active,
+  html.theme--documenter-dark .file-name:active, html.theme--documenter-dark .pagination-previous:active,
+  html.theme--documenter-dark .pagination-next:active,
+  html.theme--documenter-dark .pagination-link:active,
+  html.theme--documenter-dark .pagination-ellipsis:active, html.theme--documenter-dark .is-active.button, html.theme--documenter-dark .is-active.input, html.theme--documenter-dark #documenter .docs-sidebar form.docs-search > input.is-active, html.theme--documenter-dark .is-active.textarea, html.theme--documenter-dark .select select.is-active, html.theme--documenter-dark .is-active.file-cta,
+  html.theme--documenter-dark .is-active.file-name, html.theme--documenter-dark .is-active.pagination-previous,
+  html.theme--documenter-dark .is-active.pagination-next,
+  html.theme--documenter-dark .is-active.pagination-link,
+  html.theme--documenter-dark .is-active.pagination-ellipsis {
+    outline: none; }
+  html.theme--documenter-dark .button[disabled], html.theme--documenter-dark .input[disabled], html.theme--documenter-dark #documenter .docs-sidebar form.docs-search > input[disabled], html.theme--documenter-dark .textarea[disabled], html.theme--documenter-dark .select select[disabled], html.theme--documenter-dark .file-cta[disabled],
+  html.theme--documenter-dark .file-name[disabled], html.theme--documenter-dark .pagination-previous[disabled],
+  html.theme--documenter-dark .pagination-next[disabled],
+  html.theme--documenter-dark .pagination-link[disabled],
+  html.theme--documenter-dark .pagination-ellipsis[disabled],
+  fieldset[disabled] html.theme--documenter-dark .button,
+  html.theme--documenter-dark fieldset[disabled] .button,
+  fieldset[disabled] html.theme--documenter-dark .input,
+  html.theme--documenter-dark fieldset[disabled] .input,
+  fieldset[disabled] html.theme--documenter-dark #documenter .docs-sidebar form.docs-search > input,
+  html.theme--documenter-dark #documenter .docs-sidebar fieldset[disabled] form.docs-search > input,
+  fieldset[disabled] html.theme--documenter-dark .textarea,
+  html.theme--documenter-dark fieldset[disabled] .textarea,
+  fieldset[disabled] html.theme--documenter-dark .select select,
+  html.theme--documenter-dark .select fieldset[disabled] select,
+  fieldset[disabled] html.theme--documenter-dark .file-cta,
+  html.theme--documenter-dark fieldset[disabled] .file-cta,
+  fieldset[disabled] html.theme--documenter-dark .file-name,
+  html.theme--documenter-dark fieldset[disabled] .file-name,
+  fieldset[disabled] html.theme--documenter-dark .pagination-previous,
+  html.theme--documenter-dark fieldset[disabled] .pagination-previous,
+  fieldset[disabled] html.theme--documenter-dark .pagination-next,
+  html.theme--documenter-dark fieldset[disabled] .pagination-next,
+  fieldset[disabled] html.theme--documenter-dark .pagination-link,
+  html.theme--documenter-dark fieldset[disabled] .pagination-link,
+  fieldset[disabled] html.theme--documenter-dark .pagination-ellipsis,
+  html.theme--documenter-dark fieldset[disabled] .pagination-ellipsis {
+    cursor: not-allowed; }
+
+/*! minireset.css v0.0.4 | MIT License | github.com/jgthms/minireset.css */
+html,
+body,
+p,
+ol,
+ul,
+li,
+dl,
+dt,
+dd,
+blockquote,
+figure,
+fieldset,
+legend,
+textarea,
+pre,
+iframe,
+hr,
+h1,
+h2,
+h3,
+h4,
+h5,
+h6 {
+  margin: 0;
+  padding: 0; }
+
+h1,
+h2,
+h3,
+h4,
+h5,
+h6 {
+  font-size: 100%;
+  font-weight: normal; }
+
+ul {
+  list-style: none; }
+
+button,
+input,
+select,
+textarea {
+  margin: 0; }
+
+html {
+  box-sizing: border-box; }
+
+*, *::before, *::after {
+  box-sizing: inherit; }
+
+img,
+embed,
+iframe,
+object,
+video {
+  height: auto;
+  max-width: 100%; }
+
+audio {
+  max-width: 100%; }
+
+iframe {
+  border: 0; }
+
+table {
+  border-collapse: collapse;
+  border-spacing: 0; }
+
+td,
+th {
+  padding: 0; }
+  td:not([align]),
+  th:not([align]) {
+    text-align: left; }
+
+.is-clearfix::after {
+  clear: both;
+  content: " ";
+  display: table; }
+
+.is-pulled-left {
+  float: left !important; }
+
+.is-pulled-right {
+  float: right !important; }
+
+.is-clipped {
+  overflow: hidden !important; }
+
+.is-size-1 {
+  font-size: 3rem !important; }
+
+.is-size-2 {
+  font-size: 2.5rem !important; }
+
+.is-size-3 {
+  font-size: 2rem !important; }
+
+.is-size-4 {
+  font-size: 1.5rem !important; }
+
+.is-size-5 {
+  font-size: 1.25rem !important; }
+
+.is-size-6 {
+  font-size: 15px !important; }
+
+.is-size-7, html.theme--documenter-dark .docstring > section > a.docs-sourcelink {
+  font-size: 0.85em !important; }
+
+@media screen and (max-width: 768px) {
+  .is-size-1-mobile {
+    font-size: 3rem !important; }
+  .is-size-2-mobile {
+    font-size: 2.5rem !important; }
+  .is-size-3-mobile {
+    font-size: 2rem !important; }
+  .is-size-4-mobile {
+    font-size: 1.5rem !important; }
+  .is-size-5-mobile {
+    font-size: 1.25rem !important; }
+  .is-size-6-mobile {
+    font-size: 15px !important; }
+  .is-size-7-mobile {
+    font-size: 0.85em !important; } }
+
+@media screen and (min-width: 769px), print {
+  .is-size-1-tablet {
+    font-size: 3rem !important; }
+  .is-size-2-tablet {
+    font-size: 2.5rem !important; }
+  .is-size-3-tablet {
+    font-size: 2rem !important; }
+  .is-size-4-tablet {
+    font-size: 1.5rem !important; }
+  .is-size-5-tablet {
+    font-size: 1.25rem !important; }
+  .is-size-6-tablet {
+    font-size: 15px !important; }
+  .is-size-7-tablet {
+    font-size: 0.85em !important; } }
+
+@media screen and (max-width: 1055px) {
+  .is-size-1-touch {
+    font-size: 3rem !important; }
+  .is-size-2-touch {
+    font-size: 2.5rem !important; }
+  .is-size-3-touch {
+    font-size: 2rem !important; }
+  .is-size-4-touch {
+    font-size: 1.5rem !important; }
+  .is-size-5-touch {
+    font-size: 1.25rem !important; }
+  .is-size-6-touch {
+    font-size: 15px !important; }
+  .is-size-7-touch {
+    font-size: 0.85em !important; } }
+
+@media screen and (min-width: 1056px) {
+  .is-size-1-desktop {
+    font-size: 3rem !important; }
+  .is-size-2-desktop {
+    font-size: 2.5rem !important; }
+  .is-size-3-desktop {
+    font-size: 2rem !important; }
+  .is-size-4-desktop {
+    font-size: 1.5rem !important; }
+  .is-size-5-desktop {
+    font-size: 1.25rem !important; }
+  .is-size-6-desktop {
+    font-size: 15px !important; }
+  .is-size-7-desktop {
+    font-size: 0.85em !important; } }
+
+@media screen and (min-width: 1216px) {
+  .is-size-1-widescreen {
+    font-size: 3rem !important; }
+  .is-size-2-widescreen {
+    font-size: 2.5rem !important; }
+  .is-size-3-widescreen {
+    font-size: 2rem !important; }
+  .is-size-4-widescreen {
+    font-size: 1.5rem !important; }
+  .is-size-5-widescreen {
+    font-size: 1.25rem !important; }
+  .is-size-6-widescreen {
+    font-size: 15px !important; }
+  .is-size-7-widescreen {
+    font-size: 0.85em !important; } }
+
+@media screen and (min-width: 1408px) {
+  .is-size-1-fullhd {
+    font-size: 3rem !important; }
+  .is-size-2-fullhd {
+    font-size: 2.5rem !important; }
+  .is-size-3-fullhd {
+    font-size: 2rem !important; }
+  .is-size-4-fullhd {
+    font-size: 1.5rem !important; }
+  .is-size-5-fullhd {
+    font-size: 1.25rem !important; }
+  .is-size-6-fullhd {
+    font-size: 15px !important; }
+  .is-size-7-fullhd {
+    font-size: 0.85em !important; } }
+
+.has-text-centered {
+  text-align: center !important; }
+
+.has-text-justified {
+  text-align: justify !important; }
+
+.has-text-left {
+  text-align: left !important; }
+
+.has-text-right {
+  text-align: right !important; }
+
+@media screen and (max-width: 768px) {
+  .has-text-centered-mobile {
+    text-align: center !important; } }
+
+@media screen and (min-width: 769px), print {
+  .has-text-centered-tablet {
+    text-align: center !important; } }
+
+@media screen and (min-width: 769px) and (max-width: 1055px) {
+  .has-text-centered-tablet-only {
+    text-align: center !important; } }
+
+@media screen and (max-width: 1055px) {
+  .has-text-centered-touch {
+    text-align: center !important; } }
+
+@media screen and (min-width: 1056px) {
+  .has-text-centered-desktop {
+    text-align: center !important; } }
+
+@media screen and (min-width: 1056px) and (max-width: 1215px) {
+  .has-text-centered-desktop-only {
+    text-align: center !important; } }
+
+@media screen and (min-width: 1216px) {
+  .has-text-centered-widescreen {
+    text-align: center !important; } }
+
+@media screen and (min-width: 1216px) and (max-width: 1407px) {
+  .has-text-centered-widescreen-only {
+    text-align: center !important; } }
+
+@media screen and (min-width: 1408px) {
+  .has-text-centered-fullhd {
+    text-align: center !important; } }
+
+@media screen and (max-width: 768px) {
+  .has-text-justified-mobile {
+    text-align: justify !important; } }
+
+@media screen and (min-width: 769px), print {
+  .has-text-justified-tablet {
+    text-align: justify !important; } }
+
+@media screen and (min-width: 769px) and (max-width: 1055px) {
+  .has-text-justified-tablet-only {
+    text-align: justify !important; } }
+
+@media screen and (max-width: 1055px) {
+  .has-text-justified-touch {
+    text-align: justify !important; } }
+
+@media screen and (min-width: 1056px) {
+  .has-text-justified-desktop {
+    text-align: justify !important; } }
+
+@media screen and (min-width: 1056px) and (max-width: 1215px) {
+  .has-text-justified-desktop-only {
+    text-align: justify !important; } }
+
+@media screen and (min-width: 1216px) {
+  .has-text-justified-widescreen {
+    text-align: justify !important; } }
+
+@media screen and (min-width: 1216px) and (max-width: 1407px) {
+  .has-text-justified-widescreen-only {
+    text-align: justify !important; } }
+
+@media screen and (min-width: 1408px) {
+  .has-text-justified-fullhd {
+    text-align: justify !important; } }
+
+@media screen and (max-width: 768px) {
+  .has-text-left-mobile {
+    text-align: left !important; } }
+
+@media screen and (min-width: 769px), print {
+  .has-text-left-tablet {
+    text-align: left !important; } }
+
+@media screen and (min-width: 769px) and (max-width: 1055px) {
+  .has-text-left-tablet-only {
+    text-align: left !important; } }
+
+@media screen and (max-width: 1055px) {
+  .has-text-left-touch {
+    text-align: left !important; } }
+
+@media screen and (min-width: 1056px) {
+  .has-text-left-desktop {
+    text-align: left !important; } }
+
+@media screen and (min-width: 1056px) and (max-width: 1215px) {
+  .has-text-left-desktop-only {
+    text-align: left !important; } }
+
+@media screen and (min-width: 1216px) {
+  .has-text-left-widescreen {
+    text-align: left !important; } }
+
+@media screen and (min-width: 1216px) and (max-width: 1407px) {
+  .has-text-left-widescreen-only {
+    text-align: left !important; } }
+
+@media screen and (min-width: 1408px) {
+  .has-text-left-fullhd {
+    text-align: left !important; } }
+
+@media screen and (max-width: 768px) {
+  .has-text-right-mobile {
+    text-align: right !important; } }
+
+@media screen and (min-width: 769px), print {
+  .has-text-right-tablet {
+    text-align: right !important; } }
+
+@media screen and (min-width: 769px) and (max-width: 1055px) {
+  .has-text-right-tablet-only {
+    text-align: right !important; } }
+
+@media screen and (max-width: 1055px) {
+  .has-text-right-touch {
+    text-align: right !important; } }
+
+@media screen and (min-width: 1056px) {
+  .has-text-right-desktop {
+    text-align: right !important; } }
+
+@media screen and (min-width: 1056px) and (max-width: 1215px) {
+  .has-text-right-desktop-only {
+    text-align: right !important; } }
+
+@media screen and (min-width: 1216px) {
+  .has-text-right-widescreen {
+    text-align: right !important; } }
+
+@media screen and (min-width: 1216px) and (max-width: 1407px) {
+  .has-text-right-widescreen-only {
+    text-align: right !important; } }
+
+@media screen and (min-width: 1408px) {
+  .has-text-right-fullhd {
+    text-align: right !important; } }
+
+.is-capitalized {
+  text-transform: capitalize !important; }
+
+.is-lowercase {
+  text-transform: lowercase !important; }
+
+.is-uppercase {
+  text-transform: uppercase !important; }
+
+.is-italic {
+  font-style: italic !important; }
+
+.has-text-white {
+  color: white !important; }
+
+a.has-text-white:hover, a.has-text-white:focus {
+  color: #e6e6e6 !important; }
+
+.has-background-white {
+  background-color: white !important; }
+
+.has-text-black {
+  color: #0a0a0a !important; }
+
+a.has-text-black:hover, a.has-text-black:focus {
+  color: black !important; }
+
+.has-background-black {
+  background-color: #0a0a0a !important; }
+
+.has-text-light {
+  color: #ecf0f1 !important; }
+
+a.has-text-light:hover, a.has-text-light:focus {
+  color: #cfd9db !important; }
+
+.has-background-light {
+  background-color: #ecf0f1 !important; }
+
+.has-text-dark {
+  color: #282f2f !important; }
+
+a.has-text-dark:hover, a.has-text-dark:focus {
+  color: #111414 !important; }
+
+.has-background-dark {
+  background-color: #282f2f !important; }
+
+.has-text-primary {
+  color: #375a7f !important; }
+
+a.has-text-primary:hover, a.has-text-primary:focus {
+  color: #28415b !important; }
+
+.has-background-primary {
+  background-color: #375a7f !important; }
+
+.has-text-link {
+  color: #1abc9c !important; }
+
+a.has-text-link:hover, a.has-text-link:focus {
+  color: #148f77 !important; }
+
+.has-background-link {
+  background-color: #1abc9c !important; }
+
+.has-text-info {
+  color: #024c7d !important; }
+
+a.has-text-info:hover, a.has-text-info:focus {
+  color: #012d4b !important; }
+
+.has-background-info {
+  background-color: #024c7d !important; }
+
+.has-text-success {
+  color: #008438 !important; }
+
+a.has-text-success:hover, a.has-text-success:focus {
+  color: #005122 !important; }
+
+.has-background-success {
+  background-color: #008438 !important; }
+
+.has-text-warning {
+  color: #ad8100 !important; }
+
+a.has-text-warning:hover, a.has-text-warning:focus {
+  color: #7a5b00 !important; }
+
+.has-background-warning {
+  background-color: #ad8100 !important; }
+
+.has-text-danger {
+  color: #9e1b0d !important; }
+
+a.has-text-danger:hover, a.has-text-danger:focus {
+  color: #6f1309 !important; }
+
+.has-background-danger {
+  background-color: #9e1b0d !important; }
+
+.has-text-black-bis {
+  color: #121212 !important; }
+
+.has-background-black-bis {
+  background-color: #121212 !important; }
+
+.has-text-black-ter {
+  color: #242424 !important; }
+
+.has-background-black-ter {
+  background-color: #242424 !important; }
+
+.has-text-grey-darker {
+  color: #282f2f !important; }
+
+.has-background-grey-darker {
+  background-color: #282f2f !important; }
+
+.has-text-grey-dark {
+  color: #343c3d !important; }
+
+.has-background-grey-dark {
+  background-color: #343c3d !important; }
+
+.has-text-grey {
+  color: #5e6d6f !important; }
+
+.has-background-grey {
+  background-color: #5e6d6f !important; }
+
+.has-text-grey-light {
+  color: #8c9b9d !important; }
+
+.has-background-grey-light {
+  background-color: #8c9b9d !important; }
+
+.has-text-grey-lighter {
+  color: #dbdee0 !important; }
+
+.has-background-grey-lighter {
+  background-color: #dbdee0 !important; }
+
+.has-text-white-ter {
+  color: #ecf0f1 !important; }
+
+.has-background-white-ter {
+  background-color: #ecf0f1 !important; }
+
+.has-text-white-bis {
+  color: #fafafa !important; }
+
+.has-background-white-bis {
+  background-color: #fafafa !important; }
+
+.has-text-weight-light {
+  font-weight: 300 !important; }
+
+.has-text-weight-normal {
+  font-weight: 400 !important; }
+
+.has-text-weight-medium {
+  font-weight: 500 !important; }
+
+.has-text-weight-semibold {
+  font-weight: 600 !important; }
+
+.has-text-weight-bold {
+  font-weight: 700 !important; }
+
+.is-family-primary {
+  font-family: "Lato", -apple-system, BlinkMacSystemFont, "Segoe UI", "Helvetica Neue", "Helvetica", "Arial", sans-serif !important; }
+
+.is-family-secondary {
+  font-family: "Lato", -apple-system, BlinkMacSystemFont, "Segoe UI", "Helvetica Neue", "Helvetica", "Arial", sans-serif !important; }
+
+.is-family-sans-serif {
+  font-family: "Lato", -apple-system, BlinkMacSystemFont, "Segoe UI", "Helvetica Neue", "Helvetica", "Arial", sans-serif !important; }
+
+.is-family-monospace {
+  font-family: "Roboto Mono", "SFMono-Regular", "Menlo", "Consolas", "Liberation Mono", "DejaVu Sans Mono", monospace !important; }
+
+.is-family-code {
+  font-family: "Roboto Mono", "SFMono-Regular", "Menlo", "Consolas", "Liberation Mono", "DejaVu Sans Mono", monospace !important; }
+
+.is-block {
+  display: block !important; }
+
+@media screen and (max-width: 768px) {
+  .is-block-mobile {
+    display: block !important; } }
+
+@media screen and (min-width: 769px), print {
+  .is-block-tablet {
+    display: block !important; } }
+
+@media screen and (min-width: 769px) and (max-width: 1055px) {
+  .is-block-tablet-only {
+    display: block !important; } }
+
+@media screen and (max-width: 1055px) {
+  .is-block-touch {
+    display: block !important; } }
+
+@media screen and (min-width: 1056px) {
+  .is-block-desktop {
+    display: block !important; } }
+
+@media screen and (min-width: 1056px) and (max-width: 1215px) {
+  .is-block-desktop-only {
+    display: block !important; } }
+
+@media screen and (min-width: 1216px) {
+  .is-block-widescreen {
+    display: block !important; } }
+
+@media screen and (min-width: 1216px) and (max-width: 1407px) {
+  .is-block-widescreen-only {
+    display: block !important; } }
+
+@media screen and (min-width: 1408px) {
+  .is-block-fullhd {
+    display: block !important; } }
+
+.is-flex {
+  display: flex !important; }
+
+@media screen and (max-width: 768px) {
+  .is-flex-mobile {
+    display: flex !important; } }
+
+@media screen and (min-width: 769px), print {
+  .is-flex-tablet {
+    display: flex !important; } }
+
+@media screen and (min-width: 769px) and (max-width: 1055px) {
+  .is-flex-tablet-only {
+    display: flex !important; } }
+
+@media screen and (max-width: 1055px) {
+  .is-flex-touch {
+    display: flex !important; } }
+
+@media screen and (min-width: 1056px) {
+  .is-flex-desktop {
+    display: flex !important; } }
+
+@media screen and (min-width: 1056px) and (max-width: 1215px) {
+  .is-flex-desktop-only {
+    display: flex !important; } }
+
+@media screen and (min-width: 1216px) {
+  .is-flex-widescreen {
+    display: flex !important; } }
+
+@media screen and (min-width: 1216px) and (max-width: 1407px) {
+  .is-flex-widescreen-only {
+    display: flex !important; } }
+
+@media screen and (min-width: 1408px) {
+  .is-flex-fullhd {
+    display: flex !important; } }
+
+.is-inline {
+  display: inline !important; }
+
+@media screen and (max-width: 768px) {
+  .is-inline-mobile {
+    display: inline !important; } }
+
+@media screen and (min-width: 769px), print {
+  .is-inline-tablet {
+    display: inline !important; } }
+
+@media screen and (min-width: 769px) and (max-width: 1055px) {
+  .is-inline-tablet-only {
+    display: inline !important; } }
+
+@media screen and (max-width: 1055px) {
+  .is-inline-touch {
+    display: inline !important; } }
+
+@media screen and (min-width: 1056px) {
+  .is-inline-desktop {
+    display: inline !important; } }
+
+@media screen and (min-width: 1056px) and (max-width: 1215px) {
+  .is-inline-desktop-only {
+    display: inline !important; } }
+
+@media screen and (min-width: 1216px) {
+  .is-inline-widescreen {
+    display: inline !important; } }
+
+@media screen and (min-width: 1216px) and (max-width: 1407px) {
+  .is-inline-widescreen-only {
+    display: inline !important; } }
+
+@media screen and (min-width: 1408px) {
+  .is-inline-fullhd {
+    display: inline !important; } }
+
+.is-inline-block {
+  display: inline-block !important; }
+
+@media screen and (max-width: 768px) {
+  .is-inline-block-mobile {
+    display: inline-block !important; } }
+
+@media screen and (min-width: 769px), print {
+  .is-inline-block-tablet {
+    display: inline-block !important; } }
+
+@media screen and (min-width: 769px) and (max-width: 1055px) {
+  .is-inline-block-tablet-only {
+    display: inline-block !important; } }
+
+@media screen and (max-width: 1055px) {
+  .is-inline-block-touch {
+    display: inline-block !important; } }
+
+@media screen and (min-width: 1056px) {
+  .is-inline-block-desktop {
+    display: inline-block !important; } }
+
+@media screen and (min-width: 1056px) and (max-width: 1215px) {
+  .is-inline-block-desktop-only {
+    display: inline-block !important; } }
+
+@media screen and (min-width: 1216px) {
+  .is-inline-block-widescreen {
+    display: inline-block !important; } }
+
+@media screen and (min-width: 1216px) and (max-width: 1407px) {
+  .is-inline-block-widescreen-only {
+    display: inline-block !important; } }
+
+@media screen and (min-width: 1408px) {
+  .is-inline-block-fullhd {
+    display: inline-block !important; } }
+
+.is-inline-flex {
+  display: inline-flex !important; }
+
+@media screen and (max-width: 768px) {
+  .is-inline-flex-mobile {
+    display: inline-flex !important; } }
+
+@media screen and (min-width: 769px), print {
+  .is-inline-flex-tablet {
+    display: inline-flex !important; } }
+
+@media screen and (min-width: 769px) and (max-width: 1055px) {
+  .is-inline-flex-tablet-only {
+    display: inline-flex !important; } }
+
+@media screen and (max-width: 1055px) {
+  .is-inline-flex-touch {
+    display: inline-flex !important; } }
+
+@media screen and (min-width: 1056px) {
+  .is-inline-flex-desktop {
+    display: inline-flex !important; } }
+
+@media screen and (min-width: 1056px) and (max-width: 1215px) {
+  .is-inline-flex-desktop-only {
+    display: inline-flex !important; } }
+
+@media screen and (min-width: 1216px) {
+  .is-inline-flex-widescreen {
+    display: inline-flex !important; } }
+
+@media screen and (min-width: 1216px) and (max-width: 1407px) {
+  .is-inline-flex-widescreen-only {
+    display: inline-flex !important; } }
+
+@media screen and (min-width: 1408px) {
+  .is-inline-flex-fullhd {
+    display: inline-flex !important; } }
+
+.is-hidden {
+  display: none !important; }
+
+.is-sr-only {
+  border: none !important;
+  clip: rect(0, 0, 0, 0) !important;
+  height: 0.01em !important;
+  overflow: hidden !important;
+  padding: 0 !important;
+  position: absolute !important;
+  white-space: nowrap !important;
+  width: 0.01em !important; }
+
+@media screen and (max-width: 768px) {
+  .is-hidden-mobile {
+    display: none !important; } }
+
+@media screen and (min-width: 769px), print {
+  .is-hidden-tablet {
+    display: none !important; } }
+
+@media screen and (min-width: 769px) and (max-width: 1055px) {
+  .is-hidden-tablet-only {
+    display: none !important; } }
+
+@media screen and (max-width: 1055px) {
+  .is-hidden-touch {
+    display: none !important; } }
+
+@media screen and (min-width: 1056px) {
+  .is-hidden-desktop {
+    display: none !important; } }
+
+@media screen and (min-width: 1056px) and (max-width: 1215px) {
+  .is-hidden-desktop-only {
+    display: none !important; } }
+
+@media screen and (min-width: 1216px) {
+  .is-hidden-widescreen {
+    display: none !important; } }
+
+@media screen and (min-width: 1216px) and (max-width: 1407px) {
+  .is-hidden-widescreen-only {
+    display: none !important; } }
+
+@media screen and (min-width: 1408px) {
+  .is-hidden-fullhd {
+    display: none !important; } }
+
+.is-invisible {
+  visibility: hidden !important; }
+
+@media screen and (max-width: 768px) {
+  .is-invisible-mobile {
+    visibility: hidden !important; } }
+
+@media screen and (min-width: 769px), print {
+  .is-invisible-tablet {
+    visibility: hidden !important; } }
+
+@media screen and (min-width: 769px) and (max-width: 1055px) {
+  .is-invisible-tablet-only {
+    visibility: hidden !important; } }
+
+@media screen and (max-width: 1055px) {
+  .is-invisible-touch {
+    visibility: hidden !important; } }
+
+@media screen and (min-width: 1056px) {
+  .is-invisible-desktop {
+    visibility: hidden !important; } }
+
+@media screen and (min-width: 1056px) and (max-width: 1215px) {
+  .is-invisible-desktop-only {
+    visibility: hidden !important; } }
+
+@media screen and (min-width: 1216px) {
+  .is-invisible-widescreen {
+    visibility: hidden !important; } }
+
+@media screen and (min-width: 1216px) and (max-width: 1407px) {
+  .is-invisible-widescreen-only {
+    visibility: hidden !important; } }
+
+@media screen and (min-width: 1408px) {
+  .is-invisible-fullhd {
+    visibility: hidden !important; } }
+
+.is-marginless {
+  margin: 0 !important; }
+
+.is-paddingless {
+  padding: 0 !important; }
+
+.is-radiusless {
+  border-radius: 0 !important; }
+
+.is-shadowless {
+  box-shadow: none !important; }
+
+.is-relative {
+  position: relative !important; }
+
+html.theme--documenter-dark {
+  /* This file contain the overall layout.
+ *
+ * The main container is <div> that is identified by id #documenter.
+ */
+  /* a11y-dark theme */
+  /* Based on the Tomorrow Night Eighties theme: https://github.com/isagalaev/highlight.js/blob/master/src/styles/tomorrow-night-eighties.css */
+  /* @author: ericwbailey */
+  /* Comment */
+  /* Red */
+  /* Orange */
+  /* Yellow */
+  /* Green */
+  /* Blue */
+  /* Purple */ }
+  html.theme--documenter-dark html {
+    background-color: #1f2424;
+    font-size: 16px;
+    -moz-osx-font-smoothing: grayscale;
+    -webkit-font-smoothing: antialiased;
+    min-width: 300px;
+    overflow-x: auto;
+    overflow-y: scroll;
+    text-rendering: optimizeLegibility;
+    text-size-adjust: 100%; }
+  html.theme--documenter-dark article,
+  html.theme--documenter-dark aside,
+  html.theme--documenter-dark figure,
+  html.theme--documenter-dark footer,
+  html.theme--documenter-dark header,
+  html.theme--documenter-dark hgroup,
+  html.theme--documenter-dark section {
+    display: block; }
+  html.theme--documenter-dark body,
+  html.theme--documenter-dark button,
+  html.theme--documenter-dark input,
+  html.theme--documenter-dark select,
+  html.theme--documenter-dark textarea {
+    font-family: "Lato", -apple-system, BlinkMacSystemFont, "Segoe UI", "Helvetica Neue", "Helvetica", "Arial", sans-serif; }
+  html.theme--documenter-dark code,
+  html.theme--documenter-dark pre {
+    -moz-osx-font-smoothing: auto;
+    -webkit-font-smoothing: auto;
+    font-family: "Roboto Mono", "SFMono-Regular", "Menlo", "Consolas", "Liberation Mono", "DejaVu Sans Mono", monospace; }
+  html.theme--documenter-dark body {
+    color: #fff;
+    font-size: 1em;
+    font-weight: 400;
+    line-height: 1.5; }
+  html.theme--documenter-dark a {
+    color: #1abc9c;
+    cursor: pointer;
+    text-decoration: none; }
+    html.theme--documenter-dark a strong {
+      color: currentColor; }
+    html.theme--documenter-dark a:hover {
+      color: #1dd2af; }
+  html.theme--documenter-dark code {
+    background-color: rgba(255, 255, 255, 0.05);
+    color: #e74c3c;
+    font-size: 0.875em;
+    font-weight: normal;
+    padding: 0.1em; }
+  html.theme--documenter-dark hr {
+    background-color: #282f2f;
+    border: none;
+    display: block;
+    height: 2px;
+    margin: 1.5rem 0; }
+  html.theme--documenter-dark img {
+    height: auto;
+    max-width: 100%; }
+  html.theme--documenter-dark input[type="checkbox"],
+  html.theme--documenter-dark input[type="radio"] {
+    vertical-align: baseline; }
+  html.theme--documenter-dark small {
+    font-size: 0.875em; }
+  html.theme--documenter-dark span {
+    font-style: inherit;
+    font-weight: inherit; }
+  html.theme--documenter-dark strong {
+    color: #f2f2f2;
+    font-weight: 700; }
+  html.theme--documenter-dark fieldset {
+    border: none; }
+  html.theme--documenter-dark pre {
+    -webkit-overflow-scrolling: touch;
+    background-color: #282f2f;
+    color: #fff;
+    font-size: 0.875em;
+    overflow-x: auto;
+    padding: 1.25rem 1.5rem;
+    white-space: pre;
+    word-wrap: normal; }
+    html.theme--documenter-dark pre code {
+      background-color: transparent;
+      color: currentColor;
+      font-size: 1em;
+      padding: 0; }
+  html.theme--documenter-dark table td,
+  html.theme--documenter-dark table th {
+    vertical-align: top; }
+    html.theme--documenter-dark table td:not([align]),
+    html.theme--documenter-dark table th:not([align]) {
+      text-align: left; }
+  html.theme--documenter-dark table th {
+    color: #f2f2f2; }
+  html.theme--documenter-dark .box {
+    background-color: #343c3d;
+    border-radius: 8px;
+    box-shadow: none;
+    color: #fff;
+    display: block;
+    padding: 1.25rem; }
+  html.theme--documenter-dark a.box:hover, html.theme--documenter-dark a.box:focus {
+    box-shadow: 0 2px 3px rgba(10, 10, 10, 0.1), 0 0 0 1px #1abc9c; }
+  html.theme--documenter-dark a.box:active {
+    box-shadow: inset 0 1px 2px rgba(10, 10, 10, 0.2), 0 0 0 1px #1abc9c; }
+  html.theme--documenter-dark .button {
+    background-color: #282f2f;
+    border-color: #4c5759;
+    border-width: 1px;
+    color: #375a7f;
+    cursor: pointer;
+    justify-content: center;
+    padding-bottom: calc(0.375em - 1px);
+    padding-left: 0.75em;
+    padding-right: 0.75em;
+    padding-top: calc(0.375em - 1px);
+    text-align: center;
+    white-space: nowrap; }
+    html.theme--documenter-dark .button strong {
+      color: inherit; }
+    html.theme--documenter-dark .button .icon, html.theme--documenter-dark .button .icon.is-small, html.theme--documenter-dark .button #documenter .docs-sidebar form.docs-search > input.icon, html.theme--documenter-dark #documenter .docs-sidebar .button form.docs-search > input.icon, html.theme--documenter-dark .button .icon.is-medium, html.theme--documenter-dark .button .icon.is-large {
+      height: 1.5em;
+      width: 1.5em; }
+    html.theme--documenter-dark .button .icon:first-child:not(:last-child) {
+      margin-left: calc(-0.375em - 1px);
+      margin-right: 0.1875em; }
+    html.theme--documenter-dark .button .icon:last-child:not(:first-child) {
+      margin-left: 0.1875em;
+      margin-right: calc(-0.375em - 1px); }
+    html.theme--documenter-dark .button .icon:first-child:last-child {
+      margin-left: calc(-0.375em - 1px);
+      margin-right: calc(-0.375em - 1px); }
+    html.theme--documenter-dark .button:hover, html.theme--documenter-dark .button.is-hovered {
+      border-color: #8c9b9d;
+      color: #f2f2f2; }
+    html.theme--documenter-dark .button:focus, html.theme--documenter-dark .button.is-focused {
+      border-color: #8c9b9d;
+      color: #17a689; }
+      html.theme--documenter-dark .button:focus:not(:active), html.theme--documenter-dark .button.is-focused:not(:active) {
+        box-shadow: 0 0 0 0.125em rgba(26, 188, 156, 0.25); }
+    html.theme--documenter-dark .button:active, html.theme--documenter-dark .button.is-active {
+      border-color: #343c3d;
+      color: #f2f2f2; }
+    html.theme--documenter-dark .button.is-text {
+      background-color: transparent;
+      border-color: transparent;
+      color: #fff;
+      text-decoration: underline; }
+      html.theme--documenter-dark .button.is-text:hover, html.theme--documenter-dark .button.is-text.is-hovered, html.theme--documenter-dark .button.is-text:focus, html.theme--documenter-dark .button.is-text.is-focused {
+        background-color: #282f2f;
+        color: #f2f2f2; }
+      html.theme--documenter-dark .button.is-text:active, html.theme--documenter-dark .button.is-text.is-active {
+        background-color: #1d2122;
+        color: #f2f2f2; }
+      html.theme--documenter-dark .button.is-text[disabled],
+      fieldset[disabled] html.theme--documenter-dark .button.is-text {
+        background-color: transparent;
+        border-color: transparent;
+        box-shadow: none; }
+    html.theme--documenter-dark .button.is-white {
+      background-color: white;
+      border-color: transparent;
+      color: #0a0a0a; }
+      html.theme--documenter-dark .button.is-white:hover, html.theme--documenter-dark .button.is-white.is-hovered {
+        background-color: #f9f9f9;
+        border-color: transparent;
+        color: #0a0a0a; }
+      html.theme--documenter-dark .button.is-white:focus, html.theme--documenter-dark .button.is-white.is-focused {
+        border-color: transparent;
+        color: #0a0a0a; }
+        html.theme--documenter-dark .button.is-white:focus:not(:active), html.theme--documenter-dark .button.is-white.is-focused:not(:active) {
+          box-shadow: 0 0 0 0.125em rgba(255, 255, 255, 0.25); }
+      html.theme--documenter-dark .button.is-white:active, html.theme--documenter-dark .button.is-white.is-active {
+        background-color: #f2f2f2;
+        border-color: transparent;
+        color: #0a0a0a; }
+      html.theme--documenter-dark .button.is-white[disabled],
+      fieldset[disabled] html.theme--documenter-dark .button.is-white {
+        background-color: white;
+        border-color: transparent;
+        box-shadow: none; }
+      html.theme--documenter-dark .button.is-white.is-inverted {
+        background-color: #0a0a0a;
+        color: white; }
+        html.theme--documenter-dark .button.is-white.is-inverted:hover, html.theme--documenter-dark .button.is-white.is-inverted.is-hovered {
+          background-color: black; }
+        html.theme--documenter-dark .button.is-white.is-inverted[disabled],
+        fieldset[disabled] html.theme--documenter-dark .button.is-white.is-inverted {
+          background-color: #0a0a0a;
+          border-color: transparent;
+          box-shadow: none;
+          color: white; }
+      html.theme--documenter-dark .button.is-white.is-loading::after {
+        border-color: transparent transparent #0a0a0a #0a0a0a !important; }
+      html.theme--documenter-dark .button.is-white.is-outlined {
+        background-color: transparent;
+        border-color: white;
+        color: white; }
+        html.theme--documenter-dark .button.is-white.is-outlined:hover, html.theme--documenter-dark .button.is-white.is-outlined.is-hovered, html.theme--documenter-dark .button.is-white.is-outlined:focus, html.theme--documenter-dark .button.is-white.is-outlined.is-focused {
+          background-color: white;
+          border-color: white;
+          color: #0a0a0a; }
+        html.theme--documenter-dark .button.is-white.is-outlined.is-loading::after {
+          border-color: transparent transparent white white !important; }
+        html.theme--documenter-dark .button.is-white.is-outlined.is-loading:hover::after, html.theme--documenter-dark .button.is-white.is-outlined.is-loading.is-hovered::after, html.theme--documenter-dark .button.is-white.is-outlined.is-loading:focus::after, html.theme--documenter-dark .button.is-white.is-outlined.is-loading.is-focused::after {
+          border-color: transparent transparent #0a0a0a #0a0a0a !important; }
+        html.theme--documenter-dark .button.is-white.is-outlined[disabled],
+        fieldset[disabled] html.theme--documenter-dark .button.is-white.is-outlined {
+          background-color: transparent;
+          border-color: white;
+          box-shadow: none;
+          color: white; }
+      html.theme--documenter-dark .button.is-white.is-inverted.is-outlined {
+        background-color: transparent;
+        border-color: #0a0a0a;
+        color: #0a0a0a; }
+        html.theme--documenter-dark .button.is-white.is-inverted.is-outlined:hover, html.theme--documenter-dark .button.is-white.is-inverted.is-outlined.is-hovered, html.theme--documenter-dark .button.is-white.is-inverted.is-outlined:focus, html.theme--documenter-dark .button.is-white.is-inverted.is-outlined.is-focused {
+          background-color: #0a0a0a;
+          color: white; }
+        html.theme--documenter-dark .button.is-white.is-inverted.is-outlined.is-loading:hover::after, html.theme--documenter-dark .button.is-white.is-inverted.is-outlined.is-loading.is-hovered::after, html.theme--documenter-dark .button.is-white.is-inverted.is-outlined.is-loading:focus::after, html.theme--documenter-dark .button.is-white.is-inverted.is-outlined.is-loading.is-focused::after {
+          border-color: transparent transparent white white !important; }
+        html.theme--documenter-dark .button.is-white.is-inverted.is-outlined[disabled],
+        fieldset[disabled] html.theme--documenter-dark .button.is-white.is-inverted.is-outlined {
+          background-color: transparent;
+          border-color: #0a0a0a;
+          box-shadow: none;
+          color: #0a0a0a; }
+    html.theme--documenter-dark .button.is-black {
+      background-color: #0a0a0a;
+      border-color: transparent;
+      color: white; }
+      html.theme--documenter-dark .button.is-black:hover, html.theme--documenter-dark .button.is-black.is-hovered {
+        background-color: #040404;
+        border-color: transparent;
+        color: white; }
+      html.theme--documenter-dark .button.is-black:focus, html.theme--documenter-dark .button.is-black.is-focused {
+        border-color: transparent;
+        color: white; }
+        html.theme--documenter-dark .button.is-black:focus:not(:active), html.theme--documenter-dark .button.is-black.is-focused:not(:active) {
+          box-shadow: 0 0 0 0.125em rgba(10, 10, 10, 0.25); }
+      html.theme--documenter-dark .button.is-black:active, html.theme--documenter-dark .button.is-black.is-active {
+        background-color: black;
+        border-color: transparent;
+        color: white; }
+      html.theme--documenter-dark .button.is-black[disabled],
+      fieldset[disabled] html.theme--documenter-dark .button.is-black {
+        background-color: #0a0a0a;
+        border-color: transparent;
+        box-shadow: none; }
+      html.theme--documenter-dark .button.is-black.is-inverted {
+        background-color: white;
+        color: #0a0a0a; }
+        html.theme--documenter-dark .button.is-black.is-inverted:hover, html.theme--documenter-dark .button.is-black.is-inverted.is-hovered {
+          background-color: #f2f2f2; }
+        html.theme--documenter-dark .button.is-black.is-inverted[disabled],
+        fieldset[disabled] html.theme--documenter-dark .button.is-black.is-inverted {
+          background-color: white;
+          border-color: transparent;
+          box-shadow: none;
+          color: #0a0a0a; }
+      html.theme--documenter-dark .button.is-black.is-loading::after {
+        border-color: transparent transparent white white !important; }
+      html.theme--documenter-dark .button.is-black.is-outlined {
+        background-color: transparent;
+        border-color: #0a0a0a;
+        color: #0a0a0a; }
+        html.theme--documenter-dark .button.is-black.is-outlined:hover, html.theme--documenter-dark .button.is-black.is-outlined.is-hovered, html.theme--documenter-dark .button.is-black.is-outlined:focus, html.theme--documenter-dark .button.is-black.is-outlined.is-focused {
+          background-color: #0a0a0a;
+          border-color: #0a0a0a;
+          color: white; }
+        html.theme--documenter-dark .button.is-black.is-outlined.is-loading::after {
+          border-color: transparent transparent #0a0a0a #0a0a0a !important; }
+        html.theme--documenter-dark .button.is-black.is-outlined.is-loading:hover::after, html.theme--documenter-dark .button.is-black.is-outlined.is-loading.is-hovered::after, html.theme--documenter-dark .button.is-black.is-outlined.is-loading:focus::after, html.theme--documenter-dark .button.is-black.is-outlined.is-loading.is-focused::after {
+          border-color: transparent transparent white white !important; }
+        html.theme--documenter-dark .button.is-black.is-outlined[disabled],
+        fieldset[disabled] html.theme--documenter-dark .button.is-black.is-outlined {
+          background-color: transparent;
+          border-color: #0a0a0a;
+          box-shadow: none;
+          color: #0a0a0a; }
+      html.theme--documenter-dark .button.is-black.is-inverted.is-outlined {
+        background-color: transparent;
+        border-color: white;
+        color: white; }
+        html.theme--documenter-dark .button.is-black.is-inverted.is-outlined:hover, html.theme--documenter-dark .button.is-black.is-inverted.is-outlined.is-hovered, html.theme--documenter-dark .button.is-black.is-inverted.is-outlined:focus, html.theme--documenter-dark .button.is-black.is-inverted.is-outlined.is-focused {
+          background-color: white;
+          color: #0a0a0a; }
+        html.theme--documenter-dark .button.is-black.is-inverted.is-outlined.is-loading:hover::after, html.theme--documenter-dark .button.is-black.is-inverted.is-outlined.is-loading.is-hovered::after, html.theme--documenter-dark .button.is-black.is-inverted.is-outlined.is-loading:focus::after, html.theme--documenter-dark .button.is-black.is-inverted.is-outlined.is-loading.is-focused::after {
+          border-color: transparent transparent #0a0a0a #0a0a0a !important; }
+        html.theme--documenter-dark .button.is-black.is-inverted.is-outlined[disabled],
+        fieldset[disabled] html.theme--documenter-dark .button.is-black.is-inverted.is-outlined {
+          background-color: transparent;
+          border-color: white;
+          box-shadow: none;
+          color: white; }
+    html.theme--documenter-dark .button.is-light {
+      background-color: #ecf0f1;
+      border-color: transparent;
+      color: #282f2f; }
+      html.theme--documenter-dark .button.is-light:hover, html.theme--documenter-dark .button.is-light.is-hovered {
+        background-color: #e5eaec;
+        border-color: transparent;
+        color: #282f2f; }
+      html.theme--documenter-dark .button.is-light:focus, html.theme--documenter-dark .button.is-light.is-focused {
+        border-color: transparent;
+        color: #282f2f; }
+        html.theme--documenter-dark .button.is-light:focus:not(:active), html.theme--documenter-dark .button.is-light.is-focused:not(:active) {
+          box-shadow: 0 0 0 0.125em rgba(236, 240, 241, 0.25); }
+      html.theme--documenter-dark .button.is-light:active, html.theme--documenter-dark .button.is-light.is-active {
+        background-color: #dde4e6;
+        border-color: transparent;
+        color: #282f2f; }
+      html.theme--documenter-dark .button.is-light[disabled],
+      fieldset[disabled] html.theme--documenter-dark .button.is-light {
+        background-color: #ecf0f1;
+        border-color: transparent;
+        box-shadow: none; }
+      html.theme--documenter-dark .button.is-light.is-inverted {
+        background-color: #282f2f;
+        color: #ecf0f1; }
+        html.theme--documenter-dark .button.is-light.is-inverted:hover, html.theme--documenter-dark .button.is-light.is-inverted.is-hovered {
+          background-color: #1d2122; }
+        html.theme--documenter-dark .button.is-light.is-inverted[disabled],
+        fieldset[disabled] html.theme--documenter-dark .button.is-light.is-inverted {
+          background-color: #282f2f;
+          border-color: transparent;
+          box-shadow: none;
+          color: #ecf0f1; }
+      html.theme--documenter-dark .button.is-light.is-loading::after {
+        border-color: transparent transparent #282f2f #282f2f !important; }
+      html.theme--documenter-dark .button.is-light.is-outlined {
+        background-color: transparent;
+        border-color: #ecf0f1;
+        color: #ecf0f1; }
+        html.theme--documenter-dark .button.is-light.is-outlined:hover, html.theme--documenter-dark .button.is-light.is-outlined.is-hovered, html.theme--documenter-dark .button.is-light.is-outlined:focus, html.theme--documenter-dark .button.is-light.is-outlined.is-focused {
+          background-color: #ecf0f1;
+          border-color: #ecf0f1;
+          color: #282f2f; }
+        html.theme--documenter-dark .button.is-light.is-outlined.is-loading::after {
+          border-color: transparent transparent #ecf0f1 #ecf0f1 !important; }
+        html.theme--documenter-dark .button.is-light.is-outlined.is-loading:hover::after, html.theme--documenter-dark .button.is-light.is-outlined.is-loading.is-hovered::after, html.theme--documenter-dark .button.is-light.is-outlined.is-loading:focus::after, html.theme--documenter-dark .button.is-light.is-outlined.is-loading.is-focused::after {
+          border-color: transparent transparent #282f2f #282f2f !important; }
+        html.theme--documenter-dark .button.is-light.is-outlined[disabled],
+        fieldset[disabled] html.theme--documenter-dark .button.is-light.is-outlined {
+          background-color: transparent;
+          border-color: #ecf0f1;
+          box-shadow: none;
+          color: #ecf0f1; }
+      html.theme--documenter-dark .button.is-light.is-inverted.is-outlined {
+        background-color: transparent;
+        border-color: #282f2f;
+        color: #282f2f; }
+        html.theme--documenter-dark .button.is-light.is-inverted.is-outlined:hover, html.theme--documenter-dark .button.is-light.is-inverted.is-outlined.is-hovered, html.theme--documenter-dark .button.is-light.is-inverted.is-outlined:focus, html.theme--documenter-dark .button.is-light.is-inverted.is-outlined.is-focused {
+          background-color: #282f2f;
+          color: #ecf0f1; }
+        html.theme--documenter-dark .button.is-light.is-inverted.is-outlined.is-loading:hover::after, html.theme--documenter-dark .button.is-light.is-inverted.is-outlined.is-loading.is-hovered::after, html.theme--documenter-dark .button.is-light.is-inverted.is-outlined.is-loading:focus::after, html.theme--documenter-dark .button.is-light.is-inverted.is-outlined.is-loading.is-focused::after {
+          border-color: transparent transparent #ecf0f1 #ecf0f1 !important; }
+        html.theme--documenter-dark .button.is-light.is-inverted.is-outlined[disabled],
+        fieldset[disabled] html.theme--documenter-dark .button.is-light.is-inverted.is-outlined {
+          background-color: transparent;
+          border-color: #282f2f;
+          box-shadow: none;
+          color: #282f2f; }
+    html.theme--documenter-dark .button.is-dark, html.theme--documenter-dark .content kbd.button {
+      background-color: #282f2f;
+      border-color: transparent;
+      color: #ecf0f1; }
+      html.theme--documenter-dark .button.is-dark:hover, html.theme--documenter-dark .content kbd.button:hover, html.theme--documenter-dark .button.is-dark.is-hovered, html.theme--documenter-dark .content kbd.button.is-hovered {
+        background-color: #232829;
+        border-color: transparent;
+        color: #ecf0f1; }
+      html.theme--documenter-dark .button.is-dark:focus, html.theme--documenter-dark .content kbd.button:focus, html.theme--documenter-dark .button.is-dark.is-focused, html.theme--documenter-dark .content kbd.button.is-focused {
+        border-color: transparent;
+        color: #ecf0f1; }
+        html.theme--documenter-dark .button.is-dark:focus:not(:active), html.theme--documenter-dark .content kbd.button:focus:not(:active), html.theme--documenter-dark .button.is-dark.is-focused:not(:active), html.theme--documenter-dark .content kbd.button.is-focused:not(:active) {
+          box-shadow: 0 0 0 0.125em rgba(40, 47, 47, 0.25); }
+      html.theme--documenter-dark .button.is-dark:active, html.theme--documenter-dark .content kbd.button:active, html.theme--documenter-dark .button.is-dark.is-active, html.theme--documenter-dark .content kbd.button.is-active {
+        background-color: #1d2122;
+        border-color: transparent;
+        color: #ecf0f1; }
+      html.theme--documenter-dark .button.is-dark[disabled], html.theme--documenter-dark .content kbd.button[disabled],
+      fieldset[disabled] html.theme--documenter-dark .button.is-dark,
+      fieldset[disabled] html.theme--documenter-dark .content kbd.button {
+        background-color: #282f2f;
+        border-color: transparent;
+        box-shadow: none; }
+      html.theme--documenter-dark .button.is-dark.is-inverted, html.theme--documenter-dark .content kbd.button.is-inverted {
+        background-color: #ecf0f1;
+        color: #282f2f; }
+        html.theme--documenter-dark .button.is-dark.is-inverted:hover, html.theme--documenter-dark .content kbd.button.is-inverted:hover, html.theme--documenter-dark .button.is-dark.is-inverted.is-hovered, html.theme--documenter-dark .content kbd.button.is-inverted.is-hovered {
+          background-color: #dde4e6; }
+        html.theme--documenter-dark .button.is-dark.is-inverted[disabled], html.theme--documenter-dark .content kbd.button.is-inverted[disabled],
+        fieldset[disabled] html.theme--documenter-dark .button.is-dark.is-inverted,
+        fieldset[disabled] html.theme--documenter-dark .content kbd.button.is-inverted {
+          background-color: #ecf0f1;
+          border-color: transparent;
+          box-shadow: none;
+          color: #282f2f; }
+      html.theme--documenter-dark .button.is-dark.is-loading::after, html.theme--documenter-dark .content kbd.button.is-loading::after {
+        border-color: transparent transparent #ecf0f1 #ecf0f1 !important; }
+      html.theme--documenter-dark .button.is-dark.is-outlined, html.theme--documenter-dark .content kbd.button.is-outlined {
+        background-color: transparent;
+        border-color: #282f2f;
+        color: #282f2f; }
+        html.theme--documenter-dark .button.is-dark.is-outlined:hover, html.theme--documenter-dark .content kbd.button.is-outlined:hover, html.theme--documenter-dark .button.is-dark.is-outlined.is-hovered, html.theme--documenter-dark .content kbd.button.is-outlined.is-hovered, html.theme--documenter-dark .button.is-dark.is-outlined:focus, html.theme--documenter-dark .content kbd.button.is-outlined:focus, html.theme--documenter-dark .button.is-dark.is-outlined.is-focused, html.theme--documenter-dark .content kbd.button.is-outlined.is-focused {
+          background-color: #282f2f;
+          border-color: #282f2f;
+          color: #ecf0f1; }
+        html.theme--documenter-dark .button.is-dark.is-outlined.is-loading::after, html.theme--documenter-dark .content kbd.button.is-outlined.is-loading::after {
+          border-color: transparent transparent #282f2f #282f2f !important; }
+        html.theme--documenter-dark .button.is-dark.is-outlined.is-loading:hover::after, html.theme--documenter-dark .content kbd.button.is-outlined.is-loading:hover::after, html.theme--documenter-dark .button.is-dark.is-outlined.is-loading.is-hovered::after, html.theme--documenter-dark .content kbd.button.is-outlined.is-loading.is-hovered::after, html.theme--documenter-dark .button.is-dark.is-outlined.is-loading:focus::after, html.theme--documenter-dark .content kbd.button.is-outlined.is-loading:focus::after, html.theme--documenter-dark .button.is-dark.is-outlined.is-loading.is-focused::after, html.theme--documenter-dark .content kbd.button.is-outlined.is-loading.is-focused::after {
+          border-color: transparent transparent #ecf0f1 #ecf0f1 !important; }
+        html.theme--documenter-dark .button.is-dark.is-outlined[disabled], html.theme--documenter-dark .content kbd.button.is-outlined[disabled],
+        fieldset[disabled] html.theme--documenter-dark .button.is-dark.is-outlined,
+        fieldset[disabled] html.theme--documenter-dark .content kbd.button.is-outlined {
+          background-color: transparent;
+          border-color: #282f2f;
+          box-shadow: none;
+          color: #282f2f; }
+      html.theme--documenter-dark .button.is-dark.is-inverted.is-outlined, html.theme--documenter-dark .content kbd.button.is-inverted.is-outlined {
+        background-color: transparent;
+        border-color: #ecf0f1;
+        color: #ecf0f1; }
+        html.theme--documenter-dark .button.is-dark.is-inverted.is-outlined:hover, html.theme--documenter-dark .content kbd.button.is-inverted.is-outlined:hover, html.theme--documenter-dark .button.is-dark.is-inverted.is-outlined.is-hovered, html.theme--documenter-dark .content kbd.button.is-inverted.is-outlined.is-hovered, html.theme--documenter-dark .button.is-dark.is-inverted.is-outlined:focus, html.theme--documenter-dark .content kbd.button.is-inverted.is-outlined:focus, html.theme--documenter-dark .button.is-dark.is-inverted.is-outlined.is-focused, html.theme--documenter-dark .content kbd.button.is-inverted.is-outlined.is-focused {
+          background-color: #ecf0f1;
+          color: #282f2f; }
+        html.theme--documenter-dark .button.is-dark.is-inverted.is-outlined.is-loading:hover::after, html.theme--documenter-dark .content kbd.button.is-inverted.is-outlined.is-loading:hover::after, html.theme--documenter-dark .button.is-dark.is-inverted.is-outlined.is-loading.is-hovered::after, html.theme--documenter-dark .content kbd.button.is-inverted.is-outlined.is-loading.is-hovered::after, html.theme--documenter-dark .button.is-dark.is-inverted.is-outlined.is-loading:focus::after, html.theme--documenter-dark .content kbd.button.is-inverted.is-outlined.is-loading:focus::after, html.theme--documenter-dark .button.is-dark.is-inverted.is-outlined.is-loading.is-focused::after, html.theme--documenter-dark .content kbd.button.is-inverted.is-outlined.is-loading.is-focused::after {
+          border-color: transparent transparent #282f2f #282f2f !important; }
+        html.theme--documenter-dark .button.is-dark.is-inverted.is-outlined[disabled], html.theme--documenter-dark .content kbd.button.is-inverted.is-outlined[disabled],
+        fieldset[disabled] html.theme--documenter-dark .button.is-dark.is-inverted.is-outlined,
+        fieldset[disabled] html.theme--documenter-dark .content kbd.button.is-inverted.is-outlined {
+          background-color: transparent;
+          border-color: #ecf0f1;
+          box-shadow: none;
+          color: #ecf0f1; }
+    html.theme--documenter-dark .button.is-primary, html.theme--documenter-dark .docstring > section > a.button.docs-sourcelink {
+      background-color: #375a7f;
+      border-color: transparent;
+      color: #fff; }
+      html.theme--documenter-dark .button.is-primary:hover, html.theme--documenter-dark .docstring > section > a.button.docs-sourcelink:hover, html.theme--documenter-dark .button.is-primary.is-hovered, html.theme--documenter-dark .docstring > section > a.button.is-hovered.docs-sourcelink {
+        background-color: #335476;
+        border-color: transparent;
+        color: #fff; }
+      html.theme--documenter-dark .button.is-primary:focus, html.theme--documenter-dark .docstring > section > a.button.docs-sourcelink:focus, html.theme--documenter-dark .button.is-primary.is-focused, html.theme--documenter-dark .docstring > section > a.button.is-focused.docs-sourcelink {
+        border-color: transparent;
+        color: #fff; }
+        html.theme--documenter-dark .button.is-primary:focus:not(:active), html.theme--documenter-dark .docstring > section > a.button.docs-sourcelink:focus:not(:active), html.theme--documenter-dark .button.is-primary.is-focused:not(:active), html.theme--documenter-dark .docstring > section > a.button.is-focused.docs-sourcelink:not(:active) {
+          box-shadow: 0 0 0 0.125em rgba(55, 90, 127, 0.25); }
+      html.theme--documenter-dark .button.is-primary:active, html.theme--documenter-dark .docstring > section > a.button.docs-sourcelink:active, html.theme--documenter-dark .button.is-primary.is-active, html.theme--documenter-dark .docstring > section > a.button.is-active.docs-sourcelink {
+        background-color: #2f4d6d;
+        border-color: transparent;
+        color: #fff; }
+      html.theme--documenter-dark .button.is-primary[disabled], html.theme--documenter-dark .docstring > section > a.button.docs-sourcelink[disabled],
+      fieldset[disabled] html.theme--documenter-dark .button.is-primary,
+      fieldset[disabled] html.theme--documenter-dark .docstring > section > a.button.docs-sourcelink {
+        background-color: #375a7f;
+        border-color: transparent;
+        box-shadow: none; }
+      html.theme--documenter-dark .button.is-primary.is-inverted, html.theme--documenter-dark .docstring > section > a.button.is-inverted.docs-sourcelink {
+        background-color: #fff;
+        color: #375a7f; }
+        html.theme--documenter-dark .button.is-primary.is-inverted:hover, html.theme--documenter-dark .docstring > section > a.button.is-inverted.docs-sourcelink:hover, html.theme--documenter-dark .button.is-primary.is-inverted.is-hovered, html.theme--documenter-dark .docstring > section > a.button.is-inverted.is-hovered.docs-sourcelink {
+          background-color: #f2f2f2; }
+        html.theme--documenter-dark .button.is-primary.is-inverted[disabled], html.theme--documenter-dark .docstring > section > a.button.is-inverted.docs-sourcelink[disabled],
+        fieldset[disabled] html.theme--documenter-dark .button.is-primary.is-inverted,
+        fieldset[disabled] html.theme--documenter-dark .docstring > section > a.button.is-inverted.docs-sourcelink {
+          background-color: #fff;
+          border-color: transparent;
+          box-shadow: none;
+          color: #375a7f; }
+      html.theme--documenter-dark .button.is-primary.is-loading::after, html.theme--documenter-dark .docstring > section > a.button.is-loading.docs-sourcelink::after {
+        border-color: transparent transparent #fff #fff !important; }
+      html.theme--documenter-dark .button.is-primary.is-outlined, html.theme--documenter-dark .docstring > section > a.button.is-outlined.docs-sourcelink {
+        background-color: transparent;
+        border-color: #375a7f;
+        color: #375a7f; }
+        html.theme--documenter-dark .button.is-primary.is-outlined:hover, html.theme--documenter-dark .docstring > section > a.button.is-outlined.docs-sourcelink:hover, html.theme--documenter-dark .button.is-primary.is-outlined.is-hovered, html.theme--documenter-dark .docstring > section > a.button.is-outlined.is-hovered.docs-sourcelink, html.theme--documenter-dark .button.is-primary.is-outlined:focus, html.theme--documenter-dark .docstring > section > a.button.is-outlined.docs-sourcelink:focus, html.theme--documenter-dark .button.is-primary.is-outlined.is-focused, html.theme--documenter-dark .docstring > section > a.button.is-outlined.is-focused.docs-sourcelink {
+          background-color: #375a7f;
+          border-color: #375a7f;
+          color: #fff; }
+        html.theme--documenter-dark .button.is-primary.is-outlined.is-loading::after, html.theme--documenter-dark .docstring > section > a.button.is-outlined.is-loading.docs-sourcelink::after {
+          border-color: transparent transparent #375a7f #375a7f !important; }
+        html.theme--documenter-dark .button.is-primary.is-outlined.is-loading:hover::after, html.theme--documenter-dark .docstring > section > a.button.is-outlined.is-loading.docs-sourcelink:hover::after, html.theme--documenter-dark .button.is-primary.is-outlined.is-loading.is-hovered::after, html.theme--documenter-dark .docstring > section > a.button.is-outlined.is-loading.is-hovered.docs-sourcelink::after, html.theme--documenter-dark .button.is-primary.is-outlined.is-loading:focus::after, html.theme--documenter-dark .docstring > section > a.button.is-outlined.is-loading.docs-sourcelink:focus::after, html.theme--documenter-dark .button.is-primary.is-outlined.is-loading.is-focused::after, html.theme--documenter-dark .docstring > section > a.button.is-outlined.is-loading.is-focused.docs-sourcelink::after {
+          border-color: transparent transparent #fff #fff !important; }
+        html.theme--documenter-dark .button.is-primary.is-outlined[disabled], html.theme--documenter-dark .docstring > section > a.button.is-outlined.docs-sourcelink[disabled],
+        fieldset[disabled] html.theme--documenter-dark .button.is-primary.is-outlined,
+        fieldset[disabled] html.theme--documenter-dark .docstring > section > a.button.is-outlined.docs-sourcelink {
+          background-color: transparent;
+          border-color: #375a7f;
+          box-shadow: none;
+          color: #375a7f; }
+      html.theme--documenter-dark .button.is-primary.is-inverted.is-outlined, html.theme--documenter-dark .docstring > section > a.button.is-inverted.is-outlined.docs-sourcelink {
+        background-color: transparent;
+        border-color: #fff;
+        color: #fff; }
+        html.theme--documenter-dark .button.is-primary.is-inverted.is-outlined:hover, html.theme--documenter-dark .docstring > section > a.button.is-inverted.is-outlined.docs-sourcelink:hover, html.theme--documenter-dark .button.is-primary.is-inverted.is-outlined.is-hovered, html.theme--documenter-dark .docstring > section > a.button.is-inverted.is-outlined.is-hovered.docs-sourcelink, html.theme--documenter-dark .button.is-primary.is-inverted.is-outlined:focus, html.theme--documenter-dark .docstring > section > a.button.is-inverted.is-outlined.docs-sourcelink:focus, html.theme--documenter-dark .button.is-primary.is-inverted.is-outlined.is-focused, html.theme--documenter-dark .docstring > section > a.button.is-inverted.is-outlined.is-focused.docs-sourcelink {
+          background-color: #fff;
+          color: #375a7f; }
+        html.theme--documenter-dark .button.is-primary.is-inverted.is-outlined.is-loading:hover::after, html.theme--documenter-dark .docstring > section > a.button.is-inverted.is-outlined.is-loading.docs-sourcelink:hover::after, html.theme--documenter-dark .button.is-primary.is-inverted.is-outlined.is-loading.is-hovered::after, html.theme--documenter-dark .docstring > section > a.button.is-inverted.is-outlined.is-loading.is-hovered.docs-sourcelink::after, html.theme--documenter-dark .button.is-primary.is-inverted.is-outlined.is-loading:focus::after, html.theme--documenter-dark .docstring > section > a.button.is-inverted.is-outlined.is-loading.docs-sourcelink:focus::after, html.theme--documenter-dark .button.is-primary.is-inverted.is-outlined.is-loading.is-focused::after, html.theme--documenter-dark .docstring > section > a.button.is-inverted.is-outlined.is-loading.is-focused.docs-sourcelink::after {
+          border-color: transparent transparent #375a7f #375a7f !important; }
+        html.theme--documenter-dark .button.is-primary.is-inverted.is-outlined[disabled], html.theme--documenter-dark .docstring > section > a.button.is-inverted.is-outlined.docs-sourcelink[disabled],
+        fieldset[disabled] html.theme--documenter-dark .button.is-primary.is-inverted.is-outlined,
+        fieldset[disabled] html.theme--documenter-dark .docstring > section > a.button.is-inverted.is-outlined.docs-sourcelink {
+          background-color: transparent;
+          border-color: #fff;
+          box-shadow: none;
+          color: #fff; }
+    html.theme--documenter-dark .button.is-link {
+      background-color: #1abc9c;
+      border-color: transparent;
+      color: #fff; }
+      html.theme--documenter-dark .button.is-link:hover, html.theme--documenter-dark .button.is-link.is-hovered {
+        background-color: #18b193;
+        border-color: transparent;
+        color: #fff; }
+      html.theme--documenter-dark .button.is-link:focus, html.theme--documenter-dark .button.is-link.is-focused {
+        border-color: transparent;
+        color: #fff; }
+        html.theme--documenter-dark .button.is-link:focus:not(:active), html.theme--documenter-dark .button.is-link.is-focused:not(:active) {
+          box-shadow: 0 0 0 0.125em rgba(26, 188, 156, 0.25); }
+      html.theme--documenter-dark .button.is-link:active, html.theme--documenter-dark .button.is-link.is-active {
+        background-color: #17a689;
+        border-color: transparent;
+        color: #fff; }
+      html.theme--documenter-dark .button.is-link[disabled],
+      fieldset[disabled] html.theme--documenter-dark .button.is-link {
+        background-color: #1abc9c;
+        border-color: transparent;
+        box-shadow: none; }
+      html.theme--documenter-dark .button.is-link.is-inverted {
+        background-color: #fff;
+        color: #1abc9c; }
+        html.theme--documenter-dark .button.is-link.is-inverted:hover, html.theme--documenter-dark .button.is-link.is-inverted.is-hovered {
+          background-color: #f2f2f2; }
+        html.theme--documenter-dark .button.is-link.is-inverted[disabled],
+        fieldset[disabled] html.theme--documenter-dark .button.is-link.is-inverted {
+          background-color: #fff;
+          border-color: transparent;
+          box-shadow: none;
+          color: #1abc9c; }
+      html.theme--documenter-dark .button.is-link.is-loading::after {
+        border-color: transparent transparent #fff #fff !important; }
+      html.theme--documenter-dark .button.is-link.is-outlined {
+        background-color: transparent;
+        border-color: #1abc9c;
+        color: #1abc9c; }
+        html.theme--documenter-dark .button.is-link.is-outlined:hover, html.theme--documenter-dark .button.is-link.is-outlined.is-hovered, html.theme--documenter-dark .button.is-link.is-outlined:focus, html.theme--documenter-dark .button.is-link.is-outlined.is-focused {
+          background-color: #1abc9c;
+          border-color: #1abc9c;
+          color: #fff; }
+        html.theme--documenter-dark .button.is-link.is-outlined.is-loading::after {
+          border-color: transparent transparent #1abc9c #1abc9c !important; }
+        html.theme--documenter-dark .button.is-link.is-outlined.is-loading:hover::after, html.theme--documenter-dark .button.is-link.is-outlined.is-loading.is-hovered::after, html.theme--documenter-dark .button.is-link.is-outlined.is-loading:focus::after, html.theme--documenter-dark .button.is-link.is-outlined.is-loading.is-focused::after {
+          border-color: transparent transparent #fff #fff !important; }
+        html.theme--documenter-dark .button.is-link.is-outlined[disabled],
+        fieldset[disabled] html.theme--documenter-dark .button.is-link.is-outlined {
+          background-color: transparent;
+          border-color: #1abc9c;
+          box-shadow: none;
+          color: #1abc9c; }
+      html.theme--documenter-dark .button.is-link.is-inverted.is-outlined {
+        background-color: transparent;
+        border-color: #fff;
+        color: #fff; }
+        html.theme--documenter-dark .button.is-link.is-inverted.is-outlined:hover, html.theme--documenter-dark .button.is-link.is-inverted.is-outlined.is-hovered, html.theme--documenter-dark .button.is-link.is-inverted.is-outlined:focus, html.theme--documenter-dark .button.is-link.is-inverted.is-outlined.is-focused {
+          background-color: #fff;
+          color: #1abc9c; }
+        html.theme--documenter-dark .button.is-link.is-inverted.is-outlined.is-loading:hover::after, html.theme--documenter-dark .button.is-link.is-inverted.is-outlined.is-loading.is-hovered::after, html.theme--documenter-dark .button.is-link.is-inverted.is-outlined.is-loading:focus::after, html.theme--documenter-dark .button.is-link.is-inverted.is-outlined.is-loading.is-focused::after {
+          border-color: transparent transparent #1abc9c #1abc9c !important; }
+        html.theme--documenter-dark .button.is-link.is-inverted.is-outlined[disabled],
+        fieldset[disabled] html.theme--documenter-dark .button.is-link.is-inverted.is-outlined {
+          background-color: transparent;
+          border-color: #fff;
+          box-shadow: none;
+          color: #fff; }
+    html.theme--documenter-dark .button.is-info {
+      background-color: #024c7d;
+      border-color: transparent;
+      color: #fff; }
+      html.theme--documenter-dark .button.is-info:hover, html.theme--documenter-dark .button.is-info.is-hovered {
+        background-color: #024470;
+        border-color: transparent;
+        color: #fff; }
+      html.theme--documenter-dark .button.is-info:focus, html.theme--documenter-dark .button.is-info.is-focused {
+        border-color: transparent;
+        color: #fff; }
+        html.theme--documenter-dark .button.is-info:focus:not(:active), html.theme--documenter-dark .button.is-info.is-focused:not(:active) {
+          box-shadow: 0 0 0 0.125em rgba(2, 76, 125, 0.25); }
+      html.theme--documenter-dark .button.is-info:active, html.theme--documenter-dark .button.is-info.is-active {
+        background-color: #023d64;
+        border-color: transparent;
+        color: #fff; }
+      html.theme--documenter-dark .button.is-info[disabled],
+      fieldset[disabled] html.theme--documenter-dark .button.is-info {
+        background-color: #024c7d;
+        border-color: transparent;
+        box-shadow: none; }
+      html.theme--documenter-dark .button.is-info.is-inverted {
+        background-color: #fff;
+        color: #024c7d; }
+        html.theme--documenter-dark .button.is-info.is-inverted:hover, html.theme--documenter-dark .button.is-info.is-inverted.is-hovered {
+          background-color: #f2f2f2; }
+        html.theme--documenter-dark .button.is-info.is-inverted[disabled],
+        fieldset[disabled] html.theme--documenter-dark .button.is-info.is-inverted {
+          background-color: #fff;
+          border-color: transparent;
+          box-shadow: none;
+          color: #024c7d; }
+      html.theme--documenter-dark .button.is-info.is-loading::after {
+        border-color: transparent transparent #fff #fff !important; }
+      html.theme--documenter-dark .button.is-info.is-outlined {
+        background-color: transparent;
+        border-color: #024c7d;
+        color: #024c7d; }
+        html.theme--documenter-dark .button.is-info.is-outlined:hover, html.theme--documenter-dark .button.is-info.is-outlined.is-hovered, html.theme--documenter-dark .button.is-info.is-outlined:focus, html.theme--documenter-dark .button.is-info.is-outlined.is-focused {
+          background-color: #024c7d;
+          border-color: #024c7d;
+          color: #fff; }
+        html.theme--documenter-dark .button.is-info.is-outlined.is-loading::after {
+          border-color: transparent transparent #024c7d #024c7d !important; }
+        html.theme--documenter-dark .button.is-info.is-outlined.is-loading:hover::after, html.theme--documenter-dark .button.is-info.is-outlined.is-loading.is-hovered::after, html.theme--documenter-dark .button.is-info.is-outlined.is-loading:focus::after, html.theme--documenter-dark .button.is-info.is-outlined.is-loading.is-focused::after {
+          border-color: transparent transparent #fff #fff !important; }
+        html.theme--documenter-dark .button.is-info.is-outlined[disabled],
+        fieldset[disabled] html.theme--documenter-dark .button.is-info.is-outlined {
+          background-color: transparent;
+          border-color: #024c7d;
+          box-shadow: none;
+          color: #024c7d; }
+      html.theme--documenter-dark .button.is-info.is-inverted.is-outlined {
+        background-color: transparent;
+        border-color: #fff;
+        color: #fff; }
+        html.theme--documenter-dark .button.is-info.is-inverted.is-outlined:hover, html.theme--documenter-dark .button.is-info.is-inverted.is-outlined.is-hovered, html.theme--documenter-dark .button.is-info.is-inverted.is-outlined:focus, html.theme--documenter-dark .button.is-info.is-inverted.is-outlined.is-focused {
+          background-color: #fff;
+          color: #024c7d; }
+        html.theme--documenter-dark .button.is-info.is-inverted.is-outlined.is-loading:hover::after, html.theme--documenter-dark .button.is-info.is-inverted.is-outlined.is-loading.is-hovered::after, html.theme--documenter-dark .button.is-info.is-inverted.is-outlined.is-loading:focus::after, html.theme--documenter-dark .button.is-info.is-inverted.is-outlined.is-loading.is-focused::after {
+          border-color: transparent transparent #024c7d #024c7d !important; }
+        html.theme--documenter-dark .button.is-info.is-inverted.is-outlined[disabled],
+        fieldset[disabled] html.theme--documenter-dark .button.is-info.is-inverted.is-outlined {
+          background-color: transparent;
+          border-color: #fff;
+          box-shadow: none;
+          color: #fff; }
+    html.theme--documenter-dark .button.is-success {
+      background-color: #008438;
+      border-color: transparent;
+      color: #fff; }
+      html.theme--documenter-dark .button.is-success:hover, html.theme--documenter-dark .button.is-success.is-hovered {
+        background-color: #007733;
+        border-color: transparent;
+        color: #fff; }
+      html.theme--documenter-dark .button.is-success:focus, html.theme--documenter-dark .button.is-success.is-focused {
+        border-color: transparent;
+        color: #fff; }
+        html.theme--documenter-dark .button.is-success:focus:not(:active), html.theme--documenter-dark .button.is-success.is-focused:not(:active) {
+          box-shadow: 0 0 0 0.125em rgba(0, 132, 56, 0.25); }
+      html.theme--documenter-dark .button.is-success:active, html.theme--documenter-dark .button.is-success.is-active {
+        background-color: #006b2d;
+        border-color: transparent;
+        color: #fff; }
+      html.theme--documenter-dark .button.is-success[disabled],
+      fieldset[disabled] html.theme--documenter-dark .button.is-success {
+        background-color: #008438;
+        border-color: transparent;
+        box-shadow: none; }
+      html.theme--documenter-dark .button.is-success.is-inverted {
+        background-color: #fff;
+        color: #008438; }
+        html.theme--documenter-dark .button.is-success.is-inverted:hover, html.theme--documenter-dark .button.is-success.is-inverted.is-hovered {
+          background-color: #f2f2f2; }
+        html.theme--documenter-dark .button.is-success.is-inverted[disabled],
+        fieldset[disabled] html.theme--documenter-dark .button.is-success.is-inverted {
+          background-color: #fff;
+          border-color: transparent;
+          box-shadow: none;
+          color: #008438; }
+      html.theme--documenter-dark .button.is-success.is-loading::after {
+        border-color: transparent transparent #fff #fff !important; }
+      html.theme--documenter-dark .button.is-success.is-outlined {
+        background-color: transparent;
+        border-color: #008438;
+        color: #008438; }
+        html.theme--documenter-dark .button.is-success.is-outlined:hover, html.theme--documenter-dark .button.is-success.is-outlined.is-hovered, html.theme--documenter-dark .button.is-success.is-outlined:focus, html.theme--documenter-dark .button.is-success.is-outlined.is-focused {
+          background-color: #008438;
+          border-color: #008438;
+          color: #fff; }
+        html.theme--documenter-dark .button.is-success.is-outlined.is-loading::after {
+          border-color: transparent transparent #008438 #008438 !important; }
+        html.theme--documenter-dark .button.is-success.is-outlined.is-loading:hover::after, html.theme--documenter-dark .button.is-success.is-outlined.is-loading.is-hovered::after, html.theme--documenter-dark .button.is-success.is-outlined.is-loading:focus::after, html.theme--documenter-dark .button.is-success.is-outlined.is-loading.is-focused::after {
+          border-color: transparent transparent #fff #fff !important; }
+        html.theme--documenter-dark .button.is-success.is-outlined[disabled],
+        fieldset[disabled] html.theme--documenter-dark .button.is-success.is-outlined {
+          background-color: transparent;
+          border-color: #008438;
+          box-shadow: none;
+          color: #008438; }
+      html.theme--documenter-dark .button.is-success.is-inverted.is-outlined {
+        background-color: transparent;
+        border-color: #fff;
+        color: #fff; }
+        html.theme--documenter-dark .button.is-success.is-inverted.is-outlined:hover, html.theme--documenter-dark .button.is-success.is-inverted.is-outlined.is-hovered, html.theme--documenter-dark .button.is-success.is-inverted.is-outlined:focus, html.theme--documenter-dark .button.is-success.is-inverted.is-outlined.is-focused {
+          background-color: #fff;
+          color: #008438; }
+        html.theme--documenter-dark .button.is-success.is-inverted.is-outlined.is-loading:hover::after, html.theme--documenter-dark .button.is-success.is-inverted.is-outlined.is-loading.is-hovered::after, html.theme--documenter-dark .button.is-success.is-inverted.is-outlined.is-loading:focus::after, html.theme--documenter-dark .button.is-success.is-inverted.is-outlined.is-loading.is-focused::after {
+          border-color: transparent transparent #008438 #008438 !important; }
+        html.theme--documenter-dark .button.is-success.is-inverted.is-outlined[disabled],
+        fieldset[disabled] html.theme--documenter-dark .button.is-success.is-inverted.is-outlined {
+          background-color: transparent;
+          border-color: #fff;
+          box-shadow: none;
+          color: #fff; }
+    html.theme--documenter-dark .button.is-warning {
+      background-color: #ad8100;
+      border-color: transparent;
+      color: #fff; }
+      html.theme--documenter-dark .button.is-warning:hover, html.theme--documenter-dark .button.is-warning.is-hovered {
+        background-color: #a07700;
+        border-color: transparent;
+        color: #fff; }
+      html.theme--documenter-dark .button.is-warning:focus, html.theme--documenter-dark .button.is-warning.is-focused {
+        border-color: transparent;
+        color: #fff; }
+        html.theme--documenter-dark .button.is-warning:focus:not(:active), html.theme--documenter-dark .button.is-warning.is-focused:not(:active) {
+          box-shadow: 0 0 0 0.125em rgba(173, 129, 0, 0.25); }
+      html.theme--documenter-dark .button.is-warning:active, html.theme--documenter-dark .button.is-warning.is-active {
+        background-color: #946e00;
+        border-color: transparent;
+        color: #fff; }
+      html.theme--documenter-dark .button.is-warning[disabled],
+      fieldset[disabled] html.theme--documenter-dark .button.is-warning {
+        background-color: #ad8100;
+        border-color: transparent;
+        box-shadow: none; }
+      html.theme--documenter-dark .button.is-warning.is-inverted {
+        background-color: #fff;
+        color: #ad8100; }
+        html.theme--documenter-dark .button.is-warning.is-inverted:hover, html.theme--documenter-dark .button.is-warning.is-inverted.is-hovered {
+          background-color: #f2f2f2; }
+        html.theme--documenter-dark .button.is-warning.is-inverted[disabled],
+        fieldset[disabled] html.theme--documenter-dark .button.is-warning.is-inverted {
+          background-color: #fff;
+          border-color: transparent;
+          box-shadow: none;
+          color: #ad8100; }
+      html.theme--documenter-dark .button.is-warning.is-loading::after {
+        border-color: transparent transparent #fff #fff !important; }
+      html.theme--documenter-dark .button.is-warning.is-outlined {
+        background-color: transparent;
+        border-color: #ad8100;
+        color: #ad8100; }
+        html.theme--documenter-dark .button.is-warning.is-outlined:hover, html.theme--documenter-dark .button.is-warning.is-outlined.is-hovered, html.theme--documenter-dark .button.is-warning.is-outlined:focus, html.theme--documenter-dark .button.is-warning.is-outlined.is-focused {
+          background-color: #ad8100;
+          border-color: #ad8100;
+          color: #fff; }
+        html.theme--documenter-dark .button.is-warning.is-outlined.is-loading::after {
+          border-color: transparent transparent #ad8100 #ad8100 !important; }
+        html.theme--documenter-dark .button.is-warning.is-outlined.is-loading:hover::after, html.theme--documenter-dark .button.is-warning.is-outlined.is-loading.is-hovered::after, html.theme--documenter-dark .button.is-warning.is-outlined.is-loading:focus::after, html.theme--documenter-dark .button.is-warning.is-outlined.is-loading.is-focused::after {
+          border-color: transparent transparent #fff #fff !important; }
+        html.theme--documenter-dark .button.is-warning.is-outlined[disabled],
+        fieldset[disabled] html.theme--documenter-dark .button.is-warning.is-outlined {
+          background-color: transparent;
+          border-color: #ad8100;
+          box-shadow: none;
+          color: #ad8100; }
+      html.theme--documenter-dark .button.is-warning.is-inverted.is-outlined {
+        background-color: transparent;
+        border-color: #fff;
+        color: #fff; }
+        html.theme--documenter-dark .button.is-warning.is-inverted.is-outlined:hover, html.theme--documenter-dark .button.is-warning.is-inverted.is-outlined.is-hovered, html.theme--documenter-dark .button.is-warning.is-inverted.is-outlined:focus, html.theme--documenter-dark .button.is-warning.is-inverted.is-outlined.is-focused {
+          background-color: #fff;
+          color: #ad8100; }
+        html.theme--documenter-dark .button.is-warning.is-inverted.is-outlined.is-loading:hover::after, html.theme--documenter-dark .button.is-warning.is-inverted.is-outlined.is-loading.is-hovered::after, html.theme--documenter-dark .button.is-warning.is-inverted.is-outlined.is-loading:focus::after, html.theme--documenter-dark .button.is-warning.is-inverted.is-outlined.is-loading.is-focused::after {
+          border-color: transparent transparent #ad8100 #ad8100 !important; }
+        html.theme--documenter-dark .button.is-warning.is-inverted.is-outlined[disabled],
+        fieldset[disabled] html.theme--documenter-dark .button.is-warning.is-inverted.is-outlined {
+          background-color: transparent;
+          border-color: #fff;
+          box-shadow: none;
+          color: #fff; }
+    html.theme--documenter-dark .button.is-danger {
+      background-color: #9e1b0d;
+      border-color: transparent;
+      color: #fff; }
+      html.theme--documenter-dark .button.is-danger:hover, html.theme--documenter-dark .button.is-danger.is-hovered {
+        background-color: #92190c;
+        border-color: transparent;
+        color: #fff; }
+      html.theme--documenter-dark .button.is-danger:focus, html.theme--documenter-dark .button.is-danger.is-focused {
+        border-color: transparent;
+        color: #fff; }
+        html.theme--documenter-dark .button.is-danger:focus:not(:active), html.theme--documenter-dark .button.is-danger.is-focused:not(:active) {
+          box-shadow: 0 0 0 0.125em rgba(158, 27, 13, 0.25); }
+      html.theme--documenter-dark .button.is-danger:active, html.theme--documenter-dark .button.is-danger.is-active {
+        background-color: #86170b;
+        border-color: transparent;
+        color: #fff; }
+      html.theme--documenter-dark .button.is-danger[disabled],
+      fieldset[disabled] html.theme--documenter-dark .button.is-danger {
+        background-color: #9e1b0d;
+        border-color: transparent;
+        box-shadow: none; }
+      html.theme--documenter-dark .button.is-danger.is-inverted {
+        background-color: #fff;
+        color: #9e1b0d; }
+        html.theme--documenter-dark .button.is-danger.is-inverted:hover, html.theme--documenter-dark .button.is-danger.is-inverted.is-hovered {
+          background-color: #f2f2f2; }
+        html.theme--documenter-dark .button.is-danger.is-inverted[disabled],
+        fieldset[disabled] html.theme--documenter-dark .button.is-danger.is-inverted {
+          background-color: #fff;
+          border-color: transparent;
+          box-shadow: none;
+          color: #9e1b0d; }
+      html.theme--documenter-dark .button.is-danger.is-loading::after {
+        border-color: transparent transparent #fff #fff !important; }
+      html.theme--documenter-dark .button.is-danger.is-outlined {
+        background-color: transparent;
+        border-color: #9e1b0d;
+        color: #9e1b0d; }
+        html.theme--documenter-dark .button.is-danger.is-outlined:hover, html.theme--documenter-dark .button.is-danger.is-outlined.is-hovered, html.theme--documenter-dark .button.is-danger.is-outlined:focus, html.theme--documenter-dark .button.is-danger.is-outlined.is-focused {
+          background-color: #9e1b0d;
+          border-color: #9e1b0d;
+          color: #fff; }
+        html.theme--documenter-dark .button.is-danger.is-outlined.is-loading::after {
+          border-color: transparent transparent #9e1b0d #9e1b0d !important; }
+        html.theme--documenter-dark .button.is-danger.is-outlined.is-loading:hover::after, html.theme--documenter-dark .button.is-danger.is-outlined.is-loading.is-hovered::after, html.theme--documenter-dark .button.is-danger.is-outlined.is-loading:focus::after, html.theme--documenter-dark .button.is-danger.is-outlined.is-loading.is-focused::after {
+          border-color: transparent transparent #fff #fff !important; }
+        html.theme--documenter-dark .button.is-danger.is-outlined[disabled],
+        fieldset[disabled] html.theme--documenter-dark .button.is-danger.is-outlined {
+          background-color: transparent;
+          border-color: #9e1b0d;
+          box-shadow: none;
+          color: #9e1b0d; }
+      html.theme--documenter-dark .button.is-danger.is-inverted.is-outlined {
+        background-color: transparent;
+        border-color: #fff;
+        color: #fff; }
+        html.theme--documenter-dark .button.is-danger.is-inverted.is-outlined:hover, html.theme--documenter-dark .button.is-danger.is-inverted.is-outlined.is-hovered, html.theme--documenter-dark .button.is-danger.is-inverted.is-outlined:focus, html.theme--documenter-dark .button.is-danger.is-inverted.is-outlined.is-focused {
+          background-color: #fff;
+          color: #9e1b0d; }
+        html.theme--documenter-dark .button.is-danger.is-inverted.is-outlined.is-loading:hover::after, html.theme--documenter-dark .button.is-danger.is-inverted.is-outlined.is-loading.is-hovered::after, html.theme--documenter-dark .button.is-danger.is-inverted.is-outlined.is-loading:focus::after, html.theme--documenter-dark .button.is-danger.is-inverted.is-outlined.is-loading.is-focused::after {
+          border-color: transparent transparent #9e1b0d #9e1b0d !important; }
+        html.theme--documenter-dark .button.is-danger.is-inverted.is-outlined[disabled],
+        fieldset[disabled] html.theme--documenter-dark .button.is-danger.is-inverted.is-outlined {
+          background-color: transparent;
+          border-color: #fff;
+          box-shadow: none;
+          color: #fff; }
+    html.theme--documenter-dark .button.is-small, html.theme--documenter-dark #documenter .docs-sidebar form.docs-search > input.button {
+      border-radius: 3px;
+      font-size: 0.85em; }
+    html.theme--documenter-dark .button.is-normal {
+      font-size: 15px; }
+    html.theme--documenter-dark .button.is-medium {
+      font-size: 1.25rem; }
+    html.theme--documenter-dark .button.is-large {
+      font-size: 1.5rem; }
+    html.theme--documenter-dark .button[disabled],
+    fieldset[disabled] html.theme--documenter-dark .button {
+      background-color: #8c9b9d;
+      border-color: #dbdee0;
+      box-shadow: none;
+      opacity: 0.5; }
+    html.theme--documenter-dark .button.is-fullwidth {
+      display: flex;
+      width: 100%; }
+    html.theme--documenter-dark .button.is-loading {
+      color: transparent !important;
+      pointer-events: none; }
+      html.theme--documenter-dark .button.is-loading::after {
+        position: absolute;
+        left: calc(50% - (1em / 2));
+        top: calc(50% - (1em / 2));
+        position: absolute !important; }
+    html.theme--documenter-dark .button.is-static {
+      background-color: #282f2f;
+      border-color: #5e6d6f;
+      color: #dbdee0;
+      box-shadow: none;
+      pointer-events: none; }
+    html.theme--documenter-dark .button.is-rounded, html.theme--documenter-dark #documenter .docs-sidebar form.docs-search > input.button {
+      border-radius: 290486px;
+      padding-left: 1em;
+      padding-right: 1em; }
+  html.theme--documenter-dark .buttons {
+    align-items: center;
+    display: flex;
+    flex-wrap: wrap;
+    justify-content: flex-start; }
+    html.theme--documenter-dark .buttons .button {
+      margin-bottom: 0.5rem; }
+      html.theme--documenter-dark .buttons .button:not(:last-child):not(.is-fullwidth) {
+        margin-right: 0.5rem; }
+    html.theme--documenter-dark .buttons:last-child {
+      margin-bottom: -0.5rem; }
+    html.theme--documenter-dark .buttons:not(:last-child) {
+      margin-bottom: 1rem; }
+    html.theme--documenter-dark .buttons.are-small .button:not(.is-normal):not(.is-medium):not(.is-large) {
+      border-radius: 3px;
+      font-size: 0.85em; }
+    html.theme--documenter-dark .buttons.are-medium .button:not(.is-small):not(.is-normal):not(.is-large) {
+      font-size: 1.25rem; }
+    html.theme--documenter-dark .buttons.are-large .button:not(.is-small):not(.is-normal):not(.is-medium) {
+      font-size: 1.5rem; }
+    html.theme--documenter-dark .buttons.has-addons .button:not(:first-child) {
+      border-bottom-left-radius: 0;
+      border-top-left-radius: 0; }
+    html.theme--documenter-dark .buttons.has-addons .button:not(:last-child) {
+      border-bottom-right-radius: 0;
+      border-top-right-radius: 0;
+      margin-right: -1px; }
+    html.theme--documenter-dark .buttons.has-addons .button:last-child {
+      margin-right: 0; }
+    html.theme--documenter-dark .buttons.has-addons .button:hover, html.theme--documenter-dark .buttons.has-addons .button.is-hovered {
+      z-index: 2; }
+    html.theme--documenter-dark .buttons.has-addons .button:focus, html.theme--documenter-dark .buttons.has-addons .button.is-focused, html.theme--documenter-dark .buttons.has-addons .button:active, html.theme--documenter-dark .buttons.has-addons .button.is-active, html.theme--documenter-dark .buttons.has-addons .button.is-selected {
+      z-index: 3; }
+      html.theme--documenter-dark .buttons.has-addons .button:focus:hover, html.theme--documenter-dark .buttons.has-addons .button.is-focused:hover, html.theme--documenter-dark .buttons.has-addons .button:active:hover, html.theme--documenter-dark .buttons.has-addons .button.is-active:hover, html.theme--documenter-dark .buttons.has-addons .button.is-selected:hover {
+        z-index: 4; }
+    html.theme--documenter-dark .buttons.has-addons .button.is-expanded {
+      flex-grow: 1;
+      flex-shrink: 1; }
+    html.theme--documenter-dark .buttons.is-centered {
+      justify-content: center; }
+      html.theme--documenter-dark .buttons.is-centered:not(.has-addons) .button:not(.is-fullwidth) {
+        margin-left: 0.25rem;
+        margin-right: 0.25rem; }
+    html.theme--documenter-dark .buttons.is-right {
+      justify-content: flex-end; }
+      html.theme--documenter-dark .buttons.is-right:not(.has-addons) .button:not(.is-fullwidth) {
+        margin-left: 0.25rem;
+        margin-right: 0.25rem; }
+  html.theme--documenter-dark .container {
+    flex-grow: 1;
+    margin: 0 auto;
+    position: relative;
+    width: auto; }
+    @media screen and (min-width: 1056px) {
+      html.theme--documenter-dark .container {
+        max-width: 992px; }
+        html.theme--documenter-dark .container.is-fluid {
+          margin-left: 32px;
+          margin-right: 32px;
+          max-width: none; } }
+    @media screen and (max-width: 1215px) {
+      html.theme--documenter-dark .container.is-widescreen {
+        max-width: 1152px; } }
+    @media screen and (max-width: 1407px) {
+      html.theme--documenter-dark .container.is-fullhd {
+        max-width: 1344px; } }
+    @media screen and (min-width: 1216px) {
+      html.theme--documenter-dark .container {
+        max-width: 1152px; } }
+    @media screen and (min-width: 1408px) {
+      html.theme--documenter-dark .container {
+        max-width: 1344px; } }
+  html.theme--documenter-dark .content li + li {
+    margin-top: 0.25em; }
+  html.theme--documenter-dark .content p:not(:last-child),
+  html.theme--documenter-dark .content dl:not(:last-child),
+  html.theme--documenter-dark .content ol:not(:last-child),
+  html.theme--documenter-dark .content ul:not(:last-child),
+  html.theme--documenter-dark .content blockquote:not(:last-child),
+  html.theme--documenter-dark .content pre:not(:last-child),
+  html.theme--documenter-dark .content table:not(:last-child) {
+    margin-bottom: 1em; }
+  html.theme--documenter-dark .content h1,
+  html.theme--documenter-dark .content h2,
+  html.theme--documenter-dark .content h3,
+  html.theme--documenter-dark .content h4,
+  html.theme--documenter-dark .content h5,
+  html.theme--documenter-dark .content h6 {
+    color: #f2f2f2;
+    font-weight: 600;
+    line-height: 1.125; }
+  html.theme--documenter-dark .content h1 {
+    font-size: 2em;
+    margin-bottom: 0.5em; }
+    html.theme--documenter-dark .content h1:not(:first-child) {
+      margin-top: 1em; }
+  html.theme--documenter-dark .content h2 {
+    font-size: 1.75em;
+    margin-bottom: 0.5714em; }
+    html.theme--documenter-dark .content h2:not(:first-child) {
+      margin-top: 1.1428em; }
+  html.theme--documenter-dark .content h3 {
+    font-size: 1.5em;
+    margin-bottom: 0.6666em; }
+    html.theme--documenter-dark .content h3:not(:first-child) {
+      margin-top: 1.3333em; }
+  html.theme--documenter-dark .content h4 {
+    font-size: 1.25em;
+    margin-bottom: 0.8em; }
+  html.theme--documenter-dark .content h5 {
+    font-size: 1.125em;
+    margin-bottom: 0.8888em; }
+  html.theme--documenter-dark .content h6 {
+    font-size: 1em;
+    margin-bottom: 1em; }
+  html.theme--documenter-dark .content blockquote {
+    background-color: #282f2f;
+    border-left: 5px solid #5e6d6f;
+    padding: 1.25em 1.5em; }
+  html.theme--documenter-dark .content ol {
+    list-style-position: outside;
+    margin-left: 2em;
+    margin-top: 1em; }
+    html.theme--documenter-dark .content ol:not([type]) {
+      list-style-type: decimal; }
+      html.theme--documenter-dark .content ol:not([type]).is-lower-alpha {
+        list-style-type: lower-alpha; }
+      html.theme--documenter-dark .content ol:not([type]).is-lower-roman {
+        list-style-type: lower-roman; }
+      html.theme--documenter-dark .content ol:not([type]).is-upper-alpha {
+        list-style-type: upper-alpha; }
+      html.theme--documenter-dark .content ol:not([type]).is-upper-roman {
+        list-style-type: upper-roman; }
+  html.theme--documenter-dark .content ul {
+    list-style: disc outside;
+    margin-left: 2em;
+    margin-top: 1em; }
+    html.theme--documenter-dark .content ul ul {
+      list-style-type: circle;
+      margin-top: 0.5em; }
+      html.theme--documenter-dark .content ul ul ul {
+        list-style-type: square; }
+  html.theme--documenter-dark .content dd {
+    margin-left: 2em; }
+  html.theme--documenter-dark .content figure {
+    margin-left: 2em;
+    margin-right: 2em;
+    text-align: center; }
+    html.theme--documenter-dark .content figure:not(:first-child) {
+      margin-top: 2em; }
+    html.theme--documenter-dark .content figure:not(:last-child) {
+      margin-bottom: 2em; }
+    html.theme--documenter-dark .content figure img {
+      display: inline-block; }
+    html.theme--documenter-dark .content figure figcaption {
+      font-style: italic; }
+  html.theme--documenter-dark .content pre {
+    -webkit-overflow-scrolling: touch;
+    overflow-x: auto;
+    padding: 0.7rem 0.5rem;
+    white-space: pre;
+    word-wrap: normal; }
+  html.theme--documenter-dark .content sup,
+  html.theme--documenter-dark .content sub {
+    font-size: 75%; }
+  html.theme--documenter-dark .content table {
+    width: 100%; }
+    html.theme--documenter-dark .content table td,
+    html.theme--documenter-dark .content table th {
+      border: 1px solid #5e6d6f;
+      border-width: 0 0 1px;
+      padding: 0.5em 0.75em;
+      vertical-align: top; }
+    html.theme--documenter-dark .content table th {
+      color: #f2f2f2; }
+      html.theme--documenter-dark .content table th:not([align]) {
+        text-align: left; }
+    html.theme--documenter-dark .content table thead td,
+    html.theme--documenter-dark .content table thead th {
+      border-width: 0 0 2px;
+      color: #f2f2f2; }
+    html.theme--documenter-dark .content table tfoot td,
+    html.theme--documenter-dark .content table tfoot th {
+      border-width: 2px 0 0;
+      color: #f2f2f2; }
+    html.theme--documenter-dark .content table tbody tr:last-child td,
+    html.theme--documenter-dark .content table tbody tr:last-child th {
+      border-bottom-width: 0; }
+  html.theme--documenter-dark .content .tabs li + li {
+    margin-top: 0; }
+  html.theme--documenter-dark .content.is-small, html.theme--documenter-dark #documenter .docs-sidebar form.docs-search > input.content {
+    font-size: 0.85em; }
+  html.theme--documenter-dark .content.is-medium {
+    font-size: 1.25rem; }
+  html.theme--documenter-dark .content.is-large {
+    font-size: 1.5rem; }
+  html.theme--documenter-dark .icon {
+    align-items: center;
+    display: inline-flex;
+    justify-content: center;
+    height: 1.5rem;
+    width: 1.5rem; }
+    html.theme--documenter-dark .icon.is-small, html.theme--documenter-dark #documenter .docs-sidebar form.docs-search > input.icon {
+      height: 1rem;
+      width: 1rem; }
+    html.theme--documenter-dark .icon.is-medium {
+      height: 2rem;
+      width: 2rem; }
+    html.theme--documenter-dark .icon.is-large {
+      height: 3rem;
+      width: 3rem; }
+  html.theme--documenter-dark .image, html.theme--documenter-dark #documenter .docs-sidebar .docs-logo > img {
+    display: block;
+    position: relative; }
+    html.theme--documenter-dark .image img, html.theme--documenter-dark #documenter .docs-sidebar .docs-logo > img img {
+      display: block;
+      height: auto;
+      width: 100%; }
+      html.theme--documenter-dark .image img.is-rounded, html.theme--documenter-dark #documenter .docs-sidebar .docs-logo > img img.is-rounded {
+        border-radius: 290486px; }
+    html.theme--documenter-dark .image.is-square img, html.theme--documenter-dark #documenter .docs-sidebar .docs-logo > img.is-square img,
+    html.theme--documenter-dark .image.is-square .has-ratio,
+    html.theme--documenter-dark #documenter .docs-sidebar .docs-logo > img.is-square .has-ratio, html.theme--documenter-dark .image.is-1by1 img, html.theme--documenter-dark #documenter .docs-sidebar .docs-logo > img.is-1by1 img,
+    html.theme--documenter-dark .image.is-1by1 .has-ratio,
+    html.theme--documenter-dark #documenter .docs-sidebar .docs-logo > img.is-1by1 .has-ratio, html.theme--documenter-dark .image.is-5by4 img, html.theme--documenter-dark #documenter .docs-sidebar .docs-logo > img.is-5by4 img,
+    html.theme--documenter-dark .image.is-5by4 .has-ratio,
+    html.theme--documenter-dark #documenter .docs-sidebar .docs-logo > img.is-5by4 .has-ratio, html.theme--documenter-dark .image.is-4by3 img, html.theme--documenter-dark #documenter .docs-sidebar .docs-logo > img.is-4by3 img,
+    html.theme--documenter-dark .image.is-4by3 .has-ratio,
+    html.theme--documenter-dark #documenter .docs-sidebar .docs-logo > img.is-4by3 .has-ratio, html.theme--documenter-dark .image.is-3by2 img, html.theme--documenter-dark #documenter .docs-sidebar .docs-logo > img.is-3by2 img,
+    html.theme--documenter-dark .image.is-3by2 .has-ratio,
+    html.theme--documenter-dark #documenter .docs-sidebar .docs-logo > img.is-3by2 .has-ratio, html.theme--documenter-dark .image.is-5by3 img, html.theme--documenter-dark #documenter .docs-sidebar .docs-logo > img.is-5by3 img,
+    html.theme--documenter-dark .image.is-5by3 .has-ratio,
+    html.theme--documenter-dark #documenter .docs-sidebar .docs-logo > img.is-5by3 .has-ratio, html.theme--documenter-dark .image.is-16by9 img, html.theme--documenter-dark #documenter .docs-sidebar .docs-logo > img.is-16by9 img,
+    html.theme--documenter-dark .image.is-16by9 .has-ratio,
+    html.theme--documenter-dark #documenter .docs-sidebar .docs-logo > img.is-16by9 .has-ratio, html.theme--documenter-dark .image.is-2by1 img, html.theme--documenter-dark #documenter .docs-sidebar .docs-logo > img.is-2by1 img,
+    html.theme--documenter-dark .image.is-2by1 .has-ratio,
+    html.theme--documenter-dark #documenter .docs-sidebar .docs-logo > img.is-2by1 .has-ratio, html.theme--documenter-dark .image.is-3by1 img, html.theme--documenter-dark #documenter .docs-sidebar .docs-logo > img.is-3by1 img,
+    html.theme--documenter-dark .image.is-3by1 .has-ratio,
+    html.theme--documenter-dark #documenter .docs-sidebar .docs-logo > img.is-3by1 .has-ratio, html.theme--documenter-dark .image.is-4by5 img, html.theme--documenter-dark #documenter .docs-sidebar .docs-logo > img.is-4by5 img,
+    html.theme--documenter-dark .image.is-4by5 .has-ratio,
+    html.theme--documenter-dark #documenter .docs-sidebar .docs-logo > img.is-4by5 .has-ratio, html.theme--documenter-dark .image.is-3by4 img, html.theme--documenter-dark #documenter .docs-sidebar .docs-logo > img.is-3by4 img,
+    html.theme--documenter-dark .image.is-3by4 .has-ratio,
+    html.theme--documenter-dark #documenter .docs-sidebar .docs-logo > img.is-3by4 .has-ratio, html.theme--documenter-dark .image.is-2by3 img, html.theme--documenter-dark #documenter .docs-sidebar .docs-logo > img.is-2by3 img,
+    html.theme--documenter-dark .image.is-2by3 .has-ratio,
+    html.theme--documenter-dark #documenter .docs-sidebar .docs-logo > img.is-2by3 .has-ratio, html.theme--documenter-dark .image.is-3by5 img, html.theme--documenter-dark #documenter .docs-sidebar .docs-logo > img.is-3by5 img,
+    html.theme--documenter-dark .image.is-3by5 .has-ratio,
+    html.theme--documenter-dark #documenter .docs-sidebar .docs-logo > img.is-3by5 .has-ratio, html.theme--documenter-dark .image.is-9by16 img, html.theme--documenter-dark #documenter .docs-sidebar .docs-logo > img.is-9by16 img,
+    html.theme--documenter-dark .image.is-9by16 .has-ratio,
+    html.theme--documenter-dark #documenter .docs-sidebar .docs-logo > img.is-9by16 .has-ratio, html.theme--documenter-dark .image.is-1by2 img, html.theme--documenter-dark #documenter .docs-sidebar .docs-logo > img.is-1by2 img,
+    html.theme--documenter-dark .image.is-1by2 .has-ratio,
+    html.theme--documenter-dark #documenter .docs-sidebar .docs-logo > img.is-1by2 .has-ratio, html.theme--documenter-dark .image.is-1by3 img, html.theme--documenter-dark #documenter .docs-sidebar .docs-logo > img.is-1by3 img,
+    html.theme--documenter-dark .image.is-1by3 .has-ratio,
+    html.theme--documenter-dark #documenter .docs-sidebar .docs-logo > img.is-1by3 .has-ratio {
+      height: 100%;
+      width: 100%; }
+    html.theme--documenter-dark .image.is-square, html.theme--documenter-dark #documenter .docs-sidebar .docs-logo > img.is-square, html.theme--documenter-dark .image.is-1by1, html.theme--documenter-dark #documenter .docs-sidebar .docs-logo > img.is-1by1 {
+      padding-top: 100%; }
+    html.theme--documenter-dark .image.is-5by4, html.theme--documenter-dark #documenter .docs-sidebar .docs-logo > img.is-5by4 {
+      padding-top: 80%; }
+    html.theme--documenter-dark .image.is-4by3, html.theme--documenter-dark #documenter .docs-sidebar .docs-logo > img.is-4by3 {
+      padding-top: 75%; }
+    html.theme--documenter-dark .image.is-3by2, html.theme--documenter-dark #documenter .docs-sidebar .docs-logo > img.is-3by2 {
+      padding-top: 66.6666%; }
+    html.theme--documenter-dark .image.is-5by3, html.theme--documenter-dark #documenter .docs-sidebar .docs-logo > img.is-5by3 {
+      padding-top: 60%; }
+    html.theme--documenter-dark .image.is-16by9, html.theme--documenter-dark #documenter .docs-sidebar .docs-logo > img.is-16by9 {
+      padding-top: 56.25%; }
+    html.theme--documenter-dark .image.is-2by1, html.theme--documenter-dark #documenter .docs-sidebar .docs-logo > img.is-2by1 {
+      padding-top: 50%; }
+    html.theme--documenter-dark .image.is-3by1, html.theme--documenter-dark #documenter .docs-sidebar .docs-logo > img.is-3by1 {
+      padding-top: 33.3333%; }
+    html.theme--documenter-dark .image.is-4by5, html.theme--documenter-dark #documenter .docs-sidebar .docs-logo > img.is-4by5 {
+      padding-top: 125%; }
+    html.theme--documenter-dark .image.is-3by4, html.theme--documenter-dark #documenter .docs-sidebar .docs-logo > img.is-3by4 {
+      padding-top: 133.3333%; }
+    html.theme--documenter-dark .image.is-2by3, html.theme--documenter-dark #documenter .docs-sidebar .docs-logo > img.is-2by3 {
+      padding-top: 150%; }
+    html.theme--documenter-dark .image.is-3by5, html.theme--documenter-dark #documenter .docs-sidebar .docs-logo > img.is-3by5 {
+      padding-top: 166.6666%; }
+    html.theme--documenter-dark .image.is-9by16, html.theme--documenter-dark #documenter .docs-sidebar .docs-logo > img.is-9by16 {
+      padding-top: 177.7777%; }
+    html.theme--documenter-dark .image.is-1by2, html.theme--documenter-dark #documenter .docs-sidebar .docs-logo > img.is-1by2 {
+      padding-top: 200%; }
+    html.theme--documenter-dark .image.is-1by3, html.theme--documenter-dark #documenter .docs-sidebar .docs-logo > img.is-1by3 {
+      padding-top: 300%; }
+    html.theme--documenter-dark .image.is-16x16, html.theme--documenter-dark #documenter .docs-sidebar .docs-logo > img.is-16x16 {
+      height: 16px;
+      width: 16px; }
+    html.theme--documenter-dark .image.is-24x24, html.theme--documenter-dark #documenter .docs-sidebar .docs-logo > img.is-24x24 {
+      height: 24px;
+      width: 24px; }
+    html.theme--documenter-dark .image.is-32x32, html.theme--documenter-dark #documenter .docs-sidebar .docs-logo > img.is-32x32 {
+      height: 32px;
+      width: 32px; }
+    html.theme--documenter-dark .image.is-48x48, html.theme--documenter-dark #documenter .docs-sidebar .docs-logo > img.is-48x48 {
+      height: 48px;
+      width: 48px; }
+    html.theme--documenter-dark .image.is-64x64, html.theme--documenter-dark #documenter .docs-sidebar .docs-logo > img.is-64x64 {
+      height: 64px;
+      width: 64px; }
+    html.theme--documenter-dark .image.is-96x96, html.theme--documenter-dark #documenter .docs-sidebar .docs-logo > img.is-96x96 {
+      height: 96px;
+      width: 96px; }
+    html.theme--documenter-dark .image.is-128x128, html.theme--documenter-dark #documenter .docs-sidebar .docs-logo > img.is-128x128 {
+      height: 128px;
+      width: 128px; }
+  html.theme--documenter-dark .notification {
+    background-color: #282f2f;
+    border-radius: 0.4em;
+    padding: 1.25rem 2.5rem 1.25rem 1.5rem;
+    position: relative; }
+    html.theme--documenter-dark .notification a:not(.button):not(.dropdown-item) {
+      color: currentColor;
+      text-decoration: underline; }
+    html.theme--documenter-dark .notification strong {
+      color: currentColor; }
+    html.theme--documenter-dark .notification code,
+    html.theme--documenter-dark .notification pre {
+      background: white; }
+    html.theme--documenter-dark .notification pre code {
+      background: transparent; }
+    html.theme--documenter-dark .notification > .delete {
+      position: absolute;
+      right: 0.5rem;
+      top: 0.5rem; }
+    html.theme--documenter-dark .notification .title,
+    html.theme--documenter-dark .notification .subtitle,
+    html.theme--documenter-dark .notification .content {
+      color: currentColor; }
+    html.theme--documenter-dark .notification.is-white {
+      background-color: white;
+      color: #0a0a0a; }
+    html.theme--documenter-dark .notification.is-black {
+      background-color: #0a0a0a;
+      color: white; }
+    html.theme--documenter-dark .notification.is-light {
+      background-color: #ecf0f1;
+      color: #282f2f; }
+    html.theme--documenter-dark .notification.is-dark, html.theme--documenter-dark .content kbd.notification {
+      background-color: #282f2f;
+      color: #ecf0f1; }
+    html.theme--documenter-dark .notification.is-primary, html.theme--documenter-dark .docstring > section > a.notification.docs-sourcelink {
+      background-color: #375a7f;
+      color: #fff; }
+    html.theme--documenter-dark .notification.is-link {
+      background-color: #1abc9c;
+      color: #fff; }
+    html.theme--documenter-dark .notification.is-info {
+      background-color: #024c7d;
+      color: #fff; }
+    html.theme--documenter-dark .notification.is-success {
+      background-color: #008438;
+      color: #fff; }
+    html.theme--documenter-dark .notification.is-warning {
+      background-color: #ad8100;
+      color: #fff; }
+    html.theme--documenter-dark .notification.is-danger {
+      background-color: #9e1b0d;
+      color: #fff; }
+  html.theme--documenter-dark .progress {
+    -moz-appearance: none;
+    -webkit-appearance: none;
+    border: none;
+    border-radius: 290486px;
+    display: block;
+    height: 15px;
+    overflow: hidden;
+    padding: 0;
+    width: 100%; }
+    html.theme--documenter-dark .progress::-webkit-progress-bar {
+      background-color: #5e6d6f; }
+    html.theme--documenter-dark .progress::-webkit-progress-value {
+      background-color: #dbdee0; }
+    html.theme--documenter-dark .progress::-moz-progress-bar {
+      background-color: #dbdee0; }
+    html.theme--documenter-dark .progress::-ms-fill {
+      background-color: #dbdee0;
+      border: none; }
+    html.theme--documenter-dark .progress.is-white::-webkit-progress-value {
+      background-color: white; }
+    html.theme--documenter-dark .progress.is-white::-moz-progress-bar {
+      background-color: white; }
+    html.theme--documenter-dark .progress.is-white::-ms-fill {
+      background-color: white; }
+    html.theme--documenter-dark .progress.is-white:indeterminate {
+      background-image: linear-gradient(to right, white 30%, #5e6d6f 30%); }
+    html.theme--documenter-dark .progress.is-black::-webkit-progress-value {
+      background-color: #0a0a0a; }
+    html.theme--documenter-dark .progress.is-black::-moz-progress-bar {
+      background-color: #0a0a0a; }
+    html.theme--documenter-dark .progress.is-black::-ms-fill {
+      background-color: #0a0a0a; }
+    html.theme--documenter-dark .progress.is-black:indeterminate {
+      background-image: linear-gradient(to right, #0a0a0a 30%, #5e6d6f 30%); }
+    html.theme--documenter-dark .progress.is-light::-webkit-progress-value {
+      background-color: #ecf0f1; }
+    html.theme--documenter-dark .progress.is-light::-moz-progress-bar {
+      background-color: #ecf0f1; }
+    html.theme--documenter-dark .progress.is-light::-ms-fill {
+      background-color: #ecf0f1; }
+    html.theme--documenter-dark .progress.is-light:indeterminate {
+      background-image: linear-gradient(to right, #ecf0f1 30%, #5e6d6f 30%); }
+    html.theme--documenter-dark .progress.is-dark::-webkit-progress-value, html.theme--documenter-dark .content kbd.progress::-webkit-progress-value {
+      background-color: #282f2f; }
+    html.theme--documenter-dark .progress.is-dark::-moz-progress-bar, html.theme--documenter-dark .content kbd.progress::-moz-progress-bar {
+      background-color: #282f2f; }
+    html.theme--documenter-dark .progress.is-dark::-ms-fill, html.theme--documenter-dark .content kbd.progress::-ms-fill {
+      background-color: #282f2f; }
+    html.theme--documenter-dark .progress.is-dark:indeterminate, html.theme--documenter-dark .content kbd.progress:indeterminate {
+      background-image: linear-gradient(to right, #282f2f 30%, #5e6d6f 30%); }
+    html.theme--documenter-dark .progress.is-primary::-webkit-progress-value, html.theme--documenter-dark .docstring > section > a.progress.docs-sourcelink::-webkit-progress-value {
+      background-color: #375a7f; }
+    html.theme--documenter-dark .progress.is-primary::-moz-progress-bar, html.theme--documenter-dark .docstring > section > a.progress.docs-sourcelink::-moz-progress-bar {
+      background-color: #375a7f; }
+    html.theme--documenter-dark .progress.is-primary::-ms-fill, html.theme--documenter-dark .docstring > section > a.progress.docs-sourcelink::-ms-fill {
+      background-color: #375a7f; }
+    html.theme--documenter-dark .progress.is-primary:indeterminate, html.theme--documenter-dark .docstring > section > a.progress.docs-sourcelink:indeterminate {
+      background-image: linear-gradient(to right, #375a7f 30%, #5e6d6f 30%); }
+    html.theme--documenter-dark .progress.is-link::-webkit-progress-value {
+      background-color: #1abc9c; }
+    html.theme--documenter-dark .progress.is-link::-moz-progress-bar {
+      background-color: #1abc9c; }
+    html.theme--documenter-dark .progress.is-link::-ms-fill {
+      background-color: #1abc9c; }
+    html.theme--documenter-dark .progress.is-link:indeterminate {
+      background-image: linear-gradient(to right, #1abc9c 30%, #5e6d6f 30%); }
+    html.theme--documenter-dark .progress.is-info::-webkit-progress-value {
+      background-color: #024c7d; }
+    html.theme--documenter-dark .progress.is-info::-moz-progress-bar {
+      background-color: #024c7d; }
+    html.theme--documenter-dark .progress.is-info::-ms-fill {
+      background-color: #024c7d; }
+    html.theme--documenter-dark .progress.is-info:indeterminate {
+      background-image: linear-gradient(to right, #024c7d 30%, #5e6d6f 30%); }
+    html.theme--documenter-dark .progress.is-success::-webkit-progress-value {
+      background-color: #008438; }
+    html.theme--documenter-dark .progress.is-success::-moz-progress-bar {
+      background-color: #008438; }
+    html.theme--documenter-dark .progress.is-success::-ms-fill {
+      background-color: #008438; }
+    html.theme--documenter-dark .progress.is-success:indeterminate {
+      background-image: linear-gradient(to right, #008438 30%, #5e6d6f 30%); }
+    html.theme--documenter-dark .progress.is-warning::-webkit-progress-value {
+      background-color: #ad8100; }
+    html.theme--documenter-dark .progress.is-warning::-moz-progress-bar {
+      background-color: #ad8100; }
+    html.theme--documenter-dark .progress.is-warning::-ms-fill {
+      background-color: #ad8100; }
+    html.theme--documenter-dark .progress.is-warning:indeterminate {
+      background-image: linear-gradient(to right, #ad8100 30%, #5e6d6f 30%); }
+    html.theme--documenter-dark .progress.is-danger::-webkit-progress-value {
+      background-color: #9e1b0d; }
+    html.theme--documenter-dark .progress.is-danger::-moz-progress-bar {
+      background-color: #9e1b0d; }
+    html.theme--documenter-dark .progress.is-danger::-ms-fill {
+      background-color: #9e1b0d; }
+    html.theme--documenter-dark .progress.is-danger:indeterminate {
+      background-image: linear-gradient(to right, #9e1b0d 30%, #5e6d6f 30%); }
+    html.theme--documenter-dark .progress:indeterminate {
+      animation-duration: 1.5s;
+      animation-iteration-count: infinite;
+      animation-name: moveIndeterminate;
+      animation-timing-function: linear;
+      background-color: #5e6d6f;
+      background-image: linear-gradient(to right, #fff 30%, #5e6d6f 30%);
+      background-position: top left;
+      background-repeat: no-repeat;
+      background-size: 150% 150%; }
+      html.theme--documenter-dark .progress:indeterminate::-webkit-progress-bar {
+        background-color: transparent; }
+      html.theme--documenter-dark .progress:indeterminate::-moz-progress-bar {
+        background-color: transparent; }
+    html.theme--documenter-dark .progress.is-small, html.theme--documenter-dark #documenter .docs-sidebar form.docs-search > input.progress {
+      height: 0.85em; }
+    html.theme--documenter-dark .progress.is-medium {
+      height: 1.25rem; }
+    html.theme--documenter-dark .progress.is-large {
+      height: 1.5rem; }
+
+@keyframes moveIndeterminate {
+  from {
+    background-position: 200% 0; }
+  to {
+    background-position: -200% 0; } }
+  html.theme--documenter-dark .table {
+    background-color: #343c3d;
+    color: #fff; }
+    html.theme--documenter-dark .table td,
+    html.theme--documenter-dark .table th {
+      border: 1px solid #5e6d6f;
+      border-width: 0 0 1px;
+      padding: 0.5em 0.75em;
+      vertical-align: top; }
+      html.theme--documenter-dark .table td.is-white,
+      html.theme--documenter-dark .table th.is-white {
+        background-color: white;
+        border-color: white;
+        color: #0a0a0a; }
+      html.theme--documenter-dark .table td.is-black,
+      html.theme--documenter-dark .table th.is-black {
+        background-color: #0a0a0a;
+        border-color: #0a0a0a;
+        color: white; }
+      html.theme--documenter-dark .table td.is-light,
+      html.theme--documenter-dark .table th.is-light {
+        background-color: #ecf0f1;
+        border-color: #ecf0f1;
+        color: #282f2f; }
+      html.theme--documenter-dark .table td.is-dark,
+      html.theme--documenter-dark .table th.is-dark {
+        background-color: #282f2f;
+        border-color: #282f2f;
+        color: #ecf0f1; }
+      html.theme--documenter-dark .table td.is-primary,
+      html.theme--documenter-dark .table th.is-primary {
+        background-color: #375a7f;
+        border-color: #375a7f;
+        color: #fff; }
+      html.theme--documenter-dark .table td.is-link,
+      html.theme--documenter-dark .table th.is-link {
+        background-color: #1abc9c;
+        border-color: #1abc9c;
+        color: #fff; }
+      html.theme--documenter-dark .table td.is-info,
+      html.theme--documenter-dark .table th.is-info {
+        background-color: #024c7d;
+        border-color: #024c7d;
+        color: #fff; }
+      html.theme--documenter-dark .table td.is-success,
+      html.theme--documenter-dark .table th.is-success {
+        background-color: #008438;
+        border-color: #008438;
+        color: #fff; }
+      html.theme--documenter-dark .table td.is-warning,
+      html.theme--documenter-dark .table th.is-warning {
+        background-color: #ad8100;
+        border-color: #ad8100;
+        color: #fff; }
+      html.theme--documenter-dark .table td.is-danger,
+      html.theme--documenter-dark .table th.is-danger {
+        background-color: #9e1b0d;
+        border-color: #9e1b0d;
+        color: #fff; }
+      html.theme--documenter-dark .table td.is-narrow,
+      html.theme--documenter-dark .table th.is-narrow {
+        white-space: nowrap;
+        width: 1%; }
+      html.theme--documenter-dark .table td.is-selected,
+      html.theme--documenter-dark .table th.is-selected {
+        background-color: #375a7f;
+        color: #fff; }
+        html.theme--documenter-dark .table td.is-selected a,
+        html.theme--documenter-dark .table td.is-selected strong,
+        html.theme--documenter-dark .table th.is-selected a,
+        html.theme--documenter-dark .table th.is-selected strong {
+          color: currentColor; }
+    html.theme--documenter-dark .table th {
+      color: #f2f2f2; }
+      html.theme--documenter-dark .table th:not([align]) {
+        text-align: left; }
+    html.theme--documenter-dark .table tr.is-selected {
+      background-color: #375a7f;
+      color: #fff; }
+      html.theme--documenter-dark .table tr.is-selected a,
+      html.theme--documenter-dark .table tr.is-selected strong {
+        color: currentColor; }
+      html.theme--documenter-dark .table tr.is-selected td,
+      html.theme--documenter-dark .table tr.is-selected th {
+        border-color: #fff;
+        color: currentColor; }
+    html.theme--documenter-dark .table thead {
+      background-color: transparent; }
+      html.theme--documenter-dark .table thead td,
+      html.theme--documenter-dark .table thead th {
+        border-width: 0 0 2px;
+        color: #f2f2f2; }
+    html.theme--documenter-dark .table tfoot {
+      background-color: transparent; }
+      html.theme--documenter-dark .table tfoot td,
+      html.theme--documenter-dark .table tfoot th {
+        border-width: 2px 0 0;
+        color: #f2f2f2; }
+    html.theme--documenter-dark .table tbody {
+      background-color: transparent; }
+      html.theme--documenter-dark .table tbody tr:last-child td,
+      html.theme--documenter-dark .table tbody tr:last-child th {
+        border-bottom-width: 0; }
+    html.theme--documenter-dark .table.is-bordered td,
+    html.theme--documenter-dark .table.is-bordered th {
+      border-width: 1px; }
+    html.theme--documenter-dark .table.is-bordered tr:last-child td,
+    html.theme--documenter-dark .table.is-bordered tr:last-child th {
+      border-bottom-width: 1px; }
+    html.theme--documenter-dark .table.is-fullwidth {
+      width: 100%; }
+    html.theme--documenter-dark .table.is-hoverable tbody tr:not(.is-selected):hover {
+      background-color: #282f2f; }
+    html.theme--documenter-dark .table.is-hoverable.is-striped tbody tr:not(.is-selected):hover {
+      background-color: #282f2f; }
+      html.theme--documenter-dark .table.is-hoverable.is-striped tbody tr:not(.is-selected):hover:nth-child(even) {
+        background-color: #2d3435; }
+    html.theme--documenter-dark .table.is-narrow td,
+    html.theme--documenter-dark .table.is-narrow th {
+      padding: 0.25em 0.5em; }
+    html.theme--documenter-dark .table.is-striped tbody tr:not(.is-selected):nth-child(even) {
+      background-color: #282f2f; }
+  html.theme--documenter-dark .table-container {
+    -webkit-overflow-scrolling: touch;
+    overflow: auto;
+    overflow-y: hidden;
+    max-width: 100%; }
+  html.theme--documenter-dark .tags {
+    align-items: center;
+    display: flex;
+    flex-wrap: wrap;
+    justify-content: flex-start; }
+    html.theme--documenter-dark .tags .tag, html.theme--documenter-dark .tags .docstring > section > a.docs-sourcelink, html.theme--documenter-dark .tags .content kbd, html.theme--documenter-dark .content .tags kbd {
+      margin-bottom: 0.5rem; }
+      html.theme--documenter-dark .tags .tag:not(:last-child), html.theme--documenter-dark .tags .docstring > section > a.docs-sourcelink:not(:last-child), html.theme--documenter-dark .tags .content kbd:not(:last-child), html.theme--documenter-dark .content .tags kbd:not(:last-child) {
+        margin-right: 0.5rem; }
+    html.theme--documenter-dark .tags:last-child {
+      margin-bottom: -0.5rem; }
+    html.theme--documenter-dark .tags:not(:last-child) {
+      margin-bottom: 1rem; }
+    html.theme--documenter-dark .tags.are-medium .tag:not(.is-normal):not(.is-large), html.theme--documenter-dark .tags.are-medium .docstring > section > a.docs-sourcelink:not(.is-normal):not(.is-large), html.theme--documenter-dark .tags.are-medium .content kbd:not(.is-normal):not(.is-large), html.theme--documenter-dark .content .tags.are-medium kbd:not(.is-normal):not(.is-large) {
+      font-size: 15px; }
+    html.theme--documenter-dark .tags.are-large .tag:not(.is-normal):not(.is-medium), html.theme--documenter-dark .tags.are-large .docstring > section > a.docs-sourcelink:not(.is-normal):not(.is-medium), html.theme--documenter-dark .tags.are-large .content kbd:not(.is-normal):not(.is-medium), html.theme--documenter-dark .content .tags.are-large kbd:not(.is-normal):not(.is-medium) {
+      font-size: 1.25rem; }
+    html.theme--documenter-dark .tags.is-centered {
+      justify-content: center; }
+      html.theme--documenter-dark .tags.is-centered .tag, html.theme--documenter-dark .tags.is-centered .docstring > section > a.docs-sourcelink, html.theme--documenter-dark .tags.is-centered .content kbd, html.theme--documenter-dark .content .tags.is-centered kbd {
+        margin-right: 0.25rem;
+        margin-left: 0.25rem; }
+    html.theme--documenter-dark .tags.is-right {
+      justify-content: flex-end; }
+      html.theme--documenter-dark .tags.is-right .tag:not(:first-child), html.theme--documenter-dark .tags.is-right .docstring > section > a.docs-sourcelink:not(:first-child), html.theme--documenter-dark .tags.is-right .content kbd:not(:first-child), html.theme--documenter-dark .content .tags.is-right kbd:not(:first-child) {
+        margin-left: 0.5rem; }
+      html.theme--documenter-dark .tags.is-right .tag:not(:last-child), html.theme--documenter-dark .tags.is-right .docstring > section > a.docs-sourcelink:not(:last-child), html.theme--documenter-dark .tags.is-right .content kbd:not(:last-child), html.theme--documenter-dark .content .tags.is-right kbd:not(:last-child) {
+        margin-right: 0; }
+    html.theme--documenter-dark .tags.has-addons .tag, html.theme--documenter-dark .tags.has-addons .docstring > section > a.docs-sourcelink, html.theme--documenter-dark .tags.has-addons .content kbd, html.theme--documenter-dark .content .tags.has-addons kbd {
+      margin-right: 0; }
+      html.theme--documenter-dark .tags.has-addons .tag:not(:first-child), html.theme--documenter-dark .tags.has-addons .docstring > section > a.docs-sourcelink:not(:first-child), html.theme--documenter-dark .tags.has-addons .content kbd:not(:first-child), html.theme--documenter-dark .content .tags.has-addons kbd:not(:first-child) {
+        margin-left: 0;
+        border-bottom-left-radius: 0;
+        border-top-left-radius: 0; }
+      html.theme--documenter-dark .tags.has-addons .tag:not(:last-child), html.theme--documenter-dark .tags.has-addons .docstring > section > a.docs-sourcelink:not(:last-child), html.theme--documenter-dark .tags.has-addons .content kbd:not(:last-child), html.theme--documenter-dark .content .tags.has-addons kbd:not(:last-child) {
+        border-bottom-right-radius: 0;
+        border-top-right-radius: 0; }
+  html.theme--documenter-dark .tag:not(body), html.theme--documenter-dark .docstring > section > a.docs-sourcelink:not(body), html.theme--documenter-dark .content kbd:not(body) {
+    align-items: center;
+    background-color: #282f2f;
+    border-radius: 0.4em;
+    color: #fff;
+    display: inline-flex;
+    font-size: 0.85em;
+    height: 2em;
+    justify-content: center;
+    line-height: 1.5;
+    padding-left: 0.75em;
+    padding-right: 0.75em;
+    white-space: nowrap; }
+    html.theme--documenter-dark .tag:not(body) .delete, html.theme--documenter-dark .docstring > section > a.docs-sourcelink:not(body) .delete, html.theme--documenter-dark .content kbd:not(body) .delete {
+      margin-left: 0.25rem;
+      margin-right: -0.375rem; }
+    html.theme--documenter-dark .tag:not(body).is-white, html.theme--documenter-dark .docstring > section > a.docs-sourcelink:not(body).is-white, html.theme--documenter-dark .content kbd:not(body).is-white {
+      background-color: white;
+      color: #0a0a0a; }
+    html.theme--documenter-dark .tag:not(body).is-black, html.theme--documenter-dark .docstring > section > a.docs-sourcelink:not(body).is-black, html.theme--documenter-dark .content kbd:not(body).is-black {
+      background-color: #0a0a0a;
+      color: white; }
+    html.theme--documenter-dark .tag:not(body).is-light, html.theme--documenter-dark .docstring > section > a.docs-sourcelink:not(body).is-light, html.theme--documenter-dark .content kbd:not(body).is-light {
+      background-color: #ecf0f1;
+      color: #282f2f; }
+    html.theme--documenter-dark .tag:not(body).is-dark, html.theme--documenter-dark .docstring > section > a.docs-sourcelink:not(body).is-dark, html.theme--documenter-dark .content kbd:not(body) {
+      background-color: #282f2f;
+      color: #ecf0f1; }
+    html.theme--documenter-dark .tag:not(body).is-primary, html.theme--documenter-dark .docstring > section > a.docs-sourcelink:not(body), html.theme--documenter-dark .content kbd:not(body).is-primary {
+      background-color: #375a7f;
+      color: #fff; }
+    html.theme--documenter-dark .tag:not(body).is-link, html.theme--documenter-dark .docstring > section > a.docs-sourcelink:not(body).is-link, html.theme--documenter-dark .content kbd:not(body).is-link {
+      background-color: #1abc9c;
+      color: #fff; }
+    html.theme--documenter-dark .tag:not(body).is-info, html.theme--documenter-dark .docstring > section > a.docs-sourcelink:not(body).is-info, html.theme--documenter-dark .content kbd:not(body).is-info {
+      background-color: #024c7d;
+      color: #fff; }
+    html.theme--documenter-dark .tag:not(body).is-success, html.theme--documenter-dark .docstring > section > a.docs-sourcelink:not(body).is-success, html.theme--documenter-dark .content kbd:not(body).is-success {
+      background-color: #008438;
+      color: #fff; }
+    html.theme--documenter-dark .tag:not(body).is-warning, html.theme--documenter-dark .docstring > section > a.docs-sourcelink:not(body).is-warning, html.theme--documenter-dark .content kbd:not(body).is-warning {
+      background-color: #ad8100;
+      color: #fff; }
+    html.theme--documenter-dark .tag:not(body).is-danger, html.theme--documenter-dark .docstring > section > a.docs-sourcelink:not(body).is-danger, html.theme--documenter-dark .content kbd:not(body).is-danger {
+      background-color: #9e1b0d;
+      color: #fff; }
+    html.theme--documenter-dark .tag:not(body).is-normal, html.theme--documenter-dark .docstring > section > a.docs-sourcelink:not(body).is-normal, html.theme--documenter-dark .content kbd:not(body).is-normal {
+      font-size: 0.85em; }
+    html.theme--documenter-dark .tag:not(body).is-medium, html.theme--documenter-dark .docstring > section > a.docs-sourcelink:not(body).is-medium, html.theme--documenter-dark .content kbd:not(body).is-medium {
+      font-size: 15px; }
+    html.theme--documenter-dark .tag:not(body).is-large, html.theme--documenter-dark .docstring > section > a.docs-sourcelink:not(body).is-large, html.theme--documenter-dark .content kbd:not(body).is-large {
+      font-size: 1.25rem; }
+    html.theme--documenter-dark .tag:not(body) .icon:first-child:not(:last-child), html.theme--documenter-dark .docstring > section > a.docs-sourcelink:not(body) .icon:first-child:not(:last-child), html.theme--documenter-dark .content kbd:not(body) .icon:first-child:not(:last-child) {
+      margin-left: -0.375em;
+      margin-right: 0.1875em; }
+    html.theme--documenter-dark .tag:not(body) .icon:last-child:not(:first-child), html.theme--documenter-dark .docstring > section > a.docs-sourcelink:not(body) .icon:last-child:not(:first-child), html.theme--documenter-dark .content kbd:not(body) .icon:last-child:not(:first-child) {
+      margin-left: 0.1875em;
+      margin-right: -0.375em; }
+    html.theme--documenter-dark .tag:not(body) .icon:first-child:last-child, html.theme--documenter-dark .docstring > section > a.docs-sourcelink:not(body) .icon:first-child:last-child, html.theme--documenter-dark .content kbd:not(body) .icon:first-child:last-child {
+      margin-left: -0.375em;
+      margin-right: -0.375em; }
+    html.theme--documenter-dark .tag:not(body).is-delete, html.theme--documenter-dark .docstring > section > a.docs-sourcelink:not(body).is-delete, html.theme--documenter-dark .content kbd:not(body).is-delete {
+      margin-left: 1px;
+      padding: 0;
+      position: relative;
+      width: 2em; }
+      html.theme--documenter-dark .tag:not(body).is-delete::before, html.theme--documenter-dark .docstring > section > a.docs-sourcelink:not(body).is-delete::before, html.theme--documenter-dark .content kbd:not(body).is-delete::before, html.theme--documenter-dark .tag:not(body).is-delete::after, html.theme--documenter-dark .docstring > section > a.docs-sourcelink:not(body).is-delete::after, html.theme--documenter-dark .content kbd:not(body).is-delete::after {
+        background-color: currentColor;
+        content: "";
+        display: block;
+        left: 50%;
+        position: absolute;
+        top: 50%;
+        transform: translateX(-50%) translateY(-50%) rotate(45deg);
+        transform-origin: center center; }
+      html.theme--documenter-dark .tag:not(body).is-delete::before, html.theme--documenter-dark .docstring > section > a.docs-sourcelink:not(body).is-delete::before, html.theme--documenter-dark .content kbd:not(body).is-delete::before {
+        height: 1px;
+        width: 50%; }
+      html.theme--documenter-dark .tag:not(body).is-delete::after, html.theme--documenter-dark .docstring > section > a.docs-sourcelink:not(body).is-delete::after, html.theme--documenter-dark .content kbd:not(body).is-delete::after {
+        height: 50%;
+        width: 1px; }
+      html.theme--documenter-dark .tag:not(body).is-delete:hover, html.theme--documenter-dark .docstring > section > a.docs-sourcelink:not(body).is-delete:hover, html.theme--documenter-dark .content kbd:not(body).is-delete:hover, html.theme--documenter-dark .tag:not(body).is-delete:focus, html.theme--documenter-dark .docstring > section > a.docs-sourcelink:not(body).is-delete:focus, html.theme--documenter-dark .content kbd:not(body).is-delete:focus {
+        background-color: #1d2122; }
+      html.theme--documenter-dark .tag:not(body).is-delete:active, html.theme--documenter-dark .docstring > section > a.docs-sourcelink:not(body).is-delete:active, html.theme--documenter-dark .content kbd:not(body).is-delete:active {
+        background-color: #111414; }
+    html.theme--documenter-dark .tag:not(body).is-rounded, html.theme--documenter-dark .docstring > section > a.docs-sourcelink:not(body).is-rounded, html.theme--documenter-dark .content kbd:not(body).is-rounded, html.theme--documenter-dark #documenter .docs-sidebar form.docs-search > input.tag:not(body) {
+      border-radius: 290486px; }
+  html.theme--documenter-dark a.tag:hover, html.theme--documenter-dark .docstring > section > a.docs-sourcelink:hover {
+    text-decoration: underline; }
+  html.theme--documenter-dark .title,
+  html.theme--documenter-dark .subtitle {
+    word-break: break-word; }
+    html.theme--documenter-dark .title em,
+    html.theme--documenter-dark .title span,
+    html.theme--documenter-dark .subtitle em,
+    html.theme--documenter-dark .subtitle span {
+      font-weight: inherit; }
+    html.theme--documenter-dark .title sub,
+    html.theme--documenter-dark .subtitle sub {
+      font-size: 0.75em; }
+    html.theme--documenter-dark .title sup,
+    html.theme--documenter-dark .subtitle sup {
+      font-size: 0.75em; }
+    html.theme--documenter-dark .title .tag, html.theme--documenter-dark .title .docstring > section > a.docs-sourcelink, html.theme--documenter-dark .title .content kbd, html.theme--documenter-dark .content .title kbd,
+    html.theme--documenter-dark .subtitle .tag,
+    html.theme--documenter-dark .subtitle .docstring > section > a.docs-sourcelink,
+    html.theme--documenter-dark .subtitle .content kbd,
+    html.theme--documenter-dark .content .subtitle kbd {
+      vertical-align: middle; }
+  html.theme--documenter-dark .title {
+    color: #fff;
+    font-size: 2rem;
+    font-weight: 500;
+    line-height: 1.125; }
+    html.theme--documenter-dark .title strong {
+      color: inherit;
+      font-weight: inherit; }
+    html.theme--documenter-dark .title + .highlight {
+      margin-top: -0.75rem; }
+    html.theme--documenter-dark .title:not(.is-spaced) + .subtitle {
+      margin-top: -1.25rem; }
+    html.theme--documenter-dark .title.is-1 {
+      font-size: 3rem; }
+    html.theme--documenter-dark .title.is-2 {
+      font-size: 2.5rem; }
+    html.theme--documenter-dark .title.is-3 {
+      font-size: 2rem; }
+    html.theme--documenter-dark .title.is-4 {
+      font-size: 1.5rem; }
+    html.theme--documenter-dark .title.is-5 {
+      font-size: 1.25rem; }
+    html.theme--documenter-dark .title.is-6 {
+      font-size: 15px; }
+    html.theme--documenter-dark .title.is-7 {
+      font-size: 0.85em; }
+  html.theme--documenter-dark .subtitle {
+    color: #8c9b9d;
+    font-size: 1.25rem;
+    font-weight: 400;
+    line-height: 1.25; }
+    html.theme--documenter-dark .subtitle strong {
+      color: #8c9b9d;
+      font-weight: 600; }
+    html.theme--documenter-dark .subtitle:not(.is-spaced) + .title {
+      margin-top: -1.25rem; }
+    html.theme--documenter-dark .subtitle.is-1 {
+      font-size: 3rem; }
+    html.theme--documenter-dark .subtitle.is-2 {
+      font-size: 2.5rem; }
+    html.theme--documenter-dark .subtitle.is-3 {
+      font-size: 2rem; }
+    html.theme--documenter-dark .subtitle.is-4 {
+      font-size: 1.5rem; }
+    html.theme--documenter-dark .subtitle.is-5 {
+      font-size: 1.25rem; }
+    html.theme--documenter-dark .subtitle.is-6 {
+      font-size: 15px; }
+    html.theme--documenter-dark .subtitle.is-7 {
+      font-size: 0.85em; }
+  html.theme--documenter-dark .heading {
+    display: block;
+    font-size: 11px;
+    letter-spacing: 1px;
+    margin-bottom: 5px;
+    text-transform: uppercase; }
+  html.theme--documenter-dark .highlight {
+    font-weight: 400;
+    max-width: 100%;
+    overflow: hidden;
+    padding: 0; }
+    html.theme--documenter-dark .highlight pre {
+      overflow: auto;
+      max-width: 100%; }
+  html.theme--documenter-dark .number {
+    align-items: center;
+    background-color: #282f2f;
+    border-radius: 290486px;
+    display: inline-flex;
+    font-size: 1.25rem;
+    height: 2em;
+    justify-content: center;
+    margin-right: 1.5rem;
+    min-width: 2.5em;
+    padding: 0.25rem 0.5rem;
+    text-align: center;
+    vertical-align: top; }
+  html.theme--documenter-dark .input, html.theme--documenter-dark #documenter .docs-sidebar form.docs-search > input, html.theme--documenter-dark .textarea, html.theme--documenter-dark .select select {
+    background-color: #1f2424;
+    border-color: #5e6d6f;
+    border-radius: 0.4em;
+    color: #dbdee0; }
+    html.theme--documenter-dark .input::-moz-placeholder, html.theme--documenter-dark #documenter .docs-sidebar form.docs-search > input::-moz-placeholder, html.theme--documenter-dark .textarea::-moz-placeholder, html.theme--documenter-dark .select select::-moz-placeholder {
+      color: rgba(219, 222, 224, 0.3); }
+    html.theme--documenter-dark .input::-webkit-input-placeholder, html.theme--documenter-dark #documenter .docs-sidebar form.docs-search > input::-webkit-input-placeholder, html.theme--documenter-dark .textarea::-webkit-input-placeholder, html.theme--documenter-dark .select select::-webkit-input-placeholder {
+      color: rgba(219, 222, 224, 0.3); }
+    html.theme--documenter-dark .input:-moz-placeholder, html.theme--documenter-dark #documenter .docs-sidebar form.docs-search > input:-moz-placeholder, html.theme--documenter-dark .textarea:-moz-placeholder, html.theme--documenter-dark .select select:-moz-placeholder {
+      color: rgba(219, 222, 224, 0.3); }
+    html.theme--documenter-dark .input:-ms-input-placeholder, html.theme--documenter-dark #documenter .docs-sidebar form.docs-search > input:-ms-input-placeholder, html.theme--documenter-dark .textarea:-ms-input-placeholder, html.theme--documenter-dark .select select:-ms-input-placeholder {
+      color: rgba(219, 222, 224, 0.3); }
+    html.theme--documenter-dark .input:hover, html.theme--documenter-dark #documenter .docs-sidebar form.docs-search > input:hover, html.theme--documenter-dark .textarea:hover, html.theme--documenter-dark .select select:hover, html.theme--documenter-dark .is-hovered.input, html.theme--documenter-dark #documenter .docs-sidebar form.docs-search > input.is-hovered, html.theme--documenter-dark .is-hovered.textarea, html.theme--documenter-dark .select select.is-hovered {
+      border-color: #8c9b9d; }
+    html.theme--documenter-dark .input:focus, html.theme--documenter-dark #documenter .docs-sidebar form.docs-search > input:focus, html.theme--documenter-dark .textarea:focus, html.theme--documenter-dark .select select:focus, html.theme--documenter-dark .is-focused.input, html.theme--documenter-dark #documenter .docs-sidebar form.docs-search > input.is-focused, html.theme--documenter-dark .is-focused.textarea, html.theme--documenter-dark .select select.is-focused, html.theme--documenter-dark .input:active, html.theme--documenter-dark #documenter .docs-sidebar form.docs-search > input:active, html.theme--documenter-dark .textarea:active, html.theme--documenter-dark .select select:active, html.theme--documenter-dark .is-active.input, html.theme--documenter-dark #documenter .docs-sidebar form.docs-search > input.is-active, html.theme--documenter-dark .is-active.textarea, html.theme--documenter-dark .select select.is-active {
+      border-color: #1abc9c;
+      box-shadow: 0 0 0 0.125em rgba(26, 188, 156, 0.25); }
+    html.theme--documenter-dark .input[disabled], html.theme--documenter-dark #documenter .docs-sidebar form.docs-search > input[disabled], html.theme--documenter-dark .textarea[disabled], html.theme--documenter-dark .select select[disabled],
+    fieldset[disabled] html.theme--documenter-dark .input,
+    fieldset[disabled] html.theme--documenter-dark #documenter .docs-sidebar form.docs-search > input,
+    fieldset[disabled] html.theme--documenter-dark .textarea,
+    fieldset[disabled] html.theme--documenter-dark .select select {
+      background-color: #8c9b9d;
+      border-color: #282f2f;
+      box-shadow: none;
+      color: white; }
+      html.theme--documenter-dark .input[disabled]::-moz-placeholder, html.theme--documenter-dark #documenter .docs-sidebar form.docs-search > input[disabled]::-moz-placeholder, html.theme--documenter-dark .textarea[disabled]::-moz-placeholder, html.theme--documenter-dark .select select[disabled]::-moz-placeholder,
+      fieldset[disabled] html.theme--documenter-dark .input::-moz-placeholder,
+      fieldset[disabled] html.theme--documenter-dark #documenter .docs-sidebar form.docs-search > input::-moz-placeholder,
+      fieldset[disabled] html.theme--documenter-dark .textarea::-moz-placeholder,
+      fieldset[disabled] html.theme--documenter-dark .select select::-moz-placeholder {
+        color: rgba(255, 255, 255, 0.3); }
+      html.theme--documenter-dark .input[disabled]::-webkit-input-placeholder, html.theme--documenter-dark #documenter .docs-sidebar form.docs-search > input[disabled]::-webkit-input-placeholder, html.theme--documenter-dark .textarea[disabled]::-webkit-input-placeholder, html.theme--documenter-dark .select select[disabled]::-webkit-input-placeholder,
+      fieldset[disabled] html.theme--documenter-dark .input::-webkit-input-placeholder,
+      fieldset[disabled] html.theme--documenter-dark #documenter .docs-sidebar form.docs-search > input::-webkit-input-placeholder,
+      fieldset[disabled] html.theme--documenter-dark .textarea::-webkit-input-placeholder,
+      fieldset[disabled] html.theme--documenter-dark .select select::-webkit-input-placeholder {
+        color: rgba(255, 255, 255, 0.3); }
+      html.theme--documenter-dark .input[disabled]:-moz-placeholder, html.theme--documenter-dark #documenter .docs-sidebar form.docs-search > input[disabled]:-moz-placeholder, html.theme--documenter-dark .textarea[disabled]:-moz-placeholder, html.theme--documenter-dark .select select[disabled]:-moz-placeholder,
+      fieldset[disabled] html.theme--documenter-dark .input:-moz-placeholder,
+      fieldset[disabled] html.theme--documenter-dark #documenter .docs-sidebar form.docs-search > input:-moz-placeholder,
+      fieldset[disabled] html.theme--documenter-dark .textarea:-moz-placeholder,
+      fieldset[disabled] html.theme--documenter-dark .select select:-moz-placeholder {
+        color: rgba(255, 255, 255, 0.3); }
+      html.theme--documenter-dark .input[disabled]:-ms-input-placeholder, html.theme--documenter-dark #documenter .docs-sidebar form.docs-search > input[disabled]:-ms-input-placeholder, html.theme--documenter-dark .textarea[disabled]:-ms-input-placeholder, html.theme--documenter-dark .select select[disabled]:-ms-input-placeholder,
+      fieldset[disabled] html.theme--documenter-dark .input:-ms-input-placeholder,
+      fieldset[disabled] html.theme--documenter-dark #documenter .docs-sidebar form.docs-search > input:-ms-input-placeholder,
+      fieldset[disabled] html.theme--documenter-dark .textarea:-ms-input-placeholder,
+      fieldset[disabled] html.theme--documenter-dark .select select:-ms-input-placeholder {
+        color: rgba(255, 255, 255, 0.3); }
+  html.theme--documenter-dark .input, html.theme--documenter-dark #documenter .docs-sidebar form.docs-search > input, html.theme--documenter-dark .textarea {
+    box-shadow: inset 0 1px 2px rgba(10, 10, 10, 0.1);
+    max-width: 100%;
+    width: 100%; }
+    html.theme--documenter-dark .input[readonly], html.theme--documenter-dark #documenter .docs-sidebar form.docs-search > input[readonly], html.theme--documenter-dark .textarea[readonly] {
+      box-shadow: none; }
+    html.theme--documenter-dark .is-white.input, html.theme--documenter-dark #documenter .docs-sidebar form.docs-search > input.is-white, html.theme--documenter-dark .is-white.textarea {
+      border-color: white; }
+      html.theme--documenter-dark .is-white.input:focus, html.theme--documenter-dark #documenter .docs-sidebar form.docs-search > input.is-white:focus, html.theme--documenter-dark .is-white.textarea:focus, html.theme--documenter-dark .is-white.is-focused.input, html.theme--documenter-dark #documenter .docs-sidebar form.docs-search > input.is-white.is-focused, html.theme--documenter-dark .is-white.is-focused.textarea, html.theme--documenter-dark .is-white.input:active, html.theme--documenter-dark #documenter .docs-sidebar form.docs-search > input.is-white:active, html.theme--documenter-dark .is-white.textarea:active, html.theme--documenter-dark .is-white.is-active.input, html.theme--documenter-dark #documenter .docs-sidebar form.docs-search > input.is-white.is-active, html.theme--documenter-dark .is-white.is-active.textarea {
+        box-shadow: 0 0 0 0.125em rgba(255, 255, 255, 0.25); }
+    html.theme--documenter-dark .is-black.input, html.theme--documenter-dark #documenter .docs-sidebar form.docs-search > input.is-black, html.theme--documenter-dark .is-black.textarea {
+      border-color: #0a0a0a; }
+      html.theme--documenter-dark .is-black.input:focus, html.theme--documenter-dark #documenter .docs-sidebar form.docs-search > input.is-black:focus, html.theme--documenter-dark .is-black.textarea:focus, html.theme--documenter-dark .is-black.is-focused.input, html.theme--documenter-dark #documenter .docs-sidebar form.docs-search > input.is-black.is-focused, html.theme--documenter-dark .is-black.is-focused.textarea, html.theme--documenter-dark .is-black.input:active, html.theme--documenter-dark #documenter .docs-sidebar form.docs-search > input.is-black:active, html.theme--documenter-dark .is-black.textarea:active, html.theme--documenter-dark .is-black.is-active.input, html.theme--documenter-dark #documenter .docs-sidebar form.docs-search > input.is-black.is-active, html.theme--documenter-dark .is-black.is-active.textarea {
+        box-shadow: 0 0 0 0.125em rgba(10, 10, 10, 0.25); }
+    html.theme--documenter-dark .is-light.input, html.theme--documenter-dark #documenter .docs-sidebar form.docs-search > input.is-light, html.theme--documenter-dark .is-light.textarea {
+      border-color: #ecf0f1; }
+      html.theme--documenter-dark .is-light.input:focus, html.theme--documenter-dark #documenter .docs-sidebar form.docs-search > input.is-light:focus, html.theme--documenter-dark .is-light.textarea:focus, html.theme--documenter-dark .is-light.is-focused.input, html.theme--documenter-dark #documenter .docs-sidebar form.docs-search > input.is-light.is-focused, html.theme--documenter-dark .is-light.is-focused.textarea, html.theme--documenter-dark .is-light.input:active, html.theme--documenter-dark #documenter .docs-sidebar form.docs-search > input.is-light:active, html.theme--documenter-dark .is-light.textarea:active, html.theme--documenter-dark .is-light.is-active.input, html.theme--documenter-dark #documenter .docs-sidebar form.docs-search > input.is-light.is-active, html.theme--documenter-dark .is-light.is-active.textarea {
+        box-shadow: 0 0 0 0.125em rgba(236, 240, 241, 0.25); }
+    html.theme--documenter-dark .is-dark.input, html.theme--documenter-dark .content kbd.input, html.theme--documenter-dark #documenter .docs-sidebar form.docs-search > input.is-dark, html.theme--documenter-dark .is-dark.textarea, html.theme--documenter-dark .content kbd.textarea {
+      border-color: #282f2f; }
+      html.theme--documenter-dark .is-dark.input:focus, html.theme--documenter-dark .content kbd.input:focus, html.theme--documenter-dark #documenter .docs-sidebar form.docs-search > input.is-dark:focus, html.theme--documenter-dark .is-dark.textarea:focus, html.theme--documenter-dark .content kbd.textarea:focus, html.theme--documenter-dark .is-dark.is-focused.input, html.theme--documenter-dark .content kbd.is-focused.input, html.theme--documenter-dark #documenter .docs-sidebar form.docs-search > input.is-dark.is-focused, html.theme--documenter-dark .is-dark.is-focused.textarea, html.theme--documenter-dark .content kbd.is-focused.textarea, html.theme--documenter-dark .is-dark.input:active, html.theme--documenter-dark .content kbd.input:active, html.theme--documenter-dark #documenter .docs-sidebar form.docs-search > input.is-dark:active, html.theme--documenter-dark .is-dark.textarea:active, html.theme--documenter-dark .content kbd.textarea:active, html.theme--documenter-dark .is-dark.is-active.input, html.theme--documenter-dark .content kbd.is-active.input, html.theme--documenter-dark #documenter .docs-sidebar form.docs-search > input.is-dark.is-active, html.theme--documenter-dark .is-dark.is-active.textarea, html.theme--documenter-dark .content kbd.is-active.textarea {
+        box-shadow: 0 0 0 0.125em rgba(40, 47, 47, 0.25); }
+    html.theme--documenter-dark .is-primary.input, html.theme--documenter-dark .docstring > section > a.input.docs-sourcelink, html.theme--documenter-dark #documenter .docs-sidebar form.docs-search > input.is-primary, html.theme--documenter-dark .is-primary.textarea, html.theme--documenter-dark .docstring > section > a.textarea.docs-sourcelink {
+      border-color: #375a7f; }
+      html.theme--documenter-dark .is-primary.input:focus, html.theme--documenter-dark .docstring > section > a.input.docs-sourcelink:focus, html.theme--documenter-dark #documenter .docs-sidebar form.docs-search > input.is-primary:focus, html.theme--documenter-dark .is-primary.textarea:focus, html.theme--documenter-dark .docstring > section > a.textarea.docs-sourcelink:focus, html.theme--documenter-dark .is-primary.is-focused.input, html.theme--documenter-dark .docstring > section > a.is-focused.input.docs-sourcelink, html.theme--documenter-dark #documenter .docs-sidebar form.docs-search > input.is-primary.is-focused, html.theme--documenter-dark .is-primary.is-focused.textarea, html.theme--documenter-dark .docstring > section > a.is-focused.textarea.docs-sourcelink, html.theme--documenter-dark .is-primary.input:active, html.theme--documenter-dark .docstring > section > a.input.docs-sourcelink:active, html.theme--documenter-dark #documenter .docs-sidebar form.docs-search > input.is-primary:active, html.theme--documenter-dark .is-primary.textarea:active, html.theme--documenter-dark .docstring > section > a.textarea.docs-sourcelink:active, html.theme--documenter-dark .is-primary.is-active.input, html.theme--documenter-dark .docstring > section > a.is-active.input.docs-sourcelink, html.theme--documenter-dark #documenter .docs-sidebar form.docs-search > input.is-primary.is-active, html.theme--documenter-dark .is-primary.is-active.textarea, html.theme--documenter-dark .docstring > section > a.is-active.textarea.docs-sourcelink {
+        box-shadow: 0 0 0 0.125em rgba(55, 90, 127, 0.25); }
+    html.theme--documenter-dark .is-link.input, html.theme--documenter-dark #documenter .docs-sidebar form.docs-search > input.is-link, html.theme--documenter-dark .is-link.textarea {
+      border-color: #1abc9c; }
+      html.theme--documenter-dark .is-link.input:focus, html.theme--documenter-dark #documenter .docs-sidebar form.docs-search > input.is-link:focus, html.theme--documenter-dark .is-link.textarea:focus, html.theme--documenter-dark .is-link.is-focused.input, html.theme--documenter-dark #documenter .docs-sidebar form.docs-search > input.is-link.is-focused, html.theme--documenter-dark .is-link.is-focused.textarea, html.theme--documenter-dark .is-link.input:active, html.theme--documenter-dark #documenter .docs-sidebar form.docs-search > input.is-link:active, html.theme--documenter-dark .is-link.textarea:active, html.theme--documenter-dark .is-link.is-active.input, html.theme--documenter-dark #documenter .docs-sidebar form.docs-search > input.is-link.is-active, html.theme--documenter-dark .is-link.is-active.textarea {
+        box-shadow: 0 0 0 0.125em rgba(26, 188, 156, 0.25); }
+    html.theme--documenter-dark .is-info.input, html.theme--documenter-dark #documenter .docs-sidebar form.docs-search > input.is-info, html.theme--documenter-dark .is-info.textarea {
+      border-color: #024c7d; }
+      html.theme--documenter-dark .is-info.input:focus, html.theme--documenter-dark #documenter .docs-sidebar form.docs-search > input.is-info:focus, html.theme--documenter-dark .is-info.textarea:focus, html.theme--documenter-dark .is-info.is-focused.input, html.theme--documenter-dark #documenter .docs-sidebar form.docs-search > input.is-info.is-focused, html.theme--documenter-dark .is-info.is-focused.textarea, html.theme--documenter-dark .is-info.input:active, html.theme--documenter-dark #documenter .docs-sidebar form.docs-search > input.is-info:active, html.theme--documenter-dark .is-info.textarea:active, html.theme--documenter-dark .is-info.is-active.input, html.theme--documenter-dark #documenter .docs-sidebar form.docs-search > input.is-info.is-active, html.theme--documenter-dark .is-info.is-active.textarea {
+        box-shadow: 0 0 0 0.125em rgba(2, 76, 125, 0.25); }
+    html.theme--documenter-dark .is-success.input, html.theme--documenter-dark #documenter .docs-sidebar form.docs-search > input.is-success, html.theme--documenter-dark .is-success.textarea {
+      border-color: #008438; }
+      html.theme--documenter-dark .is-success.input:focus, html.theme--documenter-dark #documenter .docs-sidebar form.docs-search > input.is-success:focus, html.theme--documenter-dark .is-success.textarea:focus, html.theme--documenter-dark .is-success.is-focused.input, html.theme--documenter-dark #documenter .docs-sidebar form.docs-search > input.is-success.is-focused, html.theme--documenter-dark .is-success.is-focused.textarea, html.theme--documenter-dark .is-success.input:active, html.theme--documenter-dark #documenter .docs-sidebar form.docs-search > input.is-success:active, html.theme--documenter-dark .is-success.textarea:active, html.theme--documenter-dark .is-success.is-active.input, html.theme--documenter-dark #documenter .docs-sidebar form.docs-search > input.is-success.is-active, html.theme--documenter-dark .is-success.is-active.textarea {
+        box-shadow: 0 0 0 0.125em rgba(0, 132, 56, 0.25); }
+    html.theme--documenter-dark .is-warning.input, html.theme--documenter-dark #documenter .docs-sidebar form.docs-search > input.is-warning, html.theme--documenter-dark .is-warning.textarea {
+      border-color: #ad8100; }
+      html.theme--documenter-dark .is-warning.input:focus, html.theme--documenter-dark #documenter .docs-sidebar form.docs-search > input.is-warning:focus, html.theme--documenter-dark .is-warning.textarea:focus, html.theme--documenter-dark .is-warning.is-focused.input, html.theme--documenter-dark #documenter .docs-sidebar form.docs-search > input.is-warning.is-focused, html.theme--documenter-dark .is-warning.is-focused.textarea, html.theme--documenter-dark .is-warning.input:active, html.theme--documenter-dark #documenter .docs-sidebar form.docs-search > input.is-warning:active, html.theme--documenter-dark .is-warning.textarea:active, html.theme--documenter-dark .is-warning.is-active.input, html.theme--documenter-dark #documenter .docs-sidebar form.docs-search > input.is-warning.is-active, html.theme--documenter-dark .is-warning.is-active.textarea {
+        box-shadow: 0 0 0 0.125em rgba(173, 129, 0, 0.25); }
+    html.theme--documenter-dark .is-danger.input, html.theme--documenter-dark #documenter .docs-sidebar form.docs-search > input.is-danger, html.theme--documenter-dark .is-danger.textarea {
+      border-color: #9e1b0d; }
+      html.theme--documenter-dark .is-danger.input:focus, html.theme--documenter-dark #documenter .docs-sidebar form.docs-search > input.is-danger:focus, html.theme--documenter-dark .is-danger.textarea:focus, html.theme--documenter-dark .is-danger.is-focused.input, html.theme--documenter-dark #documenter .docs-sidebar form.docs-search > input.is-danger.is-focused, html.theme--documenter-dark .is-danger.is-focused.textarea, html.theme--documenter-dark .is-danger.input:active, html.theme--documenter-dark #documenter .docs-sidebar form.docs-search > input.is-danger:active, html.theme--documenter-dark .is-danger.textarea:active, html.theme--documenter-dark .is-danger.is-active.input, html.theme--documenter-dark #documenter .docs-sidebar form.docs-search > input.is-danger.is-active, html.theme--documenter-dark .is-danger.is-active.textarea {
+        box-shadow: 0 0 0 0.125em rgba(158, 27, 13, 0.25); }
+    html.theme--documenter-dark .is-small.input, html.theme--documenter-dark #documenter .docs-sidebar form.docs-search > input, html.theme--documenter-dark .is-small.textarea {
+      border-radius: 3px;
+      font-size: 0.85em; }
+    html.theme--documenter-dark .is-medium.input, html.theme--documenter-dark #documenter .docs-sidebar form.docs-search > input.is-medium, html.theme--documenter-dark .is-medium.textarea {
+      font-size: 1.25rem; }
+    html.theme--documenter-dark .is-large.input, html.theme--documenter-dark #documenter .docs-sidebar form.docs-search > input.is-large, html.theme--documenter-dark .is-large.textarea {
+      font-size: 1.5rem; }
+    html.theme--documenter-dark .is-fullwidth.input, html.theme--documenter-dark #documenter .docs-sidebar form.docs-search > input.is-fullwidth, html.theme--documenter-dark .is-fullwidth.textarea {
+      display: block;
+      width: 100%; }
+    html.theme--documenter-dark .is-inline.input, html.theme--documenter-dark #documenter .docs-sidebar form.docs-search > input.is-inline, html.theme--documenter-dark .is-inline.textarea {
+      display: inline;
+      width: auto; }
+  html.theme--documenter-dark .input.is-rounded, html.theme--documenter-dark #documenter .docs-sidebar form.docs-search > input {
+    border-radius: 290486px;
+    padding-left: 1em;
+    padding-right: 1em; }
+  html.theme--documenter-dark .input.is-static, html.theme--documenter-dark #documenter .docs-sidebar form.docs-search > input.is-static {
+    background-color: transparent;
+    border-color: transparent;
+    box-shadow: none;
+    padding-left: 0;
+    padding-right: 0; }
+  html.theme--documenter-dark .textarea {
+    display: block;
+    max-width: 100%;
+    min-width: 100%;
+    padding: 0.625em;
+    resize: vertical; }
+    html.theme--documenter-dark .textarea:not([rows]) {
+      max-height: 600px;
+      min-height: 120px; }
+    html.theme--documenter-dark .textarea[rows] {
+      height: initial; }
+    html.theme--documenter-dark .textarea.has-fixed-size {
+      resize: none; }
+  html.theme--documenter-dark .checkbox, html.theme--documenter-dark .radio {
+    cursor: pointer;
+    display: inline-block;
+    line-height: 1.25;
+    position: relative; }
+    html.theme--documenter-dark .checkbox input, html.theme--documenter-dark .radio input {
+      cursor: pointer; }
+    html.theme--documenter-dark .checkbox:hover, html.theme--documenter-dark .radio:hover {
+      color: #8c9b9d; }
+    html.theme--documenter-dark .checkbox[disabled], html.theme--documenter-dark .radio[disabled],
+    fieldset[disabled] html.theme--documenter-dark .checkbox,
+    fieldset[disabled] html.theme--documenter-dark .radio {
+      color: white;
+      cursor: not-allowed; }
+  html.theme--documenter-dark .radio + .radio {
+    margin-left: 0.5em; }
+  html.theme--documenter-dark .select {
+    display: inline-block;
+    max-width: 100%;
+    position: relative;
+    vertical-align: top; }
+    html.theme--documenter-dark .select:not(.is-multiple) {
+      height: 2.25em; }
+    html.theme--documenter-dark .select:not(.is-multiple):not(.is-loading)::after {
+      border-color: #1abc9c;
+      right: 1.125em;
+      z-index: 4; }
+    html.theme--documenter-dark .select.is-rounded select, html.theme--documenter-dark #documenter .docs-sidebar form.docs-search > input.select select {
+      border-radius: 290486px;
+      padding-left: 1em; }
+    html.theme--documenter-dark .select select {
+      cursor: pointer;
+      display: block;
+      font-size: 1em;
+      max-width: 100%;
+      outline: none; }
+      html.theme--documenter-dark .select select::-ms-expand {
+        display: none; }
+      html.theme--documenter-dark .select select[disabled]:hover,
+      fieldset[disabled] html.theme--documenter-dark .select select:hover {
+        border-color: #282f2f; }
+      html.theme--documenter-dark .select select:not([multiple]) {
+        padding-right: 2.5em; }
+      html.theme--documenter-dark .select select[multiple] {
+        height: auto;
+        padding: 0; }
+        html.theme--documenter-dark .select select[multiple] option {
+          padding: 0.5em 1em; }
+    html.theme--documenter-dark .select:not(.is-multiple):not(.is-loading):hover::after {
+      border-color: #8c9b9d; }
+    html.theme--documenter-dark .select.is-white:not(:hover)::after {
+      border-color: white; }
+    html.theme--documenter-dark .select.is-white select {
+      border-color: white; }
+      html.theme--documenter-dark .select.is-white select:hover, html.theme--documenter-dark .select.is-white select.is-hovered {
+        border-color: #f2f2f2; }
+      html.theme--documenter-dark .select.is-white select:focus, html.theme--documenter-dark .select.is-white select.is-focused, html.theme--documenter-dark .select.is-white select:active, html.theme--documenter-dark .select.is-white select.is-active {
+        box-shadow: 0 0 0 0.125em rgba(255, 255, 255, 0.25); }
+    html.theme--documenter-dark .select.is-black:not(:hover)::after {
+      border-color: #0a0a0a; }
+    html.theme--documenter-dark .select.is-black select {
+      border-color: #0a0a0a; }
+      html.theme--documenter-dark .select.is-black select:hover, html.theme--documenter-dark .select.is-black select.is-hovered {
+        border-color: black; }
+      html.theme--documenter-dark .select.is-black select:focus, html.theme--documenter-dark .select.is-black select.is-focused, html.theme--documenter-dark .select.is-black select:active, html.theme--documenter-dark .select.is-black select.is-active {
+        box-shadow: 0 0 0 0.125em rgba(10, 10, 10, 0.25); }
+    html.theme--documenter-dark .select.is-light:not(:hover)::after {
+      border-color: #ecf0f1; }
+    html.theme--documenter-dark .select.is-light select {
+      border-color: #ecf0f1; }
+      html.theme--documenter-dark .select.is-light select:hover, html.theme--documenter-dark .select.is-light select.is-hovered {
+        border-color: #dde4e6; }
+      html.theme--documenter-dark .select.is-light select:focus, html.theme--documenter-dark .select.is-light select.is-focused, html.theme--documenter-dark .select.is-light select:active, html.theme--documenter-dark .select.is-light select.is-active {
+        box-shadow: 0 0 0 0.125em rgba(236, 240, 241, 0.25); }
+    html.theme--documenter-dark .select.is-dark:not(:hover)::after, html.theme--documenter-dark .content kbd.select:not(:hover)::after {
+      border-color: #282f2f; }
+    html.theme--documenter-dark .select.is-dark select, html.theme--documenter-dark .content kbd.select select {
+      border-color: #282f2f; }
+      html.theme--documenter-dark .select.is-dark select:hover, html.theme--documenter-dark .content kbd.select select:hover, html.theme--documenter-dark .select.is-dark select.is-hovered, html.theme--documenter-dark .content kbd.select select.is-hovered {
+        border-color: #1d2122; }
+      html.theme--documenter-dark .select.is-dark select:focus, html.theme--documenter-dark .content kbd.select select:focus, html.theme--documenter-dark .select.is-dark select.is-focused, html.theme--documenter-dark .content kbd.select select.is-focused, html.theme--documenter-dark .select.is-dark select:active, html.theme--documenter-dark .content kbd.select select:active, html.theme--documenter-dark .select.is-dark select.is-active, html.theme--documenter-dark .content kbd.select select.is-active {
+        box-shadow: 0 0 0 0.125em rgba(40, 47, 47, 0.25); }
+    html.theme--documenter-dark .select.is-primary:not(:hover)::after, html.theme--documenter-dark .docstring > section > a.select.docs-sourcelink:not(:hover)::after {
+      border-color: #375a7f; }
+    html.theme--documenter-dark .select.is-primary select, html.theme--documenter-dark .docstring > section > a.select.docs-sourcelink select {
+      border-color: #375a7f; }
+      html.theme--documenter-dark .select.is-primary select:hover, html.theme--documenter-dark .docstring > section > a.select.docs-sourcelink select:hover, html.theme--documenter-dark .select.is-primary select.is-hovered, html.theme--documenter-dark .docstring > section > a.select.docs-sourcelink select.is-hovered {
+        border-color: #2f4d6d; }
+      html.theme--documenter-dark .select.is-primary select:focus, html.theme--documenter-dark .docstring > section > a.select.docs-sourcelink select:focus, html.theme--documenter-dark .select.is-primary select.is-focused, html.theme--documenter-dark .docstring > section > a.select.docs-sourcelink select.is-focused, html.theme--documenter-dark .select.is-primary select:active, html.theme--documenter-dark .docstring > section > a.select.docs-sourcelink select:active, html.theme--documenter-dark .select.is-primary select.is-active, html.theme--documenter-dark .docstring > section > a.select.docs-sourcelink select.is-active {
+        box-shadow: 0 0 0 0.125em rgba(55, 90, 127, 0.25); }
+    html.theme--documenter-dark .select.is-link:not(:hover)::after {
+      border-color: #1abc9c; }
+    html.theme--documenter-dark .select.is-link select {
+      border-color: #1abc9c; }
+      html.theme--documenter-dark .select.is-link select:hover, html.theme--documenter-dark .select.is-link select.is-hovered {
+        border-color: #17a689; }
+      html.theme--documenter-dark .select.is-link select:focus, html.theme--documenter-dark .select.is-link select.is-focused, html.theme--documenter-dark .select.is-link select:active, html.theme--documenter-dark .select.is-link select.is-active {
+        box-shadow: 0 0 0 0.125em rgba(26, 188, 156, 0.25); }
+    html.theme--documenter-dark .select.is-info:not(:hover)::after {
+      border-color: #024c7d; }
+    html.theme--documenter-dark .select.is-info select {
+      border-color: #024c7d; }
+      html.theme--documenter-dark .select.is-info select:hover, html.theme--documenter-dark .select.is-info select.is-hovered {
+        border-color: #023d64; }
+      html.theme--documenter-dark .select.is-info select:focus, html.theme--documenter-dark .select.is-info select.is-focused, html.theme--documenter-dark .select.is-info select:active, html.theme--documenter-dark .select.is-info select.is-active {
+        box-shadow: 0 0 0 0.125em rgba(2, 76, 125, 0.25); }
+    html.theme--documenter-dark .select.is-success:not(:hover)::after {
+      border-color: #008438; }
+    html.theme--documenter-dark .select.is-success select {
+      border-color: #008438; }
+      html.theme--documenter-dark .select.is-success select:hover, html.theme--documenter-dark .select.is-success select.is-hovered {
+        border-color: #006b2d; }
+      html.theme--documenter-dark .select.is-success select:focus, html.theme--documenter-dark .select.is-success select.is-focused, html.theme--documenter-dark .select.is-success select:active, html.theme--documenter-dark .select.is-success select.is-active {
+        box-shadow: 0 0 0 0.125em rgba(0, 132, 56, 0.25); }
+    html.theme--documenter-dark .select.is-warning:not(:hover)::after {
+      border-color: #ad8100; }
+    html.theme--documenter-dark .select.is-warning select {
+      border-color: #ad8100; }
+      html.theme--documenter-dark .select.is-warning select:hover, html.theme--documenter-dark .select.is-warning select.is-hovered {
+        border-color: #946e00; }
+      html.theme--documenter-dark .select.is-warning select:focus, html.theme--documenter-dark .select.is-warning select.is-focused, html.theme--documenter-dark .select.is-warning select:active, html.theme--documenter-dark .select.is-warning select.is-active {
+        box-shadow: 0 0 0 0.125em rgba(173, 129, 0, 0.25); }
+    html.theme--documenter-dark .select.is-danger:not(:hover)::after {
+      border-color: #9e1b0d; }
+    html.theme--documenter-dark .select.is-danger select {
+      border-color: #9e1b0d; }
+      html.theme--documenter-dark .select.is-danger select:hover, html.theme--documenter-dark .select.is-danger select.is-hovered {
+        border-color: #86170b; }
+      html.theme--documenter-dark .select.is-danger select:focus, html.theme--documenter-dark .select.is-danger select.is-focused, html.theme--documenter-dark .select.is-danger select:active, html.theme--documenter-dark .select.is-danger select.is-active {
+        box-shadow: 0 0 0 0.125em rgba(158, 27, 13, 0.25); }
+    html.theme--documenter-dark .select.is-small, html.theme--documenter-dark #documenter .docs-sidebar form.docs-search > input.select {
+      border-radius: 3px;
+      font-size: 0.85em; }
+    html.theme--documenter-dark .select.is-medium {
+      font-size: 1.25rem; }
+    html.theme--documenter-dark .select.is-large {
+      font-size: 1.5rem; }
+    html.theme--documenter-dark .select.is-disabled::after {
+      border-color: white; }
+    html.theme--documenter-dark .select.is-fullwidth {
+      width: 100%; }
+      html.theme--documenter-dark .select.is-fullwidth select {
+        width: 100%; }
+    html.theme--documenter-dark .select.is-loading::after {
+      margin-top: 0;
+      position: absolute;
+      right: 0.625em;
+      top: 0.625em;
+      transform: none; }
+    html.theme--documenter-dark .select.is-loading.is-small:after, html.theme--documenter-dark #documenter .docs-sidebar form.docs-search > input.select.is-loading:after {
+      font-size: 0.85em; }
+    html.theme--documenter-dark .select.is-loading.is-medium:after {
+      font-size: 1.25rem; }
+    html.theme--documenter-dark .select.is-loading.is-large:after {
+      font-size: 1.5rem; }
+  html.theme--documenter-dark .file {
+    align-items: stretch;
+    display: flex;
+    justify-content: flex-start;
+    position: relative; }
+    html.theme--documenter-dark .file.is-white .file-cta {
+      background-color: white;
+      border-color: transparent;
+      color: #0a0a0a; }
+    html.theme--documenter-dark .file.is-white:hover .file-cta, html.theme--documenter-dark .file.is-white.is-hovered .file-cta {
+      background-color: #f9f9f9;
+      border-color: transparent;
+      color: #0a0a0a; }
+    html.theme--documenter-dark .file.is-white:focus .file-cta, html.theme--documenter-dark .file.is-white.is-focused .file-cta {
+      border-color: transparent;
+      box-shadow: 0 0 0.5em rgba(255, 255, 255, 0.25);
+      color: #0a0a0a; }
+    html.theme--documenter-dark .file.is-white:active .file-cta, html.theme--documenter-dark .file.is-white.is-active .file-cta {
+      background-color: #f2f2f2;
+      border-color: transparent;
+      color: #0a0a0a; }
+    html.theme--documenter-dark .file.is-black .file-cta {
+      background-color: #0a0a0a;
+      border-color: transparent;
+      color: white; }
+    html.theme--documenter-dark .file.is-black:hover .file-cta, html.theme--documenter-dark .file.is-black.is-hovered .file-cta {
+      background-color: #040404;
+      border-color: transparent;
+      color: white; }
+    html.theme--documenter-dark .file.is-black:focus .file-cta, html.theme--documenter-dark .file.is-black.is-focused .file-cta {
+      border-color: transparent;
+      box-shadow: 0 0 0.5em rgba(10, 10, 10, 0.25);
+      color: white; }
+    html.theme--documenter-dark .file.is-black:active .file-cta, html.theme--documenter-dark .file.is-black.is-active .file-cta {
+      background-color: black;
+      border-color: transparent;
+      color: white; }
+    html.theme--documenter-dark .file.is-light .file-cta {
+      background-color: #ecf0f1;
+      border-color: transparent;
+      color: #282f2f; }
+    html.theme--documenter-dark .file.is-light:hover .file-cta, html.theme--documenter-dark .file.is-light.is-hovered .file-cta {
+      background-color: #e5eaec;
+      border-color: transparent;
+      color: #282f2f; }
+    html.theme--documenter-dark .file.is-light:focus .file-cta, html.theme--documenter-dark .file.is-light.is-focused .file-cta {
+      border-color: transparent;
+      box-shadow: 0 0 0.5em rgba(236, 240, 241, 0.25);
+      color: #282f2f; }
+    html.theme--documenter-dark .file.is-light:active .file-cta, html.theme--documenter-dark .file.is-light.is-active .file-cta {
+      background-color: #dde4e6;
+      border-color: transparent;
+      color: #282f2f; }
+    html.theme--documenter-dark .file.is-dark .file-cta, html.theme--documenter-dark .content kbd.file .file-cta {
+      background-color: #282f2f;
+      border-color: transparent;
+      color: #ecf0f1; }
+    html.theme--documenter-dark .file.is-dark:hover .file-cta, html.theme--documenter-dark .content kbd.file:hover .file-cta, html.theme--documenter-dark .file.is-dark.is-hovered .file-cta, html.theme--documenter-dark .content kbd.file.is-hovered .file-cta {
+      background-color: #232829;
+      border-color: transparent;
+      color: #ecf0f1; }
+    html.theme--documenter-dark .file.is-dark:focus .file-cta, html.theme--documenter-dark .content kbd.file:focus .file-cta, html.theme--documenter-dark .file.is-dark.is-focused .file-cta, html.theme--documenter-dark .content kbd.file.is-focused .file-cta {
+      border-color: transparent;
+      box-shadow: 0 0 0.5em rgba(40, 47, 47, 0.25);
+      color: #ecf0f1; }
+    html.theme--documenter-dark .file.is-dark:active .file-cta, html.theme--documenter-dark .content kbd.file:active .file-cta, html.theme--documenter-dark .file.is-dark.is-active .file-cta, html.theme--documenter-dark .content kbd.file.is-active .file-cta {
+      background-color: #1d2122;
+      border-color: transparent;
+      color: #ecf0f1; }
+    html.theme--documenter-dark .file.is-primary .file-cta, html.theme--documenter-dark .docstring > section > a.file.docs-sourcelink .file-cta {
+      background-color: #375a7f;
+      border-color: transparent;
+      color: #fff; }
+    html.theme--documenter-dark .file.is-primary:hover .file-cta, html.theme--documenter-dark .docstring > section > a.file.docs-sourcelink:hover .file-cta, html.theme--documenter-dark .file.is-primary.is-hovered .file-cta, html.theme--documenter-dark .docstring > section > a.file.is-hovered.docs-sourcelink .file-cta {
+      background-color: #335476;
+      border-color: transparent;
+      color: #fff; }
+    html.theme--documenter-dark .file.is-primary:focus .file-cta, html.theme--documenter-dark .docstring > section > a.file.docs-sourcelink:focus .file-cta, html.theme--documenter-dark .file.is-primary.is-focused .file-cta, html.theme--documenter-dark .docstring > section > a.file.is-focused.docs-sourcelink .file-cta {
+      border-color: transparent;
+      box-shadow: 0 0 0.5em rgba(55, 90, 127, 0.25);
+      color: #fff; }
+    html.theme--documenter-dark .file.is-primary:active .file-cta, html.theme--documenter-dark .docstring > section > a.file.docs-sourcelink:active .file-cta, html.theme--documenter-dark .file.is-primary.is-active .file-cta, html.theme--documenter-dark .docstring > section > a.file.is-active.docs-sourcelink .file-cta {
+      background-color: #2f4d6d;
+      border-color: transparent;
+      color: #fff; }
+    html.theme--documenter-dark .file.is-link .file-cta {
+      background-color: #1abc9c;
+      border-color: transparent;
+      color: #fff; }
+    html.theme--documenter-dark .file.is-link:hover .file-cta, html.theme--documenter-dark .file.is-link.is-hovered .file-cta {
+      background-color: #18b193;
+      border-color: transparent;
+      color: #fff; }
+    html.theme--documenter-dark .file.is-link:focus .file-cta, html.theme--documenter-dark .file.is-link.is-focused .file-cta {
+      border-color: transparent;
+      box-shadow: 0 0 0.5em rgba(26, 188, 156, 0.25);
+      color: #fff; }
+    html.theme--documenter-dark .file.is-link:active .file-cta, html.theme--documenter-dark .file.is-link.is-active .file-cta {
+      background-color: #17a689;
+      border-color: transparent;
+      color: #fff; }
+    html.theme--documenter-dark .file.is-info .file-cta {
+      background-color: #024c7d;
+      border-color: transparent;
+      color: #fff; }
+    html.theme--documenter-dark .file.is-info:hover .file-cta, html.theme--documenter-dark .file.is-info.is-hovered .file-cta {
+      background-color: #024470;
+      border-color: transparent;
+      color: #fff; }
+    html.theme--documenter-dark .file.is-info:focus .file-cta, html.theme--documenter-dark .file.is-info.is-focused .file-cta {
+      border-color: transparent;
+      box-shadow: 0 0 0.5em rgba(2, 76, 125, 0.25);
+      color: #fff; }
+    html.theme--documenter-dark .file.is-info:active .file-cta, html.theme--documenter-dark .file.is-info.is-active .file-cta {
+      background-color: #023d64;
+      border-color: transparent;
+      color: #fff; }
+    html.theme--documenter-dark .file.is-success .file-cta {
+      background-color: #008438;
+      border-color: transparent;
+      color: #fff; }
+    html.theme--documenter-dark .file.is-success:hover .file-cta, html.theme--documenter-dark .file.is-success.is-hovered .file-cta {
+      background-color: #007733;
+      border-color: transparent;
+      color: #fff; }
+    html.theme--documenter-dark .file.is-success:focus .file-cta, html.theme--documenter-dark .file.is-success.is-focused .file-cta {
+      border-color: transparent;
+      box-shadow: 0 0 0.5em rgba(0, 132, 56, 0.25);
+      color: #fff; }
+    html.theme--documenter-dark .file.is-success:active .file-cta, html.theme--documenter-dark .file.is-success.is-active .file-cta {
+      background-color: #006b2d;
+      border-color: transparent;
+      color: #fff; }
+    html.theme--documenter-dark .file.is-warning .file-cta {
+      background-color: #ad8100;
+      border-color: transparent;
+      color: #fff; }
+    html.theme--documenter-dark .file.is-warning:hover .file-cta, html.theme--documenter-dark .file.is-warning.is-hovered .file-cta {
+      background-color: #a07700;
+      border-color: transparent;
+      color: #fff; }
+    html.theme--documenter-dark .file.is-warning:focus .file-cta, html.theme--documenter-dark .file.is-warning.is-focused .file-cta {
+      border-color: transparent;
+      box-shadow: 0 0 0.5em rgba(173, 129, 0, 0.25);
+      color: #fff; }
+    html.theme--documenter-dark .file.is-warning:active .file-cta, html.theme--documenter-dark .file.is-warning.is-active .file-cta {
+      background-color: #946e00;
+      border-color: transparent;
+      color: #fff; }
+    html.theme--documenter-dark .file.is-danger .file-cta {
+      background-color: #9e1b0d;
+      border-color: transparent;
+      color: #fff; }
+    html.theme--documenter-dark .file.is-danger:hover .file-cta, html.theme--documenter-dark .file.is-danger.is-hovered .file-cta {
+      background-color: #92190c;
+      border-color: transparent;
+      color: #fff; }
+    html.theme--documenter-dark .file.is-danger:focus .file-cta, html.theme--documenter-dark .file.is-danger.is-focused .file-cta {
+      border-color: transparent;
+      box-shadow: 0 0 0.5em rgba(158, 27, 13, 0.25);
+      color: #fff; }
+    html.theme--documenter-dark .file.is-danger:active .file-cta, html.theme--documenter-dark .file.is-danger.is-active .file-cta {
+      background-color: #86170b;
+      border-color: transparent;
+      color: #fff; }
+    html.theme--documenter-dark .file.is-small, html.theme--documenter-dark #documenter .docs-sidebar form.docs-search > input.file {
+      font-size: 0.85em; }
+    html.theme--documenter-dark .file.is-medium {
+      font-size: 1.25rem; }
+      html.theme--documenter-dark .file.is-medium .file-icon .fa {
+        font-size: 21px; }
+    html.theme--documenter-dark .file.is-large {
+      font-size: 1.5rem; }
+      html.theme--documenter-dark .file.is-large .file-icon .fa {
+        font-size: 28px; }
+    html.theme--documenter-dark .file.has-name .file-cta {
+      border-bottom-right-radius: 0;
+      border-top-right-radius: 0; }
+    html.theme--documenter-dark .file.has-name .file-name {
+      border-bottom-left-radius: 0;
+      border-top-left-radius: 0; }
+    html.theme--documenter-dark .file.has-name.is-empty .file-cta {
+      border-radius: 0.4em; }
+    html.theme--documenter-dark .file.has-name.is-empty .file-name {
+      display: none; }
+    html.theme--documenter-dark .file.is-boxed .file-label {
+      flex-direction: column; }
+    html.theme--documenter-dark .file.is-boxed .file-cta {
+      flex-direction: column;
+      height: auto;
+      padding: 1em 3em; }
+    html.theme--documenter-dark .file.is-boxed .file-name {
+      border-width: 0 1px 1px; }
+    html.theme--documenter-dark .file.is-boxed .file-icon {
+      height: 1.5em;
+      width: 1.5em; }
+      html.theme--documenter-dark .file.is-boxed .file-icon .fa {
+        font-size: 21px; }
+    html.theme--documenter-dark .file.is-boxed.is-small .file-icon .fa, html.theme--documenter-dark #documenter .docs-sidebar form.docs-search > input.file.is-boxed .file-icon .fa {
+      font-size: 14px; }
+    html.theme--documenter-dark .file.is-boxed.is-medium .file-icon .fa {
+      font-size: 28px; }
+    html.theme--documenter-dark .file.is-boxed.is-large .file-icon .fa {
+      font-size: 35px; }
+    html.theme--documenter-dark .file.is-boxed.has-name .file-cta {
+      border-radius: 0.4em 0.4em 0 0; }
+    html.theme--documenter-dark .file.is-boxed.has-name .file-name {
+      border-radius: 0 0 0.4em 0.4em;
+      border-width: 0 1px 1px; }
+    html.theme--documenter-dark .file.is-centered {
+      justify-content: center; }
+    html.theme--documenter-dark .file.is-fullwidth .file-label {
+      width: 100%; }
+    html.theme--documenter-dark .file.is-fullwidth .file-name {
+      flex-grow: 1;
+      max-width: none; }
+    html.theme--documenter-dark .file.is-right {
+      justify-content: flex-end; }
+      html.theme--documenter-dark .file.is-right .file-cta {
+        border-radius: 0 0.4em 0.4em 0; }
+      html.theme--documenter-dark .file.is-right .file-name {
+        border-radius: 0.4em 0 0 0.4em;
+        border-width: 1px 0 1px 1px;
+        order: -1; }
+  html.theme--documenter-dark .file-label {
+    align-items: stretch;
+    display: flex;
+    cursor: pointer;
+    justify-content: flex-start;
+    overflow: hidden;
+    position: relative; }
+    html.theme--documenter-dark .file-label:hover .file-cta {
+      background-color: #e5eaec;
+      color: #282f2f; }
+    html.theme--documenter-dark .file-label:hover .file-name {
+      border-color: #596668; }
+    html.theme--documenter-dark .file-label:active .file-cta {
+      background-color: #dde4e6;
+      color: #282f2f; }
+    html.theme--documenter-dark .file-label:active .file-name {
+      border-color: #535f61; }
+  html.theme--documenter-dark .file-input {
+    height: 100%;
+    left: 0;
+    opacity: 0;
+    outline: none;
+    position: absolute;
+    top: 0;
+    width: 100%; }
+  html.theme--documenter-dark .file-cta,
+  html.theme--documenter-dark .file-name {
+    border-color: #5e6d6f;
+    border-radius: 0.4em;
+    font-size: 1em;
+    padding-left: 1em;
+    padding-right: 1em;
+    white-space: nowrap; }
+  html.theme--documenter-dark .file-cta {
+    background-color: #ecf0f1;
+    color: #343c3d; }
+  html.theme--documenter-dark .file-name {
+    border-color: #5e6d6f;
+    border-style: solid;
+    border-width: 1px 1px 1px 0;
+    display: block;
+    max-width: 16em;
+    overflow: hidden;
+    text-align: left;
+    text-overflow: ellipsis; }
+  html.theme--documenter-dark .file-icon {
+    align-items: center;
+    display: flex;
+    height: 1em;
+    justify-content: center;
+    margin-right: 0.5em;
+    width: 1em; }
+    html.theme--documenter-dark .file-icon .fa {
+      font-size: 14px; }
+  html.theme--documenter-dark .label {
+    color: #282f2f;
+    display: block;
+    font-size: 15px;
+    font-weight: 700; }
+    html.theme--documenter-dark .label:not(:last-child) {
+      margin-bottom: 0.5em; }
+    html.theme--documenter-dark .label.is-small, html.theme--documenter-dark #documenter .docs-sidebar form.docs-search > input.label {
+      font-size: 0.85em; }
+    html.theme--documenter-dark .label.is-medium {
+      font-size: 1.25rem; }
+    html.theme--documenter-dark .label.is-large {
+      font-size: 1.5rem; }
+  html.theme--documenter-dark .help {
+    display: block;
+    font-size: 0.85em;
+    margin-top: 0.25rem; }
+    html.theme--documenter-dark .help.is-white {
+      color: white; }
+    html.theme--documenter-dark .help.is-black {
+      color: #0a0a0a; }
+    html.theme--documenter-dark .help.is-light {
+      color: #ecf0f1; }
+    html.theme--documenter-dark .help.is-dark, html.theme--documenter-dark .content kbd.help {
+      color: #282f2f; }
+    html.theme--documenter-dark .help.is-primary, html.theme--documenter-dark .docstring > section > a.help.docs-sourcelink {
+      color: #375a7f; }
+    html.theme--documenter-dark .help.is-link {
+      color: #1abc9c; }
+    html.theme--documenter-dark .help.is-info {
+      color: #024c7d; }
+    html.theme--documenter-dark .help.is-success {
+      color: #008438; }
+    html.theme--documenter-dark .help.is-warning {
+      color: #ad8100; }
+    html.theme--documenter-dark .help.is-danger {
+      color: #9e1b0d; }
+  html.theme--documenter-dark .field:not(:last-child) {
+    margin-bottom: 0.75rem; }
+  html.theme--documenter-dark .field.has-addons {
+    display: flex;
+    justify-content: flex-start; }
+    html.theme--documenter-dark .field.has-addons .control:not(:last-child) {
+      margin-right: -1px; }
+    html.theme--documenter-dark .field.has-addons .control:not(:first-child):not(:last-child) .button,
+    html.theme--documenter-dark .field.has-addons .control:not(:first-child):not(:last-child) .input,
+    html.theme--documenter-dark .field.has-addons .control:not(:first-child):not(:last-child) #documenter .docs-sidebar form.docs-search > input,
+    html.theme--documenter-dark #documenter .docs-sidebar .field.has-addons .control:not(:first-child):not(:last-child) form.docs-search > input,
+    html.theme--documenter-dark .field.has-addons .control:not(:first-child):not(:last-child) .select select {
+      border-radius: 0; }
+    html.theme--documenter-dark .field.has-addons .control:first-child:not(:only-child) .button,
+    html.theme--documenter-dark .field.has-addons .control:first-child:not(:only-child) .input,
+    html.theme--documenter-dark .field.has-addons .control:first-child:not(:only-child) #documenter .docs-sidebar form.docs-search > input,
+    html.theme--documenter-dark #documenter .docs-sidebar .field.has-addons .control:first-child:not(:only-child) form.docs-search > input,
+    html.theme--documenter-dark .field.has-addons .control:first-child:not(:only-child) .select select {
+      border-bottom-right-radius: 0;
+      border-top-right-radius: 0; }
+    html.theme--documenter-dark .field.has-addons .control:last-child:not(:only-child) .button,
+    html.theme--documenter-dark .field.has-addons .control:last-child:not(:only-child) .input,
+    html.theme--documenter-dark .field.has-addons .control:last-child:not(:only-child) #documenter .docs-sidebar form.docs-search > input,
+    html.theme--documenter-dark #documenter .docs-sidebar .field.has-addons .control:last-child:not(:only-child) form.docs-search > input,
+    html.theme--documenter-dark .field.has-addons .control:last-child:not(:only-child) .select select {
+      border-bottom-left-radius: 0;
+      border-top-left-radius: 0; }
+    html.theme--documenter-dark .field.has-addons .control .button:not([disabled]):hover, html.theme--documenter-dark .field.has-addons .control .button:not([disabled]).is-hovered,
+    html.theme--documenter-dark .field.has-addons .control .input:not([disabled]):hover,
+    html.theme--documenter-dark .field.has-addons .control #documenter .docs-sidebar form.docs-search > input:not([disabled]):hover,
+    html.theme--documenter-dark #documenter .docs-sidebar .field.has-addons .control form.docs-search > input:not([disabled]):hover,
+    html.theme--documenter-dark .field.has-addons .control .input:not([disabled]).is-hovered,
+    html.theme--documenter-dark .field.has-addons .control #documenter .docs-sidebar form.docs-search > input:not([disabled]).is-hovered,
+    html.theme--documenter-dark #documenter .docs-sidebar .field.has-addons .control form.docs-search > input:not([disabled]).is-hovered,
+    html.theme--documenter-dark .field.has-addons .control .select select:not([disabled]):hover,
+    html.theme--documenter-dark .field.has-addons .control .select select:not([disabled]).is-hovered {
+      z-index: 2; }
+    html.theme--documenter-dark .field.has-addons .control .button:not([disabled]):focus, html.theme--documenter-dark .field.has-addons .control .button:not([disabled]).is-focused, html.theme--documenter-dark .field.has-addons .control .button:not([disabled]):active, html.theme--documenter-dark .field.has-addons .control .button:not([disabled]).is-active,
+    html.theme--documenter-dark .field.has-addons .control .input:not([disabled]):focus,
+    html.theme--documenter-dark .field.has-addons .control #documenter .docs-sidebar form.docs-search > input:not([disabled]):focus,
+    html.theme--documenter-dark #documenter .docs-sidebar .field.has-addons .control form.docs-search > input:not([disabled]):focus,
+    html.theme--documenter-dark .field.has-addons .control .input:not([disabled]).is-focused,
+    html.theme--documenter-dark .field.has-addons .control #documenter .docs-sidebar form.docs-search > input:not([disabled]).is-focused,
+    html.theme--documenter-dark #documenter .docs-sidebar .field.has-addons .control form.docs-search > input:not([disabled]).is-focused,
+    html.theme--documenter-dark .field.has-addons .control .input:not([disabled]):active,
+    html.theme--documenter-dark .field.has-addons .control #documenter .docs-sidebar form.docs-search > input:not([disabled]):active,
+    html.theme--documenter-dark #documenter .docs-sidebar .field.has-addons .control form.docs-search > input:not([disabled]):active,
+    html.theme--documenter-dark .field.has-addons .control .input:not([disabled]).is-active,
+    html.theme--documenter-dark .field.has-addons .control #documenter .docs-sidebar form.docs-search > input:not([disabled]).is-active,
+    html.theme--documenter-dark #documenter .docs-sidebar .field.has-addons .control form.docs-search > input:not([disabled]).is-active,
+    html.theme--documenter-dark .field.has-addons .control .select select:not([disabled]):focus,
+    html.theme--documenter-dark .field.has-addons .control .select select:not([disabled]).is-focused,
+    html.theme--documenter-dark .field.has-addons .control .select select:not([disabled]):active,
+    html.theme--documenter-dark .field.has-addons .control .select select:not([disabled]).is-active {
+      z-index: 3; }
+      html.theme--documenter-dark .field.has-addons .control .button:not([disabled]):focus:hover, html.theme--documenter-dark .field.has-addons .control .button:not([disabled]).is-focused:hover, html.theme--documenter-dark .field.has-addons .control .button:not([disabled]):active:hover, html.theme--documenter-dark .field.has-addons .control .button:not([disabled]).is-active:hover,
+      html.theme--documenter-dark .field.has-addons .control .input:not([disabled]):focus:hover,
+      html.theme--documenter-dark .field.has-addons .control #documenter .docs-sidebar form.docs-search > input:not([disabled]):focus:hover,
+      html.theme--documenter-dark #documenter .docs-sidebar .field.has-addons .control form.docs-search > input:not([disabled]):focus:hover,
+      html.theme--documenter-dark .field.has-addons .control .input:not([disabled]).is-focused:hover,
+      html.theme--documenter-dark .field.has-addons .control #documenter .docs-sidebar form.docs-search > input:not([disabled]).is-focused:hover,
+      html.theme--documenter-dark #documenter .docs-sidebar .field.has-addons .control form.docs-search > input:not([disabled]).is-focused:hover,
+      html.theme--documenter-dark .field.has-addons .control .input:not([disabled]):active:hover,
+      html.theme--documenter-dark .field.has-addons .control #documenter .docs-sidebar form.docs-search > input:not([disabled]):active:hover,
+      html.theme--documenter-dark #documenter .docs-sidebar .field.has-addons .control form.docs-search > input:not([disabled]):active:hover,
+      html.theme--documenter-dark .field.has-addons .control .input:not([disabled]).is-active:hover,
+      html.theme--documenter-dark .field.has-addons .control #documenter .docs-sidebar form.docs-search > input:not([disabled]).is-active:hover,
+      html.theme--documenter-dark #documenter .docs-sidebar .field.has-addons .control form.docs-search > input:not([disabled]).is-active:hover,
+      html.theme--documenter-dark .field.has-addons .control .select select:not([disabled]):focus:hover,
+      html.theme--documenter-dark .field.has-addons .control .select select:not([disabled]).is-focused:hover,
+      html.theme--documenter-dark .field.has-addons .control .select select:not([disabled]):active:hover,
+      html.theme--documenter-dark .field.has-addons .control .select select:not([disabled]).is-active:hover {
+        z-index: 4; }
+    html.theme--documenter-dark .field.has-addons .control.is-expanded {
+      flex-grow: 1;
+      flex-shrink: 1; }
+    html.theme--documenter-dark .field.has-addons.has-addons-centered {
+      justify-content: center; }
+    html.theme--documenter-dark .field.has-addons.has-addons-right {
+      justify-content: flex-end; }
+    html.theme--documenter-dark .field.has-addons.has-addons-fullwidth .control {
+      flex-grow: 1;
+      flex-shrink: 0; }
+  html.theme--documenter-dark .field.is-grouped {
+    display: flex;
+    justify-content: flex-start; }
+    html.theme--documenter-dark .field.is-grouped > .control {
+      flex-shrink: 0; }
+      html.theme--documenter-dark .field.is-grouped > .control:not(:last-child) {
+        margin-bottom: 0;
+        margin-right: 0.75rem; }
+      html.theme--documenter-dark .field.is-grouped > .control.is-expanded {
+        flex-grow: 1;
+        flex-shrink: 1; }
+    html.theme--documenter-dark .field.is-grouped.is-grouped-centered {
+      justify-content: center; }
+    html.theme--documenter-dark .field.is-grouped.is-grouped-right {
+      justify-content: flex-end; }
+    html.theme--documenter-dark .field.is-grouped.is-grouped-multiline {
+      flex-wrap: wrap; }
+      html.theme--documenter-dark .field.is-grouped.is-grouped-multiline > .control:last-child, html.theme--documenter-dark .field.is-grouped.is-grouped-multiline > .control:not(:last-child) {
+        margin-bottom: 0.75rem; }
+      html.theme--documenter-dark .field.is-grouped.is-grouped-multiline:last-child {
+        margin-bottom: -0.75rem; }
+      html.theme--documenter-dark .field.is-grouped.is-grouped-multiline:not(:last-child) {
+        margin-bottom: 0; }
+  @media screen and (min-width: 769px), print {
+    html.theme--documenter-dark .field.is-horizontal {
+      display: flex; } }
+  html.theme--documenter-dark .field-label .label {
+    font-size: inherit; }
+  @media screen and (max-width: 768px) {
+    html.theme--documenter-dark .field-label {
+      margin-bottom: 0.5rem; } }
+  @media screen and (min-width: 769px), print {
+    html.theme--documenter-dark .field-label {
+      flex-basis: 0;
+      flex-grow: 1;
+      flex-shrink: 0;
+      margin-right: 1.5rem;
+      text-align: right; }
+      html.theme--documenter-dark .field-label.is-small, html.theme--documenter-dark #documenter .docs-sidebar form.docs-search > input.field-label {
+        font-size: 0.85em;
+        padding-top: 0.375em; }
+      html.theme--documenter-dark .field-label.is-normal {
+        padding-top: 0.375em; }
+      html.theme--documenter-dark .field-label.is-medium {
+        font-size: 1.25rem;
+        padding-top: 0.375em; }
+      html.theme--documenter-dark .field-label.is-large {
+        font-size: 1.5rem;
+        padding-top: 0.375em; } }
+  html.theme--documenter-dark .field-body .field .field {
+    margin-bottom: 0; }
+  @media screen and (min-width: 769px), print {
+    html.theme--documenter-dark .field-body {
+      display: flex;
+      flex-basis: 0;
+      flex-grow: 5;
+      flex-shrink: 1; }
+      html.theme--documenter-dark .field-body .field {
+        margin-bottom: 0; }
+      html.theme--documenter-dark .field-body > .field {
+        flex-shrink: 1; }
+        html.theme--documenter-dark .field-body > .field:not(.is-narrow) {
+          flex-grow: 1; }
+        html.theme--documenter-dark .field-body > .field:not(:last-child) {
+          margin-right: 0.75rem; } }
+  html.theme--documenter-dark .control {
+    box-sizing: border-box;
+    clear: both;
+    font-size: 15px;
+    position: relative;
+    text-align: left; }
+    html.theme--documenter-dark .control.has-icons-left .input:focus ~ .icon, html.theme--documenter-dark .control.has-icons-left #documenter .docs-sidebar form.docs-search > input:focus ~ .icon, html.theme--documenter-dark #documenter .docs-sidebar .control.has-icons-left form.docs-search > input:focus ~ .icon,
+    html.theme--documenter-dark .control.has-icons-left .select:focus ~ .icon, html.theme--documenter-dark .control.has-icons-right .input:focus ~ .icon, html.theme--documenter-dark .control.has-icons-right #documenter .docs-sidebar form.docs-search > input:focus ~ .icon, html.theme--documenter-dark #documenter .docs-sidebar .control.has-icons-right form.docs-search > input:focus ~ .icon,
+    html.theme--documenter-dark .control.has-icons-right .select:focus ~ .icon {
+      color: #5e6d6f; }
+    html.theme--documenter-dark .control.has-icons-left .input.is-small ~ .icon, html.theme--documenter-dark .control.has-icons-left #documenter .docs-sidebar form.docs-search > input ~ .icon, html.theme--documenter-dark #documenter .docs-sidebar .control.has-icons-left form.docs-search > input ~ .icon,
+    html.theme--documenter-dark .control.has-icons-left .select.is-small ~ .icon,
+    html.theme--documenter-dark .control.has-icons-left #documenter .docs-sidebar form.docs-search > input.select ~ .icon,
+    html.theme--documenter-dark #documenter .docs-sidebar .control.has-icons-left form.docs-search > input.select ~ .icon, html.theme--documenter-dark .control.has-icons-right .input.is-small ~ .icon, html.theme--documenter-dark .control.has-icons-right #documenter .docs-sidebar form.docs-search > input ~ .icon, html.theme--documenter-dark #documenter .docs-sidebar .control.has-icons-right form.docs-search > input ~ .icon,
+    html.theme--documenter-dark .control.has-icons-right .select.is-small ~ .icon,
+    html.theme--documenter-dark .control.has-icons-right #documenter .docs-sidebar form.docs-search > input.select ~ .icon,
+    html.theme--documenter-dark #documenter .docs-sidebar .control.has-icons-right form.docs-search > input.select ~ .icon {
+      font-size: 0.85em; }
+    html.theme--documenter-dark .control.has-icons-left .input.is-medium ~ .icon, html.theme--documenter-dark .control.has-icons-left #documenter .docs-sidebar form.docs-search > input.is-medium ~ .icon, html.theme--documenter-dark #documenter .docs-sidebar .control.has-icons-left form.docs-search > input.is-medium ~ .icon,
+    html.theme--documenter-dark .control.has-icons-left .select.is-medium ~ .icon, html.theme--documenter-dark .control.has-icons-right .input.is-medium ~ .icon, html.theme--documenter-dark .control.has-icons-right #documenter .docs-sidebar form.docs-search > input.is-medium ~ .icon, html.theme--documenter-dark #documenter .docs-sidebar .control.has-icons-right form.docs-search > input.is-medium ~ .icon,
+    html.theme--documenter-dark .control.has-icons-right .select.is-medium ~ .icon {
+      font-size: 1.25rem; }
+    html.theme--documenter-dark .control.has-icons-left .input.is-large ~ .icon, html.theme--documenter-dark .control.has-icons-left #documenter .docs-sidebar form.docs-search > input.is-large ~ .icon, html.theme--documenter-dark #documenter .docs-sidebar .control.has-icons-left form.docs-search > input.is-large ~ .icon,
+    html.theme--documenter-dark .control.has-icons-left .select.is-large ~ .icon, html.theme--documenter-dark .control.has-icons-right .input.is-large ~ .icon, html.theme--documenter-dark .control.has-icons-right #documenter .docs-sidebar form.docs-search > input.is-large ~ .icon, html.theme--documenter-dark #documenter .docs-sidebar .control.has-icons-right form.docs-search > input.is-large ~ .icon,
+    html.theme--documenter-dark .control.has-icons-right .select.is-large ~ .icon {
+      font-size: 1.5rem; }
+    html.theme--documenter-dark .control.has-icons-left .icon, html.theme--documenter-dark .control.has-icons-right .icon {
+      color: #dbdee0;
+      height: 2.25em;
+      pointer-events: none;
+      position: absolute;
+      top: 0;
+      width: 2.25em;
+      z-index: 4; }
+    html.theme--documenter-dark .control.has-icons-left .input, html.theme--documenter-dark .control.has-icons-left #documenter .docs-sidebar form.docs-search > input, html.theme--documenter-dark #documenter .docs-sidebar .control.has-icons-left form.docs-search > input,
+    html.theme--documenter-dark .control.has-icons-left .select select {
+      padding-left: 2.25em; }
+    html.theme--documenter-dark .control.has-icons-left .icon.is-left {
+      left: 0; }
+    html.theme--documenter-dark .control.has-icons-right .input, html.theme--documenter-dark .control.has-icons-right #documenter .docs-sidebar form.docs-search > input, html.theme--documenter-dark #documenter .docs-sidebar .control.has-icons-right form.docs-search > input,
+    html.theme--documenter-dark .control.has-icons-right .select select {
+      padding-right: 2.25em; }
+    html.theme--documenter-dark .control.has-icons-right .icon.is-right {
+      right: 0; }
+    html.theme--documenter-dark .control.is-loading::after {
+      position: absolute !important;
+      right: 0.625em;
+      top: 0.625em;
+      z-index: 4; }
+    html.theme--documenter-dark .control.is-loading.is-small:after, html.theme--documenter-dark #documenter .docs-sidebar form.docs-search > input.control.is-loading:after {
+      font-size: 0.85em; }
+    html.theme--documenter-dark .control.is-loading.is-medium:after {
+      font-size: 1.25rem; }
+    html.theme--documenter-dark .control.is-loading.is-large:after {
+      font-size: 1.5rem; }
+  html.theme--documenter-dark .breadcrumb {
+    font-size: 15px;
+    white-space: nowrap; }
+    html.theme--documenter-dark .breadcrumb a {
+      align-items: center;
+      color: #1abc9c;
+      display: flex;
+      justify-content: center;
+      padding: 0 0.75em; }
+      html.theme--documenter-dark .breadcrumb a:hover {
+        color: #1dd2af; }
+    html.theme--documenter-dark .breadcrumb li {
+      align-items: center;
+      display: flex; }
+      html.theme--documenter-dark .breadcrumb li:first-child a {
+        padding-left: 0; }
+      html.theme--documenter-dark .breadcrumb li.is-active a {
+        color: #f2f2f2;
+        cursor: default;
+        pointer-events: none; }
+      html.theme--documenter-dark .breadcrumb li + li::before {
+        color: #8c9b9d;
+        content: "\0002f"; }
+    html.theme--documenter-dark .breadcrumb ul,
+    html.theme--documenter-dark .breadcrumb ol {
+      align-items: flex-start;
+      display: flex;
+      flex-wrap: wrap;
+      justify-content: flex-start; }
+    html.theme--documenter-dark .breadcrumb .icon:first-child {
+      margin-right: 0.5em; }
+    html.theme--documenter-dark .breadcrumb .icon:last-child {
+      margin-left: 0.5em; }
+    html.theme--documenter-dark .breadcrumb.is-centered ol,
+    html.theme--documenter-dark .breadcrumb.is-centered ul {
+      justify-content: center; }
+    html.theme--documenter-dark .breadcrumb.is-right ol,
+    html.theme--documenter-dark .breadcrumb.is-right ul {
+      justify-content: flex-end; }
+    html.theme--documenter-dark .breadcrumb.is-small, html.theme--documenter-dark #documenter .docs-sidebar form.docs-search > input.breadcrumb {
+      font-size: 0.85em; }
+    html.theme--documenter-dark .breadcrumb.is-medium {
+      font-size: 1.25rem; }
+    html.theme--documenter-dark .breadcrumb.is-large {
+      font-size: 1.5rem; }
+    html.theme--documenter-dark .breadcrumb.has-arrow-separator li + li::before {
+      content: "\02192"; }
+    html.theme--documenter-dark .breadcrumb.has-bullet-separator li + li::before {
+      content: "\02022"; }
+    html.theme--documenter-dark .breadcrumb.has-dot-separator li + li::before {
+      content: "\000b7"; }
+    html.theme--documenter-dark .breadcrumb.has-succeeds-separator li + li::before {
+      content: "\0227B"; }
+  html.theme--documenter-dark .card {
+    background-color: white;
+    box-shadow: 0 2px 3px rgba(10, 10, 10, 0.1), 0 0 0 1px rgba(10, 10, 10, 0.1);
+    color: #fff;
+    max-width: 100%;
+    position: relative; }
+  html.theme--documenter-dark .card-header {
+    background-color: transparent;
+    align-items: stretch;
+    box-shadow: 0 1px 2px rgba(10, 10, 10, 0.1);
+    display: flex; }
+  html.theme--documenter-dark .card-header-title {
+    align-items: center;
+    color: #f2f2f2;
+    display: flex;
+    flex-grow: 1;
+    font-weight: 700;
+    padding: 0.75rem; }
+    html.theme--documenter-dark .card-header-title.is-centered {
+      justify-content: center; }
+  html.theme--documenter-dark .card-header-icon {
+    align-items: center;
+    cursor: pointer;
+    display: flex;
+    justify-content: center;
+    padding: 0.75rem; }
+  html.theme--documenter-dark .card-image {
+    display: block;
+    position: relative; }
+  html.theme--documenter-dark .card-content {
+    background-color: transparent;
+    padding: 1rem 1.25rem; }
+  html.theme--documenter-dark .card-footer {
+    background-color: transparent;
+    border-top: 1px solid #5e6d6f;
+    align-items: stretch;
+    display: flex; }
+  html.theme--documenter-dark .card-footer-item {
+    align-items: center;
+    display: flex;
+    flex-basis: 0;
+    flex-grow: 1;
+    flex-shrink: 0;
+    justify-content: center;
+    padding: 0.75rem; }
+    html.theme--documenter-dark .card-footer-item:not(:last-child) {
+      border-right: 1px solid #5e6d6f; }
+  html.theme--documenter-dark .card .media:not(:last-child) {
+    margin-bottom: 1.5rem; }
+  html.theme--documenter-dark .dropdown {
+    display: inline-flex;
+    position: relative;
+    vertical-align: top; }
+    html.theme--documenter-dark .dropdown.is-active .dropdown-menu, html.theme--documenter-dark .dropdown.is-hoverable:hover .dropdown-menu {
+      display: block; }
+    html.theme--documenter-dark .dropdown.is-right .dropdown-menu {
+      left: auto;
+      right: 0; }
+    html.theme--documenter-dark .dropdown.is-up .dropdown-menu {
+      bottom: 100%;
+      padding-bottom: 4px;
+      padding-top: initial;
+      top: auto; }
+  html.theme--documenter-dark .dropdown-menu {
+    display: none;
+    left: 0;
+    min-width: 12rem;
+    padding-top: 4px;
+    position: absolute;
+    top: 100%;
+    z-index: 20; }
+  html.theme--documenter-dark .dropdown-content {
+    background-color: #282f2f;
+    border-radius: 0.4em;
+    box-shadow: 0 2px 3px rgba(10, 10, 10, 0.1), 0 0 0 1px rgba(10, 10, 10, 0.1);
+    padding-bottom: 0.5rem;
+    padding-top: 0.5rem; }
+  html.theme--documenter-dark .dropdown-item {
+    color: #fff;
+    display: block;
+    font-size: 0.875rem;
+    line-height: 1.5;
+    padding: 0.375rem 1rem;
+    position: relative; }
+  html.theme--documenter-dark a.dropdown-item,
+  html.theme--documenter-dark button.dropdown-item {
+    padding-right: 3rem;
+    text-align: left;
+    white-space: nowrap;
+    width: 100%; }
+    html.theme--documenter-dark a.dropdown-item:hover,
+    html.theme--documenter-dark button.dropdown-item:hover {
+      background-color: #282f2f;
+      color: #0a0a0a; }
+    html.theme--documenter-dark a.dropdown-item.is-active,
+    html.theme--documenter-dark button.dropdown-item.is-active {
+      background-color: #1abc9c;
+      color: #fff; }
+  html.theme--documenter-dark .dropdown-divider {
+    background-color: #5e6d6f;
+    border: none;
+    display: block;
+    height: 1px;
+    margin: 0.5rem 0; }
+  html.theme--documenter-dark .level {
+    align-items: center;
+    justify-content: space-between; }
+    html.theme--documenter-dark .level code {
+      border-radius: 0.4em; }
+    html.theme--documenter-dark .level img {
+      display: inline-block;
+      vertical-align: top; }
+    html.theme--documenter-dark .level.is-mobile {
+      display: flex; }
+      html.theme--documenter-dark .level.is-mobile .level-left,
+      html.theme--documenter-dark .level.is-mobile .level-right {
+        display: flex; }
+      html.theme--documenter-dark .level.is-mobile .level-left + .level-right {
+        margin-top: 0; }
+      html.theme--documenter-dark .level.is-mobile .level-item:not(:last-child) {
+        margin-bottom: 0;
+        margin-right: 0.75rem; }
+      html.theme--documenter-dark .level.is-mobile .level-item:not(.is-narrow) {
+        flex-grow: 1; }
+    @media screen and (min-width: 769px), print {
+      html.theme--documenter-dark .level {
+        display: flex; }
+        html.theme--documenter-dark .level > .level-item:not(.is-narrow) {
+          flex-grow: 1; } }
+  html.theme--documenter-dark .level-item {
+    align-items: center;
+    display: flex;
+    flex-basis: auto;
+    flex-grow: 0;
+    flex-shrink: 0;
+    justify-content: center; }
+    html.theme--documenter-dark .level-item .title,
+    html.theme--documenter-dark .level-item .subtitle {
+      margin-bottom: 0; }
+    @media screen and (max-width: 768px) {
+      html.theme--documenter-dark .level-item:not(:last-child) {
+        margin-bottom: 0.75rem; } }
+  html.theme--documenter-dark .level-left,
+  html.theme--documenter-dark .level-right {
+    flex-basis: auto;
+    flex-grow: 0;
+    flex-shrink: 0; }
+    html.theme--documenter-dark .level-left .level-item.is-flexible,
+    html.theme--documenter-dark .level-right .level-item.is-flexible {
+      flex-grow: 1; }
+    @media screen and (min-width: 769px), print {
+      html.theme--documenter-dark .level-left .level-item:not(:last-child),
+      html.theme--documenter-dark .level-right .level-item:not(:last-child) {
+        margin-right: 0.75rem; } }
+  html.theme--documenter-dark .level-left {
+    align-items: center;
+    justify-content: flex-start; }
+    @media screen and (max-width: 768px) {
+      html.theme--documenter-dark .level-left + .level-right {
+        margin-top: 1.5rem; } }
+    @media screen and (min-width: 769px), print {
+      html.theme--documenter-dark .level-left {
+        display: flex; } }
+  html.theme--documenter-dark .level-right {
+    align-items: center;
+    justify-content: flex-end; }
+    @media screen and (min-width: 769px), print {
+      html.theme--documenter-dark .level-right {
+        display: flex; } }
+  html.theme--documenter-dark .list {
+    background-color: white;
+    border-radius: 0.4em;
+    box-shadow: 0 2px 3px rgba(10, 10, 10, 0.1), 0 0 0 1px rgba(10, 10, 10, 0.1); }
+  html.theme--documenter-dark .list-item {
+    display: block;
+    padding: 0.5em 1em; }
+    html.theme--documenter-dark .list-item:not(a) {
+      color: #fff; }
+    html.theme--documenter-dark .list-item:first-child {
+      border-top-left-radius: 0.4em;
+      border-top-right-radius: 0.4em; }
+    html.theme--documenter-dark .list-item:last-child {
+      border-bottom-left-radius: 0.4em;
+      border-bottom-right-radius: 0.4em; }
+    html.theme--documenter-dark .list-item:not(:last-child) {
+      border-bottom: 1px solid #5e6d6f; }
+    html.theme--documenter-dark .list-item.is-active {
+      background-color: #1abc9c;
+      color: #fff; }
+  html.theme--documenter-dark a.list-item {
+    background-color: #282f2f;
+    cursor: pointer; }
+  html.theme--documenter-dark .media {
+    align-items: flex-start;
+    display: flex;
+    text-align: left; }
+    html.theme--documenter-dark .media .content:not(:last-child) {
+      margin-bottom: 0.75rem; }
+    html.theme--documenter-dark .media .media {
+      border-top: 1px solid rgba(94, 109, 111, 0.5);
+      display: flex;
+      padding-top: 0.75rem; }
+      html.theme--documenter-dark .media .media .content:not(:last-child),
+      html.theme--documenter-dark .media .media .control:not(:last-child) {
+        margin-bottom: 0.5rem; }
+      html.theme--documenter-dark .media .media .media {
+        padding-top: 0.5rem; }
+        html.theme--documenter-dark .media .media .media + .media {
+          margin-top: 0.5rem; }
+    html.theme--documenter-dark .media + .media {
+      border-top: 1px solid rgba(94, 109, 111, 0.5);
+      margin-top: 1rem;
+      padding-top: 1rem; }
+    html.theme--documenter-dark .media.is-large + .media {
+      margin-top: 1.5rem;
+      padding-top: 1.5rem; }
+  html.theme--documenter-dark .media-left,
+  html.theme--documenter-dark .media-right {
+    flex-basis: auto;
+    flex-grow: 0;
+    flex-shrink: 0; }
+  html.theme--documenter-dark .media-left {
+    margin-right: 1rem; }
+  html.theme--documenter-dark .media-right {
+    margin-left: 1rem; }
+  html.theme--documenter-dark .media-content {
+    flex-basis: auto;
+    flex-grow: 1;
+    flex-shrink: 1;
+    text-align: left; }
+  @media screen and (max-width: 768px) {
+    html.theme--documenter-dark .media-content {
+      overflow-x: auto; } }
+  html.theme--documenter-dark .menu {
+    font-size: 15px; }
+    html.theme--documenter-dark .menu.is-small, html.theme--documenter-dark #documenter .docs-sidebar form.docs-search > input.menu {
+      font-size: 0.85em; }
+    html.theme--documenter-dark .menu.is-medium {
+      font-size: 1.25rem; }
+    html.theme--documenter-dark .menu.is-large {
+      font-size: 1.5rem; }
+  html.theme--documenter-dark .menu-list {
+    line-height: 1.25; }
+    html.theme--documenter-dark .menu-list a {
+      border-radius: 3px;
+      color: #fff;
+      display: block;
+      padding: 0.5em 0.75em; }
+      html.theme--documenter-dark .menu-list a:hover {
+        background-color: #282f2f;
+        color: #f2f2f2; }
+      html.theme--documenter-dark .menu-list a.is-active {
+        background-color: #1abc9c;
+        color: #fff; }
+    html.theme--documenter-dark .menu-list li ul {
+      border-left: 1px solid #5e6d6f;
+      margin: 0.75em;
+      padding-left: 0.75em; }
+  html.theme--documenter-dark .menu-label {
+    color: white;
+    font-size: 0.75em;
+    letter-spacing: 0.1em;
+    text-transform: uppercase; }
+    html.theme--documenter-dark .menu-label:not(:first-child) {
+      margin-top: 1em; }
+    html.theme--documenter-dark .menu-label:not(:last-child) {
+      margin-bottom: 1em; }
+  html.theme--documenter-dark .message {
+    background-color: #282f2f;
+    border-radius: 0.4em;
+    font-size: 15px; }
+    html.theme--documenter-dark .message strong {
+      color: currentColor; }
+    html.theme--documenter-dark .message a:not(.button):not(.tag):not(.dropdown-item) {
+      color: currentColor;
+      text-decoration: underline; }
+    html.theme--documenter-dark .message.is-small, html.theme--documenter-dark #documenter .docs-sidebar form.docs-search > input.message {
+      font-size: 0.85em; }
+    html.theme--documenter-dark .message.is-medium {
+      font-size: 1.25rem; }
+    html.theme--documenter-dark .message.is-large {
+      font-size: 1.5rem; }
+    html.theme--documenter-dark .message.is-white {
+      background-color: white; }
+      html.theme--documenter-dark .message.is-white .message-header {
+        background-color: white;
+        color: #0a0a0a; }
+      html.theme--documenter-dark .message.is-white .message-body {
+        border-color: white;
+        color: #4d4d4d; }
+    html.theme--documenter-dark .message.is-black {
+      background-color: #fafafa; }
+      html.theme--documenter-dark .message.is-black .message-header {
+        background-color: #0a0a0a;
+        color: white; }
+      html.theme--documenter-dark .message.is-black .message-body {
+        border-color: #0a0a0a;
+        color: #090909; }
+    html.theme--documenter-dark .message.is-light {
+      background-color: #f9fafb; }
+      html.theme--documenter-dark .message.is-light .message-header {
+        background-color: #ecf0f1;
+        color: #282f2f; }
+      html.theme--documenter-dark .message.is-light .message-body {
+        border-color: #ecf0f1;
+        color: #505050; }
+    html.theme--documenter-dark .message.is-dark, html.theme--documenter-dark .content kbd.message {
+      background-color: #f9fafa; }
+      html.theme--documenter-dark .message.is-dark .message-header, html.theme--documenter-dark .content kbd.message .message-header {
+        background-color: #282f2f;
+        color: #ecf0f1; }
+      html.theme--documenter-dark .message.is-dark .message-body, html.theme--documenter-dark .content kbd.message .message-body {
+        border-color: #282f2f;
+        color: #212526; }
+    html.theme--documenter-dark .message.is-primary, html.theme--documenter-dark .docstring > section > a.message.docs-sourcelink {
+      background-color: #f8fafc; }
+      html.theme--documenter-dark .message.is-primary .message-header, html.theme--documenter-dark .docstring > section > a.message.docs-sourcelink .message-header {
+        background-color: #375a7f;
+        color: #fff; }
+      html.theme--documenter-dark .message.is-primary .message-body, html.theme--documenter-dark .docstring > section > a.message.docs-sourcelink .message-body {
+        border-color: #375a7f;
+        color: #2b4159; }
+    html.theme--documenter-dark .message.is-link {
+      background-color: #f6fefc; }
+      html.theme--documenter-dark .message.is-link .message-header {
+        background-color: #1abc9c;
+        color: #fff; }
+      html.theme--documenter-dark .message.is-link .message-body {
+        border-color: #1abc9c;
+        color: #0b2f28; }
+    html.theme--documenter-dark .message.is-info {
+      background-color: #f5fbff; }
+      html.theme--documenter-dark .message.is-info .message-header {
+        background-color: #024c7d;
+        color: #fff; }
+      html.theme--documenter-dark .message.is-info .message-body {
+        border-color: #024c7d;
+        color: #033659; }
+    html.theme--documenter-dark .message.is-success {
+      background-color: #f5fff9; }
+      html.theme--documenter-dark .message.is-success .message-header {
+        background-color: #008438;
+        color: #fff; }
+      html.theme--documenter-dark .message.is-success .message-body {
+        border-color: #008438;
+        color: #023518; }
+    html.theme--documenter-dark .message.is-warning {
+      background-color: #fffcf5; }
+      html.theme--documenter-dark .message.is-warning .message-header {
+        background-color: #ad8100;
+        color: #fff; }
+      html.theme--documenter-dark .message.is-warning .message-body {
+        border-color: #ad8100;
+        color: #3d2e03; }
+    html.theme--documenter-dark .message.is-danger {
+      background-color: #fef6f6; }
+      html.theme--documenter-dark .message.is-danger .message-header {
+        background-color: #9e1b0d;
+        color: #fff; }
+      html.theme--documenter-dark .message.is-danger .message-body {
+        border-color: #9e1b0d;
+        color: #7a170c; }
+  html.theme--documenter-dark .message-header {
+    align-items: center;
+    background-color: #fff;
+    border-radius: 0.4em 0.4em 0 0;
+    color: rgba(0, 0, 0, 0.7);
+    display: flex;
+    font-weight: 700;
+    justify-content: space-between;
+    line-height: 1.25;
+    padding: 0.75em;
+    position: relative; }
+    html.theme--documenter-dark .message-header .delete {
+      flex-grow: 0;
+      flex-shrink: 0;
+      margin-left: 0.75em; }
+    html.theme--documenter-dark .message-header + .message-body {
+      border-width: 0;
+      border-top-left-radius: 0;
+      border-top-right-radius: 0; }
+  html.theme--documenter-dark .message-body {
+    border-color: #5e6d6f;
+    border-radius: 0.4em;
+    border-style: solid;
+    border-width: 0 0 0 4px;
+    color: #fff;
+    padding: 1em 1.25em; }
+    html.theme--documenter-dark .message-body code,
+    html.theme--documenter-dark .message-body pre {
+      background-color: white; }
+    html.theme--documenter-dark .message-body pre code {
+      background-color: transparent; }
+  html.theme--documenter-dark .modal {
+    align-items: center;
+    display: none;
+    flex-direction: column;
+    justify-content: center;
+    overflow: hidden;
+    position: fixed;
+    z-index: 40; }
+    html.theme--documenter-dark .modal.is-active {
+      display: flex; }
+  html.theme--documenter-dark .modal-background {
+    background-color: rgba(10, 10, 10, 0.86); }
+  html.theme--documenter-dark .modal-content,
+  html.theme--documenter-dark .modal-card {
+    margin: 0 20px;
+    max-height: calc(100vh - 160px);
+    overflow: auto;
+    position: relative;
+    width: 100%; }
+    @media screen and (min-width: 769px), print {
+      html.theme--documenter-dark .modal-content,
+      html.theme--documenter-dark .modal-card {
+        margin: 0 auto;
+        max-height: calc(100vh - 40px);
+        width: 640px; } }
+  html.theme--documenter-dark .modal-close {
+    background: none;
+    height: 40px;
+    position: fixed;
+    right: 20px;
+    top: 20px;
+    width: 40px; }
+  html.theme--documenter-dark .modal-card {
+    display: flex;
+    flex-direction: column;
+    max-height: calc(100vh - 40px);
+    overflow: hidden;
+    -ms-overflow-y: visible; }
+  html.theme--documenter-dark .modal-card-head,
+  html.theme--documenter-dark .modal-card-foot {
+    align-items: center;
+    background-color: #282f2f;
+    display: flex;
+    flex-shrink: 0;
+    justify-content: flex-start;
+    padding: 20px;
+    position: relative; }
+  html.theme--documenter-dark .modal-card-head {
+    border-bottom: 1px solid #5e6d6f;
+    border-top-left-radius: 8px;
+    border-top-right-radius: 8px; }
+  html.theme--documenter-dark .modal-card-title {
+    color: #f2f2f2;
+    flex-grow: 1;
+    flex-shrink: 0;
+    font-size: 1.5rem;
+    line-height: 1; }
+  html.theme--documenter-dark .modal-card-foot {
+    border-bottom-left-radius: 8px;
+    border-bottom-right-radius: 8px;
+    border-top: 1px solid #5e6d6f; }
+    html.theme--documenter-dark .modal-card-foot .button:not(:last-child) {
+      margin-right: 0.5em; }
+  html.theme--documenter-dark .modal-card-body {
+    -webkit-overflow-scrolling: touch;
+    background-color: white;
+    flex-grow: 1;
+    flex-shrink: 1;
+    overflow: auto;
+    padding: 20px; }
+  html.theme--documenter-dark .navbar {
+    background-color: #375a7f;
+    min-height: 4rem;
+    position: relative;
+    z-index: 30; }
+    html.theme--documenter-dark .navbar.is-white {
+      background-color: white;
+      color: #0a0a0a; }
+      html.theme--documenter-dark .navbar.is-white .navbar-brand > .navbar-item,
+      html.theme--documenter-dark .navbar.is-white .navbar-brand .navbar-link {
+        color: #0a0a0a; }
+      html.theme--documenter-dark .navbar.is-white .navbar-brand > a.navbar-item:focus, html.theme--documenter-dark .navbar.is-white .navbar-brand > a.navbar-item:hover, html.theme--documenter-dark .navbar.is-white .navbar-brand > a.navbar-item.is-active,
+      html.theme--documenter-dark .navbar.is-white .navbar-brand .navbar-link:focus,
+      html.theme--documenter-dark .navbar.is-white .navbar-brand .navbar-link:hover,
+      html.theme--documenter-dark .navbar.is-white .navbar-brand .navbar-link.is-active {
+        background-color: #f2f2f2;
+        color: #0a0a0a; }
+      html.theme--documenter-dark .navbar.is-white .navbar-brand .navbar-link::after {
+        border-color: #0a0a0a; }
+      html.theme--documenter-dark .navbar.is-white .navbar-burger {
+        color: #0a0a0a; }
+      @media screen and (min-width: 1056px) {
+        html.theme--documenter-dark .navbar.is-white .navbar-start > .navbar-item,
+        html.theme--documenter-dark .navbar.is-white .navbar-start .navbar-link,
+        html.theme--documenter-dark .navbar.is-white .navbar-end > .navbar-item,
+        html.theme--documenter-dark .navbar.is-white .navbar-end .navbar-link {
+          color: #0a0a0a; }
+        html.theme--documenter-dark .navbar.is-white .navbar-start > a.navbar-item:focus, html.theme--documenter-dark .navbar.is-white .navbar-start > a.navbar-item:hover, html.theme--documenter-dark .navbar.is-white .navbar-start > a.navbar-item.is-active,
+        html.theme--documenter-dark .navbar.is-white .navbar-start .navbar-link:focus,
+        html.theme--documenter-dark .navbar.is-white .navbar-start .navbar-link:hover,
+        html.theme--documenter-dark .navbar.is-white .navbar-start .navbar-link.is-active,
+        html.theme--documenter-dark .navbar.is-white .navbar-end > a.navbar-item:focus,
+        html.theme--documenter-dark .navbar.is-white .navbar-end > a.navbar-item:hover,
+        html.theme--documenter-dark .navbar.is-white .navbar-end > a.navbar-item.is-active,
+        html.theme--documenter-dark .navbar.is-white .navbar-end .navbar-link:focus,
+        html.theme--documenter-dark .navbar.is-white .navbar-end .navbar-link:hover,
+        html.theme--documenter-dark .navbar.is-white .navbar-end .navbar-link.is-active {
+          background-color: #f2f2f2;
+          color: #0a0a0a; }
+        html.theme--documenter-dark .navbar.is-white .navbar-start .navbar-link::after,
+        html.theme--documenter-dark .navbar.is-white .navbar-end .navbar-link::after {
+          border-color: #0a0a0a; }
+        html.theme--documenter-dark .navbar.is-white .navbar-item.has-dropdown:focus .navbar-link,
+        html.theme--documenter-dark .navbar.is-white .navbar-item.has-dropdown:hover .navbar-link,
+        html.theme--documenter-dark .navbar.is-white .navbar-item.has-dropdown.is-active .navbar-link {
+          background-color: #f2f2f2;
+          color: #0a0a0a; }
+        html.theme--documenter-dark .navbar.is-white .navbar-dropdown a.navbar-item.is-active {
+          background-color: white;
+          color: #0a0a0a; } }
+    html.theme--documenter-dark .navbar.is-black {
+      background-color: #0a0a0a;
+      color: white; }
+      html.theme--documenter-dark .navbar.is-black .navbar-brand > .navbar-item,
+      html.theme--documenter-dark .navbar.is-black .navbar-brand .navbar-link {
+        color: white; }
+      html.theme--documenter-dark .navbar.is-black .navbar-brand > a.navbar-item:focus, html.theme--documenter-dark .navbar.is-black .navbar-brand > a.navbar-item:hover, html.theme--documenter-dark .navbar.is-black .navbar-brand > a.navbar-item.is-active,
+      html.theme--documenter-dark .navbar.is-black .navbar-brand .navbar-link:focus,
+      html.theme--documenter-dark .navbar.is-black .navbar-brand .navbar-link:hover,
+      html.theme--documenter-dark .navbar.is-black .navbar-brand .navbar-link.is-active {
+        background-color: black;
+        color: white; }
+      html.theme--documenter-dark .navbar.is-black .navbar-brand .navbar-link::after {
+        border-color: white; }
+      html.theme--documenter-dark .navbar.is-black .navbar-burger {
+        color: white; }
+      @media screen and (min-width: 1056px) {
+        html.theme--documenter-dark .navbar.is-black .navbar-start > .navbar-item,
+        html.theme--documenter-dark .navbar.is-black .navbar-start .navbar-link,
+        html.theme--documenter-dark .navbar.is-black .navbar-end > .navbar-item,
+        html.theme--documenter-dark .navbar.is-black .navbar-end .navbar-link {
+          color: white; }
+        html.theme--documenter-dark .navbar.is-black .navbar-start > a.navbar-item:focus, html.theme--documenter-dark .navbar.is-black .navbar-start > a.navbar-item:hover, html.theme--documenter-dark .navbar.is-black .navbar-start > a.navbar-item.is-active,
+        html.theme--documenter-dark .navbar.is-black .navbar-start .navbar-link:focus,
+        html.theme--documenter-dark .navbar.is-black .navbar-start .navbar-link:hover,
+        html.theme--documenter-dark .navbar.is-black .navbar-start .navbar-link.is-active,
+        html.theme--documenter-dark .navbar.is-black .navbar-end > a.navbar-item:focus,
+        html.theme--documenter-dark .navbar.is-black .navbar-end > a.navbar-item:hover,
+        html.theme--documenter-dark .navbar.is-black .navbar-end > a.navbar-item.is-active,
+        html.theme--documenter-dark .navbar.is-black .navbar-end .navbar-link:focus,
+        html.theme--documenter-dark .navbar.is-black .navbar-end .navbar-link:hover,
+        html.theme--documenter-dark .navbar.is-black .navbar-end .navbar-link.is-active {
+          background-color: black;
+          color: white; }
+        html.theme--documenter-dark .navbar.is-black .navbar-start .navbar-link::after,
+        html.theme--documenter-dark .navbar.is-black .navbar-end .navbar-link::after {
+          border-color: white; }
+        html.theme--documenter-dark .navbar.is-black .navbar-item.has-dropdown:focus .navbar-link,
+        html.theme--documenter-dark .navbar.is-black .navbar-item.has-dropdown:hover .navbar-link,
+        html.theme--documenter-dark .navbar.is-black .navbar-item.has-dropdown.is-active .navbar-link {
+          background-color: black;
+          color: white; }
+        html.theme--documenter-dark .navbar.is-black .navbar-dropdown a.navbar-item.is-active {
+          background-color: #0a0a0a;
+          color: white; } }
+    html.theme--documenter-dark .navbar.is-light {
+      background-color: #ecf0f1;
+      color: #282f2f; }
+      html.theme--documenter-dark .navbar.is-light .navbar-brand > .navbar-item,
+      html.theme--documenter-dark .navbar.is-light .navbar-brand .navbar-link {
+        color: #282f2f; }
+      html.theme--documenter-dark .navbar.is-light .navbar-brand > a.navbar-item:focus, html.theme--documenter-dark .navbar.is-light .navbar-brand > a.navbar-item:hover, html.theme--documenter-dark .navbar.is-light .navbar-brand > a.navbar-item.is-active,
+      html.theme--documenter-dark .navbar.is-light .navbar-brand .navbar-link:focus,
+      html.theme--documenter-dark .navbar.is-light .navbar-brand .navbar-link:hover,
+      html.theme--documenter-dark .navbar.is-light .navbar-brand .navbar-link.is-active {
+        background-color: #dde4e6;
+        color: #282f2f; }
+      html.theme--documenter-dark .navbar.is-light .navbar-brand .navbar-link::after {
+        border-color: #282f2f; }
+      html.theme--documenter-dark .navbar.is-light .navbar-burger {
+        color: #282f2f; }
+      @media screen and (min-width: 1056px) {
+        html.theme--documenter-dark .navbar.is-light .navbar-start > .navbar-item,
+        html.theme--documenter-dark .navbar.is-light .navbar-start .navbar-link,
+        html.theme--documenter-dark .navbar.is-light .navbar-end > .navbar-item,
+        html.theme--documenter-dark .navbar.is-light .navbar-end .navbar-link {
+          color: #282f2f; }
+        html.theme--documenter-dark .navbar.is-light .navbar-start > a.navbar-item:focus, html.theme--documenter-dark .navbar.is-light .navbar-start > a.navbar-item:hover, html.theme--documenter-dark .navbar.is-light .navbar-start > a.navbar-item.is-active,
+        html.theme--documenter-dark .navbar.is-light .navbar-start .navbar-link:focus,
+        html.theme--documenter-dark .navbar.is-light .navbar-start .navbar-link:hover,
+        html.theme--documenter-dark .navbar.is-light .navbar-start .navbar-link.is-active,
+        html.theme--documenter-dark .navbar.is-light .navbar-end > a.navbar-item:focus,
+        html.theme--documenter-dark .navbar.is-light .navbar-end > a.navbar-item:hover,
+        html.theme--documenter-dark .navbar.is-light .navbar-end > a.navbar-item.is-active,
+        html.theme--documenter-dark .navbar.is-light .navbar-end .navbar-link:focus,
+        html.theme--documenter-dark .navbar.is-light .navbar-end .navbar-link:hover,
+        html.theme--documenter-dark .navbar.is-light .navbar-end .navbar-link.is-active {
+          background-color: #dde4e6;
+          color: #282f2f; }
+        html.theme--documenter-dark .navbar.is-light .navbar-start .navbar-link::after,
+        html.theme--documenter-dark .navbar.is-light .navbar-end .navbar-link::after {
+          border-color: #282f2f; }
+        html.theme--documenter-dark .navbar.is-light .navbar-item.has-dropdown:focus .navbar-link,
+        html.theme--documenter-dark .navbar.is-light .navbar-item.has-dropdown:hover .navbar-link,
+        html.theme--documenter-dark .navbar.is-light .navbar-item.has-dropdown.is-active .navbar-link {
+          background-color: #dde4e6;
+          color: #282f2f; }
+        html.theme--documenter-dark .navbar.is-light .navbar-dropdown a.navbar-item.is-active {
+          background-color: #ecf0f1;
+          color: #282f2f; } }
+    html.theme--documenter-dark .navbar.is-dark, html.theme--documenter-dark .content kbd.navbar {
+      background-color: #282f2f;
+      color: #ecf0f1; }
+      html.theme--documenter-dark .navbar.is-dark .navbar-brand > .navbar-item, html.theme--documenter-dark .content kbd.navbar .navbar-brand > .navbar-item,
+      html.theme--documenter-dark .navbar.is-dark .navbar-brand .navbar-link,
+      html.theme--documenter-dark .content kbd.navbar .navbar-brand .navbar-link {
+        color: #ecf0f1; }
+      html.theme--documenter-dark .navbar.is-dark .navbar-brand > a.navbar-item:focus, html.theme--documenter-dark .content kbd.navbar .navbar-brand > a.navbar-item:focus, html.theme--documenter-dark .navbar.is-dark .navbar-brand > a.navbar-item:hover, html.theme--documenter-dark .content kbd.navbar .navbar-brand > a.navbar-item:hover, html.theme--documenter-dark .navbar.is-dark .navbar-brand > a.navbar-item.is-active, html.theme--documenter-dark .content kbd.navbar .navbar-brand > a.navbar-item.is-active,
+      html.theme--documenter-dark .navbar.is-dark .navbar-brand .navbar-link:focus,
+      html.theme--documenter-dark .content kbd.navbar .navbar-brand .navbar-link:focus,
+      html.theme--documenter-dark .navbar.is-dark .navbar-brand .navbar-link:hover,
+      html.theme--documenter-dark .content kbd.navbar .navbar-brand .navbar-link:hover,
+      html.theme--documenter-dark .navbar.is-dark .navbar-brand .navbar-link.is-active,
+      html.theme--documenter-dark .content kbd.navbar .navbar-brand .navbar-link.is-active {
+        background-color: #1d2122;
+        color: #ecf0f1; }
+      html.theme--documenter-dark .navbar.is-dark .navbar-brand .navbar-link::after, html.theme--documenter-dark .content kbd.navbar .navbar-brand .navbar-link::after {
+        border-color: #ecf0f1; }
+      html.theme--documenter-dark .navbar.is-dark .navbar-burger, html.theme--documenter-dark .content kbd.navbar .navbar-burger {
+        color: #ecf0f1; }
+      @media screen and (min-width: 1056px) {
+        html.theme--documenter-dark .navbar.is-dark .navbar-start > .navbar-item, html.theme--documenter-dark .content kbd.navbar .navbar-start > .navbar-item,
+        html.theme--documenter-dark .navbar.is-dark .navbar-start .navbar-link,
+        html.theme--documenter-dark .content kbd.navbar .navbar-start .navbar-link,
+        html.theme--documenter-dark .navbar.is-dark .navbar-end > .navbar-item,
+        html.theme--documenter-dark .content kbd.navbar .navbar-end > .navbar-item,
+        html.theme--documenter-dark .navbar.is-dark .navbar-end .navbar-link,
+        html.theme--documenter-dark .content kbd.navbar .navbar-end .navbar-link {
+          color: #ecf0f1; }
+        html.theme--documenter-dark .navbar.is-dark .navbar-start > a.navbar-item:focus, html.theme--documenter-dark .content kbd.navbar .navbar-start > a.navbar-item:focus, html.theme--documenter-dark .navbar.is-dark .navbar-start > a.navbar-item:hover, html.theme--documenter-dark .content kbd.navbar .navbar-start > a.navbar-item:hover, html.theme--documenter-dark .navbar.is-dark .navbar-start > a.navbar-item.is-active, html.theme--documenter-dark .content kbd.navbar .navbar-start > a.navbar-item.is-active,
+        html.theme--documenter-dark .navbar.is-dark .navbar-start .navbar-link:focus,
+        html.theme--documenter-dark .content kbd.navbar .navbar-start .navbar-link:focus,
+        html.theme--documenter-dark .navbar.is-dark .navbar-start .navbar-link:hover,
+        html.theme--documenter-dark .content kbd.navbar .navbar-start .navbar-link:hover,
+        html.theme--documenter-dark .navbar.is-dark .navbar-start .navbar-link.is-active,
+        html.theme--documenter-dark .content kbd.navbar .navbar-start .navbar-link.is-active,
+        html.theme--documenter-dark .navbar.is-dark .navbar-end > a.navbar-item:focus,
+        html.theme--documenter-dark .content kbd.navbar .navbar-end > a.navbar-item:focus,
+        html.theme--documenter-dark .navbar.is-dark .navbar-end > a.navbar-item:hover,
+        html.theme--documenter-dark .content kbd.navbar .navbar-end > a.navbar-item:hover,
+        html.theme--documenter-dark .navbar.is-dark .navbar-end > a.navbar-item.is-active,
+        html.theme--documenter-dark .content kbd.navbar .navbar-end > a.navbar-item.is-active,
+        html.theme--documenter-dark .navbar.is-dark .navbar-end .navbar-link:focus,
+        html.theme--documenter-dark .content kbd.navbar .navbar-end .navbar-link:focus,
+        html.theme--documenter-dark .navbar.is-dark .navbar-end .navbar-link:hover,
+        html.theme--documenter-dark .content kbd.navbar .navbar-end .navbar-link:hover,
+        html.theme--documenter-dark .navbar.is-dark .navbar-end .navbar-link.is-active,
+        html.theme--documenter-dark .content kbd.navbar .navbar-end .navbar-link.is-active {
+          background-color: #1d2122;
+          color: #ecf0f1; }
+        html.theme--documenter-dark .navbar.is-dark .navbar-start .navbar-link::after, html.theme--documenter-dark .content kbd.navbar .navbar-start .navbar-link::after,
+        html.theme--documenter-dark .navbar.is-dark .navbar-end .navbar-link::after,
+        html.theme--documenter-dark .content kbd.navbar .navbar-end .navbar-link::after {
+          border-color: #ecf0f1; }
+        html.theme--documenter-dark .navbar.is-dark .navbar-item.has-dropdown:focus .navbar-link, html.theme--documenter-dark .content kbd.navbar .navbar-item.has-dropdown:focus .navbar-link,
+        html.theme--documenter-dark .navbar.is-dark .navbar-item.has-dropdown:hover .navbar-link,
+        html.theme--documenter-dark .content kbd.navbar .navbar-item.has-dropdown:hover .navbar-link,
+        html.theme--documenter-dark .navbar.is-dark .navbar-item.has-dropdown.is-active .navbar-link,
+        html.theme--documenter-dark .content kbd.navbar .navbar-item.has-dropdown.is-active .navbar-link {
+          background-color: #1d2122;
+          color: #ecf0f1; }
+        html.theme--documenter-dark .navbar.is-dark .navbar-dropdown a.navbar-item.is-active, html.theme--documenter-dark .content kbd.navbar .navbar-dropdown a.navbar-item.is-active {
+          background-color: #282f2f;
+          color: #ecf0f1; } }
+    html.theme--documenter-dark .navbar.is-primary, html.theme--documenter-dark .docstring > section > a.navbar.docs-sourcelink {
+      background-color: #375a7f;
+      color: #fff; }
+      html.theme--documenter-dark .navbar.is-primary .navbar-brand > .navbar-item, html.theme--documenter-dark .docstring > section > a.navbar.docs-sourcelink .navbar-brand > .navbar-item,
+      html.theme--documenter-dark .navbar.is-primary .navbar-brand .navbar-link,
+      html.theme--documenter-dark .docstring > section > a.navbar.docs-sourcelink .navbar-brand .navbar-link {
+        color: #fff; }
+      html.theme--documenter-dark .navbar.is-primary .navbar-brand > a.navbar-item:focus, html.theme--documenter-dark .docstring > section > a.navbar.docs-sourcelink .navbar-brand > a.navbar-item:focus, html.theme--documenter-dark .navbar.is-primary .navbar-brand > a.navbar-item:hover, html.theme--documenter-dark .docstring > section > a.navbar.docs-sourcelink .navbar-brand > a.navbar-item:hover, html.theme--documenter-dark .navbar.is-primary .navbar-brand > a.navbar-item.is-active, html.theme--documenter-dark .docstring > section > a.navbar.docs-sourcelink .navbar-brand > a.navbar-item.is-active,
+      html.theme--documenter-dark .navbar.is-primary .navbar-brand .navbar-link:focus,
+      html.theme--documenter-dark .docstring > section > a.navbar.docs-sourcelink .navbar-brand .navbar-link:focus,
+      html.theme--documenter-dark .navbar.is-primary .navbar-brand .navbar-link:hover,
+      html.theme--documenter-dark .docstring > section > a.navbar.docs-sourcelink .navbar-brand .navbar-link:hover,
+      html.theme--documenter-dark .navbar.is-primary .navbar-brand .navbar-link.is-active,
+      html.theme--documenter-dark .docstring > section > a.navbar.docs-sourcelink .navbar-brand .navbar-link.is-active {
+        background-color: #2f4d6d;
+        color: #fff; }
+      html.theme--documenter-dark .navbar.is-primary .navbar-brand .navbar-link::after, html.theme--documenter-dark .docstring > section > a.navbar.docs-sourcelink .navbar-brand .navbar-link::after {
+        border-color: #fff; }
+      html.theme--documenter-dark .navbar.is-primary .navbar-burger, html.theme--documenter-dark .docstring > section > a.navbar.docs-sourcelink .navbar-burger {
+        color: #fff; }
+      @media screen and (min-width: 1056px) {
+        html.theme--documenter-dark .navbar.is-primary .navbar-start > .navbar-item, html.theme--documenter-dark .docstring > section > a.navbar.docs-sourcelink .navbar-start > .navbar-item,
+        html.theme--documenter-dark .navbar.is-primary .navbar-start .navbar-link,
+        html.theme--documenter-dark .docstring > section > a.navbar.docs-sourcelink .navbar-start .navbar-link,
+        html.theme--documenter-dark .navbar.is-primary .navbar-end > .navbar-item,
+        html.theme--documenter-dark .docstring > section > a.navbar.docs-sourcelink .navbar-end > .navbar-item,
+        html.theme--documenter-dark .navbar.is-primary .navbar-end .navbar-link,
+        html.theme--documenter-dark .docstring > section > a.navbar.docs-sourcelink .navbar-end .navbar-link {
+          color: #fff; }
+        html.theme--documenter-dark .navbar.is-primary .navbar-start > a.navbar-item:focus, html.theme--documenter-dark .docstring > section > a.navbar.docs-sourcelink .navbar-start > a.navbar-item:focus, html.theme--documenter-dark .navbar.is-primary .navbar-start > a.navbar-item:hover, html.theme--documenter-dark .docstring > section > a.navbar.docs-sourcelink .navbar-start > a.navbar-item:hover, html.theme--documenter-dark .navbar.is-primary .navbar-start > a.navbar-item.is-active, html.theme--documenter-dark .docstring > section > a.navbar.docs-sourcelink .navbar-start > a.navbar-item.is-active,
+        html.theme--documenter-dark .navbar.is-primary .navbar-start .navbar-link:focus,
+        html.theme--documenter-dark .docstring > section > a.navbar.docs-sourcelink .navbar-start .navbar-link:focus,
+        html.theme--documenter-dark .navbar.is-primary .navbar-start .navbar-link:hover,
+        html.theme--documenter-dark .docstring > section > a.navbar.docs-sourcelink .navbar-start .navbar-link:hover,
+        html.theme--documenter-dark .navbar.is-primary .navbar-start .navbar-link.is-active,
+        html.theme--documenter-dark .docstring > section > a.navbar.docs-sourcelink .navbar-start .navbar-link.is-active,
+        html.theme--documenter-dark .navbar.is-primary .navbar-end > a.navbar-item:focus,
+        html.theme--documenter-dark .docstring > section > a.navbar.docs-sourcelink .navbar-end > a.navbar-item:focus,
+        html.theme--documenter-dark .navbar.is-primary .navbar-end > a.navbar-item:hover,
+        html.theme--documenter-dark .docstring > section > a.navbar.docs-sourcelink .navbar-end > a.navbar-item:hover,
+        html.theme--documenter-dark .navbar.is-primary .navbar-end > a.navbar-item.is-active,
+        html.theme--documenter-dark .docstring > section > a.navbar.docs-sourcelink .navbar-end > a.navbar-item.is-active,
+        html.theme--documenter-dark .navbar.is-primary .navbar-end .navbar-link:focus,
+        html.theme--documenter-dark .docstring > section > a.navbar.docs-sourcelink .navbar-end .navbar-link:focus,
+        html.theme--documenter-dark .navbar.is-primary .navbar-end .navbar-link:hover,
+        html.theme--documenter-dark .docstring > section > a.navbar.docs-sourcelink .navbar-end .navbar-link:hover,
+        html.theme--documenter-dark .navbar.is-primary .navbar-end .navbar-link.is-active,
+        html.theme--documenter-dark .docstring > section > a.navbar.docs-sourcelink .navbar-end .navbar-link.is-active {
+          background-color: #2f4d6d;
+          color: #fff; }
+        html.theme--documenter-dark .navbar.is-primary .navbar-start .navbar-link::after, html.theme--documenter-dark .docstring > section > a.navbar.docs-sourcelink .navbar-start .navbar-link::after,
+        html.theme--documenter-dark .navbar.is-primary .navbar-end .navbar-link::after,
+        html.theme--documenter-dark .docstring > section > a.navbar.docs-sourcelink .navbar-end .navbar-link::after {
+          border-color: #fff; }
+        html.theme--documenter-dark .navbar.is-primary .navbar-item.has-dropdown:focus .navbar-link, html.theme--documenter-dark .docstring > section > a.navbar.docs-sourcelink .navbar-item.has-dropdown:focus .navbar-link,
+        html.theme--documenter-dark .navbar.is-primary .navbar-item.has-dropdown:hover .navbar-link,
+        html.theme--documenter-dark .docstring > section > a.navbar.docs-sourcelink .navbar-item.has-dropdown:hover .navbar-link,
+        html.theme--documenter-dark .navbar.is-primary .navbar-item.has-dropdown.is-active .navbar-link,
+        html.theme--documenter-dark .docstring > section > a.navbar.docs-sourcelink .navbar-item.has-dropdown.is-active .navbar-link {
+          background-color: #2f4d6d;
+          color: #fff; }
+        html.theme--documenter-dark .navbar.is-primary .navbar-dropdown a.navbar-item.is-active, html.theme--documenter-dark .docstring > section > a.navbar.docs-sourcelink .navbar-dropdown a.navbar-item.is-active {
+          background-color: #375a7f;
+          color: #fff; } }
+    html.theme--documenter-dark .navbar.is-link {
+      background-color: #1abc9c;
+      color: #fff; }
+      html.theme--documenter-dark .navbar.is-link .navbar-brand > .navbar-item,
+      html.theme--documenter-dark .navbar.is-link .navbar-brand .navbar-link {
+        color: #fff; }
+      html.theme--documenter-dark .navbar.is-link .navbar-brand > a.navbar-item:focus, html.theme--documenter-dark .navbar.is-link .navbar-brand > a.navbar-item:hover, html.theme--documenter-dark .navbar.is-link .navbar-brand > a.navbar-item.is-active,
+      html.theme--documenter-dark .navbar.is-link .navbar-brand .navbar-link:focus,
+      html.theme--documenter-dark .navbar.is-link .navbar-brand .navbar-link:hover,
+      html.theme--documenter-dark .navbar.is-link .navbar-brand .navbar-link.is-active {
+        background-color: #17a689;
+        color: #fff; }
+      html.theme--documenter-dark .navbar.is-link .navbar-brand .navbar-link::after {
+        border-color: #fff; }
+      html.theme--documenter-dark .navbar.is-link .navbar-burger {
+        color: #fff; }
+      @media screen and (min-width: 1056px) {
+        html.theme--documenter-dark .navbar.is-link .navbar-start > .navbar-item,
+        html.theme--documenter-dark .navbar.is-link .navbar-start .navbar-link,
+        html.theme--documenter-dark .navbar.is-link .navbar-end > .navbar-item,
+        html.theme--documenter-dark .navbar.is-link .navbar-end .navbar-link {
+          color: #fff; }
+        html.theme--documenter-dark .navbar.is-link .navbar-start > a.navbar-item:focus, html.theme--documenter-dark .navbar.is-link .navbar-start > a.navbar-item:hover, html.theme--documenter-dark .navbar.is-link .navbar-start > a.navbar-item.is-active,
+        html.theme--documenter-dark .navbar.is-link .navbar-start .navbar-link:focus,
+        html.theme--documenter-dark .navbar.is-link .navbar-start .navbar-link:hover,
+        html.theme--documenter-dark .navbar.is-link .navbar-start .navbar-link.is-active,
+        html.theme--documenter-dark .navbar.is-link .navbar-end > a.navbar-item:focus,
+        html.theme--documenter-dark .navbar.is-link .navbar-end > a.navbar-item:hover,
+        html.theme--documenter-dark .navbar.is-link .navbar-end > a.navbar-item.is-active,
+        html.theme--documenter-dark .navbar.is-link .navbar-end .navbar-link:focus,
+        html.theme--documenter-dark .navbar.is-link .navbar-end .navbar-link:hover,
+        html.theme--documenter-dark .navbar.is-link .navbar-end .navbar-link.is-active {
+          background-color: #17a689;
+          color: #fff; }
+        html.theme--documenter-dark .navbar.is-link .navbar-start .navbar-link::after,
+        html.theme--documenter-dark .navbar.is-link .navbar-end .navbar-link::after {
+          border-color: #fff; }
+        html.theme--documenter-dark .navbar.is-link .navbar-item.has-dropdown:focus .navbar-link,
+        html.theme--documenter-dark .navbar.is-link .navbar-item.has-dropdown:hover .navbar-link,
+        html.theme--documenter-dark .navbar.is-link .navbar-item.has-dropdown.is-active .navbar-link {
+          background-color: #17a689;
+          color: #fff; }
+        html.theme--documenter-dark .navbar.is-link .navbar-dropdown a.navbar-item.is-active {
+          background-color: #1abc9c;
+          color: #fff; } }
+    html.theme--documenter-dark .navbar.is-info {
+      background-color: #024c7d;
+      color: #fff; }
+      html.theme--documenter-dark .navbar.is-info .navbar-brand > .navbar-item,
+      html.theme--documenter-dark .navbar.is-info .navbar-brand .navbar-link {
+        color: #fff; }
+      html.theme--documenter-dark .navbar.is-info .navbar-brand > a.navbar-item:focus, html.theme--documenter-dark .navbar.is-info .navbar-brand > a.navbar-item:hover, html.theme--documenter-dark .navbar.is-info .navbar-brand > a.navbar-item.is-active,
+      html.theme--documenter-dark .navbar.is-info .navbar-brand .navbar-link:focus,
+      html.theme--documenter-dark .navbar.is-info .navbar-brand .navbar-link:hover,
+      html.theme--documenter-dark .navbar.is-info .navbar-brand .navbar-link.is-active {
+        background-color: #023d64;
+        color: #fff; }
+      html.theme--documenter-dark .navbar.is-info .navbar-brand .navbar-link::after {
+        border-color: #fff; }
+      html.theme--documenter-dark .navbar.is-info .navbar-burger {
+        color: #fff; }
+      @media screen and (min-width: 1056px) {
+        html.theme--documenter-dark .navbar.is-info .navbar-start > .navbar-item,
+        html.theme--documenter-dark .navbar.is-info .navbar-start .navbar-link,
+        html.theme--documenter-dark .navbar.is-info .navbar-end > .navbar-item,
+        html.theme--documenter-dark .navbar.is-info .navbar-end .navbar-link {
+          color: #fff; }
+        html.theme--documenter-dark .navbar.is-info .navbar-start > a.navbar-item:focus, html.theme--documenter-dark .navbar.is-info .navbar-start > a.navbar-item:hover, html.theme--documenter-dark .navbar.is-info .navbar-start > a.navbar-item.is-active,
+        html.theme--documenter-dark .navbar.is-info .navbar-start .navbar-link:focus,
+        html.theme--documenter-dark .navbar.is-info .navbar-start .navbar-link:hover,
+        html.theme--documenter-dark .navbar.is-info .navbar-start .navbar-link.is-active,
+        html.theme--documenter-dark .navbar.is-info .navbar-end > a.navbar-item:focus,
+        html.theme--documenter-dark .navbar.is-info .navbar-end > a.navbar-item:hover,
+        html.theme--documenter-dark .navbar.is-info .navbar-end > a.navbar-item.is-active,
+        html.theme--documenter-dark .navbar.is-info .navbar-end .navbar-link:focus,
+        html.theme--documenter-dark .navbar.is-info .navbar-end .navbar-link:hover,
+        html.theme--documenter-dark .navbar.is-info .navbar-end .navbar-link.is-active {
+          background-color: #023d64;
+          color: #fff; }
+        html.theme--documenter-dark .navbar.is-info .navbar-start .navbar-link::after,
+        html.theme--documenter-dark .navbar.is-info .navbar-end .navbar-link::after {
+          border-color: #fff; }
+        html.theme--documenter-dark .navbar.is-info .navbar-item.has-dropdown:focus .navbar-link,
+        html.theme--documenter-dark .navbar.is-info .navbar-item.has-dropdown:hover .navbar-link,
+        html.theme--documenter-dark .navbar.is-info .navbar-item.has-dropdown.is-active .navbar-link {
+          background-color: #023d64;
+          color: #fff; }
+        html.theme--documenter-dark .navbar.is-info .navbar-dropdown a.navbar-item.is-active {
+          background-color: #024c7d;
+          color: #fff; } }
+    html.theme--documenter-dark .navbar.is-success {
+      background-color: #008438;
+      color: #fff; }
+      html.theme--documenter-dark .navbar.is-success .navbar-brand > .navbar-item,
+      html.theme--documenter-dark .navbar.is-success .navbar-brand .navbar-link {
+        color: #fff; }
+      html.theme--documenter-dark .navbar.is-success .navbar-brand > a.navbar-item:focus, html.theme--documenter-dark .navbar.is-success .navbar-brand > a.navbar-item:hover, html.theme--documenter-dark .navbar.is-success .navbar-brand > a.navbar-item.is-active,
+      html.theme--documenter-dark .navbar.is-success .navbar-brand .navbar-link:focus,
+      html.theme--documenter-dark .navbar.is-success .navbar-brand .navbar-link:hover,
+      html.theme--documenter-dark .navbar.is-success .navbar-brand .navbar-link.is-active {
+        background-color: #006b2d;
+        color: #fff; }
+      html.theme--documenter-dark .navbar.is-success .navbar-brand .navbar-link::after {
+        border-color: #fff; }
+      html.theme--documenter-dark .navbar.is-success .navbar-burger {
+        color: #fff; }
+      @media screen and (min-width: 1056px) {
+        html.theme--documenter-dark .navbar.is-success .navbar-start > .navbar-item,
+        html.theme--documenter-dark .navbar.is-success .navbar-start .navbar-link,
+        html.theme--documenter-dark .navbar.is-success .navbar-end > .navbar-item,
+        html.theme--documenter-dark .navbar.is-success .navbar-end .navbar-link {
+          color: #fff; }
+        html.theme--documenter-dark .navbar.is-success .navbar-start > a.navbar-item:focus, html.theme--documenter-dark .navbar.is-success .navbar-start > a.navbar-item:hover, html.theme--documenter-dark .navbar.is-success .navbar-start > a.navbar-item.is-active,
+        html.theme--documenter-dark .navbar.is-success .navbar-start .navbar-link:focus,
+        html.theme--documenter-dark .navbar.is-success .navbar-start .navbar-link:hover,
+        html.theme--documenter-dark .navbar.is-success .navbar-start .navbar-link.is-active,
+        html.theme--documenter-dark .navbar.is-success .navbar-end > a.navbar-item:focus,
+        html.theme--documenter-dark .navbar.is-success .navbar-end > a.navbar-item:hover,
+        html.theme--documenter-dark .navbar.is-success .navbar-end > a.navbar-item.is-active,
+        html.theme--documenter-dark .navbar.is-success .navbar-end .navbar-link:focus,
+        html.theme--documenter-dark .navbar.is-success .navbar-end .navbar-link:hover,
+        html.theme--documenter-dark .navbar.is-success .navbar-end .navbar-link.is-active {
+          background-color: #006b2d;
+          color: #fff; }
+        html.theme--documenter-dark .navbar.is-success .navbar-start .navbar-link::after,
+        html.theme--documenter-dark .navbar.is-success .navbar-end .navbar-link::after {
+          border-color: #fff; }
+        html.theme--documenter-dark .navbar.is-success .navbar-item.has-dropdown:focus .navbar-link,
+        html.theme--documenter-dark .navbar.is-success .navbar-item.has-dropdown:hover .navbar-link,
+        html.theme--documenter-dark .navbar.is-success .navbar-item.has-dropdown.is-active .navbar-link {
+          background-color: #006b2d;
+          color: #fff; }
+        html.theme--documenter-dark .navbar.is-success .navbar-dropdown a.navbar-item.is-active {
+          background-color: #008438;
+          color: #fff; } }
+    html.theme--documenter-dark .navbar.is-warning {
+      background-color: #ad8100;
+      color: #fff; }
+      html.theme--documenter-dark .navbar.is-warning .navbar-brand > .navbar-item,
+      html.theme--documenter-dark .navbar.is-warning .navbar-brand .navbar-link {
+        color: #fff; }
+      html.theme--documenter-dark .navbar.is-warning .navbar-brand > a.navbar-item:focus, html.theme--documenter-dark .navbar.is-warning .navbar-brand > a.navbar-item:hover, html.theme--documenter-dark .navbar.is-warning .navbar-brand > a.navbar-item.is-active,
+      html.theme--documenter-dark .navbar.is-warning .navbar-brand .navbar-link:focus,
+      html.theme--documenter-dark .navbar.is-warning .navbar-brand .navbar-link:hover,
+      html.theme--documenter-dark .navbar.is-warning .navbar-brand .navbar-link.is-active {
+        background-color: #946e00;
+        color: #fff; }
+      html.theme--documenter-dark .navbar.is-warning .navbar-brand .navbar-link::after {
+        border-color: #fff; }
+      html.theme--documenter-dark .navbar.is-warning .navbar-burger {
+        color: #fff; }
+      @media screen and (min-width: 1056px) {
+        html.theme--documenter-dark .navbar.is-warning .navbar-start > .navbar-item,
+        html.theme--documenter-dark .navbar.is-warning .navbar-start .navbar-link,
+        html.theme--documenter-dark .navbar.is-warning .navbar-end > .navbar-item,
+        html.theme--documenter-dark .navbar.is-warning .navbar-end .navbar-link {
+          color: #fff; }
+        html.theme--documenter-dark .navbar.is-warning .navbar-start > a.navbar-item:focus, html.theme--documenter-dark .navbar.is-warning .navbar-start > a.navbar-item:hover, html.theme--documenter-dark .navbar.is-warning .navbar-start > a.navbar-item.is-active,
+        html.theme--documenter-dark .navbar.is-warning .navbar-start .navbar-link:focus,
+        html.theme--documenter-dark .navbar.is-warning .navbar-start .navbar-link:hover,
+        html.theme--documenter-dark .navbar.is-warning .navbar-start .navbar-link.is-active,
+        html.theme--documenter-dark .navbar.is-warning .navbar-end > a.navbar-item:focus,
+        html.theme--documenter-dark .navbar.is-warning .navbar-end > a.navbar-item:hover,
+        html.theme--documenter-dark .navbar.is-warning .navbar-end > a.navbar-item.is-active,
+        html.theme--documenter-dark .navbar.is-warning .navbar-end .navbar-link:focus,
+        html.theme--documenter-dark .navbar.is-warning .navbar-end .navbar-link:hover,
+        html.theme--documenter-dark .navbar.is-warning .navbar-end .navbar-link.is-active {
+          background-color: #946e00;
+          color: #fff; }
+        html.theme--documenter-dark .navbar.is-warning .navbar-start .navbar-link::after,
+        html.theme--documenter-dark .navbar.is-warning .navbar-end .navbar-link::after {
+          border-color: #fff; }
+        html.theme--documenter-dark .navbar.is-warning .navbar-item.has-dropdown:focus .navbar-link,
+        html.theme--documenter-dark .navbar.is-warning .navbar-item.has-dropdown:hover .navbar-link,
+        html.theme--documenter-dark .navbar.is-warning .navbar-item.has-dropdown.is-active .navbar-link {
+          background-color: #946e00;
+          color: #fff; }
+        html.theme--documenter-dark .navbar.is-warning .navbar-dropdown a.navbar-item.is-active {
+          background-color: #ad8100;
+          color: #fff; } }
+    html.theme--documenter-dark .navbar.is-danger {
+      background-color: #9e1b0d;
+      color: #fff; }
+      html.theme--documenter-dark .navbar.is-danger .navbar-brand > .navbar-item,
+      html.theme--documenter-dark .navbar.is-danger .navbar-brand .navbar-link {
+        color: #fff; }
+      html.theme--documenter-dark .navbar.is-danger .navbar-brand > a.navbar-item:focus, html.theme--documenter-dark .navbar.is-danger .navbar-brand > a.navbar-item:hover, html.theme--documenter-dark .navbar.is-danger .navbar-brand > a.navbar-item.is-active,
+      html.theme--documenter-dark .navbar.is-danger .navbar-brand .navbar-link:focus,
+      html.theme--documenter-dark .navbar.is-danger .navbar-brand .navbar-link:hover,
+      html.theme--documenter-dark .navbar.is-danger .navbar-brand .navbar-link.is-active {
+        background-color: #86170b;
+        color: #fff; }
+      html.theme--documenter-dark .navbar.is-danger .navbar-brand .navbar-link::after {
+        border-color: #fff; }
+      html.theme--documenter-dark .navbar.is-danger .navbar-burger {
+        color: #fff; }
+      @media screen and (min-width: 1056px) {
+        html.theme--documenter-dark .navbar.is-danger .navbar-start > .navbar-item,
+        html.theme--documenter-dark .navbar.is-danger .navbar-start .navbar-link,
+        html.theme--documenter-dark .navbar.is-danger .navbar-end > .navbar-item,
+        html.theme--documenter-dark .navbar.is-danger .navbar-end .navbar-link {
+          color: #fff; }
+        html.theme--documenter-dark .navbar.is-danger .navbar-start > a.navbar-item:focus, html.theme--documenter-dark .navbar.is-danger .navbar-start > a.navbar-item:hover, html.theme--documenter-dark .navbar.is-danger .navbar-start > a.navbar-item.is-active,
+        html.theme--documenter-dark .navbar.is-danger .navbar-start .navbar-link:focus,
+        html.theme--documenter-dark .navbar.is-danger .navbar-start .navbar-link:hover,
+        html.theme--documenter-dark .navbar.is-danger .navbar-start .navbar-link.is-active,
+        html.theme--documenter-dark .navbar.is-danger .navbar-end > a.navbar-item:focus,
+        html.theme--documenter-dark .navbar.is-danger .navbar-end > a.navbar-item:hover,
+        html.theme--documenter-dark .navbar.is-danger .navbar-end > a.navbar-item.is-active,
+        html.theme--documenter-dark .navbar.is-danger .navbar-end .navbar-link:focus,
+        html.theme--documenter-dark .navbar.is-danger .navbar-end .navbar-link:hover,
+        html.theme--documenter-dark .navbar.is-danger .navbar-end .navbar-link.is-active {
+          background-color: #86170b;
+          color: #fff; }
+        html.theme--documenter-dark .navbar.is-danger .navbar-start .navbar-link::after,
+        html.theme--documenter-dark .navbar.is-danger .navbar-end .navbar-link::after {
+          border-color: #fff; }
+        html.theme--documenter-dark .navbar.is-danger .navbar-item.has-dropdown:focus .navbar-link,
+        html.theme--documenter-dark .navbar.is-danger .navbar-item.has-dropdown:hover .navbar-link,
+        html.theme--documenter-dark .navbar.is-danger .navbar-item.has-dropdown.is-active .navbar-link {
+          background-color: #86170b;
+          color: #fff; }
+        html.theme--documenter-dark .navbar.is-danger .navbar-dropdown a.navbar-item.is-active {
+          background-color: #9e1b0d;
+          color: #fff; } }
+    html.theme--documenter-dark .navbar > .container {
+      align-items: stretch;
+      display: flex;
+      min-height: 4rem;
+      width: 100%; }
+    html.theme--documenter-dark .navbar.has-shadow {
+      box-shadow: 0 2px 0 0 #282f2f; }
+    html.theme--documenter-dark .navbar.is-fixed-bottom, html.theme--documenter-dark .navbar.is-fixed-top {
+      left: 0;
+      position: fixed;
+      right: 0;
+      z-index: 30; }
+    html.theme--documenter-dark .navbar.is-fixed-bottom {
+      bottom: 0; }
+      html.theme--documenter-dark .navbar.is-fixed-bottom.has-shadow {
+        box-shadow: 0 -2px 0 0 #282f2f; }
+    html.theme--documenter-dark .navbar.is-fixed-top {
+      top: 0; }
+  html.theme--documenter-dark html.has-navbar-fixed-top,
+  html.theme--documenter-dark body.has-navbar-fixed-top {
+    padding-top: 4rem; }
+  html.theme--documenter-dark html.has-navbar-fixed-bottom,
+  html.theme--documenter-dark body.has-navbar-fixed-bottom {
+    padding-bottom: 4rem; }
+  html.theme--documenter-dark .navbar-brand,
+  html.theme--documenter-dark .navbar-tabs {
+    align-items: stretch;
+    display: flex;
+    flex-shrink: 0;
+    min-height: 4rem; }
+  html.theme--documenter-dark .navbar-brand a.navbar-item:focus, html.theme--documenter-dark .navbar-brand a.navbar-item:hover {
+    background-color: transparent; }
+  html.theme--documenter-dark .navbar-tabs {
+    -webkit-overflow-scrolling: touch;
+    max-width: 100vw;
+    overflow-x: auto;
+    overflow-y: hidden; }
+  html.theme--documenter-dark .navbar-burger {
+    color: #fff;
+    cursor: pointer;
+    display: block;
+    height: 4rem;
+    position: relative;
+    width: 4rem;
+    margin-left: auto; }
+    html.theme--documenter-dark .navbar-burger span {
+      background-color: currentColor;
+      display: block;
+      height: 1px;
+      left: calc(50% - 8px);
+      position: absolute;
+      transform-origin: center;
+      transition-duration: 86ms;
+      transition-property: background-color, opacity, transform;
+      transition-timing-function: ease-out;
+      width: 16px; }
+      html.theme--documenter-dark .navbar-burger span:nth-child(1) {
+        top: calc(50% - 6px); }
+      html.theme--documenter-dark .navbar-burger span:nth-child(2) {
+        top: calc(50% - 1px); }
+      html.theme--documenter-dark .navbar-burger span:nth-child(3) {
+        top: calc(50% + 4px); }
+    html.theme--documenter-dark .navbar-burger:hover {
+      background-color: rgba(0, 0, 0, 0.05); }
+    html.theme--documenter-dark .navbar-burger.is-active span:nth-child(1) {
+      transform: translateY(5px) rotate(45deg); }
+    html.theme--documenter-dark .navbar-burger.is-active span:nth-child(2) {
+      opacity: 0; }
+    html.theme--documenter-dark .navbar-burger.is-active span:nth-child(3) {
+      transform: translateY(-5px) rotate(-45deg); }
+  html.theme--documenter-dark .navbar-menu {
+    display: none; }
+  html.theme--documenter-dark .navbar-item,
+  html.theme--documenter-dark .navbar-link {
+    color: #fff;
+    display: block;
+    line-height: 1.5;
+    padding: 0.5rem 0.75rem;
+    position: relative; }
+    html.theme--documenter-dark .navbar-item .icon:only-child,
+    html.theme--documenter-dark .navbar-link .icon:only-child {
+      margin-left: -0.25rem;
+      margin-right: -0.25rem; }
+  html.theme--documenter-dark a.navbar-item,
+  html.theme--documenter-dark .navbar-link {
+    cursor: pointer; }
+    html.theme--documenter-dark a.navbar-item:focus, html.theme--documenter-dark a.navbar-item:focus-within, html.theme--documenter-dark a.navbar-item:hover, html.theme--documenter-dark a.navbar-item.is-active,
+    html.theme--documenter-dark .navbar-link:focus,
+    html.theme--documenter-dark .navbar-link:focus-within,
+    html.theme--documenter-dark .navbar-link:hover,
+    html.theme--documenter-dark .navbar-link.is-active {
+      background-color: transparent;
+      color: #1abc9c; }
+  html.theme--documenter-dark .navbar-item {
+    display: block;
+    flex-grow: 0;
+    flex-shrink: 0; }
+    html.theme--documenter-dark .navbar-item img {
+      max-height: 1.75rem; }
+    html.theme--documenter-dark .navbar-item.has-dropdown {
+      padding: 0; }
+    html.theme--documenter-dark .navbar-item.is-expanded {
+      flex-grow: 1;
+      flex-shrink: 1; }
+    html.theme--documenter-dark .navbar-item.is-tab {
+      border-bottom: 1px solid transparent;
+      min-height: 4rem;
+      padding-bottom: calc(0.5rem - 1px); }
+      html.theme--documenter-dark .navbar-item.is-tab:focus, html.theme--documenter-dark .navbar-item.is-tab:hover {
+        background-color: transparent;
+        border-bottom-color: #1abc9c; }
+      html.theme--documenter-dark .navbar-item.is-tab.is-active {
+        background-color: transparent;
+        border-bottom-color: #1abc9c;
+        border-bottom-style: solid;
+        border-bottom-width: 3px;
+        color: #1abc9c;
+        padding-bottom: calc(0.5rem - 3px); }
+  html.theme--documenter-dark .navbar-content {
+    flex-grow: 1;
+    flex-shrink: 1; }
+  html.theme--documenter-dark .navbar-link:not(.is-arrowless) {
+    padding-right: 2.5em; }
+    html.theme--documenter-dark .navbar-link:not(.is-arrowless)::after {
+      border-color: #fff;
+      margin-top: -0.375em;
+      right: 1.125em; }
+  html.theme--documenter-dark .navbar-dropdown {
+    font-size: 0.875rem;
+    padding-bottom: 0.5rem;
+    padding-top: 0.5rem; }
+    html.theme--documenter-dark .navbar-dropdown .navbar-item {
+      padding-left: 1.5rem;
+      padding-right: 1.5rem; }
+  html.theme--documenter-dark .navbar-divider {
+    background-color: rgba(0, 0, 0, 0.2);
+    border: none;
+    display: none;
+    height: 2px;
+    margin: 0.5rem 0; }
+  @media screen and (max-width: 1055px) {
+    html.theme--documenter-dark .navbar > .container {
+      display: block; }
+    html.theme--documenter-dark .navbar-brand .navbar-item,
+    html.theme--documenter-dark .navbar-tabs .navbar-item {
+      align-items: center;
+      display: flex; }
+    html.theme--documenter-dark .navbar-link::after {
+      display: none; }
+    html.theme--documenter-dark .navbar-menu {
+      background-color: #375a7f;
+      box-shadow: 0 8px 16px rgba(10, 10, 10, 0.1);
+      padding: 0.5rem 0; }
+      html.theme--documenter-dark .navbar-menu.is-active {
+        display: block; }
+    html.theme--documenter-dark .navbar.is-fixed-bottom-touch, html.theme--documenter-dark .navbar.is-fixed-top-touch {
+      left: 0;
+      position: fixed;
+      right: 0;
+      z-index: 30; }
+    html.theme--documenter-dark .navbar.is-fixed-bottom-touch {
+      bottom: 0; }
+      html.theme--documenter-dark .navbar.is-fixed-bottom-touch.has-shadow {
+        box-shadow: 0 -2px 3px rgba(10, 10, 10, 0.1); }
+    html.theme--documenter-dark .navbar.is-fixed-top-touch {
+      top: 0; }
+    html.theme--documenter-dark .navbar.is-fixed-top .navbar-menu, html.theme--documenter-dark .navbar.is-fixed-top-touch .navbar-menu {
+      -webkit-overflow-scrolling: touch;
+      max-height: calc(100vh - 4rem);
+      overflow: auto; }
+    html.theme--documenter-dark html.has-navbar-fixed-top-touch,
+    html.theme--documenter-dark body.has-navbar-fixed-top-touch {
+      padding-top: 4rem; }
+    html.theme--documenter-dark html.has-navbar-fixed-bottom-touch,
+    html.theme--documenter-dark body.has-navbar-fixed-bottom-touch {
+      padding-bottom: 4rem; } }
+  @media screen and (min-width: 1056px) {
+    html.theme--documenter-dark .navbar,
+    html.theme--documenter-dark .navbar-menu,
+    html.theme--documenter-dark .navbar-start,
+    html.theme--documenter-dark .navbar-end {
+      align-items: stretch;
+      display: flex; }
+    html.theme--documenter-dark .navbar {
+      min-height: 4rem; }
+      html.theme--documenter-dark .navbar.is-spaced {
+        padding: 1rem 2rem; }
+        html.theme--documenter-dark .navbar.is-spaced .navbar-start,
+        html.theme--documenter-dark .navbar.is-spaced .navbar-end {
+          align-items: center; }
+        html.theme--documenter-dark .navbar.is-spaced a.navbar-item,
+        html.theme--documenter-dark .navbar.is-spaced .navbar-link {
+          border-radius: 0.4em; }
+      html.theme--documenter-dark .navbar.is-transparent a.navbar-item:focus, html.theme--documenter-dark .navbar.is-transparent a.navbar-item:hover, html.theme--documenter-dark .navbar.is-transparent a.navbar-item.is-active,
+      html.theme--documenter-dark .navbar.is-transparent .navbar-link:focus,
+      html.theme--documenter-dark .navbar.is-transparent .navbar-link:hover,
+      html.theme--documenter-dark .navbar.is-transparent .navbar-link.is-active {
+        background-color: transparent !important; }
+      html.theme--documenter-dark .navbar.is-transparent .navbar-item.has-dropdown.is-active .navbar-link, html.theme--documenter-dark .navbar.is-transparent .navbar-item.has-dropdown.is-hoverable:focus .navbar-link, html.theme--documenter-dark .navbar.is-transparent .navbar-item.has-dropdown.is-hoverable:focus-within .navbar-link, html.theme--documenter-dark .navbar.is-transparent .navbar-item.has-dropdown.is-hoverable:hover .navbar-link {
+        background-color: transparent !important; }
+      html.theme--documenter-dark .navbar.is-transparent .navbar-dropdown a.navbar-item:focus, html.theme--documenter-dark .navbar.is-transparent .navbar-dropdown a.navbar-item:hover {
+        background-color: transparent;
+        color: #dbdee0; }
+      html.theme--documenter-dark .navbar.is-transparent .navbar-dropdown a.navbar-item.is-active {
+        background-color: transparent;
+        color: #1abc9c; }
+    html.theme--documenter-dark .navbar-burger {
+      display: none; }
+    html.theme--documenter-dark .navbar-item,
+    html.theme--documenter-dark .navbar-link {
+      align-items: center;
+      display: flex; }
+    html.theme--documenter-dark .navbar-item {
+      display: flex; }
+      html.theme--documenter-dark .navbar-item.has-dropdown {
+        align-items: stretch; }
+      html.theme--documenter-dark .navbar-item.has-dropdown-up .navbar-link::after {
+        transform: rotate(135deg) translate(0.25em, -0.25em); }
+      html.theme--documenter-dark .navbar-item.has-dropdown-up .navbar-dropdown {
+        border-bottom: 1px solid rgba(0, 0, 0, 0.2);
+        border-radius: 8px 8px 0 0;
+        border-top: none;
+        bottom: 100%;
+        box-shadow: 0 -8px 8px rgba(10, 10, 10, 0.1);
+        top: auto; }
+      html.theme--documenter-dark .navbar-item.is-active .navbar-dropdown, html.theme--documenter-dark .navbar-item.is-hoverable:focus .navbar-dropdown, html.theme--documenter-dark .navbar-item.is-hoverable:focus-within .navbar-dropdown, html.theme--documenter-dark .navbar-item.is-hoverable:hover .navbar-dropdown {
+        display: block; }
+        .navbar.is-spaced html.theme--documenter-dark .navbar-item.is-active .navbar-dropdown, html.theme--documenter-dark .navbar-item.is-active .navbar-dropdown.is-boxed, .navbar.is-spaced html.theme--documenter-dark .navbar-item.is-hoverable:focus .navbar-dropdown, html.theme--documenter-dark .navbar-item.is-hoverable:focus .navbar-dropdown.is-boxed, .navbar.is-spaced html.theme--documenter-dark .navbar-item.is-hoverable:focus-within .navbar-dropdown, html.theme--documenter-dark .navbar-item.is-hoverable:focus-within .navbar-dropdown.is-boxed, .navbar.is-spaced html.theme--documenter-dark .navbar-item.is-hoverable:hover .navbar-dropdown, html.theme--documenter-dark .navbar-item.is-hoverable:hover .navbar-dropdown.is-boxed {
+          opacity: 1;
+          pointer-events: auto;
+          transform: translateY(0); }
+    html.theme--documenter-dark .navbar-menu {
+      flex-grow: 1;
+      flex-shrink: 0; }
+    html.theme--documenter-dark .navbar-start {
+      justify-content: flex-start;
+      margin-right: auto; }
+    html.theme--documenter-dark .navbar-end {
+      justify-content: flex-end;
+      margin-left: auto; }
+    html.theme--documenter-dark .navbar-dropdown {
+      background-color: #375a7f;
+      border-bottom-left-radius: 8px;
+      border-bottom-right-radius: 8px;
+      border-top: 1px solid rgba(0, 0, 0, 0.2);
+      box-shadow: 0 8px 8px rgba(10, 10, 10, 0.1);
+      display: none;
+      font-size: 0.875rem;
+      left: 0;
+      min-width: 100%;
+      position: absolute;
+      top: 100%;
+      z-index: 20; }
+      html.theme--documenter-dark .navbar-dropdown .navbar-item {
+        padding: 0.375rem 1rem;
+        white-space: nowrap; }
+      html.theme--documenter-dark .navbar-dropdown a.navbar-item {
+        padding-right: 3rem; }
+        html.theme--documenter-dark .navbar-dropdown a.navbar-item:focus, html.theme--documenter-dark .navbar-dropdown a.navbar-item:hover {
+          background-color: transparent;
+          color: #dbdee0; }
+        html.theme--documenter-dark .navbar-dropdown a.navbar-item.is-active {
+          background-color: transparent;
+          color: #1abc9c; }
+      .navbar.is-spaced html.theme--documenter-dark .navbar-dropdown, html.theme--documenter-dark .navbar-dropdown.is-boxed {
+        border-radius: 8px;
+        border-top: none;
+        box-shadow: 0 8px 8px rgba(10, 10, 10, 0.1), 0 0 0 1px rgba(10, 10, 10, 0.1);
+        display: block;
+        opacity: 0;
+        pointer-events: none;
+        top: calc(100% + (-4px));
+        transform: translateY(-5px);
+        transition-duration: 86ms;
+        transition-property: opacity, transform; }
+      html.theme--documenter-dark .navbar-dropdown.is-right {
+        left: auto;
+        right: 0; }
+    html.theme--documenter-dark .navbar-divider {
+      display: block; }
+    html.theme--documenter-dark .navbar > .container .navbar-brand,
+    html.theme--documenter-dark .container > .navbar .navbar-brand {
+      margin-left: -.75rem; }
+    html.theme--documenter-dark .navbar > .container .navbar-menu,
+    html.theme--documenter-dark .container > .navbar .navbar-menu {
+      margin-right: -.75rem; }
+    html.theme--documenter-dark .navbar.is-fixed-bottom-desktop, html.theme--documenter-dark .navbar.is-fixed-top-desktop {
+      left: 0;
+      position: fixed;
+      right: 0;
+      z-index: 30; }
+    html.theme--documenter-dark .navbar.is-fixed-bottom-desktop {
+      bottom: 0; }
+      html.theme--documenter-dark .navbar.is-fixed-bottom-desktop.has-shadow {
+        box-shadow: 0 -2px 3px rgba(10, 10, 10, 0.1); }
+    html.theme--documenter-dark .navbar.is-fixed-top-desktop {
+      top: 0; }
+    html.theme--documenter-dark html.has-navbar-fixed-top-desktop,
+    html.theme--documenter-dark body.has-navbar-fixed-top-desktop {
+      padding-top: 4rem; }
+    html.theme--documenter-dark html.has-navbar-fixed-bottom-desktop,
+    html.theme--documenter-dark body.has-navbar-fixed-bottom-desktop {
+      padding-bottom: 4rem; }
+    html.theme--documenter-dark html.has-spaced-navbar-fixed-top,
+    html.theme--documenter-dark body.has-spaced-navbar-fixed-top {
+      padding-top: 6rem; }
+    html.theme--documenter-dark html.has-spaced-navbar-fixed-bottom,
+    html.theme--documenter-dark body.has-spaced-navbar-fixed-bottom {
+      padding-bottom: 6rem; }
+    html.theme--documenter-dark a.navbar-item.is-active,
+    html.theme--documenter-dark .navbar-link.is-active {
+      color: #1abc9c; }
+    html.theme--documenter-dark a.navbar-item.is-active:not(:focus):not(:hover),
+    html.theme--documenter-dark .navbar-link.is-active:not(:focus):not(:hover) {
+      background-color: transparent; }
+    html.theme--documenter-dark .navbar-item.has-dropdown:focus .navbar-link, html.theme--documenter-dark .navbar-item.has-dropdown:hover .navbar-link, html.theme--documenter-dark .navbar-item.has-dropdown.is-active .navbar-link {
+      background-color: transparent; } }
+  html.theme--documenter-dark .hero.is-fullheight-with-navbar {
+    min-height: calc(100vh - 4rem); }
+  html.theme--documenter-dark .pagination {
+    font-size: 15px;
+    margin: -0.25rem; }
+    html.theme--documenter-dark .pagination.is-small, html.theme--documenter-dark #documenter .docs-sidebar form.docs-search > input.pagination {
+      font-size: 0.85em; }
+    html.theme--documenter-dark .pagination.is-medium {
+      font-size: 1.25rem; }
+    html.theme--documenter-dark .pagination.is-large {
+      font-size: 1.5rem; }
+    html.theme--documenter-dark .pagination.is-rounded .pagination-previous, html.theme--documenter-dark #documenter .docs-sidebar form.docs-search > input.pagination .pagination-previous,
+    html.theme--documenter-dark .pagination.is-rounded .pagination-next,
+    html.theme--documenter-dark #documenter .docs-sidebar form.docs-search > input.pagination .pagination-next {
+      padding-left: 1em;
+      padding-right: 1em;
+      border-radius: 290486px; }
+    html.theme--documenter-dark .pagination.is-rounded .pagination-link, html.theme--documenter-dark #documenter .docs-sidebar form.docs-search > input.pagination .pagination-link {
+      border-radius: 290486px; }
+  html.theme--documenter-dark .pagination,
+  html.theme--documenter-dark .pagination-list {
+    align-items: center;
+    display: flex;
+    justify-content: center;
+    text-align: center; }
+  html.theme--documenter-dark .pagination-previous,
+  html.theme--documenter-dark .pagination-next,
+  html.theme--documenter-dark .pagination-link,
+  html.theme--documenter-dark .pagination-ellipsis {
+    font-size: 1em;
+    justify-content: center;
+    margin: 0.25rem;
+    padding-left: 0.5em;
+    padding-right: 0.5em;
+    text-align: center; }
+  html.theme--documenter-dark .pagination-previous,
+  html.theme--documenter-dark .pagination-next,
+  html.theme--documenter-dark .pagination-link {
+    border-color: #5e6d6f;
+    color: #1abc9c;
+    min-width: 2.25em; }
+    html.theme--documenter-dark .pagination-previous:hover,
+    html.theme--documenter-dark .pagination-next:hover,
+    html.theme--documenter-dark .pagination-link:hover {
+      border-color: #8c9b9d;
+      color: #1dd2af; }
+    html.theme--documenter-dark .pagination-previous:focus,
+    html.theme--documenter-dark .pagination-next:focus,
+    html.theme--documenter-dark .pagination-link:focus {
+      border-color: #8c9b9d; }
+    html.theme--documenter-dark .pagination-previous:active,
+    html.theme--documenter-dark .pagination-next:active,
+    html.theme--documenter-dark .pagination-link:active {
+      box-shadow: inset 0 1px 2px rgba(10, 10, 10, 0.2); }
+    html.theme--documenter-dark .pagination-previous[disabled],
+    html.theme--documenter-dark .pagination-next[disabled],
+    html.theme--documenter-dark .pagination-link[disabled] {
+      background-color: #dbdee0;
+      border-color: #dbdee0;
+      box-shadow: none;
+      color: #5e6d6f;
+      opacity: 0.5; }
+  html.theme--documenter-dark .pagination-previous,
+  html.theme--documenter-dark .pagination-next {
+    padding-left: 0.75em;
+    padding-right: 0.75em;
+    white-space: nowrap; }
+  html.theme--documenter-dark .pagination-link.is-current {
+    background-color: #1abc9c;
+    border-color: #1abc9c;
+    color: #fff; }
+  html.theme--documenter-dark .pagination-ellipsis {
+    color: #8c9b9d;
+    pointer-events: none; }
+  html.theme--documenter-dark .pagination-list {
+    flex-wrap: wrap; }
+  @media screen and (max-width: 768px) {
+    html.theme--documenter-dark .pagination {
+      flex-wrap: wrap; }
+    html.theme--documenter-dark .pagination-previous,
+    html.theme--documenter-dark .pagination-next {
+      flex-grow: 1;
+      flex-shrink: 1; }
+    html.theme--documenter-dark .pagination-list li {
+      flex-grow: 1;
+      flex-shrink: 1; } }
+  @media screen and (min-width: 769px), print {
+    html.theme--documenter-dark .pagination-list {
+      flex-grow: 1;
+      flex-shrink: 1;
+      justify-content: flex-start;
+      order: 1; }
+    html.theme--documenter-dark .pagination-previous {
+      order: 2; }
+    html.theme--documenter-dark .pagination-next {
+      order: 3; }
+    html.theme--documenter-dark .pagination {
+      justify-content: space-between; }
+      html.theme--documenter-dark .pagination.is-centered .pagination-previous {
+        order: 1; }
+      html.theme--documenter-dark .pagination.is-centered .pagination-list {
+        justify-content: center;
+        order: 2; }
+      html.theme--documenter-dark .pagination.is-centered .pagination-next {
+        order: 3; }
+      html.theme--documenter-dark .pagination.is-right .pagination-previous {
+        order: 1; }
+      html.theme--documenter-dark .pagination.is-right .pagination-next {
+        order: 2; }
+      html.theme--documenter-dark .pagination.is-right .pagination-list {
+        justify-content: flex-end;
+        order: 3; } }
+  html.theme--documenter-dark .panel {
+    font-size: 15px; }
+    html.theme--documenter-dark .panel:not(:last-child) {
+      margin-bottom: 1.5rem; }
+  html.theme--documenter-dark .panel-heading,
+  html.theme--documenter-dark .panel-tabs,
+  html.theme--documenter-dark .panel-block {
+    border-bottom: 1px solid #5e6d6f;
+    border-left: 1px solid #5e6d6f;
+    border-right: 1px solid #5e6d6f; }
+    html.theme--documenter-dark .panel-heading:first-child,
+    html.theme--documenter-dark .panel-tabs:first-child,
+    html.theme--documenter-dark .panel-block:first-child {
+      border-top: 1px solid #5e6d6f; }
+  html.theme--documenter-dark .panel-heading {
+    background-color: #282f2f;
+    border-radius: 0.4em 0.4em 0 0;
+    color: #f2f2f2;
+    font-size: 1.25em;
+    font-weight: 300;
+    line-height: 1.25;
+    padding: 0.5em 0.75em; }
+  html.theme--documenter-dark .panel-tabs {
+    align-items: flex-end;
+    display: flex;
+    font-size: 0.875em;
+    justify-content: center; }
+    html.theme--documenter-dark .panel-tabs a {
+      border-bottom: 1px solid #5e6d6f;
+      margin-bottom: -1px;
+      padding: 0.5em; }
+      html.theme--documenter-dark .panel-tabs a.is-active {
+        border-bottom-color: #343c3d;
+        color: #17a689; }
+  html.theme--documenter-dark .panel-list a {
+    color: #fff; }
+    html.theme--documenter-dark .panel-list a:hover {
+      color: #1abc9c; }
+  html.theme--documenter-dark .panel-block {
+    align-items: center;
+    color: #f2f2f2;
+    display: flex;
+    justify-content: flex-start;
+    padding: 0.5em 0.75em; }
+    html.theme--documenter-dark .panel-block input[type="checkbox"] {
+      margin-right: 0.75em; }
+    html.theme--documenter-dark .panel-block > .control {
+      flex-grow: 1;
+      flex-shrink: 1;
+      width: 100%; }
+    html.theme--documenter-dark .panel-block.is-wrapped {
+      flex-wrap: wrap; }
+    html.theme--documenter-dark .panel-block.is-active {
+      border-left-color: #1abc9c;
+      color: #17a689; }
+      html.theme--documenter-dark .panel-block.is-active .panel-icon {
+        color: #1abc9c; }
+  html.theme--documenter-dark a.panel-block,
+  html.theme--documenter-dark label.panel-block {
+    cursor: pointer; }
+    html.theme--documenter-dark a.panel-block:hover,
+    html.theme--documenter-dark label.panel-block:hover {
+      background-color: #282f2f; }
+  html.theme--documenter-dark .panel-icon {
+    display: inline-block;
+    font-size: 14px;
+    height: 1em;
+    line-height: 1em;
+    text-align: center;
+    vertical-align: top;
+    width: 1em;
+    color: white;
+    margin-right: 0.75em; }
+    html.theme--documenter-dark .panel-icon .fa {
+      font-size: inherit;
+      line-height: inherit; }
+  html.theme--documenter-dark .tabs {
+    -webkit-overflow-scrolling: touch;
+    align-items: stretch;
+    display: flex;
+    font-size: 15px;
+    justify-content: space-between;
+    overflow: hidden;
+    overflow-x: auto;
+    white-space: nowrap; }
+    html.theme--documenter-dark .tabs a {
+      align-items: center;
+      border-bottom-color: #5e6d6f;
+      border-bottom-style: solid;
+      border-bottom-width: 1px;
+      color: #fff;
+      display: flex;
+      justify-content: center;
+      margin-bottom: -1px;
+      padding: 0.5em 1em;
+      vertical-align: top; }
+      html.theme--documenter-dark .tabs a:hover {
+        border-bottom-color: #f2f2f2;
+        color: #f2f2f2; }
+    html.theme--documenter-dark .tabs li {
+      display: block; }
+      html.theme--documenter-dark .tabs li.is-active a {
+        border-bottom-color: #1abc9c;
+        color: #1abc9c; }
+    html.theme--documenter-dark .tabs ul {
+      align-items: center;
+      border-bottom-color: #5e6d6f;
+      border-bottom-style: solid;
+      border-bottom-width: 1px;
+      display: flex;
+      flex-grow: 1;
+      flex-shrink: 0;
+      justify-content: flex-start; }
+      html.theme--documenter-dark .tabs ul.is-left {
+        padding-right: 0.75em; }
+      html.theme--documenter-dark .tabs ul.is-center {
+        flex: none;
+        justify-content: center;
+        padding-left: 0.75em;
+        padding-right: 0.75em; }
+      html.theme--documenter-dark .tabs ul.is-right {
+        justify-content: flex-end;
+        padding-left: 0.75em; }
+    html.theme--documenter-dark .tabs .icon:first-child {
+      margin-right: 0.5em; }
+    html.theme--documenter-dark .tabs .icon:last-child {
+      margin-left: 0.5em; }
+    html.theme--documenter-dark .tabs.is-centered ul {
+      justify-content: center; }
+    html.theme--documenter-dark .tabs.is-right ul {
+      justify-content: flex-end; }
+    html.theme--documenter-dark .tabs.is-boxed a {
+      border: 1px solid transparent;
+      border-radius: 0.4em 0.4em 0 0; }
+      html.theme--documenter-dark .tabs.is-boxed a:hover {
+        background-color: #282f2f;
+        border-bottom-color: #5e6d6f; }
+    html.theme--documenter-dark .tabs.is-boxed li.is-active a {
+      background-color: white;
+      border-color: #5e6d6f;
+      border-bottom-color: transparent !important; }
+    html.theme--documenter-dark .tabs.is-fullwidth li {
+      flex-grow: 1;
+      flex-shrink: 0; }
+    html.theme--documenter-dark .tabs.is-toggle a {
+      border-color: #5e6d6f;
+      border-style: solid;
+      border-width: 1px;
+      margin-bottom: 0;
+      position: relative; }
+      html.theme--documenter-dark .tabs.is-toggle a:hover {
+        background-color: #282f2f;
+        border-color: #8c9b9d;
+        z-index: 2; }
+    html.theme--documenter-dark .tabs.is-toggle li + li {
+      margin-left: -1px; }
+    html.theme--documenter-dark .tabs.is-toggle li:first-child a {
+      border-radius: 0.4em 0 0 0.4em; }
+    html.theme--documenter-dark .tabs.is-toggle li:last-child a {
+      border-radius: 0 0.4em 0.4em 0; }
+    html.theme--documenter-dark .tabs.is-toggle li.is-active a {
+      background-color: #1abc9c;
+      border-color: #1abc9c;
+      color: #fff;
+      z-index: 1; }
+    html.theme--documenter-dark .tabs.is-toggle ul {
+      border-bottom: none; }
+    html.theme--documenter-dark .tabs.is-toggle.is-toggle-rounded li:first-child a {
+      border-bottom-left-radius: 290486px;
+      border-top-left-radius: 290486px;
+      padding-left: 1.25em; }
+    html.theme--documenter-dark .tabs.is-toggle.is-toggle-rounded li:last-child a {
+      border-bottom-right-radius: 290486px;
+      border-top-right-radius: 290486px;
+      padding-right: 1.25em; }
+    html.theme--documenter-dark .tabs.is-small, html.theme--documenter-dark #documenter .docs-sidebar form.docs-search > input.tabs {
+      font-size: 0.85em; }
+    html.theme--documenter-dark .tabs.is-medium {
+      font-size: 1.25rem; }
+    html.theme--documenter-dark .tabs.is-large {
+      font-size: 1.5rem; }
+  html.theme--documenter-dark .column {
+    display: block;
+    flex-basis: 0;
+    flex-grow: 1;
+    flex-shrink: 1;
+    padding: 0.75rem; }
+    .columns.is-mobile > html.theme--documenter-dark .column.is-narrow {
+      flex: none; }
+    .columns.is-mobile > html.theme--documenter-dark .column.is-full {
+      flex: none;
+      width: 100%; }
+    .columns.is-mobile > html.theme--documenter-dark .column.is-three-quarters {
+      flex: none;
+      width: 75%; }
+    .columns.is-mobile > html.theme--documenter-dark .column.is-two-thirds {
+      flex: none;
+      width: 66.6666%; }
+    .columns.is-mobile > html.theme--documenter-dark .column.is-half {
+      flex: none;
+      width: 50%; }
+    .columns.is-mobile > html.theme--documenter-dark .column.is-one-third {
+      flex: none;
+      width: 33.3333%; }
+    .columns.is-mobile > html.theme--documenter-dark .column.is-one-quarter {
+      flex: none;
+      width: 25%; }
+    .columns.is-mobile > html.theme--documenter-dark .column.is-one-fifth {
+      flex: none;
+      width: 20%; }
+    .columns.is-mobile > html.theme--documenter-dark .column.is-two-fifths {
+      flex: none;
+      width: 40%; }
+    .columns.is-mobile > html.theme--documenter-dark .column.is-three-fifths {
+      flex: none;
+      width: 60%; }
+    .columns.is-mobile > html.theme--documenter-dark .column.is-four-fifths {
+      flex: none;
+      width: 80%; }
+    .columns.is-mobile > html.theme--documenter-dark .column.is-offset-three-quarters {
+      margin-left: 75%; }
+    .columns.is-mobile > html.theme--documenter-dark .column.is-offset-two-thirds {
+      margin-left: 66.6666%; }
+    .columns.is-mobile > html.theme--documenter-dark .column.is-offset-half {
+      margin-left: 50%; }
+    .columns.is-mobile > html.theme--documenter-dark .column.is-offset-one-third {
+      margin-left: 33.3333%; }
+    .columns.is-mobile > html.theme--documenter-dark .column.is-offset-one-quarter {
+      margin-left: 25%; }
+    .columns.is-mobile > html.theme--documenter-dark .column.is-offset-one-fifth {
+      margin-left: 20%; }
+    .columns.is-mobile > html.theme--documenter-dark .column.is-offset-two-fifths {
+      margin-left: 40%; }
+    .columns.is-mobile > html.theme--documenter-dark .column.is-offset-three-fifths {
+      margin-left: 60%; }
+    .columns.is-mobile > html.theme--documenter-dark .column.is-offset-four-fifths {
+      margin-left: 80%; }
+    .columns.is-mobile > html.theme--documenter-dark .column.is-0 {
+      flex: none;
+      width: 0%; }
+    .columns.is-mobile > html.theme--documenter-dark .column.is-offset-0 {
+      margin-left: 0%; }
+    .columns.is-mobile > html.theme--documenter-dark .column.is-1 {
+      flex: none;
+      width: 8.33333%; }
+    .columns.is-mobile > html.theme--documenter-dark .column.is-offset-1 {
+      margin-left: 8.33333%; }
+    .columns.is-mobile > html.theme--documenter-dark .column.is-2 {
+      flex: none;
+      width: 16.66667%; }
+    .columns.is-mobile > html.theme--documenter-dark .column.is-offset-2 {
+      margin-left: 16.66667%; }
+    .columns.is-mobile > html.theme--documenter-dark .column.is-3 {
+      flex: none;
+      width: 25%; }
+    .columns.is-mobile > html.theme--documenter-dark .column.is-offset-3 {
+      margin-left: 25%; }
+    .columns.is-mobile > html.theme--documenter-dark .column.is-4 {
+      flex: none;
+      width: 33.33333%; }
+    .columns.is-mobile > html.theme--documenter-dark .column.is-offset-4 {
+      margin-left: 33.33333%; }
+    .columns.is-mobile > html.theme--documenter-dark .column.is-5 {
+      flex: none;
+      width: 41.66667%; }
+    .columns.is-mobile > html.theme--documenter-dark .column.is-offset-5 {
+      margin-left: 41.66667%; }
+    .columns.is-mobile > html.theme--documenter-dark .column.is-6 {
+      flex: none;
+      width: 50%; }
+    .columns.is-mobile > html.theme--documenter-dark .column.is-offset-6 {
+      margin-left: 50%; }
+    .columns.is-mobile > html.theme--documenter-dark .column.is-7 {
+      flex: none;
+      width: 58.33333%; }
+    .columns.is-mobile > html.theme--documenter-dark .column.is-offset-7 {
+      margin-left: 58.33333%; }
+    .columns.is-mobile > html.theme--documenter-dark .column.is-8 {
+      flex: none;
+      width: 66.66667%; }
+    .columns.is-mobile > html.theme--documenter-dark .column.is-offset-8 {
+      margin-left: 66.66667%; }
+    .columns.is-mobile > html.theme--documenter-dark .column.is-9 {
+      flex: none;
+      width: 75%; }
+    .columns.is-mobile > html.theme--documenter-dark .column.is-offset-9 {
+      margin-left: 75%; }
+    .columns.is-mobile > html.theme--documenter-dark .column.is-10 {
+      flex: none;
+      width: 83.33333%; }
+    .columns.is-mobile > html.theme--documenter-dark .column.is-offset-10 {
+      margin-left: 83.33333%; }
+    .columns.is-mobile > html.theme--documenter-dark .column.is-11 {
+      flex: none;
+      width: 91.66667%; }
+    .columns.is-mobile > html.theme--documenter-dark .column.is-offset-11 {
+      margin-left: 91.66667%; }
+    .columns.is-mobile > html.theme--documenter-dark .column.is-12 {
+      flex: none;
+      width: 100%; }
+    .columns.is-mobile > html.theme--documenter-dark .column.is-offset-12 {
+      margin-left: 100%; }
+    @media screen and (max-width: 768px) {
+      html.theme--documenter-dark .column.is-narrow-mobile {
+        flex: none; }
+      html.theme--documenter-dark .column.is-full-mobile {
+        flex: none;
+        width: 100%; }
+      html.theme--documenter-dark .column.is-three-quarters-mobile {
+        flex: none;
+        width: 75%; }
+      html.theme--documenter-dark .column.is-two-thirds-mobile {
+        flex: none;
+        width: 66.6666%; }
+      html.theme--documenter-dark .column.is-half-mobile {
+        flex: none;
+        width: 50%; }
+      html.theme--documenter-dark .column.is-one-third-mobile {
+        flex: none;
+        width: 33.3333%; }
+      html.theme--documenter-dark .column.is-one-quarter-mobile {
+        flex: none;
+        width: 25%; }
+      html.theme--documenter-dark .column.is-one-fifth-mobile {
+        flex: none;
+        width: 20%; }
+      html.theme--documenter-dark .column.is-two-fifths-mobile {
+        flex: none;
+        width: 40%; }
+      html.theme--documenter-dark .column.is-three-fifths-mobile {
+        flex: none;
+        width: 60%; }
+      html.theme--documenter-dark .column.is-four-fifths-mobile {
+        flex: none;
+        width: 80%; }
+      html.theme--documenter-dark .column.is-offset-three-quarters-mobile {
+        margin-left: 75%; }
+      html.theme--documenter-dark .column.is-offset-two-thirds-mobile {
+        margin-left: 66.6666%; }
+      html.theme--documenter-dark .column.is-offset-half-mobile {
+        margin-left: 50%; }
+      html.theme--documenter-dark .column.is-offset-one-third-mobile {
+        margin-left: 33.3333%; }
+      html.theme--documenter-dark .column.is-offset-one-quarter-mobile {
+        margin-left: 25%; }
+      html.theme--documenter-dark .column.is-offset-one-fifth-mobile {
+        margin-left: 20%; }
+      html.theme--documenter-dark .column.is-offset-two-fifths-mobile {
+        margin-left: 40%; }
+      html.theme--documenter-dark .column.is-offset-three-fifths-mobile {
+        margin-left: 60%; }
+      html.theme--documenter-dark .column.is-offset-four-fifths-mobile {
+        margin-left: 80%; }
+      html.theme--documenter-dark .column.is-0-mobile {
+        flex: none;
+        width: 0%; }
+      html.theme--documenter-dark .column.is-offset-0-mobile {
+        margin-left: 0%; }
+      html.theme--documenter-dark .column.is-1-mobile {
+        flex: none;
+        width: 8.33333%; }
+      html.theme--documenter-dark .column.is-offset-1-mobile {
+        margin-left: 8.33333%; }
+      html.theme--documenter-dark .column.is-2-mobile {
+        flex: none;
+        width: 16.66667%; }
+      html.theme--documenter-dark .column.is-offset-2-mobile {
+        margin-left: 16.66667%; }
+      html.theme--documenter-dark .column.is-3-mobile {
+        flex: none;
+        width: 25%; }
+      html.theme--documenter-dark .column.is-offset-3-mobile {
+        margin-left: 25%; }
+      html.theme--documenter-dark .column.is-4-mobile {
+        flex: none;
+        width: 33.33333%; }
+      html.theme--documenter-dark .column.is-offset-4-mobile {
+        margin-left: 33.33333%; }
+      html.theme--documenter-dark .column.is-5-mobile {
+        flex: none;
+        width: 41.66667%; }
+      html.theme--documenter-dark .column.is-offset-5-mobile {
+        margin-left: 41.66667%; }
+      html.theme--documenter-dark .column.is-6-mobile {
+        flex: none;
+        width: 50%; }
+      html.theme--documenter-dark .column.is-offset-6-mobile {
+        margin-left: 50%; }
+      html.theme--documenter-dark .column.is-7-mobile {
+        flex: none;
+        width: 58.33333%; }
+      html.theme--documenter-dark .column.is-offset-7-mobile {
+        margin-left: 58.33333%; }
+      html.theme--documenter-dark .column.is-8-mobile {
+        flex: none;
+        width: 66.66667%; }
+      html.theme--documenter-dark .column.is-offset-8-mobile {
+        margin-left: 66.66667%; }
+      html.theme--documenter-dark .column.is-9-mobile {
+        flex: none;
+        width: 75%; }
+      html.theme--documenter-dark .column.is-offset-9-mobile {
+        margin-left: 75%; }
+      html.theme--documenter-dark .column.is-10-mobile {
+        flex: none;
+        width: 83.33333%; }
+      html.theme--documenter-dark .column.is-offset-10-mobile {
+        margin-left: 83.33333%; }
+      html.theme--documenter-dark .column.is-11-mobile {
+        flex: none;
+        width: 91.66667%; }
+      html.theme--documenter-dark .column.is-offset-11-mobile {
+        margin-left: 91.66667%; }
+      html.theme--documenter-dark .column.is-12-mobile {
+        flex: none;
+        width: 100%; }
+      html.theme--documenter-dark .column.is-offset-12-mobile {
+        margin-left: 100%; } }
+    @media screen and (min-width: 769px), print {
+      html.theme--documenter-dark .column.is-narrow, html.theme--documenter-dark .column.is-narrow-tablet {
+        flex: none; }
+      html.theme--documenter-dark .column.is-full, html.theme--documenter-dark .column.is-full-tablet {
+        flex: none;
+        width: 100%; }
+      html.theme--documenter-dark .column.is-three-quarters, html.theme--documenter-dark .column.is-three-quarters-tablet {
+        flex: none;
+        width: 75%; }
+      html.theme--documenter-dark .column.is-two-thirds, html.theme--documenter-dark .column.is-two-thirds-tablet {
+        flex: none;
+        width: 66.6666%; }
+      html.theme--documenter-dark .column.is-half, html.theme--documenter-dark .column.is-half-tablet {
+        flex: none;
+        width: 50%; }
+      html.theme--documenter-dark .column.is-one-third, html.theme--documenter-dark .column.is-one-third-tablet {
+        flex: none;
+        width: 33.3333%; }
+      html.theme--documenter-dark .column.is-one-quarter, html.theme--documenter-dark .column.is-one-quarter-tablet {
+        flex: none;
+        width: 25%; }
+      html.theme--documenter-dark .column.is-one-fifth, html.theme--documenter-dark .column.is-one-fifth-tablet {
+        flex: none;
+        width: 20%; }
+      html.theme--documenter-dark .column.is-two-fifths, html.theme--documenter-dark .column.is-two-fifths-tablet {
+        flex: none;
+        width: 40%; }
+      html.theme--documenter-dark .column.is-three-fifths, html.theme--documenter-dark .column.is-three-fifths-tablet {
+        flex: none;
+        width: 60%; }
+      html.theme--documenter-dark .column.is-four-fifths, html.theme--documenter-dark .column.is-four-fifths-tablet {
+        flex: none;
+        width: 80%; }
+      html.theme--documenter-dark .column.is-offset-three-quarters, html.theme--documenter-dark .column.is-offset-three-quarters-tablet {
+        margin-left: 75%; }
+      html.theme--documenter-dark .column.is-offset-two-thirds, html.theme--documenter-dark .column.is-offset-two-thirds-tablet {
+        margin-left: 66.6666%; }
+      html.theme--documenter-dark .column.is-offset-half, html.theme--documenter-dark .column.is-offset-half-tablet {
+        margin-left: 50%; }
+      html.theme--documenter-dark .column.is-offset-one-third, html.theme--documenter-dark .column.is-offset-one-third-tablet {
+        margin-left: 33.3333%; }
+      html.theme--documenter-dark .column.is-offset-one-quarter, html.theme--documenter-dark .column.is-offset-one-quarter-tablet {
+        margin-left: 25%; }
+      html.theme--documenter-dark .column.is-offset-one-fifth, html.theme--documenter-dark .column.is-offset-one-fifth-tablet {
+        margin-left: 20%; }
+      html.theme--documenter-dark .column.is-offset-two-fifths, html.theme--documenter-dark .column.is-offset-two-fifths-tablet {
+        margin-left: 40%; }
+      html.theme--documenter-dark .column.is-offset-three-fifths, html.theme--documenter-dark .column.is-offset-three-fifths-tablet {
+        margin-left: 60%; }
+      html.theme--documenter-dark .column.is-offset-four-fifths, html.theme--documenter-dark .column.is-offset-four-fifths-tablet {
+        margin-left: 80%; }
+      html.theme--documenter-dark .column.is-0, html.theme--documenter-dark .column.is-0-tablet {
+        flex: none;
+        width: 0%; }
+      html.theme--documenter-dark .column.is-offset-0, html.theme--documenter-dark .column.is-offset-0-tablet {
+        margin-left: 0%; }
+      html.theme--documenter-dark .column.is-1, html.theme--documenter-dark .column.is-1-tablet {
+        flex: none;
+        width: 8.33333%; }
+      html.theme--documenter-dark .column.is-offset-1, html.theme--documenter-dark .column.is-offset-1-tablet {
+        margin-left: 8.33333%; }
+      html.theme--documenter-dark .column.is-2, html.theme--documenter-dark .column.is-2-tablet {
+        flex: none;
+        width: 16.66667%; }
+      html.theme--documenter-dark .column.is-offset-2, html.theme--documenter-dark .column.is-offset-2-tablet {
+        margin-left: 16.66667%; }
+      html.theme--documenter-dark .column.is-3, html.theme--documenter-dark .column.is-3-tablet {
+        flex: none;
+        width: 25%; }
+      html.theme--documenter-dark .column.is-offset-3, html.theme--documenter-dark .column.is-offset-3-tablet {
+        margin-left: 25%; }
+      html.theme--documenter-dark .column.is-4, html.theme--documenter-dark .column.is-4-tablet {
+        flex: none;
+        width: 33.33333%; }
+      html.theme--documenter-dark .column.is-offset-4, html.theme--documenter-dark .column.is-offset-4-tablet {
+        margin-left: 33.33333%; }
+      html.theme--documenter-dark .column.is-5, html.theme--documenter-dark .column.is-5-tablet {
+        flex: none;
+        width: 41.66667%; }
+      html.theme--documenter-dark .column.is-offset-5, html.theme--documenter-dark .column.is-offset-5-tablet {
+        margin-left: 41.66667%; }
+      html.theme--documenter-dark .column.is-6, html.theme--documenter-dark .column.is-6-tablet {
+        flex: none;
+        width: 50%; }
+      html.theme--documenter-dark .column.is-offset-6, html.theme--documenter-dark .column.is-offset-6-tablet {
+        margin-left: 50%; }
+      html.theme--documenter-dark .column.is-7, html.theme--documenter-dark .column.is-7-tablet {
+        flex: none;
+        width: 58.33333%; }
+      html.theme--documenter-dark .column.is-offset-7, html.theme--documenter-dark .column.is-offset-7-tablet {
+        margin-left: 58.33333%; }
+      html.theme--documenter-dark .column.is-8, html.theme--documenter-dark .column.is-8-tablet {
+        flex: none;
+        width: 66.66667%; }
+      html.theme--documenter-dark .column.is-offset-8, html.theme--documenter-dark .column.is-offset-8-tablet {
+        margin-left: 66.66667%; }
+      html.theme--documenter-dark .column.is-9, html.theme--documenter-dark .column.is-9-tablet {
+        flex: none;
+        width: 75%; }
+      html.theme--documenter-dark .column.is-offset-9, html.theme--documenter-dark .column.is-offset-9-tablet {
+        margin-left: 75%; }
+      html.theme--documenter-dark .column.is-10, html.theme--documenter-dark .column.is-10-tablet {
+        flex: none;
+        width: 83.33333%; }
+      html.theme--documenter-dark .column.is-offset-10, html.theme--documenter-dark .column.is-offset-10-tablet {
+        margin-left: 83.33333%; }
+      html.theme--documenter-dark .column.is-11, html.theme--documenter-dark .column.is-11-tablet {
+        flex: none;
+        width: 91.66667%; }
+      html.theme--documenter-dark .column.is-offset-11, html.theme--documenter-dark .column.is-offset-11-tablet {
+        margin-left: 91.66667%; }
+      html.theme--documenter-dark .column.is-12, html.theme--documenter-dark .column.is-12-tablet {
+        flex: none;
+        width: 100%; }
+      html.theme--documenter-dark .column.is-offset-12, html.theme--documenter-dark .column.is-offset-12-tablet {
+        margin-left: 100%; } }
+    @media screen and (max-width: 1055px) {
+      html.theme--documenter-dark .column.is-narrow-touch {
+        flex: none; }
+      html.theme--documenter-dark .column.is-full-touch {
+        flex: none;
+        width: 100%; }
+      html.theme--documenter-dark .column.is-three-quarters-touch {
+        flex: none;
+        width: 75%; }
+      html.theme--documenter-dark .column.is-two-thirds-touch {
+        flex: none;
+        width: 66.6666%; }
+      html.theme--documenter-dark .column.is-half-touch {
+        flex: none;
+        width: 50%; }
+      html.theme--documenter-dark .column.is-one-third-touch {
+        flex: none;
+        width: 33.3333%; }
+      html.theme--documenter-dark .column.is-one-quarter-touch {
+        flex: none;
+        width: 25%; }
+      html.theme--documenter-dark .column.is-one-fifth-touch {
+        flex: none;
+        width: 20%; }
+      html.theme--documenter-dark .column.is-two-fifths-touch {
+        flex: none;
+        width: 40%; }
+      html.theme--documenter-dark .column.is-three-fifths-touch {
+        flex: none;
+        width: 60%; }
+      html.theme--documenter-dark .column.is-four-fifths-touch {
+        flex: none;
+        width: 80%; }
+      html.theme--documenter-dark .column.is-offset-three-quarters-touch {
+        margin-left: 75%; }
+      html.theme--documenter-dark .column.is-offset-two-thirds-touch {
+        margin-left: 66.6666%; }
+      html.theme--documenter-dark .column.is-offset-half-touch {
+        margin-left: 50%; }
+      html.theme--documenter-dark .column.is-offset-one-third-touch {
+        margin-left: 33.3333%; }
+      html.theme--documenter-dark .column.is-offset-one-quarter-touch {
+        margin-left: 25%; }
+      html.theme--documenter-dark .column.is-offset-one-fifth-touch {
+        margin-left: 20%; }
+      html.theme--documenter-dark .column.is-offset-two-fifths-touch {
+        margin-left: 40%; }
+      html.theme--documenter-dark .column.is-offset-three-fifths-touch {
+        margin-left: 60%; }
+      html.theme--documenter-dark .column.is-offset-four-fifths-touch {
+        margin-left: 80%; }
+      html.theme--documenter-dark .column.is-0-touch {
+        flex: none;
+        width: 0%; }
+      html.theme--documenter-dark .column.is-offset-0-touch {
+        margin-left: 0%; }
+      html.theme--documenter-dark .column.is-1-touch {
+        flex: none;
+        width: 8.33333%; }
+      html.theme--documenter-dark .column.is-offset-1-touch {
+        margin-left: 8.33333%; }
+      html.theme--documenter-dark .column.is-2-touch {
+        flex: none;
+        width: 16.66667%; }
+      html.theme--documenter-dark .column.is-offset-2-touch {
+        margin-left: 16.66667%; }
+      html.theme--documenter-dark .column.is-3-touch {
+        flex: none;
+        width: 25%; }
+      html.theme--documenter-dark .column.is-offset-3-touch {
+        margin-left: 25%; }
+      html.theme--documenter-dark .column.is-4-touch {
+        flex: none;
+        width: 33.33333%; }
+      html.theme--documenter-dark .column.is-offset-4-touch {
+        margin-left: 33.33333%; }
+      html.theme--documenter-dark .column.is-5-touch {
+        flex: none;
+        width: 41.66667%; }
+      html.theme--documenter-dark .column.is-offset-5-touch {
+        margin-left: 41.66667%; }
+      html.theme--documenter-dark .column.is-6-touch {
+        flex: none;
+        width: 50%; }
+      html.theme--documenter-dark .column.is-offset-6-touch {
+        margin-left: 50%; }
+      html.theme--documenter-dark .column.is-7-touch {
+        flex: none;
+        width: 58.33333%; }
+      html.theme--documenter-dark .column.is-offset-7-touch {
+        margin-left: 58.33333%; }
+      html.theme--documenter-dark .column.is-8-touch {
+        flex: none;
+        width: 66.66667%; }
+      html.theme--documenter-dark .column.is-offset-8-touch {
+        margin-left: 66.66667%; }
+      html.theme--documenter-dark .column.is-9-touch {
+        flex: none;
+        width: 75%; }
+      html.theme--documenter-dark .column.is-offset-9-touch {
+        margin-left: 75%; }
+      html.theme--documenter-dark .column.is-10-touch {
+        flex: none;
+        width: 83.33333%; }
+      html.theme--documenter-dark .column.is-offset-10-touch {
+        margin-left: 83.33333%; }
+      html.theme--documenter-dark .column.is-11-touch {
+        flex: none;
+        width: 91.66667%; }
+      html.theme--documenter-dark .column.is-offset-11-touch {
+        margin-left: 91.66667%; }
+      html.theme--documenter-dark .column.is-12-touch {
+        flex: none;
+        width: 100%; }
+      html.theme--documenter-dark .column.is-offset-12-touch {
+        margin-left: 100%; } }
+    @media screen and (min-width: 1056px) {
+      html.theme--documenter-dark .column.is-narrow-desktop {
+        flex: none; }
+      html.theme--documenter-dark .column.is-full-desktop {
+        flex: none;
+        width: 100%; }
+      html.theme--documenter-dark .column.is-three-quarters-desktop {
+        flex: none;
+        width: 75%; }
+      html.theme--documenter-dark .column.is-two-thirds-desktop {
+        flex: none;
+        width: 66.6666%; }
+      html.theme--documenter-dark .column.is-half-desktop {
+        flex: none;
+        width: 50%; }
+      html.theme--documenter-dark .column.is-one-third-desktop {
+        flex: none;
+        width: 33.3333%; }
+      html.theme--documenter-dark .column.is-one-quarter-desktop {
+        flex: none;
+        width: 25%; }
+      html.theme--documenter-dark .column.is-one-fifth-desktop {
+        flex: none;
+        width: 20%; }
+      html.theme--documenter-dark .column.is-two-fifths-desktop {
+        flex: none;
+        width: 40%; }
+      html.theme--documenter-dark .column.is-three-fifths-desktop {
+        flex: none;
+        width: 60%; }
+      html.theme--documenter-dark .column.is-four-fifths-desktop {
+        flex: none;
+        width: 80%; }
+      html.theme--documenter-dark .column.is-offset-three-quarters-desktop {
+        margin-left: 75%; }
+      html.theme--documenter-dark .column.is-offset-two-thirds-desktop {
+        margin-left: 66.6666%; }
+      html.theme--documenter-dark .column.is-offset-half-desktop {
+        margin-left: 50%; }
+      html.theme--documenter-dark .column.is-offset-one-third-desktop {
+        margin-left: 33.3333%; }
+      html.theme--documenter-dark .column.is-offset-one-quarter-desktop {
+        margin-left: 25%; }
+      html.theme--documenter-dark .column.is-offset-one-fifth-desktop {
+        margin-left: 20%; }
+      html.theme--documenter-dark .column.is-offset-two-fifths-desktop {
+        margin-left: 40%; }
+      html.theme--documenter-dark .column.is-offset-three-fifths-desktop {
+        margin-left: 60%; }
+      html.theme--documenter-dark .column.is-offset-four-fifths-desktop {
+        margin-left: 80%; }
+      html.theme--documenter-dark .column.is-0-desktop {
+        flex: none;
+        width: 0%; }
+      html.theme--documenter-dark .column.is-offset-0-desktop {
+        margin-left: 0%; }
+      html.theme--documenter-dark .column.is-1-desktop {
+        flex: none;
+        width: 8.33333%; }
+      html.theme--documenter-dark .column.is-offset-1-desktop {
+        margin-left: 8.33333%; }
+      html.theme--documenter-dark .column.is-2-desktop {
+        flex: none;
+        width: 16.66667%; }
+      html.theme--documenter-dark .column.is-offset-2-desktop {
+        margin-left: 16.66667%; }
+      html.theme--documenter-dark .column.is-3-desktop {
+        flex: none;
+        width: 25%; }
+      html.theme--documenter-dark .column.is-offset-3-desktop {
+        margin-left: 25%; }
+      html.theme--documenter-dark .column.is-4-desktop {
+        flex: none;
+        width: 33.33333%; }
+      html.theme--documenter-dark .column.is-offset-4-desktop {
+        margin-left: 33.33333%; }
+      html.theme--documenter-dark .column.is-5-desktop {
+        flex: none;
+        width: 41.66667%; }
+      html.theme--documenter-dark .column.is-offset-5-desktop {
+        margin-left: 41.66667%; }
+      html.theme--documenter-dark .column.is-6-desktop {
+        flex: none;
+        width: 50%; }
+      html.theme--documenter-dark .column.is-offset-6-desktop {
+        margin-left: 50%; }
+      html.theme--documenter-dark .column.is-7-desktop {
+        flex: none;
+        width: 58.33333%; }
+      html.theme--documenter-dark .column.is-offset-7-desktop {
+        margin-left: 58.33333%; }
+      html.theme--documenter-dark .column.is-8-desktop {
+        flex: none;
+        width: 66.66667%; }
+      html.theme--documenter-dark .column.is-offset-8-desktop {
+        margin-left: 66.66667%; }
+      html.theme--documenter-dark .column.is-9-desktop {
+        flex: none;
+        width: 75%; }
+      html.theme--documenter-dark .column.is-offset-9-desktop {
+        margin-left: 75%; }
+      html.theme--documenter-dark .column.is-10-desktop {
+        flex: none;
+        width: 83.33333%; }
+      html.theme--documenter-dark .column.is-offset-10-desktop {
+        margin-left: 83.33333%; }
+      html.theme--documenter-dark .column.is-11-desktop {
+        flex: none;
+        width: 91.66667%; }
+      html.theme--documenter-dark .column.is-offset-11-desktop {
+        margin-left: 91.66667%; }
+      html.theme--documenter-dark .column.is-12-desktop {
+        flex: none;
+        width: 100%; }
+      html.theme--documenter-dark .column.is-offset-12-desktop {
+        margin-left: 100%; } }
+    @media screen and (min-width: 1216px) {
+      html.theme--documenter-dark .column.is-narrow-widescreen {
+        flex: none; }
+      html.theme--documenter-dark .column.is-full-widescreen {
+        flex: none;
+        width: 100%; }
+      html.theme--documenter-dark .column.is-three-quarters-widescreen {
+        flex: none;
+        width: 75%; }
+      html.theme--documenter-dark .column.is-two-thirds-widescreen {
+        flex: none;
+        width: 66.6666%; }
+      html.theme--documenter-dark .column.is-half-widescreen {
+        flex: none;
+        width: 50%; }
+      html.theme--documenter-dark .column.is-one-third-widescreen {
+        flex: none;
+        width: 33.3333%; }
+      html.theme--documenter-dark .column.is-one-quarter-widescreen {
+        flex: none;
+        width: 25%; }
+      html.theme--documenter-dark .column.is-one-fifth-widescreen {
+        flex: none;
+        width: 20%; }
+      html.theme--documenter-dark .column.is-two-fifths-widescreen {
+        flex: none;
+        width: 40%; }
+      html.theme--documenter-dark .column.is-three-fifths-widescreen {
+        flex: none;
+        width: 60%; }
+      html.theme--documenter-dark .column.is-four-fifths-widescreen {
+        flex: none;
+        width: 80%; }
+      html.theme--documenter-dark .column.is-offset-three-quarters-widescreen {
+        margin-left: 75%; }
+      html.theme--documenter-dark .column.is-offset-two-thirds-widescreen {
+        margin-left: 66.6666%; }
+      html.theme--documenter-dark .column.is-offset-half-widescreen {
+        margin-left: 50%; }
+      html.theme--documenter-dark .column.is-offset-one-third-widescreen {
+        margin-left: 33.3333%; }
+      html.theme--documenter-dark .column.is-offset-one-quarter-widescreen {
+        margin-left: 25%; }
+      html.theme--documenter-dark .column.is-offset-one-fifth-widescreen {
+        margin-left: 20%; }
+      html.theme--documenter-dark .column.is-offset-two-fifths-widescreen {
+        margin-left: 40%; }
+      html.theme--documenter-dark .column.is-offset-three-fifths-widescreen {
+        margin-left: 60%; }
+      html.theme--documenter-dark .column.is-offset-four-fifths-widescreen {
+        margin-left: 80%; }
+      html.theme--documenter-dark .column.is-0-widescreen {
+        flex: none;
+        width: 0%; }
+      html.theme--documenter-dark .column.is-offset-0-widescreen {
+        margin-left: 0%; }
+      html.theme--documenter-dark .column.is-1-widescreen {
+        flex: none;
+        width: 8.33333%; }
+      html.theme--documenter-dark .column.is-offset-1-widescreen {
+        margin-left: 8.33333%; }
+      html.theme--documenter-dark .column.is-2-widescreen {
+        flex: none;
+        width: 16.66667%; }
+      html.theme--documenter-dark .column.is-offset-2-widescreen {
+        margin-left: 16.66667%; }
+      html.theme--documenter-dark .column.is-3-widescreen {
+        flex: none;
+        width: 25%; }
+      html.theme--documenter-dark .column.is-offset-3-widescreen {
+        margin-left: 25%; }
+      html.theme--documenter-dark .column.is-4-widescreen {
+        flex: none;
+        width: 33.33333%; }
+      html.theme--documenter-dark .column.is-offset-4-widescreen {
+        margin-left: 33.33333%; }
+      html.theme--documenter-dark .column.is-5-widescreen {
+        flex: none;
+        width: 41.66667%; }
+      html.theme--documenter-dark .column.is-offset-5-widescreen {
+        margin-left: 41.66667%; }
+      html.theme--documenter-dark .column.is-6-widescreen {
+        flex: none;
+        width: 50%; }
+      html.theme--documenter-dark .column.is-offset-6-widescreen {
+        margin-left: 50%; }
+      html.theme--documenter-dark .column.is-7-widescreen {
+        flex: none;
+        width: 58.33333%; }
+      html.theme--documenter-dark .column.is-offset-7-widescreen {
+        margin-left: 58.33333%; }
+      html.theme--documenter-dark .column.is-8-widescreen {
+        flex: none;
+        width: 66.66667%; }
+      html.theme--documenter-dark .column.is-offset-8-widescreen {
+        margin-left: 66.66667%; }
+      html.theme--documenter-dark .column.is-9-widescreen {
+        flex: none;
+        width: 75%; }
+      html.theme--documenter-dark .column.is-offset-9-widescreen {
+        margin-left: 75%; }
+      html.theme--documenter-dark .column.is-10-widescreen {
+        flex: none;
+        width: 83.33333%; }
+      html.theme--documenter-dark .column.is-offset-10-widescreen {
+        margin-left: 83.33333%; }
+      html.theme--documenter-dark .column.is-11-widescreen {
+        flex: none;
+        width: 91.66667%; }
+      html.theme--documenter-dark .column.is-offset-11-widescreen {
+        margin-left: 91.66667%; }
+      html.theme--documenter-dark .column.is-12-widescreen {
+        flex: none;
+        width: 100%; }
+      html.theme--documenter-dark .column.is-offset-12-widescreen {
+        margin-left: 100%; } }
+    @media screen and (min-width: 1408px) {
+      html.theme--documenter-dark .column.is-narrow-fullhd {
+        flex: none; }
+      html.theme--documenter-dark .column.is-full-fullhd {
+        flex: none;
+        width: 100%; }
+      html.theme--documenter-dark .column.is-three-quarters-fullhd {
+        flex: none;
+        width: 75%; }
+      html.theme--documenter-dark .column.is-two-thirds-fullhd {
+        flex: none;
+        width: 66.6666%; }
+      html.theme--documenter-dark .column.is-half-fullhd {
+        flex: none;
+        width: 50%; }
+      html.theme--documenter-dark .column.is-one-third-fullhd {
+        flex: none;
+        width: 33.3333%; }
+      html.theme--documenter-dark .column.is-one-quarter-fullhd {
+        flex: none;
+        width: 25%; }
+      html.theme--documenter-dark .column.is-one-fifth-fullhd {
+        flex: none;
+        width: 20%; }
+      html.theme--documenter-dark .column.is-two-fifths-fullhd {
+        flex: none;
+        width: 40%; }
+      html.theme--documenter-dark .column.is-three-fifths-fullhd {
+        flex: none;
+        width: 60%; }
+      html.theme--documenter-dark .column.is-four-fifths-fullhd {
+        flex: none;
+        width: 80%; }
+      html.theme--documenter-dark .column.is-offset-three-quarters-fullhd {
+        margin-left: 75%; }
+      html.theme--documenter-dark .column.is-offset-two-thirds-fullhd {
+        margin-left: 66.6666%; }
+      html.theme--documenter-dark .column.is-offset-half-fullhd {
+        margin-left: 50%; }
+      html.theme--documenter-dark .column.is-offset-one-third-fullhd {
+        margin-left: 33.3333%; }
+      html.theme--documenter-dark .column.is-offset-one-quarter-fullhd {
+        margin-left: 25%; }
+      html.theme--documenter-dark .column.is-offset-one-fifth-fullhd {
+        margin-left: 20%; }
+      html.theme--documenter-dark .column.is-offset-two-fifths-fullhd {
+        margin-left: 40%; }
+      html.theme--documenter-dark .column.is-offset-three-fifths-fullhd {
+        margin-left: 60%; }
+      html.theme--documenter-dark .column.is-offset-four-fifths-fullhd {
+        margin-left: 80%; }
+      html.theme--documenter-dark .column.is-0-fullhd {
+        flex: none;
+        width: 0%; }
+      html.theme--documenter-dark .column.is-offset-0-fullhd {
+        margin-left: 0%; }
+      html.theme--documenter-dark .column.is-1-fullhd {
+        flex: none;
+        width: 8.33333%; }
+      html.theme--documenter-dark .column.is-offset-1-fullhd {
+        margin-left: 8.33333%; }
+      html.theme--documenter-dark .column.is-2-fullhd {
+        flex: none;
+        width: 16.66667%; }
+      html.theme--documenter-dark .column.is-offset-2-fullhd {
+        margin-left: 16.66667%; }
+      html.theme--documenter-dark .column.is-3-fullhd {
+        flex: none;
+        width: 25%; }
+      html.theme--documenter-dark .column.is-offset-3-fullhd {
+        margin-left: 25%; }
+      html.theme--documenter-dark .column.is-4-fullhd {
+        flex: none;
+        width: 33.33333%; }
+      html.theme--documenter-dark .column.is-offset-4-fullhd {
+        margin-left: 33.33333%; }
+      html.theme--documenter-dark .column.is-5-fullhd {
+        flex: none;
+        width: 41.66667%; }
+      html.theme--documenter-dark .column.is-offset-5-fullhd {
+        margin-left: 41.66667%; }
+      html.theme--documenter-dark .column.is-6-fullhd {
+        flex: none;
+        width: 50%; }
+      html.theme--documenter-dark .column.is-offset-6-fullhd {
+        margin-left: 50%; }
+      html.theme--documenter-dark .column.is-7-fullhd {
+        flex: none;
+        width: 58.33333%; }
+      html.theme--documenter-dark .column.is-offset-7-fullhd {
+        margin-left: 58.33333%; }
+      html.theme--documenter-dark .column.is-8-fullhd {
+        flex: none;
+        width: 66.66667%; }
+      html.theme--documenter-dark .column.is-offset-8-fullhd {
+        margin-left: 66.66667%; }
+      html.theme--documenter-dark .column.is-9-fullhd {
+        flex: none;
+        width: 75%; }
+      html.theme--documenter-dark .column.is-offset-9-fullhd {
+        margin-left: 75%; }
+      html.theme--documenter-dark .column.is-10-fullhd {
+        flex: none;
+        width: 83.33333%; }
+      html.theme--documenter-dark .column.is-offset-10-fullhd {
+        margin-left: 83.33333%; }
+      html.theme--documenter-dark .column.is-11-fullhd {
+        flex: none;
+        width: 91.66667%; }
+      html.theme--documenter-dark .column.is-offset-11-fullhd {
+        margin-left: 91.66667%; }
+      html.theme--documenter-dark .column.is-12-fullhd {
+        flex: none;
+        width: 100%; }
+      html.theme--documenter-dark .column.is-offset-12-fullhd {
+        margin-left: 100%; } }
+  html.theme--documenter-dark .columns {
+    margin-left: -0.75rem;
+    margin-right: -0.75rem;
+    margin-top: -0.75rem; }
+    html.theme--documenter-dark .columns:last-child {
+      margin-bottom: -0.75rem; }
+    html.theme--documenter-dark .columns:not(:last-child) {
+      margin-bottom: calc(1.5rem - 0.75rem); }
+    html.theme--documenter-dark .columns.is-centered {
+      justify-content: center; }
+    html.theme--documenter-dark .columns.is-gapless {
+      margin-left: 0;
+      margin-right: 0;
+      margin-top: 0; }
+      html.theme--documenter-dark .columns.is-gapless > .column {
+        margin: 0;
+        padding: 0 !important; }
+      html.theme--documenter-dark .columns.is-gapless:not(:last-child) {
+        margin-bottom: 1.5rem; }
+      html.theme--documenter-dark .columns.is-gapless:last-child {
+        margin-bottom: 0; }
+    html.theme--documenter-dark .columns.is-mobile {
+      display: flex; }
+    html.theme--documenter-dark .columns.is-multiline {
+      flex-wrap: wrap; }
+    html.theme--documenter-dark .columns.is-vcentered {
+      align-items: center; }
+    @media screen and (min-width: 769px), print {
+      html.theme--documenter-dark .columns:not(.is-desktop) {
+        display: flex; } }
+    @media screen and (min-width: 1056px) {
+      html.theme--documenter-dark .columns.is-desktop {
+        display: flex; } }
+  html.theme--documenter-dark .columns.is-variable {
+    --columnGap: 0.75rem;
+    margin-left: calc(-1 * var(--columnGap));
+    margin-right: calc(-1 * var(--columnGap)); }
+    html.theme--documenter-dark .columns.is-variable .column {
+      padding-left: var(--columnGap);
+      padding-right: var(--columnGap); }
+    html.theme--documenter-dark .columns.is-variable.is-0 {
+      --columnGap: 0rem; }
+    @media screen and (max-width: 768px) {
+      html.theme--documenter-dark .columns.is-variable.is-0-mobile {
+        --columnGap: 0rem; } }
+    @media screen and (min-width: 769px), print {
+      html.theme--documenter-dark .columns.is-variable.is-0-tablet {
+        --columnGap: 0rem; } }
+    @media screen and (min-width: 769px) and (max-width: 1055px) {
+      html.theme--documenter-dark .columns.is-variable.is-0-tablet-only {
+        --columnGap: 0rem; } }
+    @media screen and (max-width: 1055px) {
+      html.theme--documenter-dark .columns.is-variable.is-0-touch {
+        --columnGap: 0rem; } }
+    @media screen and (min-width: 1056px) {
+      html.theme--documenter-dark .columns.is-variable.is-0-desktop {
+        --columnGap: 0rem; } }
+    @media screen and (min-width: 1056px) and (max-width: 1215px) {
+      html.theme--documenter-dark .columns.is-variable.is-0-desktop-only {
+        --columnGap: 0rem; } }
+    @media screen and (min-width: 1216px) {
+      html.theme--documenter-dark .columns.is-variable.is-0-widescreen {
+        --columnGap: 0rem; } }
+    @media screen and (min-width: 1216px) and (max-width: 1407px) {
+      html.theme--documenter-dark .columns.is-variable.is-0-widescreen-only {
+        --columnGap: 0rem; } }
+    @media screen and (min-width: 1408px) {
+      html.theme--documenter-dark .columns.is-variable.is-0-fullhd {
+        --columnGap: 0rem; } }
+    html.theme--documenter-dark .columns.is-variable.is-1 {
+      --columnGap: 0.25rem; }
+    @media screen and (max-width: 768px) {
+      html.theme--documenter-dark .columns.is-variable.is-1-mobile {
+        --columnGap: 0.25rem; } }
+    @media screen and (min-width: 769px), print {
+      html.theme--documenter-dark .columns.is-variable.is-1-tablet {
+        --columnGap: 0.25rem; } }
+    @media screen and (min-width: 769px) and (max-width: 1055px) {
+      html.theme--documenter-dark .columns.is-variable.is-1-tablet-only {
+        --columnGap: 0.25rem; } }
+    @media screen and (max-width: 1055px) {
+      html.theme--documenter-dark .columns.is-variable.is-1-touch {
+        --columnGap: 0.25rem; } }
+    @media screen and (min-width: 1056px) {
+      html.theme--documenter-dark .columns.is-variable.is-1-desktop {
+        --columnGap: 0.25rem; } }
+    @media screen and (min-width: 1056px) and (max-width: 1215px) {
+      html.theme--documenter-dark .columns.is-variable.is-1-desktop-only {
+        --columnGap: 0.25rem; } }
+    @media screen and (min-width: 1216px) {
+      html.theme--documenter-dark .columns.is-variable.is-1-widescreen {
+        --columnGap: 0.25rem; } }
+    @media screen and (min-width: 1216px) and (max-width: 1407px) {
+      html.theme--documenter-dark .columns.is-variable.is-1-widescreen-only {
+        --columnGap: 0.25rem; } }
+    @media screen and (min-width: 1408px) {
+      html.theme--documenter-dark .columns.is-variable.is-1-fullhd {
+        --columnGap: 0.25rem; } }
+    html.theme--documenter-dark .columns.is-variable.is-2 {
+      --columnGap: 0.5rem; }
+    @media screen and (max-width: 768px) {
+      html.theme--documenter-dark .columns.is-variable.is-2-mobile {
+        --columnGap: 0.5rem; } }
+    @media screen and (min-width: 769px), print {
+      html.theme--documenter-dark .columns.is-variable.is-2-tablet {
+        --columnGap: 0.5rem; } }
+    @media screen and (min-width: 769px) and (max-width: 1055px) {
+      html.theme--documenter-dark .columns.is-variable.is-2-tablet-only {
+        --columnGap: 0.5rem; } }
+    @media screen and (max-width: 1055px) {
+      html.theme--documenter-dark .columns.is-variable.is-2-touch {
+        --columnGap: 0.5rem; } }
+    @media screen and (min-width: 1056px) {
+      html.theme--documenter-dark .columns.is-variable.is-2-desktop {
+        --columnGap: 0.5rem; } }
+    @media screen and (min-width: 1056px) and (max-width: 1215px) {
+      html.theme--documenter-dark .columns.is-variable.is-2-desktop-only {
+        --columnGap: 0.5rem; } }
+    @media screen and (min-width: 1216px) {
+      html.theme--documenter-dark .columns.is-variable.is-2-widescreen {
+        --columnGap: 0.5rem; } }
+    @media screen and (min-width: 1216px) and (max-width: 1407px) {
+      html.theme--documenter-dark .columns.is-variable.is-2-widescreen-only {
+        --columnGap: 0.5rem; } }
+    @media screen and (min-width: 1408px) {
+      html.theme--documenter-dark .columns.is-variable.is-2-fullhd {
+        --columnGap: 0.5rem; } }
+    html.theme--documenter-dark .columns.is-variable.is-3 {
+      --columnGap: 0.75rem; }
+    @media screen and (max-width: 768px) {
+      html.theme--documenter-dark .columns.is-variable.is-3-mobile {
+        --columnGap: 0.75rem; } }
+    @media screen and (min-width: 769px), print {
+      html.theme--documenter-dark .columns.is-variable.is-3-tablet {
+        --columnGap: 0.75rem; } }
+    @media screen and (min-width: 769px) and (max-width: 1055px) {
+      html.theme--documenter-dark .columns.is-variable.is-3-tablet-only {
+        --columnGap: 0.75rem; } }
+    @media screen and (max-width: 1055px) {
+      html.theme--documenter-dark .columns.is-variable.is-3-touch {
+        --columnGap: 0.75rem; } }
+    @media screen and (min-width: 1056px) {
+      html.theme--documenter-dark .columns.is-variable.is-3-desktop {
+        --columnGap: 0.75rem; } }
+    @media screen and (min-width: 1056px) and (max-width: 1215px) {
+      html.theme--documenter-dark .columns.is-variable.is-3-desktop-only {
+        --columnGap: 0.75rem; } }
+    @media screen and (min-width: 1216px) {
+      html.theme--documenter-dark .columns.is-variable.is-3-widescreen {
+        --columnGap: 0.75rem; } }
+    @media screen and (min-width: 1216px) and (max-width: 1407px) {
+      html.theme--documenter-dark .columns.is-variable.is-3-widescreen-only {
+        --columnGap: 0.75rem; } }
+    @media screen and (min-width: 1408px) {
+      html.theme--documenter-dark .columns.is-variable.is-3-fullhd {
+        --columnGap: 0.75rem; } }
+    html.theme--documenter-dark .columns.is-variable.is-4 {
+      --columnGap: 1rem; }
+    @media screen and (max-width: 768px) {
+      html.theme--documenter-dark .columns.is-variable.is-4-mobile {
+        --columnGap: 1rem; } }
+    @media screen and (min-width: 769px), print {
+      html.theme--documenter-dark .columns.is-variable.is-4-tablet {
+        --columnGap: 1rem; } }
+    @media screen and (min-width: 769px) and (max-width: 1055px) {
+      html.theme--documenter-dark .columns.is-variable.is-4-tablet-only {
+        --columnGap: 1rem; } }
+    @media screen and (max-width: 1055px) {
+      html.theme--documenter-dark .columns.is-variable.is-4-touch {
+        --columnGap: 1rem; } }
+    @media screen and (min-width: 1056px) {
+      html.theme--documenter-dark .columns.is-variable.is-4-desktop {
+        --columnGap: 1rem; } }
+    @media screen and (min-width: 1056px) and (max-width: 1215px) {
+      html.theme--documenter-dark .columns.is-variable.is-4-desktop-only {
+        --columnGap: 1rem; } }
+    @media screen and (min-width: 1216px) {
+      html.theme--documenter-dark .columns.is-variable.is-4-widescreen {
+        --columnGap: 1rem; } }
+    @media screen and (min-width: 1216px) and (max-width: 1407px) {
+      html.theme--documenter-dark .columns.is-variable.is-4-widescreen-only {
+        --columnGap: 1rem; } }
+    @media screen and (min-width: 1408px) {
+      html.theme--documenter-dark .columns.is-variable.is-4-fullhd {
+        --columnGap: 1rem; } }
+    html.theme--documenter-dark .columns.is-variable.is-5 {
+      --columnGap: 1.25rem; }
+    @media screen and (max-width: 768px) {
+      html.theme--documenter-dark .columns.is-variable.is-5-mobile {
+        --columnGap: 1.25rem; } }
+    @media screen and (min-width: 769px), print {
+      html.theme--documenter-dark .columns.is-variable.is-5-tablet {
+        --columnGap: 1.25rem; } }
+    @media screen and (min-width: 769px) and (max-width: 1055px) {
+      html.theme--documenter-dark .columns.is-variable.is-5-tablet-only {
+        --columnGap: 1.25rem; } }
+    @media screen and (max-width: 1055px) {
+      html.theme--documenter-dark .columns.is-variable.is-5-touch {
+        --columnGap: 1.25rem; } }
+    @media screen and (min-width: 1056px) {
+      html.theme--documenter-dark .columns.is-variable.is-5-desktop {
+        --columnGap: 1.25rem; } }
+    @media screen and (min-width: 1056px) and (max-width: 1215px) {
+      html.theme--documenter-dark .columns.is-variable.is-5-desktop-only {
+        --columnGap: 1.25rem; } }
+    @media screen and (min-width: 1216px) {
+      html.theme--documenter-dark .columns.is-variable.is-5-widescreen {
+        --columnGap: 1.25rem; } }
+    @media screen and (min-width: 1216px) and (max-width: 1407px) {
+      html.theme--documenter-dark .columns.is-variable.is-5-widescreen-only {
+        --columnGap: 1.25rem; } }
+    @media screen and (min-width: 1408px) {
+      html.theme--documenter-dark .columns.is-variable.is-5-fullhd {
+        --columnGap: 1.25rem; } }
+    html.theme--documenter-dark .columns.is-variable.is-6 {
+      --columnGap: 1.5rem; }
+    @media screen and (max-width: 768px) {
+      html.theme--documenter-dark .columns.is-variable.is-6-mobile {
+        --columnGap: 1.5rem; } }
+    @media screen and (min-width: 769px), print {
+      html.theme--documenter-dark .columns.is-variable.is-6-tablet {
+        --columnGap: 1.5rem; } }
+    @media screen and (min-width: 769px) and (max-width: 1055px) {
+      html.theme--documenter-dark .columns.is-variable.is-6-tablet-only {
+        --columnGap: 1.5rem; } }
+    @media screen and (max-width: 1055px) {
+      html.theme--documenter-dark .columns.is-variable.is-6-touch {
+        --columnGap: 1.5rem; } }
+    @media screen and (min-width: 1056px) {
+      html.theme--documenter-dark .columns.is-variable.is-6-desktop {
+        --columnGap: 1.5rem; } }
+    @media screen and (min-width: 1056px) and (max-width: 1215px) {
+      html.theme--documenter-dark .columns.is-variable.is-6-desktop-only {
+        --columnGap: 1.5rem; } }
+    @media screen and (min-width: 1216px) {
+      html.theme--documenter-dark .columns.is-variable.is-6-widescreen {
+        --columnGap: 1.5rem; } }
+    @media screen and (min-width: 1216px) and (max-width: 1407px) {
+      html.theme--documenter-dark .columns.is-variable.is-6-widescreen-only {
+        --columnGap: 1.5rem; } }
+    @media screen and (min-width: 1408px) {
+      html.theme--documenter-dark .columns.is-variable.is-6-fullhd {
+        --columnGap: 1.5rem; } }
+    html.theme--documenter-dark .columns.is-variable.is-7 {
+      --columnGap: 1.75rem; }
+    @media screen and (max-width: 768px) {
+      html.theme--documenter-dark .columns.is-variable.is-7-mobile {
+        --columnGap: 1.75rem; } }
+    @media screen and (min-width: 769px), print {
+      html.theme--documenter-dark .columns.is-variable.is-7-tablet {
+        --columnGap: 1.75rem; } }
+    @media screen and (min-width: 769px) and (max-width: 1055px) {
+      html.theme--documenter-dark .columns.is-variable.is-7-tablet-only {
+        --columnGap: 1.75rem; } }
+    @media screen and (max-width: 1055px) {
+      html.theme--documenter-dark .columns.is-variable.is-7-touch {
+        --columnGap: 1.75rem; } }
+    @media screen and (min-width: 1056px) {
+      html.theme--documenter-dark .columns.is-variable.is-7-desktop {
+        --columnGap: 1.75rem; } }
+    @media screen and (min-width: 1056px) and (max-width: 1215px) {
+      html.theme--documenter-dark .columns.is-variable.is-7-desktop-only {
+        --columnGap: 1.75rem; } }
+    @media screen and (min-width: 1216px) {
+      html.theme--documenter-dark .columns.is-variable.is-7-widescreen {
+        --columnGap: 1.75rem; } }
+    @media screen and (min-width: 1216px) and (max-width: 1407px) {
+      html.theme--documenter-dark .columns.is-variable.is-7-widescreen-only {
+        --columnGap: 1.75rem; } }
+    @media screen and (min-width: 1408px) {
+      html.theme--documenter-dark .columns.is-variable.is-7-fullhd {
+        --columnGap: 1.75rem; } }
+    html.theme--documenter-dark .columns.is-variable.is-8 {
+      --columnGap: 2rem; }
+    @media screen and (max-width: 768px) {
+      html.theme--documenter-dark .columns.is-variable.is-8-mobile {
+        --columnGap: 2rem; } }
+    @media screen and (min-width: 769px), print {
+      html.theme--documenter-dark .columns.is-variable.is-8-tablet {
+        --columnGap: 2rem; } }
+    @media screen and (min-width: 769px) and (max-width: 1055px) {
+      html.theme--documenter-dark .columns.is-variable.is-8-tablet-only {
+        --columnGap: 2rem; } }
+    @media screen and (max-width: 1055px) {
+      html.theme--documenter-dark .columns.is-variable.is-8-touch {
+        --columnGap: 2rem; } }
+    @media screen and (min-width: 1056px) {
+      html.theme--documenter-dark .columns.is-variable.is-8-desktop {
+        --columnGap: 2rem; } }
+    @media screen and (min-width: 1056px) and (max-width: 1215px) {
+      html.theme--documenter-dark .columns.is-variable.is-8-desktop-only {
+        --columnGap: 2rem; } }
+    @media screen and (min-width: 1216px) {
+      html.theme--documenter-dark .columns.is-variable.is-8-widescreen {
+        --columnGap: 2rem; } }
+    @media screen and (min-width: 1216px) and (max-width: 1407px) {
+      html.theme--documenter-dark .columns.is-variable.is-8-widescreen-only {
+        --columnGap: 2rem; } }
+    @media screen and (min-width: 1408px) {
+      html.theme--documenter-dark .columns.is-variable.is-8-fullhd {
+        --columnGap: 2rem; } }
+  html.theme--documenter-dark .tile {
+    align-items: stretch;
+    display: block;
+    flex-basis: 0;
+    flex-grow: 1;
+    flex-shrink: 1;
+    min-height: min-content; }
+    html.theme--documenter-dark .tile.is-ancestor {
+      margin-left: -0.75rem;
+      margin-right: -0.75rem;
+      margin-top: -0.75rem; }
+      html.theme--documenter-dark .tile.is-ancestor:last-child {
+        margin-bottom: -0.75rem; }
+      html.theme--documenter-dark .tile.is-ancestor:not(:last-child) {
+        margin-bottom: 0.75rem; }
+    html.theme--documenter-dark .tile.is-child {
+      margin: 0 !important; }
+    html.theme--documenter-dark .tile.is-parent {
+      padding: 0.75rem; }
+    html.theme--documenter-dark .tile.is-vertical {
+      flex-direction: column; }
+      html.theme--documenter-dark .tile.is-vertical > .tile.is-child:not(:last-child) {
+        margin-bottom: 1.5rem !important; }
+    @media screen and (min-width: 769px), print {
+      html.theme--documenter-dark .tile:not(.is-child) {
+        display: flex; }
+      html.theme--documenter-dark .tile.is-1 {
+        flex: none;
+        width: 8.33333%; }
+      html.theme--documenter-dark .tile.is-2 {
+        flex: none;
+        width: 16.66667%; }
+      html.theme--documenter-dark .tile.is-3 {
+        flex: none;
+        width: 25%; }
+      html.theme--documenter-dark .tile.is-4 {
+        flex: none;
+        width: 33.33333%; }
+      html.theme--documenter-dark .tile.is-5 {
+        flex: none;
+        width: 41.66667%; }
+      html.theme--documenter-dark .tile.is-6 {
+        flex: none;
+        width: 50%; }
+      html.theme--documenter-dark .tile.is-7 {
+        flex: none;
+        width: 58.33333%; }
+      html.theme--documenter-dark .tile.is-8 {
+        flex: none;
+        width: 66.66667%; }
+      html.theme--documenter-dark .tile.is-9 {
+        flex: none;
+        width: 75%; }
+      html.theme--documenter-dark .tile.is-10 {
+        flex: none;
+        width: 83.33333%; }
+      html.theme--documenter-dark .tile.is-11 {
+        flex: none;
+        width: 91.66667%; }
+      html.theme--documenter-dark .tile.is-12 {
+        flex: none;
+        width: 100%; } }
+  html.theme--documenter-dark .hero {
+    align-items: stretch;
+    display: flex;
+    flex-direction: column;
+    justify-content: space-between; }
+    html.theme--documenter-dark .hero .navbar {
+      background: none; }
+    html.theme--documenter-dark .hero .tabs ul {
+      border-bottom: none; }
+    html.theme--documenter-dark .hero.is-white {
+      background-color: white;
+      color: #0a0a0a; }
+      html.theme--documenter-dark .hero.is-white a:not(.button):not(.dropdown-item):not(.tag):not(.pagination-link.is-current),
+      html.theme--documenter-dark .hero.is-white strong {
+        color: inherit; }
+      html.theme--documenter-dark .hero.is-white .title {
+        color: #0a0a0a; }
+      html.theme--documenter-dark .hero.is-white .subtitle {
+        color: rgba(10, 10, 10, 0.9); }
+        html.theme--documenter-dark .hero.is-white .subtitle a:not(.button),
+        html.theme--documenter-dark .hero.is-white .subtitle strong {
+          color: #0a0a0a; }
+      @media screen and (max-width: 1055px) {
+        html.theme--documenter-dark .hero.is-white .navbar-menu {
+          background-color: white; } }
+      html.theme--documenter-dark .hero.is-white .navbar-item,
+      html.theme--documenter-dark .hero.is-white .navbar-link {
+        color: rgba(10, 10, 10, 0.7); }
+      html.theme--documenter-dark .hero.is-white a.navbar-item:hover, html.theme--documenter-dark .hero.is-white a.navbar-item.is-active,
+      html.theme--documenter-dark .hero.is-white .navbar-link:hover,
+      html.theme--documenter-dark .hero.is-white .navbar-link.is-active {
+        background-color: #f2f2f2;
+        color: #0a0a0a; }
+      html.theme--documenter-dark .hero.is-white .tabs a {
+        color: #0a0a0a;
+        opacity: 0.9; }
+        html.theme--documenter-dark .hero.is-white .tabs a:hover {
+          opacity: 1; }
+      html.theme--documenter-dark .hero.is-white .tabs li.is-active a {
+        opacity: 1; }
+      html.theme--documenter-dark .hero.is-white .tabs.is-boxed a, html.theme--documenter-dark .hero.is-white .tabs.is-toggle a {
+        color: #0a0a0a; }
+        html.theme--documenter-dark .hero.is-white .tabs.is-boxed a:hover, html.theme--documenter-dark .hero.is-white .tabs.is-toggle a:hover {
+          background-color: rgba(10, 10, 10, 0.1); }
+      html.theme--documenter-dark .hero.is-white .tabs.is-boxed li.is-active a, html.theme--documenter-dark .hero.is-white .tabs.is-boxed li.is-active a:hover, html.theme--documenter-dark .hero.is-white .tabs.is-toggle li.is-active a, html.theme--documenter-dark .hero.is-white .tabs.is-toggle li.is-active a:hover {
+        background-color: #0a0a0a;
+        border-color: #0a0a0a;
+        color: white; }
+      html.theme--documenter-dark .hero.is-white.is-bold {
+        background-image: linear-gradient(141deg, #e6e6e6 0%, white 71%, white 100%); }
+        @media screen and (max-width: 768px) {
+          html.theme--documenter-dark .hero.is-white.is-bold .navbar-menu {
+            background-image: linear-gradient(141deg, #e6e6e6 0%, white 71%, white 100%); } }
+    html.theme--documenter-dark .hero.is-black {
+      background-color: #0a0a0a;
+      color: white; }
+      html.theme--documenter-dark .hero.is-black a:not(.button):not(.dropdown-item):not(.tag):not(.pagination-link.is-current),
+      html.theme--documenter-dark .hero.is-black strong {
+        color: inherit; }
+      html.theme--documenter-dark .hero.is-black .title {
+        color: white; }
+      html.theme--documenter-dark .hero.is-black .subtitle {
+        color: rgba(255, 255, 255, 0.9); }
+        html.theme--documenter-dark .hero.is-black .subtitle a:not(.button),
+        html.theme--documenter-dark .hero.is-black .subtitle strong {
+          color: white; }
+      @media screen and (max-width: 1055px) {
+        html.theme--documenter-dark .hero.is-black .navbar-menu {
+          background-color: #0a0a0a; } }
+      html.theme--documenter-dark .hero.is-black .navbar-item,
+      html.theme--documenter-dark .hero.is-black .navbar-link {
+        color: rgba(255, 255, 255, 0.7); }
+      html.theme--documenter-dark .hero.is-black a.navbar-item:hover, html.theme--documenter-dark .hero.is-black a.navbar-item.is-active,
+      html.theme--documenter-dark .hero.is-black .navbar-link:hover,
+      html.theme--documenter-dark .hero.is-black .navbar-link.is-active {
+        background-color: black;
+        color: white; }
+      html.theme--documenter-dark .hero.is-black .tabs a {
+        color: white;
+        opacity: 0.9; }
+        html.theme--documenter-dark .hero.is-black .tabs a:hover {
+          opacity: 1; }
+      html.theme--documenter-dark .hero.is-black .tabs li.is-active a {
+        opacity: 1; }
+      html.theme--documenter-dark .hero.is-black .tabs.is-boxed a, html.theme--documenter-dark .hero.is-black .tabs.is-toggle a {
+        color: white; }
+        html.theme--documenter-dark .hero.is-black .tabs.is-boxed a:hover, html.theme--documenter-dark .hero.is-black .tabs.is-toggle a:hover {
+          background-color: rgba(10, 10, 10, 0.1); }
+      html.theme--documenter-dark .hero.is-black .tabs.is-boxed li.is-active a, html.theme--documenter-dark .hero.is-black .tabs.is-boxed li.is-active a:hover, html.theme--documenter-dark .hero.is-black .tabs.is-toggle li.is-active a, html.theme--documenter-dark .hero.is-black .tabs.is-toggle li.is-active a:hover {
+        background-color: white;
+        border-color: white;
+        color: #0a0a0a; }
+      html.theme--documenter-dark .hero.is-black.is-bold {
+        background-image: linear-gradient(141deg, black 0%, #0a0a0a 71%, #181616 100%); }
+        @media screen and (max-width: 768px) {
+          html.theme--documenter-dark .hero.is-black.is-bold .navbar-menu {
+            background-image: linear-gradient(141deg, black 0%, #0a0a0a 71%, #181616 100%); } }
+    html.theme--documenter-dark .hero.is-light {
+      background-color: #ecf0f1;
+      color: #282f2f; }
+      html.theme--documenter-dark .hero.is-light a:not(.button):not(.dropdown-item):not(.tag):not(.pagination-link.is-current),
+      html.theme--documenter-dark .hero.is-light strong {
+        color: inherit; }
+      html.theme--documenter-dark .hero.is-light .title {
+        color: #282f2f; }
+      html.theme--documenter-dark .hero.is-light .subtitle {
+        color: rgba(40, 47, 47, 0.9); }
+        html.theme--documenter-dark .hero.is-light .subtitle a:not(.button),
+        html.theme--documenter-dark .hero.is-light .subtitle strong {
+          color: #282f2f; }
+      @media screen and (max-width: 1055px) {
+        html.theme--documenter-dark .hero.is-light .navbar-menu {
+          background-color: #ecf0f1; } }
+      html.theme--documenter-dark .hero.is-light .navbar-item,
+      html.theme--documenter-dark .hero.is-light .navbar-link {
+        color: rgba(40, 47, 47, 0.7); }
+      html.theme--documenter-dark .hero.is-light a.navbar-item:hover, html.theme--documenter-dark .hero.is-light a.navbar-item.is-active,
+      html.theme--documenter-dark .hero.is-light .navbar-link:hover,
+      html.theme--documenter-dark .hero.is-light .navbar-link.is-active {
+        background-color: #dde4e6;
+        color: #282f2f; }
+      html.theme--documenter-dark .hero.is-light .tabs a {
+        color: #282f2f;
+        opacity: 0.9; }
+        html.theme--documenter-dark .hero.is-light .tabs a:hover {
+          opacity: 1; }
+      html.theme--documenter-dark .hero.is-light .tabs li.is-active a {
+        opacity: 1; }
+      html.theme--documenter-dark .hero.is-light .tabs.is-boxed a, html.theme--documenter-dark .hero.is-light .tabs.is-toggle a {
+        color: #282f2f; }
+        html.theme--documenter-dark .hero.is-light .tabs.is-boxed a:hover, html.theme--documenter-dark .hero.is-light .tabs.is-toggle a:hover {
+          background-color: rgba(10, 10, 10, 0.1); }
+      html.theme--documenter-dark .hero.is-light .tabs.is-boxed li.is-active a, html.theme--documenter-dark .hero.is-light .tabs.is-boxed li.is-active a:hover, html.theme--documenter-dark .hero.is-light .tabs.is-toggle li.is-active a, html.theme--documenter-dark .hero.is-light .tabs.is-toggle li.is-active a:hover {
+        background-color: #282f2f;
+        border-color: #282f2f;
+        color: #ecf0f1; }
+      html.theme--documenter-dark .hero.is-light.is-bold {
+        background-image: linear-gradient(141deg, #cadfe0 0%, #ecf0f1 71%, #fafbfc 100%); }
+        @media screen and (max-width: 768px) {
+          html.theme--documenter-dark .hero.is-light.is-bold .navbar-menu {
+            background-image: linear-gradient(141deg, #cadfe0 0%, #ecf0f1 71%, #fafbfc 100%); } }
+    html.theme--documenter-dark .hero.is-dark, html.theme--documenter-dark .content kbd.hero {
+      background-color: #282f2f;
+      color: #ecf0f1; }
+      html.theme--documenter-dark .hero.is-dark a:not(.button):not(.dropdown-item):not(.tag):not(.pagination-link.is-current), html.theme--documenter-dark .content kbd.hero a:not(.button):not(.dropdown-item):not(.tag):not(.pagination-link.is-current),
+      html.theme--documenter-dark .hero.is-dark strong,
+      html.theme--documenter-dark .content kbd.hero strong {
+        color: inherit; }
+      html.theme--documenter-dark .hero.is-dark .title, html.theme--documenter-dark .content kbd.hero .title {
+        color: #ecf0f1; }
+      html.theme--documenter-dark .hero.is-dark .subtitle, html.theme--documenter-dark .content kbd.hero .subtitle {
+        color: rgba(236, 240, 241, 0.9); }
+        html.theme--documenter-dark .hero.is-dark .subtitle a:not(.button), html.theme--documenter-dark .content kbd.hero .subtitle a:not(.button),
+        html.theme--documenter-dark .hero.is-dark .subtitle strong,
+        html.theme--documenter-dark .content kbd.hero .subtitle strong {
+          color: #ecf0f1; }
+      @media screen and (max-width: 1055px) {
+        html.theme--documenter-dark .hero.is-dark .navbar-menu, html.theme--documenter-dark .content kbd.hero .navbar-menu {
+          background-color: #282f2f; } }
+      html.theme--documenter-dark .hero.is-dark .navbar-item, html.theme--documenter-dark .content kbd.hero .navbar-item,
+      html.theme--documenter-dark .hero.is-dark .navbar-link,
+      html.theme--documenter-dark .content kbd.hero .navbar-link {
+        color: rgba(236, 240, 241, 0.7); }
+      html.theme--documenter-dark .hero.is-dark a.navbar-item:hover, html.theme--documenter-dark .content kbd.hero a.navbar-item:hover, html.theme--documenter-dark .hero.is-dark a.navbar-item.is-active, html.theme--documenter-dark .content kbd.hero a.navbar-item.is-active,
+      html.theme--documenter-dark .hero.is-dark .navbar-link:hover,
+      html.theme--documenter-dark .content kbd.hero .navbar-link:hover,
+      html.theme--documenter-dark .hero.is-dark .navbar-link.is-active,
+      html.theme--documenter-dark .content kbd.hero .navbar-link.is-active {
+        background-color: #1d2122;
+        color: #ecf0f1; }
+      html.theme--documenter-dark .hero.is-dark .tabs a, html.theme--documenter-dark .content kbd.hero .tabs a {
+        color: #ecf0f1;
+        opacity: 0.9; }
+        html.theme--documenter-dark .hero.is-dark .tabs a:hover, html.theme--documenter-dark .content kbd.hero .tabs a:hover {
+          opacity: 1; }
+      html.theme--documenter-dark .hero.is-dark .tabs li.is-active a, html.theme--documenter-dark .content kbd.hero .tabs li.is-active a {
+        opacity: 1; }
+      html.theme--documenter-dark .hero.is-dark .tabs.is-boxed a, html.theme--documenter-dark .content kbd.hero .tabs.is-boxed a, html.theme--documenter-dark .hero.is-dark .tabs.is-toggle a, html.theme--documenter-dark .content kbd.hero .tabs.is-toggle a {
+        color: #ecf0f1; }
+        html.theme--documenter-dark .hero.is-dark .tabs.is-boxed a:hover, html.theme--documenter-dark .content kbd.hero .tabs.is-boxed a:hover, html.theme--documenter-dark .hero.is-dark .tabs.is-toggle a:hover, html.theme--documenter-dark .content kbd.hero .tabs.is-toggle a:hover {
+          background-color: rgba(10, 10, 10, 0.1); }
+      html.theme--documenter-dark .hero.is-dark .tabs.is-boxed li.is-active a, html.theme--documenter-dark .content kbd.hero .tabs.is-boxed li.is-active a, html.theme--documenter-dark .hero.is-dark .tabs.is-boxed li.is-active a:hover, html.theme--documenter-dark .content kbd.hero .tabs.is-boxed li.is-active a:hover, html.theme--documenter-dark .hero.is-dark .tabs.is-toggle li.is-active a, html.theme--documenter-dark .content kbd.hero .tabs.is-toggle li.is-active a, html.theme--documenter-dark .hero.is-dark .tabs.is-toggle li.is-active a:hover, html.theme--documenter-dark .content kbd.hero .tabs.is-toggle li.is-active a:hover {
+        background-color: #ecf0f1;
+        border-color: #ecf0f1;
+        color: #282f2f; }
+      html.theme--documenter-dark .hero.is-dark.is-bold, html.theme--documenter-dark .content kbd.hero.is-bold {
+        background-image: linear-gradient(141deg, #0f1615 0%, #282f2f 71%, #313c40 100%); }
+        @media screen and (max-width: 768px) {
+          html.theme--documenter-dark .hero.is-dark.is-bold .navbar-menu, html.theme--documenter-dark .content kbd.hero.is-bold .navbar-menu {
+            background-image: linear-gradient(141deg, #0f1615 0%, #282f2f 71%, #313c40 100%); } }
+    html.theme--documenter-dark .hero.is-primary, html.theme--documenter-dark .docstring > section > a.hero.docs-sourcelink {
+      background-color: #375a7f;
+      color: #fff; }
+      html.theme--documenter-dark .hero.is-primary a:not(.button):not(.dropdown-item):not(.tag):not(.pagination-link.is-current), html.theme--documenter-dark .docstring > section > a.hero.docs-sourcelink a:not(.button):not(.dropdown-item):not(.tag):not(.pagination-link.is-current),
+      html.theme--documenter-dark .hero.is-primary strong,
+      html.theme--documenter-dark .docstring > section > a.hero.docs-sourcelink strong {
+        color: inherit; }
+      html.theme--documenter-dark .hero.is-primary .title, html.theme--documenter-dark .docstring > section > a.hero.docs-sourcelink .title {
+        color: #fff; }
+      html.theme--documenter-dark .hero.is-primary .subtitle, html.theme--documenter-dark .docstring > section > a.hero.docs-sourcelink .subtitle {
+        color: rgba(255, 255, 255, 0.9); }
+        html.theme--documenter-dark .hero.is-primary .subtitle a:not(.button), html.theme--documenter-dark .docstring > section > a.hero.docs-sourcelink .subtitle a:not(.button),
+        html.theme--documenter-dark .hero.is-primary .subtitle strong,
+        html.theme--documenter-dark .docstring > section > a.hero.docs-sourcelink .subtitle strong {
+          color: #fff; }
+      @media screen and (max-width: 1055px) {
+        html.theme--documenter-dark .hero.is-primary .navbar-menu, html.theme--documenter-dark .docstring > section > a.hero.docs-sourcelink .navbar-menu {
+          background-color: #375a7f; } }
+      html.theme--documenter-dark .hero.is-primary .navbar-item, html.theme--documenter-dark .docstring > section > a.hero.docs-sourcelink .navbar-item,
+      html.theme--documenter-dark .hero.is-primary .navbar-link,
+      html.theme--documenter-dark .docstring > section > a.hero.docs-sourcelink .navbar-link {
+        color: rgba(255, 255, 255, 0.7); }
+      html.theme--documenter-dark .hero.is-primary a.navbar-item:hover, html.theme--documenter-dark .docstring > section > a.hero.docs-sourcelink a.navbar-item:hover, html.theme--documenter-dark .hero.is-primary a.navbar-item.is-active, html.theme--documenter-dark .docstring > section > a.hero.docs-sourcelink a.navbar-item.is-active,
+      html.theme--documenter-dark .hero.is-primary .navbar-link:hover,
+      html.theme--documenter-dark .docstring > section > a.hero.docs-sourcelink .navbar-link:hover,
+      html.theme--documenter-dark .hero.is-primary .navbar-link.is-active,
+      html.theme--documenter-dark .docstring > section > a.hero.docs-sourcelink .navbar-link.is-active {
+        background-color: #2f4d6d;
+        color: #fff; }
+      html.theme--documenter-dark .hero.is-primary .tabs a, html.theme--documenter-dark .docstring > section > a.hero.docs-sourcelink .tabs a {
+        color: #fff;
+        opacity: 0.9; }
+        html.theme--documenter-dark .hero.is-primary .tabs a:hover, html.theme--documenter-dark .docstring > section > a.hero.docs-sourcelink .tabs a:hover {
+          opacity: 1; }
+      html.theme--documenter-dark .hero.is-primary .tabs li.is-active a, html.theme--documenter-dark .docstring > section > a.hero.docs-sourcelink .tabs li.is-active a {
+        opacity: 1; }
+      html.theme--documenter-dark .hero.is-primary .tabs.is-boxed a, html.theme--documenter-dark .docstring > section > a.hero.docs-sourcelink .tabs.is-boxed a, html.theme--documenter-dark .hero.is-primary .tabs.is-toggle a, html.theme--documenter-dark .docstring > section > a.hero.docs-sourcelink .tabs.is-toggle a {
+        color: #fff; }
+        html.theme--documenter-dark .hero.is-primary .tabs.is-boxed a:hover, html.theme--documenter-dark .docstring > section > a.hero.docs-sourcelink .tabs.is-boxed a:hover, html.theme--documenter-dark .hero.is-primary .tabs.is-toggle a:hover, html.theme--documenter-dark .docstring > section > a.hero.docs-sourcelink .tabs.is-toggle a:hover {
+          background-color: rgba(10, 10, 10, 0.1); }
+      html.theme--documenter-dark .hero.is-primary .tabs.is-boxed li.is-active a, html.theme--documenter-dark .docstring > section > a.hero.docs-sourcelink .tabs.is-boxed li.is-active a, html.theme--documenter-dark .hero.is-primary .tabs.is-boxed li.is-active a:hover, html.theme--documenter-dark .docstring > section > a.hero.docs-sourcelink .tabs.is-boxed li.is-active a:hover, html.theme--documenter-dark .hero.is-primary .tabs.is-toggle li.is-active a, html.theme--documenter-dark .docstring > section > a.hero.docs-sourcelink .tabs.is-toggle li.is-active a, html.theme--documenter-dark .hero.is-primary .tabs.is-toggle li.is-active a:hover, html.theme--documenter-dark .docstring > section > a.hero.docs-sourcelink .tabs.is-toggle li.is-active a:hover {
+        background-color: #fff;
+        border-color: #fff;
+        color: #375a7f; }
+      html.theme--documenter-dark .hero.is-primary.is-bold, html.theme--documenter-dark .docstring > section > a.hero.is-bold.docs-sourcelink {
+        background-image: linear-gradient(141deg, #214b62 0%, #375a7f 71%, #3a5796 100%); }
+        @media screen and (max-width: 768px) {
+          html.theme--documenter-dark .hero.is-primary.is-bold .navbar-menu, html.theme--documenter-dark .docstring > section > a.hero.is-bold.docs-sourcelink .navbar-menu {
+            background-image: linear-gradient(141deg, #214b62 0%, #375a7f 71%, #3a5796 100%); } }
+    html.theme--documenter-dark .hero.is-link {
+      background-color: #1abc9c;
+      color: #fff; }
+      html.theme--documenter-dark .hero.is-link a:not(.button):not(.dropdown-item):not(.tag):not(.pagination-link.is-current),
+      html.theme--documenter-dark .hero.is-link strong {
+        color: inherit; }
+      html.theme--documenter-dark .hero.is-link .title {
+        color: #fff; }
+      html.theme--documenter-dark .hero.is-link .subtitle {
+        color: rgba(255, 255, 255, 0.9); }
+        html.theme--documenter-dark .hero.is-link .subtitle a:not(.button),
+        html.theme--documenter-dark .hero.is-link .subtitle strong {
+          color: #fff; }
+      @media screen and (max-width: 1055px) {
+        html.theme--documenter-dark .hero.is-link .navbar-menu {
+          background-color: #1abc9c; } }
+      html.theme--documenter-dark .hero.is-link .navbar-item,
+      html.theme--documenter-dark .hero.is-link .navbar-link {
+        color: rgba(255, 255, 255, 0.7); }
+      html.theme--documenter-dark .hero.is-link a.navbar-item:hover, html.theme--documenter-dark .hero.is-link a.navbar-item.is-active,
+      html.theme--documenter-dark .hero.is-link .navbar-link:hover,
+      html.theme--documenter-dark .hero.is-link .navbar-link.is-active {
+        background-color: #17a689;
+        color: #fff; }
+      html.theme--documenter-dark .hero.is-link .tabs a {
+        color: #fff;
+        opacity: 0.9; }
+        html.theme--documenter-dark .hero.is-link .tabs a:hover {
+          opacity: 1; }
+      html.theme--documenter-dark .hero.is-link .tabs li.is-active a {
+        opacity: 1; }
+      html.theme--documenter-dark .hero.is-link .tabs.is-boxed a, html.theme--documenter-dark .hero.is-link .tabs.is-toggle a {
+        color: #fff; }
+        html.theme--documenter-dark .hero.is-link .tabs.is-boxed a:hover, html.theme--documenter-dark .hero.is-link .tabs.is-toggle a:hover {
+          background-color: rgba(10, 10, 10, 0.1); }
+      html.theme--documenter-dark .hero.is-link .tabs.is-boxed li.is-active a, html.theme--documenter-dark .hero.is-link .tabs.is-boxed li.is-active a:hover, html.theme--documenter-dark .hero.is-link .tabs.is-toggle li.is-active a, html.theme--documenter-dark .hero.is-link .tabs.is-toggle li.is-active a:hover {
+        background-color: #fff;
+        border-color: #fff;
+        color: #1abc9c; }
+      html.theme--documenter-dark .hero.is-link.is-bold {
+        background-image: linear-gradient(141deg, #0c9764 0%, #1abc9c 71%, #17d8d2 100%); }
+        @media screen and (max-width: 768px) {
+          html.theme--documenter-dark .hero.is-link.is-bold .navbar-menu {
+            background-image: linear-gradient(141deg, #0c9764 0%, #1abc9c 71%, #17d8d2 100%); } }
+    html.theme--documenter-dark .hero.is-info {
+      background-color: #024c7d;
+      color: #fff; }
+      html.theme--documenter-dark .hero.is-info a:not(.button):not(.dropdown-item):not(.tag):not(.pagination-link.is-current),
+      html.theme--documenter-dark .hero.is-info strong {
+        color: inherit; }
+      html.theme--documenter-dark .hero.is-info .title {
+        color: #fff; }
+      html.theme--documenter-dark .hero.is-info .subtitle {
+        color: rgba(255, 255, 255, 0.9); }
+        html.theme--documenter-dark .hero.is-info .subtitle a:not(.button),
+        html.theme--documenter-dark .hero.is-info .subtitle strong {
+          color: #fff; }
+      @media screen and (max-width: 1055px) {
+        html.theme--documenter-dark .hero.is-info .navbar-menu {
+          background-color: #024c7d; } }
+      html.theme--documenter-dark .hero.is-info .navbar-item,
+      html.theme--documenter-dark .hero.is-info .navbar-link {
+        color: rgba(255, 255, 255, 0.7); }
+      html.theme--documenter-dark .hero.is-info a.navbar-item:hover, html.theme--documenter-dark .hero.is-info a.navbar-item.is-active,
+      html.theme--documenter-dark .hero.is-info .navbar-link:hover,
+      html.theme--documenter-dark .hero.is-info .navbar-link.is-active {
+        background-color: #023d64;
+        color: #fff; }
+      html.theme--documenter-dark .hero.is-info .tabs a {
+        color: #fff;
+        opacity: 0.9; }
+        html.theme--documenter-dark .hero.is-info .tabs a:hover {
+          opacity: 1; }
+      html.theme--documenter-dark .hero.is-info .tabs li.is-active a {
+        opacity: 1; }
+      html.theme--documenter-dark .hero.is-info .tabs.is-boxed a, html.theme--documenter-dark .hero.is-info .tabs.is-toggle a {
+        color: #fff; }
+        html.theme--documenter-dark .hero.is-info .tabs.is-boxed a:hover, html.theme--documenter-dark .hero.is-info .tabs.is-toggle a:hover {
+          background-color: rgba(10, 10, 10, 0.1); }
+      html.theme--documenter-dark .hero.is-info .tabs.is-boxed li.is-active a, html.theme--documenter-dark .hero.is-info .tabs.is-boxed li.is-active a:hover, html.theme--documenter-dark .hero.is-info .tabs.is-toggle li.is-active a, html.theme--documenter-dark .hero.is-info .tabs.is-toggle li.is-active a:hover {
+        background-color: #fff;
+        border-color: #fff;
+        color: #024c7d; }
+      html.theme--documenter-dark .hero.is-info.is-bold {
+        background-image: linear-gradient(141deg, #003a4c 0%, #024c7d 71%, #004299 100%); }
+        @media screen and (max-width: 768px) {
+          html.theme--documenter-dark .hero.is-info.is-bold .navbar-menu {
+            background-image: linear-gradient(141deg, #003a4c 0%, #024c7d 71%, #004299 100%); } }
+    html.theme--documenter-dark .hero.is-success {
+      background-color: #008438;
+      color: #fff; }
+      html.theme--documenter-dark .hero.is-success a:not(.button):not(.dropdown-item):not(.tag):not(.pagination-link.is-current),
+      html.theme--documenter-dark .hero.is-success strong {
+        color: inherit; }
+      html.theme--documenter-dark .hero.is-success .title {
+        color: #fff; }
+      html.theme--documenter-dark .hero.is-success .subtitle {
+        color: rgba(255, 255, 255, 0.9); }
+        html.theme--documenter-dark .hero.is-success .subtitle a:not(.button),
+        html.theme--documenter-dark .hero.is-success .subtitle strong {
+          color: #fff; }
+      @media screen and (max-width: 1055px) {
+        html.theme--documenter-dark .hero.is-success .navbar-menu {
+          background-color: #008438; } }
+      html.theme--documenter-dark .hero.is-success .navbar-item,
+      html.theme--documenter-dark .hero.is-success .navbar-link {
+        color: rgba(255, 255, 255, 0.7); }
+      html.theme--documenter-dark .hero.is-success a.navbar-item:hover, html.theme--documenter-dark .hero.is-success a.navbar-item.is-active,
+      html.theme--documenter-dark .hero.is-success .navbar-link:hover,
+      html.theme--documenter-dark .hero.is-success .navbar-link.is-active {
+        background-color: #006b2d;
+        color: #fff; }
+      html.theme--documenter-dark .hero.is-success .tabs a {
+        color: #fff;
+        opacity: 0.9; }
+        html.theme--documenter-dark .hero.is-success .tabs a:hover {
+          opacity: 1; }
+      html.theme--documenter-dark .hero.is-success .tabs li.is-active a {
+        opacity: 1; }
+      html.theme--documenter-dark .hero.is-success .tabs.is-boxed a, html.theme--documenter-dark .hero.is-success .tabs.is-toggle a {
+        color: #fff; }
+        html.theme--documenter-dark .hero.is-success .tabs.is-boxed a:hover, html.theme--documenter-dark .hero.is-success .tabs.is-toggle a:hover {
+          background-color: rgba(10, 10, 10, 0.1); }
+      html.theme--documenter-dark .hero.is-success .tabs.is-boxed li.is-active a, html.theme--documenter-dark .hero.is-success .tabs.is-boxed li.is-active a:hover, html.theme--documenter-dark .hero.is-success .tabs.is-toggle li.is-active a, html.theme--documenter-dark .hero.is-success .tabs.is-toggle li.is-active a:hover {
+        background-color: #fff;
+        border-color: #fff;
+        color: #008438; }
+      html.theme--documenter-dark .hero.is-success.is-bold {
+        background-image: linear-gradient(141deg, #005115 0%, #008438 71%, #009e5d 100%); }
+        @media screen and (max-width: 768px) {
+          html.theme--documenter-dark .hero.is-success.is-bold .navbar-menu {
+            background-image: linear-gradient(141deg, #005115 0%, #008438 71%, #009e5d 100%); } }
+    html.theme--documenter-dark .hero.is-warning {
+      background-color: #ad8100;
+      color: #fff; }
+      html.theme--documenter-dark .hero.is-warning a:not(.button):not(.dropdown-item):not(.tag):not(.pagination-link.is-current),
+      html.theme--documenter-dark .hero.is-warning strong {
+        color: inherit; }
+      html.theme--documenter-dark .hero.is-warning .title {
+        color: #fff; }
+      html.theme--documenter-dark .hero.is-warning .subtitle {
+        color: rgba(255, 255, 255, 0.9); }
+        html.theme--documenter-dark .hero.is-warning .subtitle a:not(.button),
+        html.theme--documenter-dark .hero.is-warning .subtitle strong {
+          color: #fff; }
+      @media screen and (max-width: 1055px) {
+        html.theme--documenter-dark .hero.is-warning .navbar-menu {
+          background-color: #ad8100; } }
+      html.theme--documenter-dark .hero.is-warning .navbar-item,
+      html.theme--documenter-dark .hero.is-warning .navbar-link {
+        color: rgba(255, 255, 255, 0.7); }
+      html.theme--documenter-dark .hero.is-warning a.navbar-item:hover, html.theme--documenter-dark .hero.is-warning a.navbar-item.is-active,
+      html.theme--documenter-dark .hero.is-warning .navbar-link:hover,
+      html.theme--documenter-dark .hero.is-warning .navbar-link.is-active {
+        background-color: #946e00;
+        color: #fff; }
+      html.theme--documenter-dark .hero.is-warning .tabs a {
+        color: #fff;
+        opacity: 0.9; }
+        html.theme--documenter-dark .hero.is-warning .tabs a:hover {
+          opacity: 1; }
+      html.theme--documenter-dark .hero.is-warning .tabs li.is-active a {
+        opacity: 1; }
+      html.theme--documenter-dark .hero.is-warning .tabs.is-boxed a, html.theme--documenter-dark .hero.is-warning .tabs.is-toggle a {
+        color: #fff; }
+        html.theme--documenter-dark .hero.is-warning .tabs.is-boxed a:hover, html.theme--documenter-dark .hero.is-warning .tabs.is-toggle a:hover {
+          background-color: rgba(10, 10, 10, 0.1); }
+      html.theme--documenter-dark .hero.is-warning .tabs.is-boxed li.is-active a, html.theme--documenter-dark .hero.is-warning .tabs.is-boxed li.is-active a:hover, html.theme--documenter-dark .hero.is-warning .tabs.is-toggle li.is-active a, html.theme--documenter-dark .hero.is-warning .tabs.is-toggle li.is-active a:hover {
+        background-color: #fff;
+        border-color: #fff;
+        color: #ad8100; }
+      html.theme--documenter-dark .hero.is-warning.is-bold {
+        background-image: linear-gradient(141deg, #7a4700 0%, #ad8100 71%, #c7b500 100%); }
+        @media screen and (max-width: 768px) {
+          html.theme--documenter-dark .hero.is-warning.is-bold .navbar-menu {
+            background-image: linear-gradient(141deg, #7a4700 0%, #ad8100 71%, #c7b500 100%); } }
+    html.theme--documenter-dark .hero.is-danger {
+      background-color: #9e1b0d;
+      color: #fff; }
+      html.theme--documenter-dark .hero.is-danger a:not(.button):not(.dropdown-item):not(.tag):not(.pagination-link.is-current),
+      html.theme--documenter-dark .hero.is-danger strong {
+        color: inherit; }
+      html.theme--documenter-dark .hero.is-danger .title {
+        color: #fff; }
+      html.theme--documenter-dark .hero.is-danger .subtitle {
+        color: rgba(255, 255, 255, 0.9); }
+        html.theme--documenter-dark .hero.is-danger .subtitle a:not(.button),
+        html.theme--documenter-dark .hero.is-danger .subtitle strong {
+          color: #fff; }
+      @media screen and (max-width: 1055px) {
+        html.theme--documenter-dark .hero.is-danger .navbar-menu {
+          background-color: #9e1b0d; } }
+      html.theme--documenter-dark .hero.is-danger .navbar-item,
+      html.theme--documenter-dark .hero.is-danger .navbar-link {
+        color: rgba(255, 255, 255, 0.7); }
+      html.theme--documenter-dark .hero.is-danger a.navbar-item:hover, html.theme--documenter-dark .hero.is-danger a.navbar-item.is-active,
+      html.theme--documenter-dark .hero.is-danger .navbar-link:hover,
+      html.theme--documenter-dark .hero.is-danger .navbar-link.is-active {
+        background-color: #86170b;
+        color: #fff; }
+      html.theme--documenter-dark .hero.is-danger .tabs a {
+        color: #fff;
+        opacity: 0.9; }
+        html.theme--documenter-dark .hero.is-danger .tabs a:hover {
+          opacity: 1; }
+      html.theme--documenter-dark .hero.is-danger .tabs li.is-active a {
+        opacity: 1; }
+      html.theme--documenter-dark .hero.is-danger .tabs.is-boxed a, html.theme--documenter-dark .hero.is-danger .tabs.is-toggle a {
+        color: #fff; }
+        html.theme--documenter-dark .hero.is-danger .tabs.is-boxed a:hover, html.theme--documenter-dark .hero.is-danger .tabs.is-toggle a:hover {
+          background-color: rgba(10, 10, 10, 0.1); }
+      html.theme--documenter-dark .hero.is-danger .tabs.is-boxed li.is-active a, html.theme--documenter-dark .hero.is-danger .tabs.is-boxed li.is-active a:hover, html.theme--documenter-dark .hero.is-danger .tabs.is-toggle li.is-active a, html.theme--documenter-dark .hero.is-danger .tabs.is-toggle li.is-active a:hover {
+        background-color: #fff;
+        border-color: #fff;
+        color: #9e1b0d; }
+      html.theme--documenter-dark .hero.is-danger.is-bold {
+        background-image: linear-gradient(141deg, #75030b 0%, #9e1b0d 71%, #ba380a 100%); }
+        @media screen and (max-width: 768px) {
+          html.theme--documenter-dark .hero.is-danger.is-bold .navbar-menu {
+            background-image: linear-gradient(141deg, #75030b 0%, #9e1b0d 71%, #ba380a 100%); } }
+    html.theme--documenter-dark .hero.is-small .hero-body, html.theme--documenter-dark #documenter .docs-sidebar form.docs-search > input.hero .hero-body {
+      padding-bottom: 1.5rem;
+      padding-top: 1.5rem; }
+    @media screen and (min-width: 769px), print {
+      html.theme--documenter-dark .hero.is-medium .hero-body {
+        padding-bottom: 9rem;
+        padding-top: 9rem; } }
+    @media screen and (min-width: 769px), print {
+      html.theme--documenter-dark .hero.is-large .hero-body {
+        padding-bottom: 18rem;
+        padding-top: 18rem; } }
+    html.theme--documenter-dark .hero.is-halfheight .hero-body, html.theme--documenter-dark .hero.is-fullheight .hero-body, html.theme--documenter-dark .hero.is-fullheight-with-navbar .hero-body {
+      align-items: center;
+      display: flex; }
+      html.theme--documenter-dark .hero.is-halfheight .hero-body > .container, html.theme--documenter-dark .hero.is-fullheight .hero-body > .container, html.theme--documenter-dark .hero.is-fullheight-with-navbar .hero-body > .container {
+        flex-grow: 1;
+        flex-shrink: 1; }
+    html.theme--documenter-dark .hero.is-halfheight {
+      min-height: 50vh; }
+    html.theme--documenter-dark .hero.is-fullheight {
+      min-height: 100vh; }
+  html.theme--documenter-dark .hero-video {
+    overflow: hidden; }
+    html.theme--documenter-dark .hero-video video {
+      left: 50%;
+      min-height: 100%;
+      min-width: 100%;
+      position: absolute;
+      top: 50%;
+      transform: translate3d(-50%, -50%, 0); }
+    html.theme--documenter-dark .hero-video.is-transparent {
+      opacity: 0.3; }
+    @media screen and (max-width: 768px) {
+      html.theme--documenter-dark .hero-video {
+        display: none; } }
+  html.theme--documenter-dark .hero-buttons {
+    margin-top: 1.5rem; }
+    @media screen and (max-width: 768px) {
+      html.theme--documenter-dark .hero-buttons .button {
+        display: flex; }
+        html.theme--documenter-dark .hero-buttons .button:not(:last-child) {
+          margin-bottom: 0.75rem; } }
+    @media screen and (min-width: 769px), print {
+      html.theme--documenter-dark .hero-buttons {
+        display: flex;
+        justify-content: center; }
+        html.theme--documenter-dark .hero-buttons .button:not(:last-child) {
+          margin-right: 1.5rem; } }
+  html.theme--documenter-dark .hero-head,
+  html.theme--documenter-dark .hero-foot {
+    flex-grow: 0;
+    flex-shrink: 0; }
+  html.theme--documenter-dark .hero-body {
+    flex-grow: 1;
+    flex-shrink: 0;
+    padding: 3rem 1.5rem; }
+  html.theme--documenter-dark .section {
+    padding: 3rem 1.5rem; }
+    @media screen and (min-width: 1056px) {
+      html.theme--documenter-dark .section.is-medium {
+        padding: 9rem 1.5rem; }
+      html.theme--documenter-dark .section.is-large {
+        padding: 18rem 1.5rem; } }
+  html.theme--documenter-dark .footer {
+    background-color: #282f2f;
+    padding: 3rem 1.5rem 6rem; }
+  html.theme--documenter-dark hr {
+    height: 1px; }
+  html.theme--documenter-dark h6 {
+    text-transform: uppercase;
+    letter-spacing: 0.5px; }
+  html.theme--documenter-dark .hero {
+    background-color: #343c3d; }
+  html.theme--documenter-dark a {
+    transition: all 200ms ease; }
+  html.theme--documenter-dark .button {
+    transition: all 200ms ease;
+    border-width: 1px;
+    color: white; }
+    html.theme--documenter-dark .button.is-active, html.theme--documenter-dark .button.is-focused, html.theme--documenter-dark .button:active, html.theme--documenter-dark .button:focus {
+      box-shadow: 0 0 0 2px rgba(140, 155, 157, 0.5); }
+    html.theme--documenter-dark .button.is-white.is-hovered, html.theme--documenter-dark .button.is-white:hover {
+      background-color: white; }
+    html.theme--documenter-dark .button.is-white.is-active, html.theme--documenter-dark .button.is-white.is-focused, html.theme--documenter-dark .button.is-white:active, html.theme--documenter-dark .button.is-white:focus {
+      border-color: white;
+      box-shadow: 0 0 0 2px rgba(255, 255, 255, 0.5); }
+    html.theme--documenter-dark .button.is-black.is-hovered, html.theme--documenter-dark .button.is-black:hover {
+      background-color: #1d1d1d; }
+    html.theme--documenter-dark .button.is-black.is-active, html.theme--documenter-dark .button.is-black.is-focused, html.theme--documenter-dark .button.is-black:active, html.theme--documenter-dark .button.is-black:focus {
+      border-color: #0a0a0a;
+      box-shadow: 0 0 0 2px rgba(10, 10, 10, 0.5); }
+    html.theme--documenter-dark .button.is-light.is-hovered, html.theme--documenter-dark .button.is-light:hover {
+      background-color: white; }
+    html.theme--documenter-dark .button.is-light.is-active, html.theme--documenter-dark .button.is-light.is-focused, html.theme--documenter-dark .button.is-light:active, html.theme--documenter-dark .button.is-light:focus {
+      border-color: #ecf0f1;
+      box-shadow: 0 0 0 2px rgba(236, 240, 241, 0.5); }
+    html.theme--documenter-dark .button.is-dark.is-hovered, html.theme--documenter-dark .content kbd.button.is-hovered, html.theme--documenter-dark .button.is-dark:hover, html.theme--documenter-dark .content kbd.button:hover {
+      background-color: #3a4344; }
+    html.theme--documenter-dark .button.is-dark.is-active, html.theme--documenter-dark .content kbd.button.is-active, html.theme--documenter-dark .button.is-dark.is-focused, html.theme--documenter-dark .content kbd.button.is-focused, html.theme--documenter-dark .button.is-dark:active, html.theme--documenter-dark .content kbd.button:active, html.theme--documenter-dark .button.is-dark:focus, html.theme--documenter-dark .content kbd.button:focus {
+      border-color: #282f2f;
+      box-shadow: 0 0 0 2px rgba(40, 47, 47, 0.5); }
+    html.theme--documenter-dark .button.is-primary.is-hovered, html.theme--documenter-dark .docstring > section > a.button.is-hovered.docs-sourcelink, html.theme--documenter-dark .button.is-primary:hover, html.theme--documenter-dark .docstring > section > a.button.docs-sourcelink:hover {
+      background-color: #436d9a; }
+    html.theme--documenter-dark .button.is-primary.is-active, html.theme--documenter-dark .docstring > section > a.button.is-active.docs-sourcelink, html.theme--documenter-dark .button.is-primary.is-focused, html.theme--documenter-dark .docstring > section > a.button.is-focused.docs-sourcelink, html.theme--documenter-dark .button.is-primary:active, html.theme--documenter-dark .docstring > section > a.button.docs-sourcelink:active, html.theme--documenter-dark .button.is-primary:focus, html.theme--documenter-dark .docstring > section > a.button.docs-sourcelink:focus {
+      border-color: #375a7f;
+      box-shadow: 0 0 0 2px rgba(55, 90, 127, 0.5); }
+    html.theme--documenter-dark .button.is-link.is-hovered, html.theme--documenter-dark .button.is-link:hover {
+      background-color: #1fdeb8; }
+    html.theme--documenter-dark .button.is-link.is-active, html.theme--documenter-dark .button.is-link.is-focused, html.theme--documenter-dark .button.is-link:active, html.theme--documenter-dark .button.is-link:focus {
+      border-color: #1abc9c;
+      box-shadow: 0 0 0 2px rgba(26, 188, 156, 0.5); }
+    html.theme--documenter-dark .button.is-info.is-hovered, html.theme--documenter-dark .button.is-info:hover {
+      background-color: #0363a3; }
+    html.theme--documenter-dark .button.is-info.is-active, html.theme--documenter-dark .button.is-info.is-focused, html.theme--documenter-dark .button.is-info:active, html.theme--documenter-dark .button.is-info:focus {
+      border-color: #024c7d;
+      box-shadow: 0 0 0 2px rgba(2, 76, 125, 0.5); }
+    html.theme--documenter-dark .button.is-success.is-hovered, html.theme--documenter-dark .button.is-success:hover {
+      background-color: #00aa48; }
+    html.theme--documenter-dark .button.is-success.is-active, html.theme--documenter-dark .button.is-success.is-focused, html.theme--documenter-dark .button.is-success:active, html.theme--documenter-dark .button.is-success:focus {
+      border-color: #008438;
+      box-shadow: 0 0 0 2px rgba(0, 132, 56, 0.5); }
+    html.theme--documenter-dark .button.is-warning.is-hovered, html.theme--documenter-dark .button.is-warning:hover {
+      background-color: #d39e00; }
+    html.theme--documenter-dark .button.is-warning.is-active, html.theme--documenter-dark .button.is-warning.is-focused, html.theme--documenter-dark .button.is-warning:active, html.theme--documenter-dark .button.is-warning:focus {
+      border-color: #ad8100;
+      box-shadow: 0 0 0 2px rgba(173, 129, 0, 0.5); }
+    html.theme--documenter-dark .button.is-danger.is-hovered, html.theme--documenter-dark .button.is-danger:hover {
+      background-color: #c12110; }
+    html.theme--documenter-dark .button.is-danger.is-active, html.theme--documenter-dark .button.is-danger.is-focused, html.theme--documenter-dark .button.is-danger:active, html.theme--documenter-dark .button.is-danger:focus {
+      border-color: #9e1b0d;
+      box-shadow: 0 0 0 2px rgba(158, 27, 13, 0.5); }
+  html.theme--documenter-dark .label {
+    color: #dbdee0; }
+  html.theme--documenter-dark .button,
+  html.theme--documenter-dark .control.has-icons-left .icon,
+  html.theme--documenter-dark .control.has-icons-right .icon,
+  html.theme--documenter-dark .input,
+  html.theme--documenter-dark #documenter .docs-sidebar form.docs-search > input,
+  html.theme--documenter-dark .pagination-ellipsis,
+  html.theme--documenter-dark .pagination-link,
+  html.theme--documenter-dark .pagination-next,
+  html.theme--documenter-dark .pagination-previous,
+  html.theme--documenter-dark .select,
+  html.theme--documenter-dark .select select,
+  html.theme--documenter-dark .textarea {
+    height: 2.5em; }
+  
+  html.theme--documenter-dark .input,
+  html.theme--documenter-dark #documenter .docs-sidebar form.docs-search > input,
+  html.theme--documenter-dark .textarea {
+    transition: all 200ms ease;
+    box-shadow: none;
+    border-width: 1px;
+    padding-left: 1em;
+    padding-right: 1em; }
+  html.theme--documenter-dark .select:after,
+  html.theme--documenter-dark .select select {
+    border-width: 1px; }
+  html.theme--documenter-dark .control.has-addons .button,
+  html.theme--documenter-dark .control.has-addons .input,
+  html.theme--documenter-dark .control.has-addons #documenter .docs-sidebar form.docs-search > input,
+  html.theme--documenter-dark #documenter .docs-sidebar .control.has-addons form.docs-search > input,
+  html.theme--documenter-dark .control.has-addons .select {
+    margin-right: -1px; }
+  html.theme--documenter-dark .notification {
+    background-color: #343c3d; }
+  html.theme--documenter-dark .card {
+    box-shadow: none;
+    border: 1px solid #343c3d;
+    background-color: #282f2f;
+    border-radius: 0.4em; }
+    html.theme--documenter-dark .card .card-image img {
+      border-radius: 0.4em 0.4em 0 0; }
+    html.theme--documenter-dark .card .card-header {
+      box-shadow: none;
+      background-color: rgba(18, 18, 18, 0.2);
+      border-radius: 0.4em 0.4em 0 0; }
+    html.theme--documenter-dark .card .card-footer {
+      background-color: rgba(18, 18, 18, 0.2); }
+    html.theme--documenter-dark .card .card-footer,
+    html.theme--documenter-dark .card .card-footer-item {
+      border-width: 1px;
+      border-color: #343c3d; }
+  html.theme--documenter-dark .notification.is-white a:not(.button) {
+    color: #0a0a0a;
+    text-decoration: underline; }
+  html.theme--documenter-dark .notification.is-black a:not(.button) {
+    color: white;
+    text-decoration: underline; }
+  html.theme--documenter-dark .notification.is-light a:not(.button) {
+    color: #282f2f;
+    text-decoration: underline; }
+  html.theme--documenter-dark .notification.is-dark a:not(.button), html.theme--documenter-dark .content kbd.notification a:not(.button) {
+    color: #ecf0f1;
+    text-decoration: underline; }
+  html.theme--documenter-dark .notification.is-primary a:not(.button), html.theme--documenter-dark .docstring > section > a.notification.docs-sourcelink a:not(.button) {
+    color: #fff;
+    text-decoration: underline; }
+  html.theme--documenter-dark .notification.is-link a:not(.button) {
+    color: #fff;
+    text-decoration: underline; }
+  html.theme--documenter-dark .notification.is-info a:not(.button) {
+    color: #fff;
+    text-decoration: underline; }
+  html.theme--documenter-dark .notification.is-success a:not(.button) {
+    color: #fff;
+    text-decoration: underline; }
+  html.theme--documenter-dark .notification.is-warning a:not(.button) {
+    color: #fff;
+    text-decoration: underline; }
+  html.theme--documenter-dark .notification.is-danger a:not(.button) {
+    color: #fff;
+    text-decoration: underline; }
+  html.theme--documenter-dark .tag, html.theme--documenter-dark .docstring > section > a.docs-sourcelink, html.theme--documenter-dark .content kbd {
+    border-radius: 0.4em; }
+  html.theme--documenter-dark .menu-list a {
+    transition: all 300ms ease; }
+  html.theme--documenter-dark .modal-card-body {
+    background-color: #282f2f; }
+  html.theme--documenter-dark .modal-card-foot,
+  html.theme--documenter-dark .modal-card-head {
+    border-color: #343c3d; }
+  html.theme--documenter-dark .message-header {
+    font-weight: 700;
+    background-color: #343c3d;
+    color: white; }
+  html.theme--documenter-dark .message-body {
+    border-width: 1px;
+    border-color: #343c3d; }
+  html.theme--documenter-dark .navbar {
+    border-radius: 0.4em; }
+    html.theme--documenter-dark .navbar.is-transparent {
+      background: none; }
+    html.theme--documenter-dark .navbar.is-primary .navbar-dropdown a.navbar-item.is-active, html.theme--documenter-dark .docstring > section > a.navbar.docs-sourcelink .navbar-dropdown a.navbar-item.is-active {
+      background-color: #1abc9c; }
+    @media screen and (max-width: 1055px) {
+      html.theme--documenter-dark .navbar .navbar-menu {
+        background-color: #375a7f;
+        border-radius: 0 0 0.4em 0.4em; } }
+  html.theme--documenter-dark .hero .navbar,
+  html.theme--documenter-dark body > .navbar {
+    border-radius: 0; }
+  html.theme--documenter-dark .pagination-link,
+  html.theme--documenter-dark .pagination-next,
+  html.theme--documenter-dark .pagination-previous {
+    border-width: 1px; }
+  html.theme--documenter-dark .panel-block,
+  html.theme--documenter-dark .panel-heading,
+  html.theme--documenter-dark .panel-tabs {
+    border-width: 1px; }
+    html.theme--documenter-dark .panel-block:first-child,
+    html.theme--documenter-dark .panel-heading:first-child,
+    html.theme--documenter-dark .panel-tabs:first-child {
+      border-top-width: 1px; }
+  html.theme--documenter-dark .panel-heading {
+    font-weight: 700; }
+  html.theme--documenter-dark .panel-tabs a {
+    border-width: 1px;
+    margin-bottom: -1px; }
+    html.theme--documenter-dark .panel-tabs a.is-active {
+      border-bottom-color: #17a689; }
+  html.theme--documenter-dark .panel-block:hover {
+    color: #1dd2af; }
+    html.theme--documenter-dark .panel-block:hover .panel-icon {
+      color: #1dd2af; }
+  html.theme--documenter-dark .panel-block.is-active .panel-icon {
+    color: #17a689; }
+  html.theme--documenter-dark .tabs a {
+    border-bottom-width: 1px;
+    margin-bottom: -1px; }
+  html.theme--documenter-dark .tabs ul {
+    border-bottom-width: 1px; }
+  html.theme--documenter-dark .tabs.is-boxed a {
+    border-width: 1px; }
+  html.theme--documenter-dark .tabs.is-boxed li.is-active a {
+    background-color: #1f2424; }
+  html.theme--documenter-dark .tabs.is-toggle li a {
+    border-width: 1px;
+    margin-bottom: 0; }
+  html.theme--documenter-dark .tabs.is-toggle li + li {
+    margin-left: -1px; }
+  html.theme--documenter-dark .hero.is-white .navbar .navbar-dropdown .navbar-item:hover {
+    background-color: transparent; }
+  html.theme--documenter-dark .hero.is-black .navbar .navbar-dropdown .navbar-item:hover {
+    background-color: transparent; }
+  html.theme--documenter-dark .hero.is-light .navbar .navbar-dropdown .navbar-item:hover {
+    background-color: transparent; }
+  html.theme--documenter-dark .hero.is-dark .navbar .navbar-dropdown .navbar-item:hover, html.theme--documenter-dark .content kbd.hero .navbar .navbar-dropdown .navbar-item:hover {
+    background-color: transparent; }
+  html.theme--documenter-dark .hero.is-primary .navbar .navbar-dropdown .navbar-item:hover, html.theme--documenter-dark .docstring > section > a.hero.docs-sourcelink .navbar .navbar-dropdown .navbar-item:hover {
+    background-color: transparent; }
+  html.theme--documenter-dark .hero.is-link .navbar .navbar-dropdown .navbar-item:hover {
+    background-color: transparent; }
+  html.theme--documenter-dark .hero.is-info .navbar .navbar-dropdown .navbar-item:hover {
+    background-color: transparent; }
+  html.theme--documenter-dark .hero.is-success .navbar .navbar-dropdown .navbar-item:hover {
+    background-color: transparent; }
+  html.theme--documenter-dark .hero.is-warning .navbar .navbar-dropdown .navbar-item:hover {
+    background-color: transparent; }
+  html.theme--documenter-dark .hero.is-danger .navbar .navbar-dropdown .navbar-item:hover {
+    background-color: transparent; }
+  html.theme--documenter-dark h1 .docs-heading-anchor, html.theme--documenter-dark h1 .docs-heading-anchor:hover, html.theme--documenter-dark h1 .docs-heading-anchor:visited, html.theme--documenter-dark h2 .docs-heading-anchor, html.theme--documenter-dark h2 .docs-heading-anchor:hover, html.theme--documenter-dark h2 .docs-heading-anchor:visited, html.theme--documenter-dark h3 .docs-heading-anchor, html.theme--documenter-dark h3 .docs-heading-anchor:hover, html.theme--documenter-dark h3 .docs-heading-anchor:visited, html.theme--documenter-dark h4 .docs-heading-anchor, html.theme--documenter-dark h4 .docs-heading-anchor:hover, html.theme--documenter-dark h4 .docs-heading-anchor:visited, html.theme--documenter-dark h5 .docs-heading-anchor, html.theme--documenter-dark h5 .docs-heading-anchor:hover, html.theme--documenter-dark h5 .docs-heading-anchor:visited, html.theme--documenter-dark h6 .docs-heading-anchor, html.theme--documenter-dark h6 .docs-heading-anchor:hover, html.theme--documenter-dark h6 .docs-heading-anchor:visited {
+    color: #f2f2f2; }
+  html.theme--documenter-dark h1 .docs-heading-anchor-permalink, html.theme--documenter-dark h2 .docs-heading-anchor-permalink, html.theme--documenter-dark h3 .docs-heading-anchor-permalink, html.theme--documenter-dark h4 .docs-heading-anchor-permalink, html.theme--documenter-dark h5 .docs-heading-anchor-permalink, html.theme--documenter-dark h6 .docs-heading-anchor-permalink {
+    visibility: hidden;
+    vertical-align: middle;
+    margin-left: 0.5em;
+    font-size: 0.7rem; }
+    html.theme--documenter-dark h1 .docs-heading-anchor-permalink::before, html.theme--documenter-dark h2 .docs-heading-anchor-permalink::before, html.theme--documenter-dark h3 .docs-heading-anchor-permalink::before, html.theme--documenter-dark h4 .docs-heading-anchor-permalink::before, html.theme--documenter-dark h5 .docs-heading-anchor-permalink::before, html.theme--documenter-dark h6 .docs-heading-anchor-permalink::before {
+      font-family: "Font Awesome 5 Free";
+      font-weight: 900;
+      content: "\f0c1"; }
+  html.theme--documenter-dark h1:hover .docs-heading-anchor-permalink, html.theme--documenter-dark h2:hover .docs-heading-anchor-permalink, html.theme--documenter-dark h3:hover .docs-heading-anchor-permalink, html.theme--documenter-dark h4:hover .docs-heading-anchor-permalink, html.theme--documenter-dark h5:hover .docs-heading-anchor-permalink, html.theme--documenter-dark h6:hover .docs-heading-anchor-permalink {
+    visibility: visible; }
+  html.theme--documenter-dark .docs-light-only {
+    display: none !important; }
+  html.theme--documenter-dark .admonition {
+    background-color: #282f2f;
+    border-style: solid;
+    border-width: 1px;
+    border-color: #5e6d6f;
+    border-radius: 0.4em;
+    font-size: 15px; }
+    html.theme--documenter-dark .admonition strong {
+      color: currentColor; }
+    html.theme--documenter-dark .admonition.is-small, html.theme--documenter-dark #documenter .docs-sidebar form.docs-search > input.admonition {
+      font-size: 0.85em; }
+    html.theme--documenter-dark .admonition.is-medium {
+      font-size: 1.25rem; }
+    html.theme--documenter-dark .admonition.is-large {
+      font-size: 1.5rem; }
+    html.theme--documenter-dark .admonition.is-default {
+      background-color: #282f2f;
+      border-color: #5e6d6f; }
+      html.theme--documenter-dark .admonition.is-default > .admonition-header {
+        background-color: #5e6d6f; }
+    html.theme--documenter-dark .admonition.is-info {
+      background-color: #282f2f;
+      border-color: #024c7d; }
+      html.theme--documenter-dark .admonition.is-info > .admonition-header {
+        background-color: #024c7d; }
+    html.theme--documenter-dark .admonition.is-success {
+      background-color: #282f2f;
+      border-color: #008438; }
+      html.theme--documenter-dark .admonition.is-success > .admonition-header {
+        background-color: #008438; }
+    html.theme--documenter-dark .admonition.is-warning {
+      background-color: #282f2f;
+      border-color: #ad8100; }
+      html.theme--documenter-dark .admonition.is-warning > .admonition-header {
+        background-color: #ad8100; }
+    html.theme--documenter-dark .admonition.is-danger {
+      background-color: #282f2f;
+      border-color: #9e1b0d; }
+      html.theme--documenter-dark .admonition.is-danger > .admonition-header {
+        background-color: #9e1b0d; }
+    html.theme--documenter-dark .admonition.is-compat {
+      background-color: #282f2f;
+      border-color: #137886; }
+      html.theme--documenter-dark .admonition.is-compat > .admonition-header {
+        background-color: #137886; }
+  html.theme--documenter-dark .admonition-header {
+    background-color: #5e6d6f;
+    align-items: center;
+    font-weight: 700;
+    justify-content: space-between;
+    line-height: 1.25;
+    padding: 0.75em;
+    position: relative; }
+    html.theme--documenter-dark .admonition-header:before {
+      font-family: "Font Awesome 5 Free";
+      font-weight: 900;
+      margin-right: 0.75em;
+      content: "\f06a"; }
+  html.theme--documenter-dark .admonition-body {
+    color: #fff;
+    padding: 1em 1.25em; }
+    html.theme--documenter-dark .admonition-body pre {
+      background-color: #282f2f; }
+    html.theme--documenter-dark .admonition-body code {
+      background-color: rgba(255, 255, 255, 0.05); }
+  html.theme--documenter-dark .docstring {
+    margin-bottom: 1em;
+    background-color: transparent;
+    border: 1px solid #5e6d6f;
+    box-shadow: none;
+    max-width: 100%; }
+    html.theme--documenter-dark .docstring > header {
+      display: flex;
+      flex-grow: 1;
+      align-items: stretch;
+      padding: 0.75rem;
+      background-color: #282f2f;
+      box-shadow: 0 1px 2px rgba(10, 10, 10, 0.1);
+      box-shadow: none;
+      border-bottom: 1px solid #5e6d6f; }
+      html.theme--documenter-dark .docstring > header code {
+        background-color: transparent; }
+      html.theme--documenter-dark .docstring > header .docstring-binding {
+        margin-right: 0.3em; }
+      html.theme--documenter-dark .docstring > header .docstring-category {
+        margin-left: 0.3em; }
+    html.theme--documenter-dark .docstring > section {
+      position: relative;
+      padding: 1rem 1.25rem;
+      border-bottom: 1px solid #5e6d6f; }
+      html.theme--documenter-dark .docstring > section:last-child {
+        border-bottom: none; }
+      html.theme--documenter-dark .docstring > section > a.docs-sourcelink {
+        transition: opacity 0.3s;
+        opacity: 0;
+        position: absolute;
+        right: 0.625rem;
+        bottom: 0.5rem; }
+    html.theme--documenter-dark .docstring:hover > section > a.docs-sourcelink {
+      opacity: 0.2; }
+    html.theme--documenter-dark .docstring > section:hover a.docs-sourcelink {
+      opacity: 1; }
+  html.theme--documenter-dark .content pre {
+    border: 1px solid #5e6d6f; }
+  html.theme--documenter-dark .content code {
+    font-weight: inherit; }
+  html.theme--documenter-dark .content a code {
+    color: #1abc9c; }
+  html.theme--documenter-dark .content h1 code, html.theme--documenter-dark .content h2 code, html.theme--documenter-dark .content h3 code, html.theme--documenter-dark .content h4 code, html.theme--documenter-dark .content h5 code, html.theme--documenter-dark .content h6 code {
+    color: #f2f2f2; }
+  html.theme--documenter-dark .content table {
+    display: block;
+    width: initial;
+    max-width: 100%;
+    overflow-x: auto; }
+  html.theme--documenter-dark .content blockquote > ul:first-child, html.theme--documenter-dark .content blockquote > ol:first-child, html.theme--documenter-dark .content .admonition-body > ul:first-child, html.theme--documenter-dark .content .admonition-body > ol:first-child {
+    margin-top: 0; }
+  html.theme--documenter-dark .breadcrumb a.is-disabled {
+    cursor: default;
+    pointer-events: none; }
+    html.theme--documenter-dark .breadcrumb a.is-disabled, html.theme--documenter-dark .breadcrumb a.is-disabled:hover {
+      color: #f2f2f2; }
+  html.theme--documenter-dark .hljs {
+    background: initial !important;
+    padding: initial !important; }
+  html.theme--documenter-dark .katex .katex-mathml {
+    top: 0;
+    right: 0; }
+  html.theme--documenter-dark html {
+    -moz-osx-font-smoothing: auto;
+    -webkit-font-smoothing: auto; }
+  html.theme--documenter-dark #documenter .docs-main > article {
+    overflow-wrap: break-word; }
+  @media screen and (min-width: 1056px) {
+    html.theme--documenter-dark #documenter .docs-main {
+      max-width: 52rem;
+      margin-left: 20rem;
+      padding-right: 1rem; } }
+  @media screen and (max-width: 1055px) {
+    html.theme--documenter-dark #documenter .docs-main {
+      width: 100%; }
+      html.theme--documenter-dark #documenter .docs-main > article {
+        max-width: 52rem;
+        margin-left: auto;
+        margin-right: auto;
+        margin-bottom: 1rem;
+        padding: 0 1rem; }
+      html.theme--documenter-dark #documenter .docs-main > header, html.theme--documenter-dark #documenter .docs-main > nav {
+        max-width: 100%;
+        width: 100%;
+        margin: 0; } }
+  html.theme--documenter-dark #documenter .docs-main header.docs-navbar {
+    background-color: #1f2424;
+    border-bottom: 1px solid #5e6d6f;
+    z-index: 2;
+    min-height: 4rem;
+    margin-bottom: 1rem;
+    display: flex; }
+    html.theme--documenter-dark #documenter .docs-main header.docs-navbar .breadcrumb {
+      flex-grow: 1; }
+    html.theme--documenter-dark #documenter .docs-main header.docs-navbar .docs-right {
+      display: flex;
+      white-space: nowrap; }
+      html.theme--documenter-dark #documenter .docs-main header.docs-navbar .docs-right .docs-icon, html.theme--documenter-dark #documenter .docs-main header.docs-navbar .docs-right .docs-label, html.theme--documenter-dark #documenter .docs-main header.docs-navbar .docs-right .docs-sidebar-button {
+        display: inline-block; }
+      html.theme--documenter-dark #documenter .docs-main header.docs-navbar .docs-right .docs-label {
+        padding: 0;
+        margin-left: 0.3em; }
+      html.theme--documenter-dark #documenter .docs-main header.docs-navbar .docs-right .docs-settings-button {
+        margin: auto 0 auto 1rem; }
+      html.theme--documenter-dark #documenter .docs-main header.docs-navbar .docs-right .docs-sidebar-button {
+        font-size: 1.5rem;
+        margin: auto 0 auto 1rem; }
+    html.theme--documenter-dark #documenter .docs-main header.docs-navbar > * {
+      margin: auto 0; }
+    @media screen and (max-width: 1055px) {
+      html.theme--documenter-dark #documenter .docs-main header.docs-navbar {
+        position: sticky;
+        top: 0;
+        padding: 0 1rem;
+        /* For Headroom.js */
+        transition-property: top, box-shadow;
+        -webkit-transition-property: top, box-shadow;
+        /* Safari */
+        transition-duration: 0.3s;
+        -webkit-transition-duration: 0.3s;
+        /* Safari */ }
+        html.theme--documenter-dark #documenter .docs-main header.docs-navbar.headroom--not-top {
+          box-shadow: 0.2rem 0rem 0.4rem #171717;
+          transition-duration: 0.7s;
+          -webkit-transition-duration: 0.7s;
+          /* Safari */ }
+        html.theme--documenter-dark #documenter .docs-main header.docs-navbar.headroom--unpinned.headroom--not-top.headroom--not-bottom {
+          top: -4.5rem;
+          transition-duration: 0.7s;
+          -webkit-transition-duration: 0.7s;
+          /* Safari */ } }
+  html.theme--documenter-dark #documenter .docs-main section.footnotes {
+    border-top: 1px solid #5e6d6f; }
+    html.theme--documenter-dark #documenter .docs-main section.footnotes li .tag:first-child, html.theme--documenter-dark #documenter .docs-main section.footnotes li .docstring > section > a.docs-sourcelink:first-child, html.theme--documenter-dark #documenter .docs-main section.footnotes li .content kbd:first-child, html.theme--documenter-dark .content #documenter .docs-main section.footnotes li kbd:first-child {
+      margin-right: 1em;
+      margin-bottom: 0.4em; }
+  html.theme--documenter-dark #documenter .docs-main .docs-footer {
+    display: flex;
+    margin-left: 0;
+    margin-right: 0;
+    border-top: 1px solid #5e6d6f;
+    padding-top: 1rem;
+    padding-bottom: 1rem; }
+    @media screen and (max-width: 1055px) {
+      html.theme--documenter-dark #documenter .docs-main .docs-footer {
+        padding-left: 1rem;
+        padding-right: 1rem; } }
+    html.theme--documenter-dark #documenter .docs-main .docs-footer .docs-footer-nextpage, html.theme--documenter-dark #documenter .docs-main .docs-footer .docs-footer-prevpage {
+      flex-grow: 1; }
+    html.theme--documenter-dark #documenter .docs-main .docs-footer .docs-footer-nextpage {
+      text-align: right; }
+  html.theme--documenter-dark #documenter .docs-sidebar {
+    display: flex;
+    flex-direction: column;
+    color: #fff;
+    background-color: #282f2f;
+    border-right: 1px solid #5e6d6f;
+    padding: 0;
+    flex: 0 0 18rem;
+    z-index: 5;
+    position: fixed;
+    left: -18rem;
+    width: 18rem;
+    height: 100%;
+    transition: left 0.3s;
+    /* Setting up a nicer theme style for the scrollbar */ }
+    html.theme--documenter-dark #documenter .docs-sidebar.visible {
+      left: 0;
+      box-shadow: 0.4rem 0rem 0.8rem #171717; }
+      @media screen and (min-width: 1056px) {
+        html.theme--documenter-dark #documenter .docs-sidebar.visible {
+          box-shadow: none; } }
+    @media screen and (min-width: 1056px) {
+      html.theme--documenter-dark #documenter .docs-sidebar {
+        left: 0;
+        top: 0; } }
+    html.theme--documenter-dark #documenter .docs-sidebar .docs-logo {
+      margin-top: 1rem;
+      padding: 0 1rem; }
+      html.theme--documenter-dark #documenter .docs-sidebar .docs-logo > img {
+        max-height: 6rem;
+        margin: auto; }
+    html.theme--documenter-dark #documenter .docs-sidebar .docs-package-name {
+      flex-shrink: 0;
+      font-size: 1.5rem;
+      font-weight: 700;
+      text-align: center;
+      white-space: nowrap;
+      overflow: hidden;
+      padding: 0.5rem 0; }
+      html.theme--documenter-dark #documenter .docs-sidebar .docs-package-name .docs-autofit {
+        max-width: 16.2rem; }
+    html.theme--documenter-dark #documenter .docs-sidebar .docs-version-selector {
+      border-top: 1px solid #5e6d6f;
+      display: none;
+      padding: 0.5rem; }
+      html.theme--documenter-dark #documenter .docs-sidebar .docs-version-selector.visible {
+        display: flex; }
+    html.theme--documenter-dark #documenter .docs-sidebar ul.docs-menu {
+      flex-grow: 1;
+      user-select: none;
+      font-size: 15px;
+      border-top: 1px solid #5e6d6f;
+      padding-bottom: 1.5rem;
+      /* Managing collapsible submenus */ }
+      html.theme--documenter-dark #documenter .docs-sidebar ul.docs-menu > li > .tocitem {
+        font-weight: bold; }
+      html.theme--documenter-dark #documenter .docs-sidebar ul.docs-menu > li li {
+        font-size: 14.25px;
+        margin-left: 1em;
+        border-left: 1px solid #5e6d6f; }
+      html.theme--documenter-dark #documenter .docs-sidebar ul.docs-menu input.collapse-toggle {
+        display: none; }
+      html.theme--documenter-dark #documenter .docs-sidebar ul.docs-menu ul.collapsed {
+        display: none; }
+      html.theme--documenter-dark #documenter .docs-sidebar ul.docs-menu input:checked ~ ul.collapsed {
+        display: block; }
+      html.theme--documenter-dark #documenter .docs-sidebar ul.docs-menu label.tocitem {
+        display: flex; }
+        html.theme--documenter-dark #documenter .docs-sidebar ul.docs-menu label.tocitem .docs-label {
+          flex-grow: 2; }
+        html.theme--documenter-dark #documenter .docs-sidebar ul.docs-menu label.tocitem .docs-chevron {
+          display: inline-block;
+          font-style: normal;
+          font-variant: normal;
+          text-rendering: auto;
+          line-height: 1;
+          font-size: 11.25px;
+          margin-left: 1rem;
+          margin-top: auto;
+          margin-bottom: auto; }
+          html.theme--documenter-dark #documenter .docs-sidebar ul.docs-menu label.tocitem .docs-chevron::before {
+            font-family: "Font Awesome 5 Free";
+            font-weight: 900;
+            content: "\f054"; }
+      html.theme--documenter-dark #documenter .docs-sidebar ul.docs-menu input:checked ~ label.tocitem .docs-chevron::before {
+        content: "\f078"; }
+      html.theme--documenter-dark #documenter .docs-sidebar ul.docs-menu .tocitem {
+        display: block;
+        padding: 0.5rem 0.5rem; }
+        html.theme--documenter-dark #documenter .docs-sidebar ul.docs-menu .tocitem, html.theme--documenter-dark #documenter .docs-sidebar ul.docs-menu .tocitem:hover {
+          color: #fff; }
+      html.theme--documenter-dark #documenter .docs-sidebar ul.docs-menu a.tocitem:hover, html.theme--documenter-dark #documenter .docs-sidebar ul.docs-menu label.tocitem:hover {
+        background-color: #32393a; }
+      html.theme--documenter-dark #documenter .docs-sidebar ul.docs-menu li.is-active {
+        border-top: 1px solid #718385;
+        border-bottom: 1px solid #5e6d6f;
+        background-color: #1f2424; }
+        html.theme--documenter-dark #documenter .docs-sidebar ul.docs-menu li.is-active > .tocitem, html.theme--documenter-dark #documenter .docs-sidebar ul.docs-menu li.is-active > .tocitem:hover {
+          background-color: #1f2424;
+          color: #fff; }
+      html.theme--documenter-dark #documenter .docs-sidebar ul.docs-menu > li.is-active:first-child {
+        border-top: none; }
+      html.theme--documenter-dark #documenter .docs-sidebar ul.docs-menu ul.internal {
+        margin: 0 0.5rem 0.5rem;
+        border-top: 1px solid #5e6d6f; }
+        html.theme--documenter-dark #documenter .docs-sidebar ul.docs-menu ul.internal li {
+          font-size: 12.75px;
+          border-left: none;
+          margin-left: 0;
+          margin-top: 0.5rem; }
+        html.theme--documenter-dark #documenter .docs-sidebar ul.docs-menu ul.internal .tocitem {
+          width: 100%;
+          padding: 0; }
+          html.theme--documenter-dark #documenter .docs-sidebar ul.docs-menu ul.internal .tocitem::before {
+            content: "⚬";
+            margin-right: 0.4em; }
+    html.theme--documenter-dark #documenter .docs-sidebar form.docs-search {
+      margin: auto;
+      margin-top: 0.5rem;
+      margin-bottom: 0.5rem; }
+      html.theme--documenter-dark #documenter .docs-sidebar form.docs-search > input {
+        width: 14.4rem; }
+    @media screen and (min-width: 1056px) {
+      html.theme--documenter-dark #documenter .docs-sidebar ul.docs-menu {
+        overflow-y: auto;
+        -webkit-overflow-scroll: touch; }
+        html.theme--documenter-dark #documenter .docs-sidebar ul.docs-menu::-webkit-scrollbar {
+          width: .3rem;
+          background: none; }
+        html.theme--documenter-dark #documenter .docs-sidebar ul.docs-menu::-webkit-scrollbar-thumb {
+          border-radius: 5px 0px 0px 5px;
+          background: #3b4445; }
+        html.theme--documenter-dark #documenter .docs-sidebar ul.docs-menu::-webkit-scrollbar-thumb:hover {
+          background: #4e5a5c; } }
+    @media screen and (max-width: 1055px) {
+      html.theme--documenter-dark #documenter .docs-sidebar {
+        overflow-y: auto;
+        -webkit-overflow-scroll: touch; }
+        html.theme--documenter-dark #documenter .docs-sidebar::-webkit-scrollbar {
+          width: .3rem;
+          background: none; }
+        html.theme--documenter-dark #documenter .docs-sidebar::-webkit-scrollbar-thumb {
+          border-radius: 5px 0px 0px 5px;
+          background: #3b4445; }
+        html.theme--documenter-dark #documenter .docs-sidebar::-webkit-scrollbar-thumb:hover {
+          background: #4e5a5c; } }
+  html.theme--documenter-dark #documenter .docs-main #documenter-search-info {
+    margin-bottom: 1rem; }
+  html.theme--documenter-dark #documenter .docs-main #documenter-search-results {
+    list-style-type: circle;
+    list-style-position: outside; }
+    html.theme--documenter-dark #documenter .docs-main #documenter-search-results li {
+      margin-left: 2rem; }
+    html.theme--documenter-dark #documenter .docs-main #documenter-search-results .docs-highlight {
+      background-color: yellow; }
+  html.theme--documenter-dark {
+    background-color: #1f2424;
+    font-size: 16px;
+    min-width: 300px;
+    overflow-x: auto;
+    overflow-y: scroll;
+    text-rendering: optimizeLegibility;
+    text-size-adjust: 100%; }
+  html.theme--documenter-dark .hljs-comment,
+  html.theme--documenter-dark .hljs-quote {
+    color: #d4d0ab; }
+  html.theme--documenter-dark .hljs-variable,
+  html.theme--documenter-dark .hljs-template-variable,
+  html.theme--documenter-dark .hljs-tag,
+  html.theme--documenter-dark .hljs-name,
+  html.theme--documenter-dark .hljs-selector-id,
+  html.theme--documenter-dark .hljs-selector-class,
+  html.theme--documenter-dark .hljs-regexp,
+  html.theme--documenter-dark .hljs-deletion {
+    color: #ffa07a; }
+  html.theme--documenter-dark .hljs-number,
+  html.theme--documenter-dark .hljs-built_in,
+  html.theme--documenter-dark .hljs-builtin-name,
+  html.theme--documenter-dark .hljs-literal,
+  html.theme--documenter-dark .hljs-type,
+  html.theme--documenter-dark .hljs-params,
+  html.theme--documenter-dark .hljs-meta,
+  html.theme--documenter-dark .hljs-link {
+    color: #f5ab35; }
+  html.theme--documenter-dark .hljs-attribute {
+    color: #ffd700; }
+  html.theme--documenter-dark .hljs-string,
+  html.theme--documenter-dark .hljs-symbol,
+  html.theme--documenter-dark .hljs-bullet,
+  html.theme--documenter-dark .hljs-addition {
+    color: #abe338; }
+  html.theme--documenter-dark .hljs-title,
+  html.theme--documenter-dark .hljs-section {
+    color: #00e0e0; }
+  html.theme--documenter-dark .hljs-keyword,
+  html.theme--documenter-dark .hljs-selector-tag {
+    color: #dcc6e0; }
+  html.theme--documenter-dark .hljs {
+    display: block;
+    overflow-x: auto;
+    background: #2b2b2b;
+    color: #f8f8f2;
+    padding: 0.5em; }
+  html.theme--documenter-dark .hljs-emphasis {
+    font-style: italic; }
+  html.theme--documenter-dark .hljs-strong {
+    font-weight: bold; }
+  @media screen and (-ms-high-contrast: active) {
+    html.theme--documenter-dark .hljs-addition,
+    html.theme--documenter-dark .hljs-attribute,
+    html.theme--documenter-dark .hljs-built_in,
+    html.theme--documenter-dark .hljs-builtin-name,
+    html.theme--documenter-dark .hljs-bullet,
+    html.theme--documenter-dark .hljs-comment,
+    html.theme--documenter-dark .hljs-link,
+    html.theme--documenter-dark .hljs-literal,
+    html.theme--documenter-dark .hljs-meta,
+    html.theme--documenter-dark .hljs-number,
+    html.theme--documenter-dark .hljs-params,
+    html.theme--documenter-dark .hljs-string,
+    html.theme--documenter-dark .hljs-symbol,
+    html.theme--documenter-dark .hljs-type,
+    html.theme--documenter-dark .hljs-quote {
+      color: highlight; }
+    html.theme--documenter-dark .hljs-keyword,
+    html.theme--documenter-dark .hljs-selector-tag {
+      font-weight: bold; } }
+  html.theme--documenter-dark .hljs-subst {
+    color: #f8f8f2; }
diff -pruN 1.3.1+dfsg-1/debian/embedded/Documenter/assets/html/themes/documenter-light.css 1.4.0+dfsg-1/debian/embedded/Documenter/assets/html/themes/documenter-light.css
--- 1.3.1+dfsg-1/debian/embedded/Documenter/assets/html/themes/documenter-light.css	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/debian/embedded/Documenter/assets/html/themes/documenter-light.css	2020-03-30 16:16:04.000000000 +0000
@@ -0,0 +1,7609 @@
+@charset "UTF-8";
+/* Font Awesome 5 mixin. Can be included in any rule that should render Font Awesome icons. */
+@keyframes spinAround {
+  from {
+    transform: rotate(0deg); }
+  to {
+    transform: rotate(359deg); } }
+
+.delete, .modal-close, .is-unselectable, .button, .file, .breadcrumb, .pagination-previous,
+.pagination-next,
+.pagination-link,
+.pagination-ellipsis, .tabs {
+  -webkit-touch-callout: none;
+  -webkit-user-select: none;
+  -moz-user-select: none;
+  -ms-user-select: none;
+  user-select: none; }
+
+.select:not(.is-multiple):not(.is-loading)::after, .navbar-link:not(.is-arrowless)::after {
+  border: 3px solid transparent;
+  border-radius: 2px;
+  border-right: 0;
+  border-top: 0;
+  content: " ";
+  display: block;
+  height: 0.625em;
+  margin-top: -0.4375em;
+  pointer-events: none;
+  position: absolute;
+  top: 50%;
+  transform: rotate(-45deg);
+  transform-origin: center;
+  width: 0.625em; }
+
+.box:not(:last-child), .content:not(:last-child), .notification:not(:last-child), .progress:not(:last-child), .table:not(:last-child), .table-container:not(:last-child), .title:not(:last-child),
+.subtitle:not(:last-child), .block:not(:last-child), .highlight:not(:last-child), .breadcrumb:not(:last-child), .level:not(:last-child), .list:not(:last-child), .message:not(:last-child), .tabs:not(:last-child), .admonition:not(:last-child) {
+  margin-bottom: 1.5rem; }
+
+.delete, .modal-close {
+  -moz-appearance: none;
+  -webkit-appearance: none;
+  background-color: rgba(10, 10, 10, 0.2);
+  border: none;
+  border-radius: 290486px;
+  cursor: pointer;
+  pointer-events: auto;
+  display: inline-block;
+  flex-grow: 0;
+  flex-shrink: 0;
+  font-size: 0;
+  height: 20px;
+  max-height: 20px;
+  max-width: 20px;
+  min-height: 20px;
+  min-width: 20px;
+  outline: none;
+  position: relative;
+  vertical-align: top;
+  width: 20px; }
+  .delete::before, .modal-close::before, .delete::after, .modal-close::after {
+    background-color: white;
+    content: "";
+    display: block;
+    left: 50%;
+    position: absolute;
+    top: 50%;
+    transform: translateX(-50%) translateY(-50%) rotate(45deg);
+    transform-origin: center center; }
+  .delete::before, .modal-close::before {
+    height: 2px;
+    width: 50%; }
+  .delete::after, .modal-close::after {
+    height: 50%;
+    width: 2px; }
+  .delete:hover, .modal-close:hover, .delete:focus, .modal-close:focus {
+    background-color: rgba(10, 10, 10, 0.3); }
+  .delete:active, .modal-close:active {
+    background-color: rgba(10, 10, 10, 0.4); }
+  .is-small.delete, #documenter .docs-sidebar form.docs-search > input.delete, .is-small.modal-close, #documenter .docs-sidebar form.docs-search > input.modal-close {
+    height: 16px;
+    max-height: 16px;
+    max-width: 16px;
+    min-height: 16px;
+    min-width: 16px;
+    width: 16px; }
+  .is-medium.delete, .is-medium.modal-close {
+    height: 24px;
+    max-height: 24px;
+    max-width: 24px;
+    min-height: 24px;
+    min-width: 24px;
+    width: 24px; }
+  .is-large.delete, .is-large.modal-close {
+    height: 32px;
+    max-height: 32px;
+    max-width: 32px;
+    min-height: 32px;
+    min-width: 32px;
+    width: 32px; }
+
+.button.is-loading::after, .loader, .select.is-loading::after, .control.is-loading::after {
+  animation: spinAround 500ms infinite linear;
+  border: 2px solid #dbdbdb;
+  border-radius: 290486px;
+  border-right-color: transparent;
+  border-top-color: transparent;
+  content: "";
+  display: block;
+  height: 1em;
+  position: relative;
+  width: 1em; }
+
+.is-overlay, .image.is-square img, #documenter .docs-sidebar .docs-logo > img.is-square img,
+.image.is-square .has-ratio,
+#documenter .docs-sidebar .docs-logo > img.is-square .has-ratio, .image.is-1by1 img, #documenter .docs-sidebar .docs-logo > img.is-1by1 img,
+.image.is-1by1 .has-ratio,
+#documenter .docs-sidebar .docs-logo > img.is-1by1 .has-ratio, .image.is-5by4 img, #documenter .docs-sidebar .docs-logo > img.is-5by4 img,
+.image.is-5by4 .has-ratio,
+#documenter .docs-sidebar .docs-logo > img.is-5by4 .has-ratio, .image.is-4by3 img, #documenter .docs-sidebar .docs-logo > img.is-4by3 img,
+.image.is-4by3 .has-ratio,
+#documenter .docs-sidebar .docs-logo > img.is-4by3 .has-ratio, .image.is-3by2 img, #documenter .docs-sidebar .docs-logo > img.is-3by2 img,
+.image.is-3by2 .has-ratio,
+#documenter .docs-sidebar .docs-logo > img.is-3by2 .has-ratio, .image.is-5by3 img, #documenter .docs-sidebar .docs-logo > img.is-5by3 img,
+.image.is-5by3 .has-ratio,
+#documenter .docs-sidebar .docs-logo > img.is-5by3 .has-ratio, .image.is-16by9 img, #documenter .docs-sidebar .docs-logo > img.is-16by9 img,
+.image.is-16by9 .has-ratio,
+#documenter .docs-sidebar .docs-logo > img.is-16by9 .has-ratio, .image.is-2by1 img, #documenter .docs-sidebar .docs-logo > img.is-2by1 img,
+.image.is-2by1 .has-ratio,
+#documenter .docs-sidebar .docs-logo > img.is-2by1 .has-ratio, .image.is-3by1 img, #documenter .docs-sidebar .docs-logo > img.is-3by1 img,
+.image.is-3by1 .has-ratio,
+#documenter .docs-sidebar .docs-logo > img.is-3by1 .has-ratio, .image.is-4by5 img, #documenter .docs-sidebar .docs-logo > img.is-4by5 img,
+.image.is-4by5 .has-ratio,
+#documenter .docs-sidebar .docs-logo > img.is-4by5 .has-ratio, .image.is-3by4 img, #documenter .docs-sidebar .docs-logo > img.is-3by4 img,
+.image.is-3by4 .has-ratio,
+#documenter .docs-sidebar .docs-logo > img.is-3by4 .has-ratio, .image.is-2by3 img, #documenter .docs-sidebar .docs-logo > img.is-2by3 img,
+.image.is-2by3 .has-ratio,
+#documenter .docs-sidebar .docs-logo > img.is-2by3 .has-ratio, .image.is-3by5 img, #documenter .docs-sidebar .docs-logo > img.is-3by5 img,
+.image.is-3by5 .has-ratio,
+#documenter .docs-sidebar .docs-logo > img.is-3by5 .has-ratio, .image.is-9by16 img, #documenter .docs-sidebar .docs-logo > img.is-9by16 img,
+.image.is-9by16 .has-ratio,
+#documenter .docs-sidebar .docs-logo > img.is-9by16 .has-ratio, .image.is-1by2 img, #documenter .docs-sidebar .docs-logo > img.is-1by2 img,
+.image.is-1by2 .has-ratio,
+#documenter .docs-sidebar .docs-logo > img.is-1by2 .has-ratio, .image.is-1by3 img, #documenter .docs-sidebar .docs-logo > img.is-1by3 img,
+.image.is-1by3 .has-ratio,
+#documenter .docs-sidebar .docs-logo > img.is-1by3 .has-ratio, .modal, .modal-background, .hero-video {
+  bottom: 0;
+  left: 0;
+  position: absolute;
+  right: 0;
+  top: 0; }
+
+.button, .input, #documenter .docs-sidebar form.docs-search > input, .textarea, .select select, .file-cta,
+.file-name, .pagination-previous,
+.pagination-next,
+.pagination-link,
+.pagination-ellipsis {
+  -moz-appearance: none;
+  -webkit-appearance: none;
+  align-items: center;
+  border: 1px solid transparent;
+  border-radius: 4px;
+  box-shadow: none;
+  display: inline-flex;
+  font-size: 1rem;
+  height: 2.25em;
+  justify-content: flex-start;
+  line-height: 1.5;
+  padding-bottom: calc(0.375em - 1px);
+  padding-left: calc(0.625em - 1px);
+  padding-right: calc(0.625em - 1px);
+  padding-top: calc(0.375em - 1px);
+  position: relative;
+  vertical-align: top; }
+  .button:focus, .input:focus, #documenter .docs-sidebar form.docs-search > input:focus, .textarea:focus, .select select:focus, .file-cta:focus,
+  .file-name:focus, .pagination-previous:focus,
+  .pagination-next:focus,
+  .pagination-link:focus,
+  .pagination-ellipsis:focus, .is-focused.button, .is-focused.input, #documenter .docs-sidebar form.docs-search > input.is-focused, .is-focused.textarea, .select select.is-focused, .is-focused.file-cta,
+  .is-focused.file-name, .is-focused.pagination-previous,
+  .is-focused.pagination-next,
+  .is-focused.pagination-link,
+  .is-focused.pagination-ellipsis, .button:active, .input:active, #documenter .docs-sidebar form.docs-search > input:active, .textarea:active, .select select:active, .file-cta:active,
+  .file-name:active, .pagination-previous:active,
+  .pagination-next:active,
+  .pagination-link:active,
+  .pagination-ellipsis:active, .is-active.button, .is-active.input, #documenter .docs-sidebar form.docs-search > input.is-active, .is-active.textarea, .select select.is-active, .is-active.file-cta,
+  .is-active.file-name, .is-active.pagination-previous,
+  .is-active.pagination-next,
+  .is-active.pagination-link,
+  .is-active.pagination-ellipsis {
+    outline: none; }
+  .button[disabled], .input[disabled], #documenter .docs-sidebar form.docs-search > input[disabled], .textarea[disabled], .select select[disabled], .file-cta[disabled],
+  .file-name[disabled], .pagination-previous[disabled],
+  .pagination-next[disabled],
+  .pagination-link[disabled],
+  .pagination-ellipsis[disabled],
+  fieldset[disabled] .button,
+  fieldset[disabled] .input,
+  fieldset[disabled] #documenter .docs-sidebar form.docs-search > input,
+  #documenter .docs-sidebar fieldset[disabled] form.docs-search > input,
+  fieldset[disabled] .textarea,
+  fieldset[disabled] .select select,
+  .select fieldset[disabled] select,
+  fieldset[disabled] .file-cta,
+  fieldset[disabled] .file-name,
+  fieldset[disabled] .pagination-previous,
+  fieldset[disabled] .pagination-next,
+  fieldset[disabled] .pagination-link,
+  fieldset[disabled] .pagination-ellipsis {
+    cursor: not-allowed; }
+
+/*! minireset.css v0.0.4 | MIT License | github.com/jgthms/minireset.css */
+html,
+body,
+p,
+ol,
+ul,
+li,
+dl,
+dt,
+dd,
+blockquote,
+figure,
+fieldset,
+legend,
+textarea,
+pre,
+iframe,
+hr,
+h1,
+h2,
+h3,
+h4,
+h5,
+h6 {
+  margin: 0;
+  padding: 0; }
+
+h1,
+h2,
+h3,
+h4,
+h5,
+h6 {
+  font-size: 100%;
+  font-weight: normal; }
+
+ul {
+  list-style: none; }
+
+button,
+input,
+select,
+textarea {
+  margin: 0; }
+
+html {
+  box-sizing: border-box; }
+
+*, *::before, *::after {
+  box-sizing: inherit; }
+
+img,
+embed,
+iframe,
+object,
+video {
+  height: auto;
+  max-width: 100%; }
+
+audio {
+  max-width: 100%; }
+
+iframe {
+  border: 0; }
+
+table {
+  border-collapse: collapse;
+  border-spacing: 0; }
+
+td,
+th {
+  padding: 0; }
+  td:not([align]),
+  th:not([align]) {
+    text-align: left; }
+
+html {
+  background-color: white;
+  font-size: 16px;
+  -moz-osx-font-smoothing: grayscale;
+  -webkit-font-smoothing: antialiased;
+  min-width: 300px;
+  overflow-x: auto;
+  overflow-y: scroll;
+  text-rendering: optimizeLegibility;
+  text-size-adjust: 100%; }
+
+article,
+aside,
+figure,
+footer,
+header,
+hgroup,
+section {
+  display: block; }
+
+body,
+button,
+input,
+select,
+textarea {
+  font-family: "Lato", -apple-system, BlinkMacSystemFont, "Segoe UI", "Helvetica Neue", "Helvetica", "Arial", sans-serif; }
+
+code,
+pre {
+  -moz-osx-font-smoothing: auto;
+  -webkit-font-smoothing: auto;
+  font-family: "Roboto Mono", "SFMono-Regular", "Menlo", "Consolas", "Liberation Mono", "DejaVu Sans Mono", monospace; }
+
+body {
+  color: #222222;
+  font-size: 1em;
+  font-weight: 400;
+  line-height: 1.5; }
+
+a {
+  color: #2e63b8;
+  cursor: pointer;
+  text-decoration: none; }
+  a strong {
+    color: currentColor; }
+  a:hover {
+    color: #363636; }
+
+code {
+  background-color: rgba(0, 0, 0, 0.05);
+  color: #000000;
+  font-size: 0.875em;
+  font-weight: normal;
+  padding: 0.1em; }
+
+hr {
+  background-color: whitesmoke;
+  border: none;
+  display: block;
+  height: 2px;
+  margin: 1.5rem 0; }
+
+img {
+  height: auto;
+  max-width: 100%; }
+
+input[type="checkbox"],
+input[type="radio"] {
+  vertical-align: baseline; }
+
+small {
+  font-size: 0.875em; }
+
+span {
+  font-style: inherit;
+  font-weight: inherit; }
+
+strong {
+  color: #222222;
+  font-weight: 700; }
+
+fieldset {
+  border: none; }
+
+pre {
+  -webkit-overflow-scrolling: touch;
+  background-color: whitesmoke;
+  color: #222222;
+  font-size: 0.875em;
+  overflow-x: auto;
+  padding: 1.25rem 1.5rem;
+  white-space: pre;
+  word-wrap: normal; }
+  pre code {
+    background-color: transparent;
+    color: currentColor;
+    font-size: 1em;
+    padding: 0; }
+
+table td,
+table th {
+  vertical-align: top; }
+  table td:not([align]),
+  table th:not([align]) {
+    text-align: left; }
+
+table th {
+  color: #222222; }
+
+.is-clearfix::after {
+  clear: both;
+  content: " ";
+  display: table; }
+
+.is-pulled-left {
+  float: left !important; }
+
+.is-pulled-right {
+  float: right !important; }
+
+.is-clipped {
+  overflow: hidden !important; }
+
+.is-size-1 {
+  font-size: 3rem !important; }
+
+.is-size-2 {
+  font-size: 2.5rem !important; }
+
+.is-size-3 {
+  font-size: 2rem !important; }
+
+.is-size-4 {
+  font-size: 1.5rem !important; }
+
+.is-size-5 {
+  font-size: 1.25rem !important; }
+
+.is-size-6 {
+  font-size: 1rem !important; }
+
+.is-size-7, .docstring > section > a.docs-sourcelink {
+  font-size: 0.75rem !important; }
+
+@media screen and (max-width: 768px) {
+  .is-size-1-mobile {
+    font-size: 3rem !important; }
+  .is-size-2-mobile {
+    font-size: 2.5rem !important; }
+  .is-size-3-mobile {
+    font-size: 2rem !important; }
+  .is-size-4-mobile {
+    font-size: 1.5rem !important; }
+  .is-size-5-mobile {
+    font-size: 1.25rem !important; }
+  .is-size-6-mobile {
+    font-size: 1rem !important; }
+  .is-size-7-mobile {
+    font-size: 0.75rem !important; } }
+
+@media screen and (min-width: 769px), print {
+  .is-size-1-tablet {
+    font-size: 3rem !important; }
+  .is-size-2-tablet {
+    font-size: 2.5rem !important; }
+  .is-size-3-tablet {
+    font-size: 2rem !important; }
+  .is-size-4-tablet {
+    font-size: 1.5rem !important; }
+  .is-size-5-tablet {
+    font-size: 1.25rem !important; }
+  .is-size-6-tablet {
+    font-size: 1rem !important; }
+  .is-size-7-tablet {
+    font-size: 0.75rem !important; } }
+
+@media screen and (max-width: 1055px) {
+  .is-size-1-touch {
+    font-size: 3rem !important; }
+  .is-size-2-touch {
+    font-size: 2.5rem !important; }
+  .is-size-3-touch {
+    font-size: 2rem !important; }
+  .is-size-4-touch {
+    font-size: 1.5rem !important; }
+  .is-size-5-touch {
+    font-size: 1.25rem !important; }
+  .is-size-6-touch {
+    font-size: 1rem !important; }
+  .is-size-7-touch {
+    font-size: 0.75rem !important; } }
+
+@media screen and (min-width: 1056px) {
+  .is-size-1-desktop {
+    font-size: 3rem !important; }
+  .is-size-2-desktop {
+    font-size: 2.5rem !important; }
+  .is-size-3-desktop {
+    font-size: 2rem !important; }
+  .is-size-4-desktop {
+    font-size: 1.5rem !important; }
+  .is-size-5-desktop {
+    font-size: 1.25rem !important; }
+  .is-size-6-desktop {
+    font-size: 1rem !important; }
+  .is-size-7-desktop {
+    font-size: 0.75rem !important; } }
+
+@media screen and (min-width: 1216px) {
+  .is-size-1-widescreen {
+    font-size: 3rem !important; }
+  .is-size-2-widescreen {
+    font-size: 2.5rem !important; }
+  .is-size-3-widescreen {
+    font-size: 2rem !important; }
+  .is-size-4-widescreen {
+    font-size: 1.5rem !important; }
+  .is-size-5-widescreen {
+    font-size: 1.25rem !important; }
+  .is-size-6-widescreen {
+    font-size: 1rem !important; }
+  .is-size-7-widescreen {
+    font-size: 0.75rem !important; } }
+
+@media screen and (min-width: 1408px) {
+  .is-size-1-fullhd {
+    font-size: 3rem !important; }
+  .is-size-2-fullhd {
+    font-size: 2.5rem !important; }
+  .is-size-3-fullhd {
+    font-size: 2rem !important; }
+  .is-size-4-fullhd {
+    font-size: 1.5rem !important; }
+  .is-size-5-fullhd {
+    font-size: 1.25rem !important; }
+  .is-size-6-fullhd {
+    font-size: 1rem !important; }
+  .is-size-7-fullhd {
+    font-size: 0.75rem !important; } }
+
+.has-text-centered {
+  text-align: center !important; }
+
+.has-text-justified {
+  text-align: justify !important; }
+
+.has-text-left {
+  text-align: left !important; }
+
+.has-text-right {
+  text-align: right !important; }
+
+@media screen and (max-width: 768px) {
+  .has-text-centered-mobile {
+    text-align: center !important; } }
+
+@media screen and (min-width: 769px), print {
+  .has-text-centered-tablet {
+    text-align: center !important; } }
+
+@media screen and (min-width: 769px) and (max-width: 1055px) {
+  .has-text-centered-tablet-only {
+    text-align: center !important; } }
+
+@media screen and (max-width: 1055px) {
+  .has-text-centered-touch {
+    text-align: center !important; } }
+
+@media screen and (min-width: 1056px) {
+  .has-text-centered-desktop {
+    text-align: center !important; } }
+
+@media screen and (min-width: 1056px) and (max-width: 1215px) {
+  .has-text-centered-desktop-only {
+    text-align: center !important; } }
+
+@media screen and (min-width: 1216px) {
+  .has-text-centered-widescreen {
+    text-align: center !important; } }
+
+@media screen and (min-width: 1216px) and (max-width: 1407px) {
+  .has-text-centered-widescreen-only {
+    text-align: center !important; } }
+
+@media screen and (min-width: 1408px) {
+  .has-text-centered-fullhd {
+    text-align: center !important; } }
+
+@media screen and (max-width: 768px) {
+  .has-text-justified-mobile {
+    text-align: justify !important; } }
+
+@media screen and (min-width: 769px), print {
+  .has-text-justified-tablet {
+    text-align: justify !important; } }
+
+@media screen and (min-width: 769px) and (max-width: 1055px) {
+  .has-text-justified-tablet-only {
+    text-align: justify !important; } }
+
+@media screen and (max-width: 1055px) {
+  .has-text-justified-touch {
+    text-align: justify !important; } }
+
+@media screen and (min-width: 1056px) {
+  .has-text-justified-desktop {
+    text-align: justify !important; } }
+
+@media screen and (min-width: 1056px) and (max-width: 1215px) {
+  .has-text-justified-desktop-only {
+    text-align: justify !important; } }
+
+@media screen and (min-width: 1216px) {
+  .has-text-justified-widescreen {
+    text-align: justify !important; } }
+
+@media screen and (min-width: 1216px) and (max-width: 1407px) {
+  .has-text-justified-widescreen-only {
+    text-align: justify !important; } }
+
+@media screen and (min-width: 1408px) {
+  .has-text-justified-fullhd {
+    text-align: justify !important; } }
+
+@media screen and (max-width: 768px) {
+  .has-text-left-mobile {
+    text-align: left !important; } }
+
+@media screen and (min-width: 769px), print {
+  .has-text-left-tablet {
+    text-align: left !important; } }
+
+@media screen and (min-width: 769px) and (max-width: 1055px) {
+  .has-text-left-tablet-only {
+    text-align: left !important; } }
+
+@media screen and (max-width: 1055px) {
+  .has-text-left-touch {
+    text-align: left !important; } }
+
+@media screen and (min-width: 1056px) {
+  .has-text-left-desktop {
+    text-align: left !important; } }
+
+@media screen and (min-width: 1056px) and (max-width: 1215px) {
+  .has-text-left-desktop-only {
+    text-align: left !important; } }
+
+@media screen and (min-width: 1216px) {
+  .has-text-left-widescreen {
+    text-align: left !important; } }
+
+@media screen and (min-width: 1216px) and (max-width: 1407px) {
+  .has-text-left-widescreen-only {
+    text-align: left !important; } }
+
+@media screen and (min-width: 1408px) {
+  .has-text-left-fullhd {
+    text-align: left !important; } }
+
+@media screen and (max-width: 768px) {
+  .has-text-right-mobile {
+    text-align: right !important; } }
+
+@media screen and (min-width: 769px), print {
+  .has-text-right-tablet {
+    text-align: right !important; } }
+
+@media screen and (min-width: 769px) and (max-width: 1055px) {
+  .has-text-right-tablet-only {
+    text-align: right !important; } }
+
+@media screen and (max-width: 1055px) {
+  .has-text-right-touch {
+    text-align: right !important; } }
+
+@media screen and (min-width: 1056px) {
+  .has-text-right-desktop {
+    text-align: right !important; } }
+
+@media screen and (min-width: 1056px) and (max-width: 1215px) {
+  .has-text-right-desktop-only {
+    text-align: right !important; } }
+
+@media screen and (min-width: 1216px) {
+  .has-text-right-widescreen {
+    text-align: right !important; } }
+
+@media screen and (min-width: 1216px) and (max-width: 1407px) {
+  .has-text-right-widescreen-only {
+    text-align: right !important; } }
+
+@media screen and (min-width: 1408px) {
+  .has-text-right-fullhd {
+    text-align: right !important; } }
+
+.is-capitalized {
+  text-transform: capitalize !important; }
+
+.is-lowercase {
+  text-transform: lowercase !important; }
+
+.is-uppercase {
+  text-transform: uppercase !important; }
+
+.is-italic {
+  font-style: italic !important; }
+
+.has-text-white {
+  color: white !important; }
+
+a.has-text-white:hover, a.has-text-white:focus {
+  color: #e6e6e6 !important; }
+
+.has-background-white {
+  background-color: white !important; }
+
+.has-text-black {
+  color: #0a0a0a !important; }
+
+a.has-text-black:hover, a.has-text-black:focus {
+  color: black !important; }
+
+.has-background-black {
+  background-color: #0a0a0a !important; }
+
+.has-text-light {
+  color: whitesmoke !important; }
+
+a.has-text-light:hover, a.has-text-light:focus {
+  color: #dbdbdb !important; }
+
+.has-background-light {
+  background-color: whitesmoke !important; }
+
+.has-text-dark {
+  color: #363636 !important; }
+
+a.has-text-dark:hover, a.has-text-dark:focus {
+  color: #1c1c1c !important; }
+
+.has-background-dark {
+  background-color: #363636 !important; }
+
+.has-text-primary {
+  color: #4eb5de !important; }
+
+a.has-text-primary:hover, a.has-text-primary:focus {
+  color: #27a1d2 !important; }
+
+.has-background-primary {
+  background-color: #4eb5de !important; }
+
+.has-text-link {
+  color: #2e63b8 !important; }
+
+a.has-text-link:hover, a.has-text-link:focus {
+  color: #244d8f !important; }
+
+.has-background-link {
+  background-color: #2e63b8 !important; }
+
+.has-text-info {
+  color: #209cee !important; }
+
+a.has-text-info:hover, a.has-text-info:focus {
+  color: #0f81cc !important; }
+
+.has-background-info {
+  background-color: #209cee !important; }
+
+.has-text-success {
+  color: #22c35b !important; }
+
+a.has-text-success:hover, a.has-text-success:focus {
+  color: #1a9847 !important; }
+
+.has-background-success {
+  background-color: #22c35b !important; }
+
+.has-text-warning {
+  color: #ffdd57 !important; }
+
+a.has-text-warning:hover, a.has-text-warning:focus {
+  color: #ffd324 !important; }
+
+.has-background-warning {
+  background-color: #ffdd57 !important; }
+
+.has-text-danger {
+  color: #da0b00 !important; }
+
+a.has-text-danger:hover, a.has-text-danger:focus {
+  color: #a70800 !important; }
+
+.has-background-danger {
+  background-color: #da0b00 !important; }
+
+.has-text-black-bis {
+  color: #121212 !important; }
+
+.has-background-black-bis {
+  background-color: #121212 !important; }
+
+.has-text-black-ter {
+  color: #242424 !important; }
+
+.has-background-black-ter {
+  background-color: #242424 !important; }
+
+.has-text-grey-darker {
+  color: #363636 !important; }
+
+.has-background-grey-darker {
+  background-color: #363636 !important; }
+
+.has-text-grey-dark {
+  color: #4a4a4a !important; }
+
+.has-background-grey-dark {
+  background-color: #4a4a4a !important; }
+
+.has-text-grey {
+  color: #7a7a7a !important; }
+
+.has-background-grey {
+  background-color: #7a7a7a !important; }
+
+.has-text-grey-light {
+  color: #b5b5b5 !important; }
+
+.has-background-grey-light {
+  background-color: #b5b5b5 !important; }
+
+.has-text-grey-lighter {
+  color: #dbdbdb !important; }
+
+.has-background-grey-lighter {
+  background-color: #dbdbdb !important; }
+
+.has-text-white-ter {
+  color: whitesmoke !important; }
+
+.has-background-white-ter {
+  background-color: whitesmoke !important; }
+
+.has-text-white-bis {
+  color: #fafafa !important; }
+
+.has-background-white-bis {
+  background-color: #fafafa !important; }
+
+.has-text-weight-light {
+  font-weight: 300 !important; }
+
+.has-text-weight-normal {
+  font-weight: 400 !important; }
+
+.has-text-weight-medium {
+  font-weight: 500 !important; }
+
+.has-text-weight-semibold {
+  font-weight: 600 !important; }
+
+.has-text-weight-bold {
+  font-weight: 700 !important; }
+
+.is-family-primary {
+  font-family: "Lato", -apple-system, BlinkMacSystemFont, "Segoe UI", "Helvetica Neue", "Helvetica", "Arial", sans-serif !important; }
+
+.is-family-secondary {
+  font-family: "Lato", -apple-system, BlinkMacSystemFont, "Segoe UI", "Helvetica Neue", "Helvetica", "Arial", sans-serif !important; }
+
+.is-family-sans-serif {
+  font-family: "Lato", -apple-system, BlinkMacSystemFont, "Segoe UI", "Helvetica Neue", "Helvetica", "Arial", sans-serif !important; }
+
+.is-family-monospace {
+  font-family: "Roboto Mono", "SFMono-Regular", "Menlo", "Consolas", "Liberation Mono", "DejaVu Sans Mono", monospace !important; }
+
+.is-family-code {
+  font-family: "Roboto Mono", "SFMono-Regular", "Menlo", "Consolas", "Liberation Mono", "DejaVu Sans Mono", monospace !important; }
+
+.is-block {
+  display: block !important; }
+
+@media screen and (max-width: 768px) {
+  .is-block-mobile {
+    display: block !important; } }
+
+@media screen and (min-width: 769px), print {
+  .is-block-tablet {
+    display: block !important; } }
+
+@media screen and (min-width: 769px) and (max-width: 1055px) {
+  .is-block-tablet-only {
+    display: block !important; } }
+
+@media screen and (max-width: 1055px) {
+  .is-block-touch {
+    display: block !important; } }
+
+@media screen and (min-width: 1056px) {
+  .is-block-desktop {
+    display: block !important; } }
+
+@media screen and (min-width: 1056px) and (max-width: 1215px) {
+  .is-block-desktop-only {
+    display: block !important; } }
+
+@media screen and (min-width: 1216px) {
+  .is-block-widescreen {
+    display: block !important; } }
+
+@media screen and (min-width: 1216px) and (max-width: 1407px) {
+  .is-block-widescreen-only {
+    display: block !important; } }
+
+@media screen and (min-width: 1408px) {
+  .is-block-fullhd {
+    display: block !important; } }
+
+.is-flex {
+  display: flex !important; }
+
+@media screen and (max-width: 768px) {
+  .is-flex-mobile {
+    display: flex !important; } }
+
+@media screen and (min-width: 769px), print {
+  .is-flex-tablet {
+    display: flex !important; } }
+
+@media screen and (min-width: 769px) and (max-width: 1055px) {
+  .is-flex-tablet-only {
+    display: flex !important; } }
+
+@media screen and (max-width: 1055px) {
+  .is-flex-touch {
+    display: flex !important; } }
+
+@media screen and (min-width: 1056px) {
+  .is-flex-desktop {
+    display: flex !important; } }
+
+@media screen and (min-width: 1056px) and (max-width: 1215px) {
+  .is-flex-desktop-only {
+    display: flex !important; } }
+
+@media screen and (min-width: 1216px) {
+  .is-flex-widescreen {
+    display: flex !important; } }
+
+@media screen and (min-width: 1216px) and (max-width: 1407px) {
+  .is-flex-widescreen-only {
+    display: flex !important; } }
+
+@media screen and (min-width: 1408px) {
+  .is-flex-fullhd {
+    display: flex !important; } }
+
+.is-inline {
+  display: inline !important; }
+
+@media screen and (max-width: 768px) {
+  .is-inline-mobile {
+    display: inline !important; } }
+
+@media screen and (min-width: 769px), print {
+  .is-inline-tablet {
+    display: inline !important; } }
+
+@media screen and (min-width: 769px) and (max-width: 1055px) {
+  .is-inline-tablet-only {
+    display: inline !important; } }
+
+@media screen and (max-width: 1055px) {
+  .is-inline-touch {
+    display: inline !important; } }
+
+@media screen and (min-width: 1056px) {
+  .is-inline-desktop {
+    display: inline !important; } }
+
+@media screen and (min-width: 1056px) and (max-width: 1215px) {
+  .is-inline-desktop-only {
+    display: inline !important; } }
+
+@media screen and (min-width: 1216px) {
+  .is-inline-widescreen {
+    display: inline !important; } }
+
+@media screen and (min-width: 1216px) and (max-width: 1407px) {
+  .is-inline-widescreen-only {
+    display: inline !important; } }
+
+@media screen and (min-width: 1408px) {
+  .is-inline-fullhd {
+    display: inline !important; } }
+
+.is-inline-block {
+  display: inline-block !important; }
+
+@media screen and (max-width: 768px) {
+  .is-inline-block-mobile {
+    display: inline-block !important; } }
+
+@media screen and (min-width: 769px), print {
+  .is-inline-block-tablet {
+    display: inline-block !important; } }
+
+@media screen and (min-width: 769px) and (max-width: 1055px) {
+  .is-inline-block-tablet-only {
+    display: inline-block !important; } }
+
+@media screen and (max-width: 1055px) {
+  .is-inline-block-touch {
+    display: inline-block !important; } }
+
+@media screen and (min-width: 1056px) {
+  .is-inline-block-desktop {
+    display: inline-block !important; } }
+
+@media screen and (min-width: 1056px) and (max-width: 1215px) {
+  .is-inline-block-desktop-only {
+    display: inline-block !important; } }
+
+@media screen and (min-width: 1216px) {
+  .is-inline-block-widescreen {
+    display: inline-block !important; } }
+
+@media screen and (min-width: 1216px) and (max-width: 1407px) {
+  .is-inline-block-widescreen-only {
+    display: inline-block !important; } }
+
+@media screen and (min-width: 1408px) {
+  .is-inline-block-fullhd {
+    display: inline-block !important; } }
+
+.is-inline-flex {
+  display: inline-flex !important; }
+
+@media screen and (max-width: 768px) {
+  .is-inline-flex-mobile {
+    display: inline-flex !important; } }
+
+@media screen and (min-width: 769px), print {
+  .is-inline-flex-tablet {
+    display: inline-flex !important; } }
+
+@media screen and (min-width: 769px) and (max-width: 1055px) {
+  .is-inline-flex-tablet-only {
+    display: inline-flex !important; } }
+
+@media screen and (max-width: 1055px) {
+  .is-inline-flex-touch {
+    display: inline-flex !important; } }
+
+@media screen and (min-width: 1056px) {
+  .is-inline-flex-desktop {
+    display: inline-flex !important; } }
+
+@media screen and (min-width: 1056px) and (max-width: 1215px) {
+  .is-inline-flex-desktop-only {
+    display: inline-flex !important; } }
+
+@media screen and (min-width: 1216px) {
+  .is-inline-flex-widescreen {
+    display: inline-flex !important; } }
+
+@media screen and (min-width: 1216px) and (max-width: 1407px) {
+  .is-inline-flex-widescreen-only {
+    display: inline-flex !important; } }
+
+@media screen and (min-width: 1408px) {
+  .is-inline-flex-fullhd {
+    display: inline-flex !important; } }
+
+.is-hidden {
+  display: none !important; }
+
+.is-sr-only {
+  border: none !important;
+  clip: rect(0, 0, 0, 0) !important;
+  height: 0.01em !important;
+  overflow: hidden !important;
+  padding: 0 !important;
+  position: absolute !important;
+  white-space: nowrap !important;
+  width: 0.01em !important; }
+
+@media screen and (max-width: 768px) {
+  .is-hidden-mobile {
+    display: none !important; } }
+
+@media screen and (min-width: 769px), print {
+  .is-hidden-tablet {
+    display: none !important; } }
+
+@media screen and (min-width: 769px) and (max-width: 1055px) {
+  .is-hidden-tablet-only {
+    display: none !important; } }
+
+@media screen and (max-width: 1055px) {
+  .is-hidden-touch {
+    display: none !important; } }
+
+@media screen and (min-width: 1056px) {
+  .is-hidden-desktop {
+    display: none !important; } }
+
+@media screen and (min-width: 1056px) and (max-width: 1215px) {
+  .is-hidden-desktop-only {
+    display: none !important; } }
+
+@media screen and (min-width: 1216px) {
+  .is-hidden-widescreen {
+    display: none !important; } }
+
+@media screen and (min-width: 1216px) and (max-width: 1407px) {
+  .is-hidden-widescreen-only {
+    display: none !important; } }
+
+@media screen and (min-width: 1408px) {
+  .is-hidden-fullhd {
+    display: none !important; } }
+
+.is-invisible {
+  visibility: hidden !important; }
+
+@media screen and (max-width: 768px) {
+  .is-invisible-mobile {
+    visibility: hidden !important; } }
+
+@media screen and (min-width: 769px), print {
+  .is-invisible-tablet {
+    visibility: hidden !important; } }
+
+@media screen and (min-width: 769px) and (max-width: 1055px) {
+  .is-invisible-tablet-only {
+    visibility: hidden !important; } }
+
+@media screen and (max-width: 1055px) {
+  .is-invisible-touch {
+    visibility: hidden !important; } }
+
+@media screen and (min-width: 1056px) {
+  .is-invisible-desktop {
+    visibility: hidden !important; } }
+
+@media screen and (min-width: 1056px) and (max-width: 1215px) {
+  .is-invisible-desktop-only {
+    visibility: hidden !important; } }
+
+@media screen and (min-width: 1216px) {
+  .is-invisible-widescreen {
+    visibility: hidden !important; } }
+
+@media screen and (min-width: 1216px) and (max-width: 1407px) {
+  .is-invisible-widescreen-only {
+    visibility: hidden !important; } }
+
+@media screen and (min-width: 1408px) {
+  .is-invisible-fullhd {
+    visibility: hidden !important; } }
+
+.is-marginless {
+  margin: 0 !important; }
+
+.is-paddingless {
+  padding: 0 !important; }
+
+.is-radiusless {
+  border-radius: 0 !important; }
+
+.is-shadowless {
+  box-shadow: none !important; }
+
+.is-relative {
+  position: relative !important; }
+
+.box {
+  background-color: white;
+  border-radius: 6px;
+  box-shadow: 0 2px 3px rgba(10, 10, 10, 0.1), 0 0 0 1px rgba(10, 10, 10, 0.1);
+  color: #222222;
+  display: block;
+  padding: 1.25rem; }
+
+a.box:hover, a.box:focus {
+  box-shadow: 0 2px 3px rgba(10, 10, 10, 0.1), 0 0 0 1px #2e63b8; }
+
+a.box:active {
+  box-shadow: inset 0 1px 2px rgba(10, 10, 10, 0.2), 0 0 0 1px #2e63b8; }
+
+.button {
+  background-color: white;
+  border-color: #dbdbdb;
+  border-width: 1px;
+  color: #363636;
+  cursor: pointer;
+  justify-content: center;
+  padding-bottom: calc(0.375em - 1px);
+  padding-left: 0.75em;
+  padding-right: 0.75em;
+  padding-top: calc(0.375em - 1px);
+  text-align: center;
+  white-space: nowrap; }
+  .button strong {
+    color: inherit; }
+  .button .icon, .button .icon.is-small, .button #documenter .docs-sidebar form.docs-search > input.icon, #documenter .docs-sidebar .button form.docs-search > input.icon, .button .icon.is-medium, .button .icon.is-large {
+    height: 1.5em;
+    width: 1.5em; }
+  .button .icon:first-child:not(:last-child) {
+    margin-left: calc(-0.375em - 1px);
+    margin-right: 0.1875em; }
+  .button .icon:last-child:not(:first-child) {
+    margin-left: 0.1875em;
+    margin-right: calc(-0.375em - 1px); }
+  .button .icon:first-child:last-child {
+    margin-left: calc(-0.375em - 1px);
+    margin-right: calc(-0.375em - 1px); }
+  .button:hover, .button.is-hovered {
+    border-color: #b5b5b5;
+    color: #363636; }
+  .button:focus, .button.is-focused {
+    border-color: #2e63b8;
+    color: #363636; }
+    .button:focus:not(:active), .button.is-focused:not(:active) {
+      box-shadow: 0 0 0 0.125em rgba(46, 99, 184, 0.25); }
+  .button:active, .button.is-active {
+    border-color: #4a4a4a;
+    color: #363636; }
+  .button.is-text {
+    background-color: transparent;
+    border-color: transparent;
+    color: #222222;
+    text-decoration: underline; }
+    .button.is-text:hover, .button.is-text.is-hovered, .button.is-text:focus, .button.is-text.is-focused {
+      background-color: whitesmoke;
+      color: #222222; }
+    .button.is-text:active, .button.is-text.is-active {
+      background-color: #e8e8e8;
+      color: #222222; }
+    .button.is-text[disabled],
+    fieldset[disabled] .button.is-text {
+      background-color: transparent;
+      border-color: transparent;
+      box-shadow: none; }
+  .button.is-white {
+    background-color: white;
+    border-color: transparent;
+    color: #0a0a0a; }
+    .button.is-white:hover, .button.is-white.is-hovered {
+      background-color: #f9f9f9;
+      border-color: transparent;
+      color: #0a0a0a; }
+    .button.is-white:focus, .button.is-white.is-focused {
+      border-color: transparent;
+      color: #0a0a0a; }
+      .button.is-white:focus:not(:active), .button.is-white.is-focused:not(:active) {
+        box-shadow: 0 0 0 0.125em rgba(255, 255, 255, 0.25); }
+    .button.is-white:active, .button.is-white.is-active {
+      background-color: #f2f2f2;
+      border-color: transparent;
+      color: #0a0a0a; }
+    .button.is-white[disabled],
+    fieldset[disabled] .button.is-white {
+      background-color: white;
+      border-color: transparent;
+      box-shadow: none; }
+    .button.is-white.is-inverted {
+      background-color: #0a0a0a;
+      color: white; }
+      .button.is-white.is-inverted:hover, .button.is-white.is-inverted.is-hovered {
+        background-color: black; }
+      .button.is-white.is-inverted[disabled],
+      fieldset[disabled] .button.is-white.is-inverted {
+        background-color: #0a0a0a;
+        border-color: transparent;
+        box-shadow: none;
+        color: white; }
+    .button.is-white.is-loading::after {
+      border-color: transparent transparent #0a0a0a #0a0a0a !important; }
+    .button.is-white.is-outlined {
+      background-color: transparent;
+      border-color: white;
+      color: white; }
+      .button.is-white.is-outlined:hover, .button.is-white.is-outlined.is-hovered, .button.is-white.is-outlined:focus, .button.is-white.is-outlined.is-focused {
+        background-color: white;
+        border-color: white;
+        color: #0a0a0a; }
+      .button.is-white.is-outlined.is-loading::after {
+        border-color: transparent transparent white white !important; }
+      .button.is-white.is-outlined.is-loading:hover::after, .button.is-white.is-outlined.is-loading.is-hovered::after, .button.is-white.is-outlined.is-loading:focus::after, .button.is-white.is-outlined.is-loading.is-focused::after {
+        border-color: transparent transparent #0a0a0a #0a0a0a !important; }
+      .button.is-white.is-outlined[disabled],
+      fieldset[disabled] .button.is-white.is-outlined {
+        background-color: transparent;
+        border-color: white;
+        box-shadow: none;
+        color: white; }
+    .button.is-white.is-inverted.is-outlined {
+      background-color: transparent;
+      border-color: #0a0a0a;
+      color: #0a0a0a; }
+      .button.is-white.is-inverted.is-outlined:hover, .button.is-white.is-inverted.is-outlined.is-hovered, .button.is-white.is-inverted.is-outlined:focus, .button.is-white.is-inverted.is-outlined.is-focused {
+        background-color: #0a0a0a;
+        color: white; }
+      .button.is-white.is-inverted.is-outlined.is-loading:hover::after, .button.is-white.is-inverted.is-outlined.is-loading.is-hovered::after, .button.is-white.is-inverted.is-outlined.is-loading:focus::after, .button.is-white.is-inverted.is-outlined.is-loading.is-focused::after {
+        border-color: transparent transparent white white !important; }
+      .button.is-white.is-inverted.is-outlined[disabled],
+      fieldset[disabled] .button.is-white.is-inverted.is-outlined {
+        background-color: transparent;
+        border-color: #0a0a0a;
+        box-shadow: none;
+        color: #0a0a0a; }
+  .button.is-black {
+    background-color: #0a0a0a;
+    border-color: transparent;
+    color: white; }
+    .button.is-black:hover, .button.is-black.is-hovered {
+      background-color: #040404;
+      border-color: transparent;
+      color: white; }
+    .button.is-black:focus, .button.is-black.is-focused {
+      border-color: transparent;
+      color: white; }
+      .button.is-black:focus:not(:active), .button.is-black.is-focused:not(:active) {
+        box-shadow: 0 0 0 0.125em rgba(10, 10, 10, 0.25); }
+    .button.is-black:active, .button.is-black.is-active {
+      background-color: black;
+      border-color: transparent;
+      color: white; }
+    .button.is-black[disabled],
+    fieldset[disabled] .button.is-black {
+      background-color: #0a0a0a;
+      border-color: transparent;
+      box-shadow: none; }
+    .button.is-black.is-inverted {
+      background-color: white;
+      color: #0a0a0a; }
+      .button.is-black.is-inverted:hover, .button.is-black.is-inverted.is-hovered {
+        background-color: #f2f2f2; }
+      .button.is-black.is-inverted[disabled],
+      fieldset[disabled] .button.is-black.is-inverted {
+        background-color: white;
+        border-color: transparent;
+        box-shadow: none;
+        color: #0a0a0a; }
+    .button.is-black.is-loading::after {
+      border-color: transparent transparent white white !important; }
+    .button.is-black.is-outlined {
+      background-color: transparent;
+      border-color: #0a0a0a;
+      color: #0a0a0a; }
+      .button.is-black.is-outlined:hover, .button.is-black.is-outlined.is-hovered, .button.is-black.is-outlined:focus, .button.is-black.is-outlined.is-focused {
+        background-color: #0a0a0a;
+        border-color: #0a0a0a;
+        color: white; }
+      .button.is-black.is-outlined.is-loading::after {
+        border-color: transparent transparent #0a0a0a #0a0a0a !important; }
+      .button.is-black.is-outlined.is-loading:hover::after, .button.is-black.is-outlined.is-loading.is-hovered::after, .button.is-black.is-outlined.is-loading:focus::after, .button.is-black.is-outlined.is-loading.is-focused::after {
+        border-color: transparent transparent white white !important; }
+      .button.is-black.is-outlined[disabled],
+      fieldset[disabled] .button.is-black.is-outlined {
+        background-color: transparent;
+        border-color: #0a0a0a;
+        box-shadow: none;
+        color: #0a0a0a; }
+    .button.is-black.is-inverted.is-outlined {
+      background-color: transparent;
+      border-color: white;
+      color: white; }
+      .button.is-black.is-inverted.is-outlined:hover, .button.is-black.is-inverted.is-outlined.is-hovered, .button.is-black.is-inverted.is-outlined:focus, .button.is-black.is-inverted.is-outlined.is-focused {
+        background-color: white;
+        color: #0a0a0a; }
+      .button.is-black.is-inverted.is-outlined.is-loading:hover::after, .button.is-black.is-inverted.is-outlined.is-loading.is-hovered::after, .button.is-black.is-inverted.is-outlined.is-loading:focus::after, .button.is-black.is-inverted.is-outlined.is-loading.is-focused::after {
+        border-color: transparent transparent #0a0a0a #0a0a0a !important; }
+      .button.is-black.is-inverted.is-outlined[disabled],
+      fieldset[disabled] .button.is-black.is-inverted.is-outlined {
+        background-color: transparent;
+        border-color: white;
+        box-shadow: none;
+        color: white; }
+  .button.is-light {
+    background-color: whitesmoke;
+    border-color: transparent;
+    color: #363636; }
+    .button.is-light:hover, .button.is-light.is-hovered {
+      background-color: #eeeeee;
+      border-color: transparent;
+      color: #363636; }
+    .button.is-light:focus, .button.is-light.is-focused {
+      border-color: transparent;
+      color: #363636; }
+      .button.is-light:focus:not(:active), .button.is-light.is-focused:not(:active) {
+        box-shadow: 0 0 0 0.125em rgba(245, 245, 245, 0.25); }
+    .button.is-light:active, .button.is-light.is-active {
+      background-color: #e8e8e8;
+      border-color: transparent;
+      color: #363636; }
+    .button.is-light[disabled],
+    fieldset[disabled] .button.is-light {
+      background-color: whitesmoke;
+      border-color: transparent;
+      box-shadow: none; }
+    .button.is-light.is-inverted {
+      background-color: #363636;
+      color: whitesmoke; }
+      .button.is-light.is-inverted:hover, .button.is-light.is-inverted.is-hovered {
+        background-color: #292929; }
+      .button.is-light.is-inverted[disabled],
+      fieldset[disabled] .button.is-light.is-inverted {
+        background-color: #363636;
+        border-color: transparent;
+        box-shadow: none;
+        color: whitesmoke; }
+    .button.is-light.is-loading::after {
+      border-color: transparent transparent #363636 #363636 !important; }
+    .button.is-light.is-outlined {
+      background-color: transparent;
+      border-color: whitesmoke;
+      color: whitesmoke; }
+      .button.is-light.is-outlined:hover, .button.is-light.is-outlined.is-hovered, .button.is-light.is-outlined:focus, .button.is-light.is-outlined.is-focused {
+        background-color: whitesmoke;
+        border-color: whitesmoke;
+        color: #363636; }
+      .button.is-light.is-outlined.is-loading::after {
+        border-color: transparent transparent whitesmoke whitesmoke !important; }
+      .button.is-light.is-outlined.is-loading:hover::after, .button.is-light.is-outlined.is-loading.is-hovered::after, .button.is-light.is-outlined.is-loading:focus::after, .button.is-light.is-outlined.is-loading.is-focused::after {
+        border-color: transparent transparent #363636 #363636 !important; }
+      .button.is-light.is-outlined[disabled],
+      fieldset[disabled] .button.is-light.is-outlined {
+        background-color: transparent;
+        border-color: whitesmoke;
+        box-shadow: none;
+        color: whitesmoke; }
+    .button.is-light.is-inverted.is-outlined {
+      background-color: transparent;
+      border-color: #363636;
+      color: #363636; }
+      .button.is-light.is-inverted.is-outlined:hover, .button.is-light.is-inverted.is-outlined.is-hovered, .button.is-light.is-inverted.is-outlined:focus, .button.is-light.is-inverted.is-outlined.is-focused {
+        background-color: #363636;
+        color: whitesmoke; }
+      .button.is-light.is-inverted.is-outlined.is-loading:hover::after, .button.is-light.is-inverted.is-outlined.is-loading.is-hovered::after, .button.is-light.is-inverted.is-outlined.is-loading:focus::after, .button.is-light.is-inverted.is-outlined.is-loading.is-focused::after {
+        border-color: transparent transparent whitesmoke whitesmoke !important; }
+      .button.is-light.is-inverted.is-outlined[disabled],
+      fieldset[disabled] .button.is-light.is-inverted.is-outlined {
+        background-color: transparent;
+        border-color: #363636;
+        box-shadow: none;
+        color: #363636; }
+  .button.is-dark, .content kbd.button {
+    background-color: #363636;
+    border-color: transparent;
+    color: whitesmoke; }
+    .button.is-dark:hover, .content kbd.button:hover, .button.is-dark.is-hovered, .content kbd.button.is-hovered {
+      background-color: #2f2f2f;
+      border-color: transparent;
+      color: whitesmoke; }
+    .button.is-dark:focus, .content kbd.button:focus, .button.is-dark.is-focused, .content kbd.button.is-focused {
+      border-color: transparent;
+      color: whitesmoke; }
+      .button.is-dark:focus:not(:active), .content kbd.button:focus:not(:active), .button.is-dark.is-focused:not(:active), .content kbd.button.is-focused:not(:active) {
+        box-shadow: 0 0 0 0.125em rgba(54, 54, 54, 0.25); }
+    .button.is-dark:active, .content kbd.button:active, .button.is-dark.is-active, .content kbd.button.is-active {
+      background-color: #292929;
+      border-color: transparent;
+      color: whitesmoke; }
+    .button.is-dark[disabled], .content kbd.button[disabled],
+    fieldset[disabled] .button.is-dark,
+    fieldset[disabled] .content kbd.button,
+    .content fieldset[disabled] kbd.button {
+      background-color: #363636;
+      border-color: transparent;
+      box-shadow: none; }
+    .button.is-dark.is-inverted, .content kbd.button.is-inverted {
+      background-color: whitesmoke;
+      color: #363636; }
+      .button.is-dark.is-inverted:hover, .content kbd.button.is-inverted:hover, .button.is-dark.is-inverted.is-hovered, .content kbd.button.is-inverted.is-hovered {
+        background-color: #e8e8e8; }
+      .button.is-dark.is-inverted[disabled], .content kbd.button.is-inverted[disabled],
+      fieldset[disabled] .button.is-dark.is-inverted,
+      fieldset[disabled] .content kbd.button.is-inverted,
+      .content fieldset[disabled] kbd.button.is-inverted {
+        background-color: whitesmoke;
+        border-color: transparent;
+        box-shadow: none;
+        color: #363636; }
+    .button.is-dark.is-loading::after, .content kbd.button.is-loading::after {
+      border-color: transparent transparent whitesmoke whitesmoke !important; }
+    .button.is-dark.is-outlined, .content kbd.button.is-outlined {
+      background-color: transparent;
+      border-color: #363636;
+      color: #363636; }
+      .button.is-dark.is-outlined:hover, .content kbd.button.is-outlined:hover, .button.is-dark.is-outlined.is-hovered, .content kbd.button.is-outlined.is-hovered, .button.is-dark.is-outlined:focus, .content kbd.button.is-outlined:focus, .button.is-dark.is-outlined.is-focused, .content kbd.button.is-outlined.is-focused {
+        background-color: #363636;
+        border-color: #363636;
+        color: whitesmoke; }
+      .button.is-dark.is-outlined.is-loading::after, .content kbd.button.is-outlined.is-loading::after {
+        border-color: transparent transparent #363636 #363636 !important; }
+      .button.is-dark.is-outlined.is-loading:hover::after, .content kbd.button.is-outlined.is-loading:hover::after, .button.is-dark.is-outlined.is-loading.is-hovered::after, .content kbd.button.is-outlined.is-loading.is-hovered::after, .button.is-dark.is-outlined.is-loading:focus::after, .content kbd.button.is-outlined.is-loading:focus::after, .button.is-dark.is-outlined.is-loading.is-focused::after, .content kbd.button.is-outlined.is-loading.is-focused::after {
+        border-color: transparent transparent whitesmoke whitesmoke !important; }
+      .button.is-dark.is-outlined[disabled], .content kbd.button.is-outlined[disabled],
+      fieldset[disabled] .button.is-dark.is-outlined,
+      fieldset[disabled] .content kbd.button.is-outlined,
+      .content fieldset[disabled] kbd.button.is-outlined {
+        background-color: transparent;
+        border-color: #363636;
+        box-shadow: none;
+        color: #363636; }
+    .button.is-dark.is-inverted.is-outlined, .content kbd.button.is-inverted.is-outlined {
+      background-color: transparent;
+      border-color: whitesmoke;
+      color: whitesmoke; }
+      .button.is-dark.is-inverted.is-outlined:hover, .content kbd.button.is-inverted.is-outlined:hover, .button.is-dark.is-inverted.is-outlined.is-hovered, .content kbd.button.is-inverted.is-outlined.is-hovered, .button.is-dark.is-inverted.is-outlined:focus, .content kbd.button.is-inverted.is-outlined:focus, .button.is-dark.is-inverted.is-outlined.is-focused, .content kbd.button.is-inverted.is-outlined.is-focused {
+        background-color: whitesmoke;
+        color: #363636; }
+      .button.is-dark.is-inverted.is-outlined.is-loading:hover::after, .content kbd.button.is-inverted.is-outlined.is-loading:hover::after, .button.is-dark.is-inverted.is-outlined.is-loading.is-hovered::after, .content kbd.button.is-inverted.is-outlined.is-loading.is-hovered::after, .button.is-dark.is-inverted.is-outlined.is-loading:focus::after, .content kbd.button.is-inverted.is-outlined.is-loading:focus::after, .button.is-dark.is-inverted.is-outlined.is-loading.is-focused::after, .content kbd.button.is-inverted.is-outlined.is-loading.is-focused::after {
+        border-color: transparent transparent #363636 #363636 !important; }
+      .button.is-dark.is-inverted.is-outlined[disabled], .content kbd.button.is-inverted.is-outlined[disabled],
+      fieldset[disabled] .button.is-dark.is-inverted.is-outlined,
+      fieldset[disabled] .content kbd.button.is-inverted.is-outlined,
+      .content fieldset[disabled] kbd.button.is-inverted.is-outlined {
+        background-color: transparent;
+        border-color: whitesmoke;
+        box-shadow: none;
+        color: whitesmoke; }
+  .button.is-primary, .docstring > section > a.button.docs-sourcelink {
+    background-color: #4eb5de;
+    border-color: transparent;
+    color: #fff; }
+    .button.is-primary:hover, .docstring > section > a.button.docs-sourcelink:hover, .button.is-primary.is-hovered, .docstring > section > a.button.is-hovered.docs-sourcelink {
+      background-color: #43b1dc;
+      border-color: transparent;
+      color: #fff; }
+    .button.is-primary:focus, .docstring > section > a.button.docs-sourcelink:focus, .button.is-primary.is-focused, .docstring > section > a.button.is-focused.docs-sourcelink {
+      border-color: transparent;
+      color: #fff; }
+      .button.is-primary:focus:not(:active), .docstring > section > a.button.docs-sourcelink:focus:not(:active), .button.is-primary.is-focused:not(:active), .docstring > section > a.button.is-focused.docs-sourcelink:not(:active) {
+        box-shadow: 0 0 0 0.125em rgba(78, 181, 222, 0.25); }
+    .button.is-primary:active, .docstring > section > a.button.docs-sourcelink:active, .button.is-primary.is-active, .docstring > section > a.button.is-active.docs-sourcelink {
+      background-color: #39acda;
+      border-color: transparent;
+      color: #fff; }
+    .button.is-primary[disabled], .docstring > section > a.button.docs-sourcelink[disabled],
+    fieldset[disabled] .button.is-primary,
+    fieldset[disabled] .docstring > section > a.button.docs-sourcelink {
+      background-color: #4eb5de;
+      border-color: transparent;
+      box-shadow: none; }
+    .button.is-primary.is-inverted, .docstring > section > a.button.is-inverted.docs-sourcelink {
+      background-color: #fff;
+      color: #4eb5de; }
+      .button.is-primary.is-inverted:hover, .docstring > section > a.button.is-inverted.docs-sourcelink:hover, .button.is-primary.is-inverted.is-hovered, .docstring > section > a.button.is-inverted.is-hovered.docs-sourcelink {
+        background-color: #f2f2f2; }
+      .button.is-primary.is-inverted[disabled], .docstring > section > a.button.is-inverted.docs-sourcelink[disabled],
+      fieldset[disabled] .button.is-primary.is-inverted,
+      fieldset[disabled] .docstring > section > a.button.is-inverted.docs-sourcelink {
+        background-color: #fff;
+        border-color: transparent;
+        box-shadow: none;
+        color: #4eb5de; }
+    .button.is-primary.is-loading::after, .docstring > section > a.button.is-loading.docs-sourcelink::after {
+      border-color: transparent transparent #fff #fff !important; }
+    .button.is-primary.is-outlined, .docstring > section > a.button.is-outlined.docs-sourcelink {
+      background-color: transparent;
+      border-color: #4eb5de;
+      color: #4eb5de; }
+      .button.is-primary.is-outlined:hover, .docstring > section > a.button.is-outlined.docs-sourcelink:hover, .button.is-primary.is-outlined.is-hovered, .docstring > section > a.button.is-outlined.is-hovered.docs-sourcelink, .button.is-primary.is-outlined:focus, .docstring > section > a.button.is-outlined.docs-sourcelink:focus, .button.is-primary.is-outlined.is-focused, .docstring > section > a.button.is-outlined.is-focused.docs-sourcelink {
+        background-color: #4eb5de;
+        border-color: #4eb5de;
+        color: #fff; }
+      .button.is-primary.is-outlined.is-loading::after, .docstring > section > a.button.is-outlined.is-loading.docs-sourcelink::after {
+        border-color: transparent transparent #4eb5de #4eb5de !important; }
+      .button.is-primary.is-outlined.is-loading:hover::after, .docstring > section > a.button.is-outlined.is-loading.docs-sourcelink:hover::after, .button.is-primary.is-outlined.is-loading.is-hovered::after, .docstring > section > a.button.is-outlined.is-loading.is-hovered.docs-sourcelink::after, .button.is-primary.is-outlined.is-loading:focus::after, .docstring > section > a.button.is-outlined.is-loading.docs-sourcelink:focus::after, .button.is-primary.is-outlined.is-loading.is-focused::after, .docstring > section > a.button.is-outlined.is-loading.is-focused.docs-sourcelink::after {
+        border-color: transparent transparent #fff #fff !important; }
+      .button.is-primary.is-outlined[disabled], .docstring > section > a.button.is-outlined.docs-sourcelink[disabled],
+      fieldset[disabled] .button.is-primary.is-outlined,
+      fieldset[disabled] .docstring > section > a.button.is-outlined.docs-sourcelink {
+        background-color: transparent;
+        border-color: #4eb5de;
+        box-shadow: none;
+        color: #4eb5de; }
+    .button.is-primary.is-inverted.is-outlined, .docstring > section > a.button.is-inverted.is-outlined.docs-sourcelink {
+      background-color: transparent;
+      border-color: #fff;
+      color: #fff; }
+      .button.is-primary.is-inverted.is-outlined:hover, .docstring > section > a.button.is-inverted.is-outlined.docs-sourcelink:hover, .button.is-primary.is-inverted.is-outlined.is-hovered, .docstring > section > a.button.is-inverted.is-outlined.is-hovered.docs-sourcelink, .button.is-primary.is-inverted.is-outlined:focus, .docstring > section > a.button.is-inverted.is-outlined.docs-sourcelink:focus, .button.is-primary.is-inverted.is-outlined.is-focused, .docstring > section > a.button.is-inverted.is-outlined.is-focused.docs-sourcelink {
+        background-color: #fff;
+        color: #4eb5de; }
+      .button.is-primary.is-inverted.is-outlined.is-loading:hover::after, .docstring > section > a.button.is-inverted.is-outlined.is-loading.docs-sourcelink:hover::after, .button.is-primary.is-inverted.is-outlined.is-loading.is-hovered::after, .docstring > section > a.button.is-inverted.is-outlined.is-loading.is-hovered.docs-sourcelink::after, .button.is-primary.is-inverted.is-outlined.is-loading:focus::after, .docstring > section > a.button.is-inverted.is-outlined.is-loading.docs-sourcelink:focus::after, .button.is-primary.is-inverted.is-outlined.is-loading.is-focused::after, .docstring > section > a.button.is-inverted.is-outlined.is-loading.is-focused.docs-sourcelink::after {
+        border-color: transparent transparent #4eb5de #4eb5de !important; }
+      .button.is-primary.is-inverted.is-outlined[disabled], .docstring > section > a.button.is-inverted.is-outlined.docs-sourcelink[disabled],
+      fieldset[disabled] .button.is-primary.is-inverted.is-outlined,
+      fieldset[disabled] .docstring > section > a.button.is-inverted.is-outlined.docs-sourcelink {
+        background-color: transparent;
+        border-color: #fff;
+        box-shadow: none;
+        color: #fff; }
+  .button.is-link {
+    background-color: #2e63b8;
+    border-color: transparent;
+    color: #fff; }
+    .button.is-link:hover, .button.is-link.is-hovered {
+      background-color: #2b5eae;
+      border-color: transparent;
+      color: #fff; }
+    .button.is-link:focus, .button.is-link.is-focused {
+      border-color: transparent;
+      color: #fff; }
+      .button.is-link:focus:not(:active), .button.is-link.is-focused:not(:active) {
+        box-shadow: 0 0 0 0.125em rgba(46, 99, 184, 0.25); }
+    .button.is-link:active, .button.is-link.is-active {
+      background-color: #2958a4;
+      border-color: transparent;
+      color: #fff; }
+    .button.is-link[disabled],
+    fieldset[disabled] .button.is-link {
+      background-color: #2e63b8;
+      border-color: transparent;
+      box-shadow: none; }
+    .button.is-link.is-inverted {
+      background-color: #fff;
+      color: #2e63b8; }
+      .button.is-link.is-inverted:hover, .button.is-link.is-inverted.is-hovered {
+        background-color: #f2f2f2; }
+      .button.is-link.is-inverted[disabled],
+      fieldset[disabled] .button.is-link.is-inverted {
+        background-color: #fff;
+        border-color: transparent;
+        box-shadow: none;
+        color: #2e63b8; }
+    .button.is-link.is-loading::after {
+      border-color: transparent transparent #fff #fff !important; }
+    .button.is-link.is-outlined {
+      background-color: transparent;
+      border-color: #2e63b8;
+      color: #2e63b8; }
+      .button.is-link.is-outlined:hover, .button.is-link.is-outlined.is-hovered, .button.is-link.is-outlined:focus, .button.is-link.is-outlined.is-focused {
+        background-color: #2e63b8;
+        border-color: #2e63b8;
+        color: #fff; }
+      .button.is-link.is-outlined.is-loading::after {
+        border-color: transparent transparent #2e63b8 #2e63b8 !important; }
+      .button.is-link.is-outlined.is-loading:hover::after, .button.is-link.is-outlined.is-loading.is-hovered::after, .button.is-link.is-outlined.is-loading:focus::after, .button.is-link.is-outlined.is-loading.is-focused::after {
+        border-color: transparent transparent #fff #fff !important; }
+      .button.is-link.is-outlined[disabled],
+      fieldset[disabled] .button.is-link.is-outlined {
+        background-color: transparent;
+        border-color: #2e63b8;
+        box-shadow: none;
+        color: #2e63b8; }
+    .button.is-link.is-inverted.is-outlined {
+      background-color: transparent;
+      border-color: #fff;
+      color: #fff; }
+      .button.is-link.is-inverted.is-outlined:hover, .button.is-link.is-inverted.is-outlined.is-hovered, .button.is-link.is-inverted.is-outlined:focus, .button.is-link.is-inverted.is-outlined.is-focused {
+        background-color: #fff;
+        color: #2e63b8; }
+      .button.is-link.is-inverted.is-outlined.is-loading:hover::after, .button.is-link.is-inverted.is-outlined.is-loading.is-hovered::after, .button.is-link.is-inverted.is-outlined.is-loading:focus::after, .button.is-link.is-inverted.is-outlined.is-loading.is-focused::after {
+        border-color: transparent transparent #2e63b8 #2e63b8 !important; }
+      .button.is-link.is-inverted.is-outlined[disabled],
+      fieldset[disabled] .button.is-link.is-inverted.is-outlined {
+        background-color: transparent;
+        border-color: #fff;
+        box-shadow: none;
+        color: #fff; }
+  .button.is-info {
+    background-color: #209cee;
+    border-color: transparent;
+    color: #fff; }
+    .button.is-info:hover, .button.is-info.is-hovered {
+      background-color: #1496ed;
+      border-color: transparent;
+      color: #fff; }
+    .button.is-info:focus, .button.is-info.is-focused {
+      border-color: transparent;
+      color: #fff; }
+      .button.is-info:focus:not(:active), .button.is-info.is-focused:not(:active) {
+        box-shadow: 0 0 0 0.125em rgba(32, 156, 238, 0.25); }
+    .button.is-info:active, .button.is-info.is-active {
+      background-color: #118fe4;
+      border-color: transparent;
+      color: #fff; }
+    .button.is-info[disabled],
+    fieldset[disabled] .button.is-info {
+      background-color: #209cee;
+      border-color: transparent;
+      box-shadow: none; }
+    .button.is-info.is-inverted {
+      background-color: #fff;
+      color: #209cee; }
+      .button.is-info.is-inverted:hover, .button.is-info.is-inverted.is-hovered {
+        background-color: #f2f2f2; }
+      .button.is-info.is-inverted[disabled],
+      fieldset[disabled] .button.is-info.is-inverted {
+        background-color: #fff;
+        border-color: transparent;
+        box-shadow: none;
+        color: #209cee; }
+    .button.is-info.is-loading::after {
+      border-color: transparent transparent #fff #fff !important; }
+    .button.is-info.is-outlined {
+      background-color: transparent;
+      border-color: #209cee;
+      color: #209cee; }
+      .button.is-info.is-outlined:hover, .button.is-info.is-outlined.is-hovered, .button.is-info.is-outlined:focus, .button.is-info.is-outlined.is-focused {
+        background-color: #209cee;
+        border-color: #209cee;
+        color: #fff; }
+      .button.is-info.is-outlined.is-loading::after {
+        border-color: transparent transparent #209cee #209cee !important; }
+      .button.is-info.is-outlined.is-loading:hover::after, .button.is-info.is-outlined.is-loading.is-hovered::after, .button.is-info.is-outlined.is-loading:focus::after, .button.is-info.is-outlined.is-loading.is-focused::after {
+        border-color: transparent transparent #fff #fff !important; }
+      .button.is-info.is-outlined[disabled],
+      fieldset[disabled] .button.is-info.is-outlined {
+        background-color: transparent;
+        border-color: #209cee;
+        box-shadow: none;
+        color: #209cee; }
+    .button.is-info.is-inverted.is-outlined {
+      background-color: transparent;
+      border-color: #fff;
+      color: #fff; }
+      .button.is-info.is-inverted.is-outlined:hover, .button.is-info.is-inverted.is-outlined.is-hovered, .button.is-info.is-inverted.is-outlined:focus, .button.is-info.is-inverted.is-outlined.is-focused {
+        background-color: #fff;
+        color: #209cee; }
+      .button.is-info.is-inverted.is-outlined.is-loading:hover::after, .button.is-info.is-inverted.is-outlined.is-loading.is-hovered::after, .button.is-info.is-inverted.is-outlined.is-loading:focus::after, .button.is-info.is-inverted.is-outlined.is-loading.is-focused::after {
+        border-color: transparent transparent #209cee #209cee !important; }
+      .button.is-info.is-inverted.is-outlined[disabled],
+      fieldset[disabled] .button.is-info.is-inverted.is-outlined {
+        background-color: transparent;
+        border-color: #fff;
+        box-shadow: none;
+        color: #fff; }
+  .button.is-success {
+    background-color: #22c35b;
+    border-color: transparent;
+    color: #fff; }
+    .button.is-success:hover, .button.is-success.is-hovered {
+      background-color: #20b856;
+      border-color: transparent;
+      color: #fff; }
+    .button.is-success:focus, .button.is-success.is-focused {
+      border-color: transparent;
+      color: #fff; }
+      .button.is-success:focus:not(:active), .button.is-success.is-focused:not(:active) {
+        box-shadow: 0 0 0 0.125em rgba(34, 195, 91, 0.25); }
+    .button.is-success:active, .button.is-success.is-active {
+      background-color: #1ead51;
+      border-color: transparent;
+      color: #fff; }
+    .button.is-success[disabled],
+    fieldset[disabled] .button.is-success {
+      background-color: #22c35b;
+      border-color: transparent;
+      box-shadow: none; }
+    .button.is-success.is-inverted {
+      background-color: #fff;
+      color: #22c35b; }
+      .button.is-success.is-inverted:hover, .button.is-success.is-inverted.is-hovered {
+        background-color: #f2f2f2; }
+      .button.is-success.is-inverted[disabled],
+      fieldset[disabled] .button.is-success.is-inverted {
+        background-color: #fff;
+        border-color: transparent;
+        box-shadow: none;
+        color: #22c35b; }
+    .button.is-success.is-loading::after {
+      border-color: transparent transparent #fff #fff !important; }
+    .button.is-success.is-outlined {
+      background-color: transparent;
+      border-color: #22c35b;
+      color: #22c35b; }
+      .button.is-success.is-outlined:hover, .button.is-success.is-outlined.is-hovered, .button.is-success.is-outlined:focus, .button.is-success.is-outlined.is-focused {
+        background-color: #22c35b;
+        border-color: #22c35b;
+        color: #fff; }
+      .button.is-success.is-outlined.is-loading::after {
+        border-color: transparent transparent #22c35b #22c35b !important; }
+      .button.is-success.is-outlined.is-loading:hover::after, .button.is-success.is-outlined.is-loading.is-hovered::after, .button.is-success.is-outlined.is-loading:focus::after, .button.is-success.is-outlined.is-loading.is-focused::after {
+        border-color: transparent transparent #fff #fff !important; }
+      .button.is-success.is-outlined[disabled],
+      fieldset[disabled] .button.is-success.is-outlined {
+        background-color: transparent;
+        border-color: #22c35b;
+        box-shadow: none;
+        color: #22c35b; }
+    .button.is-success.is-inverted.is-outlined {
+      background-color: transparent;
+      border-color: #fff;
+      color: #fff; }
+      .button.is-success.is-inverted.is-outlined:hover, .button.is-success.is-inverted.is-outlined.is-hovered, .button.is-success.is-inverted.is-outlined:focus, .button.is-success.is-inverted.is-outlined.is-focused {
+        background-color: #fff;
+        color: #22c35b; }
+      .button.is-success.is-inverted.is-outlined.is-loading:hover::after, .button.is-success.is-inverted.is-outlined.is-loading.is-hovered::after, .button.is-success.is-inverted.is-outlined.is-loading:focus::after, .button.is-success.is-inverted.is-outlined.is-loading.is-focused::after {
+        border-color: transparent transparent #22c35b #22c35b !important; }
+      .button.is-success.is-inverted.is-outlined[disabled],
+      fieldset[disabled] .button.is-success.is-inverted.is-outlined {
+        background-color: transparent;
+        border-color: #fff;
+        box-shadow: none;
+        color: #fff; }
+  .button.is-warning {
+    background-color: #ffdd57;
+    border-color: transparent;
+    color: rgba(0, 0, 0, 0.7); }
+    .button.is-warning:hover, .button.is-warning.is-hovered {
+      background-color: #ffdb4a;
+      border-color: transparent;
+      color: rgba(0, 0, 0, 0.7); }
+    .button.is-warning:focus, .button.is-warning.is-focused {
+      border-color: transparent;
+      color: rgba(0, 0, 0, 0.7); }
+      .button.is-warning:focus:not(:active), .button.is-warning.is-focused:not(:active) {
+        box-shadow: 0 0 0 0.125em rgba(255, 221, 87, 0.25); }
+    .button.is-warning:active, .button.is-warning.is-active {
+      background-color: #ffd83d;
+      border-color: transparent;
+      color: rgba(0, 0, 0, 0.7); }
+    .button.is-warning[disabled],
+    fieldset[disabled] .button.is-warning {
+      background-color: #ffdd57;
+      border-color: transparent;
+      box-shadow: none; }
+    .button.is-warning.is-inverted {
+      background-color: rgba(0, 0, 0, 0.7);
+      color: #ffdd57; }
+      .button.is-warning.is-inverted:hover, .button.is-warning.is-inverted.is-hovered {
+        background-color: rgba(0, 0, 0, 0.7); }
+      .button.is-warning.is-inverted[disabled],
+      fieldset[disabled] .button.is-warning.is-inverted {
+        background-color: rgba(0, 0, 0, 0.7);
+        border-color: transparent;
+        box-shadow: none;
+        color: #ffdd57; }
+    .button.is-warning.is-loading::after {
+      border-color: transparent transparent rgba(0, 0, 0, 0.7) rgba(0, 0, 0, 0.7) !important; }
+    .button.is-warning.is-outlined {
+      background-color: transparent;
+      border-color: #ffdd57;
+      color: #ffdd57; }
+      .button.is-warning.is-outlined:hover, .button.is-warning.is-outlined.is-hovered, .button.is-warning.is-outlined:focus, .button.is-warning.is-outlined.is-focused {
+        background-color: #ffdd57;
+        border-color: #ffdd57;
+        color: rgba(0, 0, 0, 0.7); }
+      .button.is-warning.is-outlined.is-loading::after {
+        border-color: transparent transparent #ffdd57 #ffdd57 !important; }
+      .button.is-warning.is-outlined.is-loading:hover::after, .button.is-warning.is-outlined.is-loading.is-hovered::after, .button.is-warning.is-outlined.is-loading:focus::after, .button.is-warning.is-outlined.is-loading.is-focused::after {
+        border-color: transparent transparent rgba(0, 0, 0, 0.7) rgba(0, 0, 0, 0.7) !important; }
+      .button.is-warning.is-outlined[disabled],
+      fieldset[disabled] .button.is-warning.is-outlined {
+        background-color: transparent;
+        border-color: #ffdd57;
+        box-shadow: none;
+        color: #ffdd57; }
+    .button.is-warning.is-inverted.is-outlined {
+      background-color: transparent;
+      border-color: rgba(0, 0, 0, 0.7);
+      color: rgba(0, 0, 0, 0.7); }
+      .button.is-warning.is-inverted.is-outlined:hover, .button.is-warning.is-inverted.is-outlined.is-hovered, .button.is-warning.is-inverted.is-outlined:focus, .button.is-warning.is-inverted.is-outlined.is-focused {
+        background-color: rgba(0, 0, 0, 0.7);
+        color: #ffdd57; }
+      .button.is-warning.is-inverted.is-outlined.is-loading:hover::after, .button.is-warning.is-inverted.is-outlined.is-loading.is-hovered::after, .button.is-warning.is-inverted.is-outlined.is-loading:focus::after, .button.is-warning.is-inverted.is-outlined.is-loading.is-focused::after {
+        border-color: transparent transparent #ffdd57 #ffdd57 !important; }
+      .button.is-warning.is-inverted.is-outlined[disabled],
+      fieldset[disabled] .button.is-warning.is-inverted.is-outlined {
+        background-color: transparent;
+        border-color: rgba(0, 0, 0, 0.7);
+        box-shadow: none;
+        color: rgba(0, 0, 0, 0.7); }
+  .button.is-danger {
+    background-color: #da0b00;
+    border-color: transparent;
+    color: #fff; }
+    .button.is-danger:hover, .button.is-danger.is-hovered {
+      background-color: #cd0a00;
+      border-color: transparent;
+      color: #fff; }
+    .button.is-danger:focus, .button.is-danger.is-focused {
+      border-color: transparent;
+      color: #fff; }
+      .button.is-danger:focus:not(:active), .button.is-danger.is-focused:not(:active) {
+        box-shadow: 0 0 0 0.125em rgba(218, 11, 0, 0.25); }
+    .button.is-danger:active, .button.is-danger.is-active {
+      background-color: #c10a00;
+      border-color: transparent;
+      color: #fff; }
+    .button.is-danger[disabled],
+    fieldset[disabled] .button.is-danger {
+      background-color: #da0b00;
+      border-color: transparent;
+      box-shadow: none; }
+    .button.is-danger.is-inverted {
+      background-color: #fff;
+      color: #da0b00; }
+      .button.is-danger.is-inverted:hover, .button.is-danger.is-inverted.is-hovered {
+        background-color: #f2f2f2; }
+      .button.is-danger.is-inverted[disabled],
+      fieldset[disabled] .button.is-danger.is-inverted {
+        background-color: #fff;
+        border-color: transparent;
+        box-shadow: none;
+        color: #da0b00; }
+    .button.is-danger.is-loading::after {
+      border-color: transparent transparent #fff #fff !important; }
+    .button.is-danger.is-outlined {
+      background-color: transparent;
+      border-color: #da0b00;
+      color: #da0b00; }
+      .button.is-danger.is-outlined:hover, .button.is-danger.is-outlined.is-hovered, .button.is-danger.is-outlined:focus, .button.is-danger.is-outlined.is-focused {
+        background-color: #da0b00;
+        border-color: #da0b00;
+        color: #fff; }
+      .button.is-danger.is-outlined.is-loading::after {
+        border-color: transparent transparent #da0b00 #da0b00 !important; }
+      .button.is-danger.is-outlined.is-loading:hover::after, .button.is-danger.is-outlined.is-loading.is-hovered::after, .button.is-danger.is-outlined.is-loading:focus::after, .button.is-danger.is-outlined.is-loading.is-focused::after {
+        border-color: transparent transparent #fff #fff !important; }
+      .button.is-danger.is-outlined[disabled],
+      fieldset[disabled] .button.is-danger.is-outlined {
+        background-color: transparent;
+        border-color: #da0b00;
+        box-shadow: none;
+        color: #da0b00; }
+    .button.is-danger.is-inverted.is-outlined {
+      background-color: transparent;
+      border-color: #fff;
+      color: #fff; }
+      .button.is-danger.is-inverted.is-outlined:hover, .button.is-danger.is-inverted.is-outlined.is-hovered, .button.is-danger.is-inverted.is-outlined:focus, .button.is-danger.is-inverted.is-outlined.is-focused {
+        background-color: #fff;
+        color: #da0b00; }
+      .button.is-danger.is-inverted.is-outlined.is-loading:hover::after, .button.is-danger.is-inverted.is-outlined.is-loading.is-hovered::after, .button.is-danger.is-inverted.is-outlined.is-loading:focus::after, .button.is-danger.is-inverted.is-outlined.is-loading.is-focused::after {
+        border-color: transparent transparent #da0b00 #da0b00 !important; }
+      .button.is-danger.is-inverted.is-outlined[disabled],
+      fieldset[disabled] .button.is-danger.is-inverted.is-outlined {
+        background-color: transparent;
+        border-color: #fff;
+        box-shadow: none;
+        color: #fff; }
+  .button.is-small, #documenter .docs-sidebar form.docs-search > input.button {
+    border-radius: 2px;
+    font-size: 0.75rem; }
+  .button.is-normal {
+    font-size: 1rem; }
+  .button.is-medium {
+    font-size: 1.25rem; }
+  .button.is-large {
+    font-size: 1.5rem; }
+  .button[disabled],
+  fieldset[disabled] .button {
+    background-color: white;
+    border-color: #dbdbdb;
+    box-shadow: none;
+    opacity: 0.5; }
+  .button.is-fullwidth {
+    display: flex;
+    width: 100%; }
+  .button.is-loading {
+    color: transparent !important;
+    pointer-events: none; }
+    .button.is-loading::after {
+      position: absolute;
+      left: calc(50% - (1em / 2));
+      top: calc(50% - (1em / 2));
+      position: absolute !important; }
+  .button.is-static {
+    background-color: whitesmoke;
+    border-color: #dbdbdb;
+    color: #7a7a7a;
+    box-shadow: none;
+    pointer-events: none; }
+  .button.is-rounded, #documenter .docs-sidebar form.docs-search > input.button {
+    border-radius: 290486px;
+    padding-left: 1em;
+    padding-right: 1em; }
+
+.buttons {
+  align-items: center;
+  display: flex;
+  flex-wrap: wrap;
+  justify-content: flex-start; }
+  .buttons .button {
+    margin-bottom: 0.5rem; }
+    .buttons .button:not(:last-child):not(.is-fullwidth) {
+      margin-right: 0.5rem; }
+  .buttons:last-child {
+    margin-bottom: -0.5rem; }
+  .buttons:not(:last-child) {
+    margin-bottom: 1rem; }
+  .buttons.are-small .button:not(.is-normal):not(.is-medium):not(.is-large) {
+    border-radius: 2px;
+    font-size: 0.75rem; }
+  .buttons.are-medium .button:not(.is-small):not(.is-normal):not(.is-large) {
+    font-size: 1.25rem; }
+  .buttons.are-large .button:not(.is-small):not(.is-normal):not(.is-medium) {
+    font-size: 1.5rem; }
+  .buttons.has-addons .button:not(:first-child) {
+    border-bottom-left-radius: 0;
+    border-top-left-radius: 0; }
+  .buttons.has-addons .button:not(:last-child) {
+    border-bottom-right-radius: 0;
+    border-top-right-radius: 0;
+    margin-right: -1px; }
+  .buttons.has-addons .button:last-child {
+    margin-right: 0; }
+  .buttons.has-addons .button:hover, .buttons.has-addons .button.is-hovered {
+    z-index: 2; }
+  .buttons.has-addons .button:focus, .buttons.has-addons .button.is-focused, .buttons.has-addons .button:active, .buttons.has-addons .button.is-active, .buttons.has-addons .button.is-selected {
+    z-index: 3; }
+    .buttons.has-addons .button:focus:hover, .buttons.has-addons .button.is-focused:hover, .buttons.has-addons .button:active:hover, .buttons.has-addons .button.is-active:hover, .buttons.has-addons .button.is-selected:hover {
+      z-index: 4; }
+  .buttons.has-addons .button.is-expanded {
+    flex-grow: 1;
+    flex-shrink: 1; }
+  .buttons.is-centered {
+    justify-content: center; }
+    .buttons.is-centered:not(.has-addons) .button:not(.is-fullwidth) {
+      margin-left: 0.25rem;
+      margin-right: 0.25rem; }
+  .buttons.is-right {
+    justify-content: flex-end; }
+    .buttons.is-right:not(.has-addons) .button:not(.is-fullwidth) {
+      margin-left: 0.25rem;
+      margin-right: 0.25rem; }
+
+.container {
+  flex-grow: 1;
+  margin: 0 auto;
+  position: relative;
+  width: auto; }
+  @media screen and (min-width: 1056px) {
+    .container {
+      max-width: 992px; }
+      .container.is-fluid {
+        margin-left: 32px;
+        margin-right: 32px;
+        max-width: none; } }
+  @media screen and (max-width: 1215px) {
+    .container.is-widescreen {
+      max-width: 1152px; } }
+  @media screen and (max-width: 1407px) {
+    .container.is-fullhd {
+      max-width: 1344px; } }
+  @media screen and (min-width: 1216px) {
+    .container {
+      max-width: 1152px; } }
+  @media screen and (min-width: 1408px) {
+    .container {
+      max-width: 1344px; } }
+
+.content li + li {
+  margin-top: 0.25em; }
+
+.content p:not(:last-child),
+.content dl:not(:last-child),
+.content ol:not(:last-child),
+.content ul:not(:last-child),
+.content blockquote:not(:last-child),
+.content pre:not(:last-child),
+.content table:not(:last-child) {
+  margin-bottom: 1em; }
+
+.content h1,
+.content h2,
+.content h3,
+.content h4,
+.content h5,
+.content h6 {
+  color: #222222;
+  font-weight: 600;
+  line-height: 1.125; }
+
+.content h1 {
+  font-size: 2em;
+  margin-bottom: 0.5em; }
+  .content h1:not(:first-child) {
+    margin-top: 1em; }
+
+.content h2 {
+  font-size: 1.75em;
+  margin-bottom: 0.5714em; }
+  .content h2:not(:first-child) {
+    margin-top: 1.1428em; }
+
+.content h3 {
+  font-size: 1.5em;
+  margin-bottom: 0.6666em; }
+  .content h3:not(:first-child) {
+    margin-top: 1.3333em; }
+
+.content h4 {
+  font-size: 1.25em;
+  margin-bottom: 0.8em; }
+
+.content h5 {
+  font-size: 1.125em;
+  margin-bottom: 0.8888em; }
+
+.content h6 {
+  font-size: 1em;
+  margin-bottom: 1em; }
+
+.content blockquote {
+  background-color: whitesmoke;
+  border-left: 5px solid #dbdbdb;
+  padding: 1.25em 1.5em; }
+
+.content ol {
+  list-style-position: outside;
+  margin-left: 2em;
+  margin-top: 1em; }
+  .content ol:not([type]) {
+    list-style-type: decimal; }
+    .content ol:not([type]).is-lower-alpha {
+      list-style-type: lower-alpha; }
+    .content ol:not([type]).is-lower-roman {
+      list-style-type: lower-roman; }
+    .content ol:not([type]).is-upper-alpha {
+      list-style-type: upper-alpha; }
+    .content ol:not([type]).is-upper-roman {
+      list-style-type: upper-roman; }
+
+.content ul {
+  list-style: disc outside;
+  margin-left: 2em;
+  margin-top: 1em; }
+  .content ul ul {
+    list-style-type: circle;
+    margin-top: 0.5em; }
+    .content ul ul ul {
+      list-style-type: square; }
+
+.content dd {
+  margin-left: 2em; }
+
+.content figure {
+  margin-left: 2em;
+  margin-right: 2em;
+  text-align: center; }
+  .content figure:not(:first-child) {
+    margin-top: 2em; }
+  .content figure:not(:last-child) {
+    margin-bottom: 2em; }
+  .content figure img {
+    display: inline-block; }
+  .content figure figcaption {
+    font-style: italic; }
+
+.content pre {
+  -webkit-overflow-scrolling: touch;
+  overflow-x: auto;
+  padding: 0.7rem 0.5rem;
+  white-space: pre;
+  word-wrap: normal; }
+
+.content sup,
+.content sub {
+  font-size: 75%; }
+
+.content table {
+  width: 100%; }
+  .content table td,
+  .content table th {
+    border: 1px solid #dbdbdb;
+    border-width: 0 0 1px;
+    padding: 0.5em 0.75em;
+    vertical-align: top; }
+  .content table th {
+    color: #222222; }
+    .content table th:not([align]) {
+      text-align: left; }
+  .content table thead td,
+  .content table thead th {
+    border-width: 0 0 2px;
+    color: #222222; }
+  .content table tfoot td,
+  .content table tfoot th {
+    border-width: 2px 0 0;
+    color: #222222; }
+  .content table tbody tr:last-child td,
+  .content table tbody tr:last-child th {
+    border-bottom-width: 0; }
+
+.content .tabs li + li {
+  margin-top: 0; }
+
+.content.is-small, #documenter .docs-sidebar form.docs-search > input.content {
+  font-size: 0.75rem; }
+
+.content.is-medium {
+  font-size: 1.25rem; }
+
+.content.is-large {
+  font-size: 1.5rem; }
+
+.icon {
+  align-items: center;
+  display: inline-flex;
+  justify-content: center;
+  height: 1.5rem;
+  width: 1.5rem; }
+  .icon.is-small, #documenter .docs-sidebar form.docs-search > input.icon {
+    height: 1rem;
+    width: 1rem; }
+  .icon.is-medium {
+    height: 2rem;
+    width: 2rem; }
+  .icon.is-large {
+    height: 3rem;
+    width: 3rem; }
+
+.image, #documenter .docs-sidebar .docs-logo > img {
+  display: block;
+  position: relative; }
+  .image img, #documenter .docs-sidebar .docs-logo > img img {
+    display: block;
+    height: auto;
+    width: 100%; }
+    .image img.is-rounded, #documenter .docs-sidebar .docs-logo > img img.is-rounded {
+      border-radius: 290486px; }
+  .image.is-square img, #documenter .docs-sidebar .docs-logo > img.is-square img,
+  .image.is-square .has-ratio,
+  #documenter .docs-sidebar .docs-logo > img.is-square .has-ratio, .image.is-1by1 img, #documenter .docs-sidebar .docs-logo > img.is-1by1 img,
+  .image.is-1by1 .has-ratio,
+  #documenter .docs-sidebar .docs-logo > img.is-1by1 .has-ratio, .image.is-5by4 img, #documenter .docs-sidebar .docs-logo > img.is-5by4 img,
+  .image.is-5by4 .has-ratio,
+  #documenter .docs-sidebar .docs-logo > img.is-5by4 .has-ratio, .image.is-4by3 img, #documenter .docs-sidebar .docs-logo > img.is-4by3 img,
+  .image.is-4by3 .has-ratio,
+  #documenter .docs-sidebar .docs-logo > img.is-4by3 .has-ratio, .image.is-3by2 img, #documenter .docs-sidebar .docs-logo > img.is-3by2 img,
+  .image.is-3by2 .has-ratio,
+  #documenter .docs-sidebar .docs-logo > img.is-3by2 .has-ratio, .image.is-5by3 img, #documenter .docs-sidebar .docs-logo > img.is-5by3 img,
+  .image.is-5by3 .has-ratio,
+  #documenter .docs-sidebar .docs-logo > img.is-5by3 .has-ratio, .image.is-16by9 img, #documenter .docs-sidebar .docs-logo > img.is-16by9 img,
+  .image.is-16by9 .has-ratio,
+  #documenter .docs-sidebar .docs-logo > img.is-16by9 .has-ratio, .image.is-2by1 img, #documenter .docs-sidebar .docs-logo > img.is-2by1 img,
+  .image.is-2by1 .has-ratio,
+  #documenter .docs-sidebar .docs-logo > img.is-2by1 .has-ratio, .image.is-3by1 img, #documenter .docs-sidebar .docs-logo > img.is-3by1 img,
+  .image.is-3by1 .has-ratio,
+  #documenter .docs-sidebar .docs-logo > img.is-3by1 .has-ratio, .image.is-4by5 img, #documenter .docs-sidebar .docs-logo > img.is-4by5 img,
+  .image.is-4by5 .has-ratio,
+  #documenter .docs-sidebar .docs-logo > img.is-4by5 .has-ratio, .image.is-3by4 img, #documenter .docs-sidebar .docs-logo > img.is-3by4 img,
+  .image.is-3by4 .has-ratio,
+  #documenter .docs-sidebar .docs-logo > img.is-3by4 .has-ratio, .image.is-2by3 img, #documenter .docs-sidebar .docs-logo > img.is-2by3 img,
+  .image.is-2by3 .has-ratio,
+  #documenter .docs-sidebar .docs-logo > img.is-2by3 .has-ratio, .image.is-3by5 img, #documenter .docs-sidebar .docs-logo > img.is-3by5 img,
+  .image.is-3by5 .has-ratio,
+  #documenter .docs-sidebar .docs-logo > img.is-3by5 .has-ratio, .image.is-9by16 img, #documenter .docs-sidebar .docs-logo > img.is-9by16 img,
+  .image.is-9by16 .has-ratio,
+  #documenter .docs-sidebar .docs-logo > img.is-9by16 .has-ratio, .image.is-1by2 img, #documenter .docs-sidebar .docs-logo > img.is-1by2 img,
+  .image.is-1by2 .has-ratio,
+  #documenter .docs-sidebar .docs-logo > img.is-1by2 .has-ratio, .image.is-1by3 img, #documenter .docs-sidebar .docs-logo > img.is-1by3 img,
+  .image.is-1by3 .has-ratio,
+  #documenter .docs-sidebar .docs-logo > img.is-1by3 .has-ratio {
+    height: 100%;
+    width: 100%; }
+  .image.is-square, #documenter .docs-sidebar .docs-logo > img.is-square, .image.is-1by1, #documenter .docs-sidebar .docs-logo > img.is-1by1 {
+    padding-top: 100%; }
+  .image.is-5by4, #documenter .docs-sidebar .docs-logo > img.is-5by4 {
+    padding-top: 80%; }
+  .image.is-4by3, #documenter .docs-sidebar .docs-logo > img.is-4by3 {
+    padding-top: 75%; }
+  .image.is-3by2, #documenter .docs-sidebar .docs-logo > img.is-3by2 {
+    padding-top: 66.6666%; }
+  .image.is-5by3, #documenter .docs-sidebar .docs-logo > img.is-5by3 {
+    padding-top: 60%; }
+  .image.is-16by9, #documenter .docs-sidebar .docs-logo > img.is-16by9 {
+    padding-top: 56.25%; }
+  .image.is-2by1, #documenter .docs-sidebar .docs-logo > img.is-2by1 {
+    padding-top: 50%; }
+  .image.is-3by1, #documenter .docs-sidebar .docs-logo > img.is-3by1 {
+    padding-top: 33.3333%; }
+  .image.is-4by5, #documenter .docs-sidebar .docs-logo > img.is-4by5 {
+    padding-top: 125%; }
+  .image.is-3by4, #documenter .docs-sidebar .docs-logo > img.is-3by4 {
+    padding-top: 133.3333%; }
+  .image.is-2by3, #documenter .docs-sidebar .docs-logo > img.is-2by3 {
+    padding-top: 150%; }
+  .image.is-3by5, #documenter .docs-sidebar .docs-logo > img.is-3by5 {
+    padding-top: 166.6666%; }
+  .image.is-9by16, #documenter .docs-sidebar .docs-logo > img.is-9by16 {
+    padding-top: 177.7777%; }
+  .image.is-1by2, #documenter .docs-sidebar .docs-logo > img.is-1by2 {
+    padding-top: 200%; }
+  .image.is-1by3, #documenter .docs-sidebar .docs-logo > img.is-1by3 {
+    padding-top: 300%; }
+  .image.is-16x16, #documenter .docs-sidebar .docs-logo > img.is-16x16 {
+    height: 16px;
+    width: 16px; }
+  .image.is-24x24, #documenter .docs-sidebar .docs-logo > img.is-24x24 {
+    height: 24px;
+    width: 24px; }
+  .image.is-32x32, #documenter .docs-sidebar .docs-logo > img.is-32x32 {
+    height: 32px;
+    width: 32px; }
+  .image.is-48x48, #documenter .docs-sidebar .docs-logo > img.is-48x48 {
+    height: 48px;
+    width: 48px; }
+  .image.is-64x64, #documenter .docs-sidebar .docs-logo > img.is-64x64 {
+    height: 64px;
+    width: 64px; }
+  .image.is-96x96, #documenter .docs-sidebar .docs-logo > img.is-96x96 {
+    height: 96px;
+    width: 96px; }
+  .image.is-128x128, #documenter .docs-sidebar .docs-logo > img.is-128x128 {
+    height: 128px;
+    width: 128px; }
+
+.notification {
+  background-color: whitesmoke;
+  border-radius: 4px;
+  padding: 1.25rem 2.5rem 1.25rem 1.5rem;
+  position: relative; }
+  .notification a:not(.button):not(.dropdown-item) {
+    color: currentColor;
+    text-decoration: underline; }
+  .notification strong {
+    color: currentColor; }
+  .notification code,
+  .notification pre {
+    background: white; }
+  .notification pre code {
+    background: transparent; }
+  .notification > .delete {
+    position: absolute;
+    right: 0.5rem;
+    top: 0.5rem; }
+  .notification .title,
+  .notification .subtitle,
+  .notification .content {
+    color: currentColor; }
+  .notification.is-white {
+    background-color: white;
+    color: #0a0a0a; }
+  .notification.is-black {
+    background-color: #0a0a0a;
+    color: white; }
+  .notification.is-light {
+    background-color: whitesmoke;
+    color: #363636; }
+  .notification.is-dark, .content kbd.notification {
+    background-color: #363636;
+    color: whitesmoke; }
+  .notification.is-primary, .docstring > section > a.notification.docs-sourcelink {
+    background-color: #4eb5de;
+    color: #fff; }
+  .notification.is-link {
+    background-color: #2e63b8;
+    color: #fff; }
+  .notification.is-info {
+    background-color: #209cee;
+    color: #fff; }
+  .notification.is-success {
+    background-color: #22c35b;
+    color: #fff; }
+  .notification.is-warning {
+    background-color: #ffdd57;
+    color: rgba(0, 0, 0, 0.7); }
+  .notification.is-danger {
+    background-color: #da0b00;
+    color: #fff; }
+
+.progress {
+  -moz-appearance: none;
+  -webkit-appearance: none;
+  border: none;
+  border-radius: 290486px;
+  display: block;
+  height: 1rem;
+  overflow: hidden;
+  padding: 0;
+  width: 100%; }
+  .progress::-webkit-progress-bar {
+    background-color: #dbdbdb; }
+  .progress::-webkit-progress-value {
+    background-color: #222222; }
+  .progress::-moz-progress-bar {
+    background-color: #222222; }
+  .progress::-ms-fill {
+    background-color: #222222;
+    border: none; }
+  .progress.is-white::-webkit-progress-value {
+    background-color: white; }
+  .progress.is-white::-moz-progress-bar {
+    background-color: white; }
+  .progress.is-white::-ms-fill {
+    background-color: white; }
+  .progress.is-white:indeterminate {
+    background-image: linear-gradient(to right, white 30%, #dbdbdb 30%); }
+  .progress.is-black::-webkit-progress-value {
+    background-color: #0a0a0a; }
+  .progress.is-black::-moz-progress-bar {
+    background-color: #0a0a0a; }
+  .progress.is-black::-ms-fill {
+    background-color: #0a0a0a; }
+  .progress.is-black:indeterminate {
+    background-image: linear-gradient(to right, #0a0a0a 30%, #dbdbdb 30%); }
+  .progress.is-light::-webkit-progress-value {
+    background-color: whitesmoke; }
+  .progress.is-light::-moz-progress-bar {
+    background-color: whitesmoke; }
+  .progress.is-light::-ms-fill {
+    background-color: whitesmoke; }
+  .progress.is-light:indeterminate {
+    background-image: linear-gradient(to right, whitesmoke 30%, #dbdbdb 30%); }
+  .progress.is-dark::-webkit-progress-value, .content kbd.progress::-webkit-progress-value {
+    background-color: #363636; }
+  .progress.is-dark::-moz-progress-bar, .content kbd.progress::-moz-progress-bar {
+    background-color: #363636; }
+  .progress.is-dark::-ms-fill, .content kbd.progress::-ms-fill {
+    background-color: #363636; }
+  .progress.is-dark:indeterminate, .content kbd.progress:indeterminate {
+    background-image: linear-gradient(to right, #363636 30%, #dbdbdb 30%); }
+  .progress.is-primary::-webkit-progress-value, .docstring > section > a.progress.docs-sourcelink::-webkit-progress-value {
+    background-color: #4eb5de; }
+  .progress.is-primary::-moz-progress-bar, .docstring > section > a.progress.docs-sourcelink::-moz-progress-bar {
+    background-color: #4eb5de; }
+  .progress.is-primary::-ms-fill, .docstring > section > a.progress.docs-sourcelink::-ms-fill {
+    background-color: #4eb5de; }
+  .progress.is-primary:indeterminate, .docstring > section > a.progress.docs-sourcelink:indeterminate {
+    background-image: linear-gradient(to right, #4eb5de 30%, #dbdbdb 30%); }
+  .progress.is-link::-webkit-progress-value {
+    background-color: #2e63b8; }
+  .progress.is-link::-moz-progress-bar {
+    background-color: #2e63b8; }
+  .progress.is-link::-ms-fill {
+    background-color: #2e63b8; }
+  .progress.is-link:indeterminate {
+    background-image: linear-gradient(to right, #2e63b8 30%, #dbdbdb 30%); }
+  .progress.is-info::-webkit-progress-value {
+    background-color: #209cee; }
+  .progress.is-info::-moz-progress-bar {
+    background-color: #209cee; }
+  .progress.is-info::-ms-fill {
+    background-color: #209cee; }
+  .progress.is-info:indeterminate {
+    background-image: linear-gradient(to right, #209cee 30%, #dbdbdb 30%); }
+  .progress.is-success::-webkit-progress-value {
+    background-color: #22c35b; }
+  .progress.is-success::-moz-progress-bar {
+    background-color: #22c35b; }
+  .progress.is-success::-ms-fill {
+    background-color: #22c35b; }
+  .progress.is-success:indeterminate {
+    background-image: linear-gradient(to right, #22c35b 30%, #dbdbdb 30%); }
+  .progress.is-warning::-webkit-progress-value {
+    background-color: #ffdd57; }
+  .progress.is-warning::-moz-progress-bar {
+    background-color: #ffdd57; }
+  .progress.is-warning::-ms-fill {
+    background-color: #ffdd57; }
+  .progress.is-warning:indeterminate {
+    background-image: linear-gradient(to right, #ffdd57 30%, #dbdbdb 30%); }
+  .progress.is-danger::-webkit-progress-value {
+    background-color: #da0b00; }
+  .progress.is-danger::-moz-progress-bar {
+    background-color: #da0b00; }
+  .progress.is-danger::-ms-fill {
+    background-color: #da0b00; }
+  .progress.is-danger:indeterminate {
+    background-image: linear-gradient(to right, #da0b00 30%, #dbdbdb 30%); }
+  .progress:indeterminate {
+    animation-duration: 1.5s;
+    animation-iteration-count: infinite;
+    animation-name: moveIndeterminate;
+    animation-timing-function: linear;
+    background-color: #dbdbdb;
+    background-image: linear-gradient(to right, #222222 30%, #dbdbdb 30%);
+    background-position: top left;
+    background-repeat: no-repeat;
+    background-size: 150% 150%; }
+    .progress:indeterminate::-webkit-progress-bar {
+      background-color: transparent; }
+    .progress:indeterminate::-moz-progress-bar {
+      background-color: transparent; }
+  .progress.is-small, #documenter .docs-sidebar form.docs-search > input.progress {
+    height: 0.75rem; }
+  .progress.is-medium {
+    height: 1.25rem; }
+  .progress.is-large {
+    height: 1.5rem; }
+
+@keyframes moveIndeterminate {
+  from {
+    background-position: 200% 0; }
+  to {
+    background-position: -200% 0; } }
+
+.table {
+  background-color: white;
+  color: #363636; }
+  .table td,
+  .table th {
+    border: 1px solid #dbdbdb;
+    border-width: 0 0 1px;
+    padding: 0.5em 0.75em;
+    vertical-align: top; }
+    .table td.is-white,
+    .table th.is-white {
+      background-color: white;
+      border-color: white;
+      color: #0a0a0a; }
+    .table td.is-black,
+    .table th.is-black {
+      background-color: #0a0a0a;
+      border-color: #0a0a0a;
+      color: white; }
+    .table td.is-light,
+    .table th.is-light {
+      background-color: whitesmoke;
+      border-color: whitesmoke;
+      color: #363636; }
+    .table td.is-dark,
+    .table th.is-dark {
+      background-color: #363636;
+      border-color: #363636;
+      color: whitesmoke; }
+    .table td.is-primary,
+    .table th.is-primary {
+      background-color: #4eb5de;
+      border-color: #4eb5de;
+      color: #fff; }
+    .table td.is-link,
+    .table th.is-link {
+      background-color: #2e63b8;
+      border-color: #2e63b8;
+      color: #fff; }
+    .table td.is-info,
+    .table th.is-info {
+      background-color: #209cee;
+      border-color: #209cee;
+      color: #fff; }
+    .table td.is-success,
+    .table th.is-success {
+      background-color: #22c35b;
+      border-color: #22c35b;
+      color: #fff; }
+    .table td.is-warning,
+    .table th.is-warning {
+      background-color: #ffdd57;
+      border-color: #ffdd57;
+      color: rgba(0, 0, 0, 0.7); }
+    .table td.is-danger,
+    .table th.is-danger {
+      background-color: #da0b00;
+      border-color: #da0b00;
+      color: #fff; }
+    .table td.is-narrow,
+    .table th.is-narrow {
+      white-space: nowrap;
+      width: 1%; }
+    .table td.is-selected,
+    .table th.is-selected {
+      background-color: #4eb5de;
+      color: #fff; }
+      .table td.is-selected a,
+      .table td.is-selected strong,
+      .table th.is-selected a,
+      .table th.is-selected strong {
+        color: currentColor; }
+  .table th {
+    color: #222222; }
+    .table th:not([align]) {
+      text-align: left; }
+  .table tr.is-selected {
+    background-color: #4eb5de;
+    color: #fff; }
+    .table tr.is-selected a,
+    .table tr.is-selected strong {
+      color: currentColor; }
+    .table tr.is-selected td,
+    .table tr.is-selected th {
+      border-color: #fff;
+      color: currentColor; }
+  .table thead {
+    background-color: transparent; }
+    .table thead td,
+    .table thead th {
+      border-width: 0 0 2px;
+      color: #222222; }
+  .table tfoot {
+    background-color: transparent; }
+    .table tfoot td,
+    .table tfoot th {
+      border-width: 2px 0 0;
+      color: #222222; }
+  .table tbody {
+    background-color: transparent; }
+    .table tbody tr:last-child td,
+    .table tbody tr:last-child th {
+      border-bottom-width: 0; }
+  .table.is-bordered td,
+  .table.is-bordered th {
+    border-width: 1px; }
+  .table.is-bordered tr:last-child td,
+  .table.is-bordered tr:last-child th {
+    border-bottom-width: 1px; }
+  .table.is-fullwidth {
+    width: 100%; }
+  .table.is-hoverable tbody tr:not(.is-selected):hover {
+    background-color: #fafafa; }
+  .table.is-hoverable.is-striped tbody tr:not(.is-selected):hover {
+    background-color: #fafafa; }
+    .table.is-hoverable.is-striped tbody tr:not(.is-selected):hover:nth-child(even) {
+      background-color: whitesmoke; }
+  .table.is-narrow td,
+  .table.is-narrow th {
+    padding: 0.25em 0.5em; }
+  .table.is-striped tbody tr:not(.is-selected):nth-child(even) {
+    background-color: #fafafa; }
+
+.table-container {
+  -webkit-overflow-scrolling: touch;
+  overflow: auto;
+  overflow-y: hidden;
+  max-width: 100%; }
+
+.tags {
+  align-items: center;
+  display: flex;
+  flex-wrap: wrap;
+  justify-content: flex-start; }
+  .tags .tag, .tags .docstring > section > a.docs-sourcelink, .tags .content kbd, .content .tags kbd {
+    margin-bottom: 0.5rem; }
+    .tags .tag:not(:last-child), .tags .docstring > section > a.docs-sourcelink:not(:last-child), .tags .content kbd:not(:last-child), .content .tags kbd:not(:last-child) {
+      margin-right: 0.5rem; }
+  .tags:last-child {
+    margin-bottom: -0.5rem; }
+  .tags:not(:last-child) {
+    margin-bottom: 1rem; }
+  .tags.are-medium .tag:not(.is-normal):not(.is-large), .tags.are-medium .docstring > section > a.docs-sourcelink:not(.is-normal):not(.is-large), .tags.are-medium .content kbd:not(.is-normal):not(.is-large), .content .tags.are-medium kbd:not(.is-normal):not(.is-large) {
+    font-size: 1rem; }
+  .tags.are-large .tag:not(.is-normal):not(.is-medium), .tags.are-large .docstring > section > a.docs-sourcelink:not(.is-normal):not(.is-medium), .tags.are-large .content kbd:not(.is-normal):not(.is-medium), .content .tags.are-large kbd:not(.is-normal):not(.is-medium) {
+    font-size: 1.25rem; }
+  .tags.is-centered {
+    justify-content: center; }
+    .tags.is-centered .tag, .tags.is-centered .docstring > section > a.docs-sourcelink, .tags.is-centered .content kbd, .content .tags.is-centered kbd {
+      margin-right: 0.25rem;
+      margin-left: 0.25rem; }
+  .tags.is-right {
+    justify-content: flex-end; }
+    .tags.is-right .tag:not(:first-child), .tags.is-right .docstring > section > a.docs-sourcelink:not(:first-child), .tags.is-right .content kbd:not(:first-child), .content .tags.is-right kbd:not(:first-child) {
+      margin-left: 0.5rem; }
+    .tags.is-right .tag:not(:last-child), .tags.is-right .docstring > section > a.docs-sourcelink:not(:last-child), .tags.is-right .content kbd:not(:last-child), .content .tags.is-right kbd:not(:last-child) {
+      margin-right: 0; }
+  .tags.has-addons .tag, .tags.has-addons .docstring > section > a.docs-sourcelink, .tags.has-addons .content kbd, .content .tags.has-addons kbd {
+    margin-right: 0; }
+    .tags.has-addons .tag:not(:first-child), .tags.has-addons .docstring > section > a.docs-sourcelink:not(:first-child), .tags.has-addons .content kbd:not(:first-child), .content .tags.has-addons kbd:not(:first-child) {
+      margin-left: 0;
+      border-bottom-left-radius: 0;
+      border-top-left-radius: 0; }
+    .tags.has-addons .tag:not(:last-child), .tags.has-addons .docstring > section > a.docs-sourcelink:not(:last-child), .tags.has-addons .content kbd:not(:last-child), .content .tags.has-addons kbd:not(:last-child) {
+      border-bottom-right-radius: 0;
+      border-top-right-radius: 0; }
+
+.tag:not(body), .docstring > section > a.docs-sourcelink:not(body), .content kbd:not(body) {
+  align-items: center;
+  background-color: whitesmoke;
+  border-radius: 4px;
+  color: #222222;
+  display: inline-flex;
+  font-size: 0.75rem;
+  height: 2em;
+  justify-content: center;
+  line-height: 1.5;
+  padding-left: 0.75em;
+  padding-right: 0.75em;
+  white-space: nowrap; }
+  .tag:not(body) .delete, .docstring > section > a.docs-sourcelink:not(body) .delete, .content kbd:not(body) .delete {
+    margin-left: 0.25rem;
+    margin-right: -0.375rem; }
+  .tag:not(body).is-white, .docstring > section > a.docs-sourcelink:not(body).is-white, .content kbd:not(body).is-white {
+    background-color: white;
+    color: #0a0a0a; }
+  .tag:not(body).is-black, .docstring > section > a.docs-sourcelink:not(body).is-black, .content kbd:not(body).is-black {
+    background-color: #0a0a0a;
+    color: white; }
+  .tag:not(body).is-light, .docstring > section > a.docs-sourcelink:not(body).is-light, .content kbd:not(body).is-light {
+    background-color: whitesmoke;
+    color: #363636; }
+  .tag:not(body).is-dark, .docstring > section > a.docs-sourcelink:not(body).is-dark, .content kbd:not(body) {
+    background-color: #363636;
+    color: whitesmoke; }
+  .tag:not(body).is-primary, .docstring > section > a.docs-sourcelink:not(body), .content kbd:not(body).is-primary {
+    background-color: #4eb5de;
+    color: #fff; }
+  .tag:not(body).is-link, .docstring > section > a.docs-sourcelink:not(body).is-link, .content kbd:not(body).is-link {
+    background-color: #2e63b8;
+    color: #fff; }
+  .tag:not(body).is-info, .docstring > section > a.docs-sourcelink:not(body).is-info, .content kbd:not(body).is-info {
+    background-color: #209cee;
+    color: #fff; }
+  .tag:not(body).is-success, .docstring > section > a.docs-sourcelink:not(body).is-success, .content kbd:not(body).is-success {
+    background-color: #22c35b;
+    color: #fff; }
+  .tag:not(body).is-warning, .docstring > section > a.docs-sourcelink:not(body).is-warning, .content kbd:not(body).is-warning {
+    background-color: #ffdd57;
+    color: rgba(0, 0, 0, 0.7); }
+  .tag:not(body).is-danger, .docstring > section > a.docs-sourcelink:not(body).is-danger, .content kbd:not(body).is-danger {
+    background-color: #da0b00;
+    color: #fff; }
+  .tag:not(body).is-normal, .docstring > section > a.docs-sourcelink:not(body).is-normal, .content kbd:not(body).is-normal {
+    font-size: 0.75rem; }
+  .tag:not(body).is-medium, .docstring > section > a.docs-sourcelink:not(body).is-medium, .content kbd:not(body).is-medium {
+    font-size: 1rem; }
+  .tag:not(body).is-large, .docstring > section > a.docs-sourcelink:not(body).is-large, .content kbd:not(body).is-large {
+    font-size: 1.25rem; }
+  .tag:not(body) .icon:first-child:not(:last-child), .docstring > section > a.docs-sourcelink:not(body) .icon:first-child:not(:last-child), .content kbd:not(body) .icon:first-child:not(:last-child) {
+    margin-left: -0.375em;
+    margin-right: 0.1875em; }
+  .tag:not(body) .icon:last-child:not(:first-child), .docstring > section > a.docs-sourcelink:not(body) .icon:last-child:not(:first-child), .content kbd:not(body) .icon:last-child:not(:first-child) {
+    margin-left: 0.1875em;
+    margin-right: -0.375em; }
+  .tag:not(body) .icon:first-child:last-child, .docstring > section > a.docs-sourcelink:not(body) .icon:first-child:last-child, .content kbd:not(body) .icon:first-child:last-child {
+    margin-left: -0.375em;
+    margin-right: -0.375em; }
+  .tag:not(body).is-delete, .docstring > section > a.docs-sourcelink:not(body).is-delete, .content kbd:not(body).is-delete {
+    margin-left: 1px;
+    padding: 0;
+    position: relative;
+    width: 2em; }
+    .tag:not(body).is-delete::before, .docstring > section > a.docs-sourcelink:not(body).is-delete::before, .content kbd:not(body).is-delete::before, .tag:not(body).is-delete::after, .docstring > section > a.docs-sourcelink:not(body).is-delete::after, .content kbd:not(body).is-delete::after {
+      background-color: currentColor;
+      content: "";
+      display: block;
+      left: 50%;
+      position: absolute;
+      top: 50%;
+      transform: translateX(-50%) translateY(-50%) rotate(45deg);
+      transform-origin: center center; }
+    .tag:not(body).is-delete::before, .docstring > section > a.docs-sourcelink:not(body).is-delete::before, .content kbd:not(body).is-delete::before {
+      height: 1px;
+      width: 50%; }
+    .tag:not(body).is-delete::after, .docstring > section > a.docs-sourcelink:not(body).is-delete::after, .content kbd:not(body).is-delete::after {
+      height: 50%;
+      width: 1px; }
+    .tag:not(body).is-delete:hover, .docstring > section > a.docs-sourcelink:not(body).is-delete:hover, .content kbd:not(body).is-delete:hover, .tag:not(body).is-delete:focus, .docstring > section > a.docs-sourcelink:not(body).is-delete:focus, .content kbd:not(body).is-delete:focus {
+      background-color: #e8e8e8; }
+    .tag:not(body).is-delete:active, .docstring > section > a.docs-sourcelink:not(body).is-delete:active, .content kbd:not(body).is-delete:active {
+      background-color: #dbdbdb; }
+  .tag:not(body).is-rounded, .docstring > section > a.docs-sourcelink:not(body).is-rounded, .content kbd:not(body).is-rounded, #documenter .docs-sidebar form.docs-search > input.tag:not(body) {
+    border-radius: 290486px; }
+
+a.tag:hover, .docstring > section > a.docs-sourcelink:hover {
+  text-decoration: underline; }
+
+.title,
+.subtitle {
+  word-break: break-word; }
+  .title em,
+  .title span,
+  .subtitle em,
+  .subtitle span {
+    font-weight: inherit; }
+  .title sub,
+  .subtitle sub {
+    font-size: 0.75em; }
+  .title sup,
+  .subtitle sup {
+    font-size: 0.75em; }
+  .title .tag, .title .docstring > section > a.docs-sourcelink, .title .content kbd, .content .title kbd,
+  .subtitle .tag,
+  .subtitle .docstring > section > a.docs-sourcelink,
+  .subtitle .content kbd,
+  .content .subtitle kbd {
+    vertical-align: middle; }
+
+.title {
+  color: #363636;
+  font-size: 2rem;
+  font-weight: 600;
+  line-height: 1.125; }
+  .title strong {
+    color: inherit;
+    font-weight: inherit; }
+  .title + .highlight {
+    margin-top: -0.75rem; }
+  .title:not(.is-spaced) + .subtitle {
+    margin-top: -1.25rem; }
+  .title.is-1 {
+    font-size: 3rem; }
+  .title.is-2 {
+    font-size: 2.5rem; }
+  .title.is-3 {
+    font-size: 2rem; }
+  .title.is-4 {
+    font-size: 1.5rem; }
+  .title.is-5 {
+    font-size: 1.25rem; }
+  .title.is-6 {
+    font-size: 1rem; }
+  .title.is-7 {
+    font-size: 0.75rem; }
+
+.subtitle {
+  color: #4a4a4a;
+  font-size: 1.25rem;
+  font-weight: 400;
+  line-height: 1.25; }
+  .subtitle strong {
+    color: #363636;
+    font-weight: 600; }
+  .subtitle:not(.is-spaced) + .title {
+    margin-top: -1.25rem; }
+  .subtitle.is-1 {
+    font-size: 3rem; }
+  .subtitle.is-2 {
+    font-size: 2.5rem; }
+  .subtitle.is-3 {
+    font-size: 2rem; }
+  .subtitle.is-4 {
+    font-size: 1.5rem; }
+  .subtitle.is-5 {
+    font-size: 1.25rem; }
+  .subtitle.is-6 {
+    font-size: 1rem; }
+  .subtitle.is-7 {
+    font-size: 0.75rem; }
+
+.heading {
+  display: block;
+  font-size: 11px;
+  letter-spacing: 1px;
+  margin-bottom: 5px;
+  text-transform: uppercase; }
+
+.highlight {
+  font-weight: 400;
+  max-width: 100%;
+  overflow: hidden;
+  padding: 0; }
+  .highlight pre {
+    overflow: auto;
+    max-width: 100%; }
+
+.number {
+  align-items: center;
+  background-color: whitesmoke;
+  border-radius: 290486px;
+  display: inline-flex;
+  font-size: 1.25rem;
+  height: 2em;
+  justify-content: center;
+  margin-right: 1.5rem;
+  min-width: 2.5em;
+  padding: 0.25rem 0.5rem;
+  text-align: center;
+  vertical-align: top; }
+
+.input, #documenter .docs-sidebar form.docs-search > input, .textarea, .select select {
+  background-color: white;
+  border-color: #dbdbdb;
+  border-radius: 4px;
+  color: #363636; }
+  .input::-moz-placeholder, #documenter .docs-sidebar form.docs-search > input::-moz-placeholder, .textarea::-moz-placeholder, .select select::-moz-placeholder {
+    color: rgba(54, 54, 54, 0.3); }
+  .input::-webkit-input-placeholder, #documenter .docs-sidebar form.docs-search > input::-webkit-input-placeholder, .textarea::-webkit-input-placeholder, .select select::-webkit-input-placeholder {
+    color: rgba(54, 54, 54, 0.3); }
+  .input:-moz-placeholder, #documenter .docs-sidebar form.docs-search > input:-moz-placeholder, .textarea:-moz-placeholder, .select select:-moz-placeholder {
+    color: rgba(54, 54, 54, 0.3); }
+  .input:-ms-input-placeholder, #documenter .docs-sidebar form.docs-search > input:-ms-input-placeholder, .textarea:-ms-input-placeholder, .select select:-ms-input-placeholder {
+    color: rgba(54, 54, 54, 0.3); }
+  .input:hover, #documenter .docs-sidebar form.docs-search > input:hover, .textarea:hover, .select select:hover, .is-hovered.input, #documenter .docs-sidebar form.docs-search > input.is-hovered, .is-hovered.textarea, .select select.is-hovered {
+    border-color: #b5b5b5; }
+  .input:focus, #documenter .docs-sidebar form.docs-search > input:focus, .textarea:focus, .select select:focus, .is-focused.input, #documenter .docs-sidebar form.docs-search > input.is-focused, .is-focused.textarea, .select select.is-focused, .input:active, #documenter .docs-sidebar form.docs-search > input:active, .textarea:active, .select select:active, .is-active.input, #documenter .docs-sidebar form.docs-search > input.is-active, .is-active.textarea, .select select.is-active {
+    border-color: #2e63b8;
+    box-shadow: 0 0 0 0.125em rgba(46, 99, 184, 0.25); }
+  .input[disabled], #documenter .docs-sidebar form.docs-search > input[disabled], .textarea[disabled], .select select[disabled],
+  fieldset[disabled] .input,
+  fieldset[disabled] #documenter .docs-sidebar form.docs-search > input,
+  #documenter .docs-sidebar fieldset[disabled] form.docs-search > input,
+  fieldset[disabled] .textarea,
+  fieldset[disabled] .select select,
+  .select fieldset[disabled] select {
+    background-color: whitesmoke;
+    border-color: whitesmoke;
+    box-shadow: none;
+    color: #7a7a7a; }
+    .input[disabled]::-moz-placeholder, #documenter .docs-sidebar form.docs-search > input[disabled]::-moz-placeholder, .textarea[disabled]::-moz-placeholder, .select select[disabled]::-moz-placeholder,
+    fieldset[disabled] .input::-moz-placeholder,
+    fieldset[disabled] #documenter .docs-sidebar form.docs-search > input::-moz-placeholder,
+    #documenter .docs-sidebar fieldset[disabled] form.docs-search > input::-moz-placeholder,
+    fieldset[disabled] .textarea::-moz-placeholder,
+    fieldset[disabled] .select select::-moz-placeholder,
+    .select fieldset[disabled] select::-moz-placeholder {
+      color: rgba(122, 122, 122, 0.3); }
+    .input[disabled]::-webkit-input-placeholder, #documenter .docs-sidebar form.docs-search > input[disabled]::-webkit-input-placeholder, .textarea[disabled]::-webkit-input-placeholder, .select select[disabled]::-webkit-input-placeholder,
+    fieldset[disabled] .input::-webkit-input-placeholder,
+    fieldset[disabled] #documenter .docs-sidebar form.docs-search > input::-webkit-input-placeholder,
+    #documenter .docs-sidebar fieldset[disabled] form.docs-search > input::-webkit-input-placeholder,
+    fieldset[disabled] .textarea::-webkit-input-placeholder,
+    fieldset[disabled] .select select::-webkit-input-placeholder,
+    .select fieldset[disabled] select::-webkit-input-placeholder {
+      color: rgba(122, 122, 122, 0.3); }
+    .input[disabled]:-moz-placeholder, #documenter .docs-sidebar form.docs-search > input[disabled]:-moz-placeholder, .textarea[disabled]:-moz-placeholder, .select select[disabled]:-moz-placeholder,
+    fieldset[disabled] .input:-moz-placeholder,
+    fieldset[disabled] #documenter .docs-sidebar form.docs-search > input:-moz-placeholder,
+    #documenter .docs-sidebar fieldset[disabled] form.docs-search > input:-moz-placeholder,
+    fieldset[disabled] .textarea:-moz-placeholder,
+    fieldset[disabled] .select select:-moz-placeholder,
+    .select fieldset[disabled] select:-moz-placeholder {
+      color: rgba(122, 122, 122, 0.3); }
+    .input[disabled]:-ms-input-placeholder, #documenter .docs-sidebar form.docs-search > input[disabled]:-ms-input-placeholder, .textarea[disabled]:-ms-input-placeholder, .select select[disabled]:-ms-input-placeholder,
+    fieldset[disabled] .input:-ms-input-placeholder,
+    fieldset[disabled] #documenter .docs-sidebar form.docs-search > input:-ms-input-placeholder,
+    #documenter .docs-sidebar fieldset[disabled] form.docs-search > input:-ms-input-placeholder,
+    fieldset[disabled] .textarea:-ms-input-placeholder,
+    fieldset[disabled] .select select:-ms-input-placeholder,
+    .select fieldset[disabled] select:-ms-input-placeholder {
+      color: rgba(122, 122, 122, 0.3); }
+
+.input, #documenter .docs-sidebar form.docs-search > input, .textarea {
+  box-shadow: inset 0 1px 2px rgba(10, 10, 10, 0.1);
+  max-width: 100%;
+  width: 100%; }
+  .input[readonly], #documenter .docs-sidebar form.docs-search > input[readonly], .textarea[readonly] {
+    box-shadow: none; }
+  .is-white.input, #documenter .docs-sidebar form.docs-search > input.is-white, .is-white.textarea {
+    border-color: white; }
+    .is-white.input:focus, #documenter .docs-sidebar form.docs-search > input.is-white:focus, .is-white.textarea:focus, .is-white.is-focused.input, #documenter .docs-sidebar form.docs-search > input.is-white.is-focused, .is-white.is-focused.textarea, .is-white.input:active, #documenter .docs-sidebar form.docs-search > input.is-white:active, .is-white.textarea:active, .is-white.is-active.input, #documenter .docs-sidebar form.docs-search > input.is-white.is-active, .is-white.is-active.textarea {
+      box-shadow: 0 0 0 0.125em rgba(255, 255, 255, 0.25); }
+  .is-black.input, #documenter .docs-sidebar form.docs-search > input.is-black, .is-black.textarea {
+    border-color: #0a0a0a; }
+    .is-black.input:focus, #documenter .docs-sidebar form.docs-search > input.is-black:focus, .is-black.textarea:focus, .is-black.is-focused.input, #documenter .docs-sidebar form.docs-search > input.is-black.is-focused, .is-black.is-focused.textarea, .is-black.input:active, #documenter .docs-sidebar form.docs-search > input.is-black:active, .is-black.textarea:active, .is-black.is-active.input, #documenter .docs-sidebar form.docs-search > input.is-black.is-active, .is-black.is-active.textarea {
+      box-shadow: 0 0 0 0.125em rgba(10, 10, 10, 0.25); }
+  .is-light.input, #documenter .docs-sidebar form.docs-search > input.is-light, .is-light.textarea {
+    border-color: whitesmoke; }
+    .is-light.input:focus, #documenter .docs-sidebar form.docs-search > input.is-light:focus, .is-light.textarea:focus, .is-light.is-focused.input, #documenter .docs-sidebar form.docs-search > input.is-light.is-focused, .is-light.is-focused.textarea, .is-light.input:active, #documenter .docs-sidebar form.docs-search > input.is-light:active, .is-light.textarea:active, .is-light.is-active.input, #documenter .docs-sidebar form.docs-search > input.is-light.is-active, .is-light.is-active.textarea {
+      box-shadow: 0 0 0 0.125em rgba(245, 245, 245, 0.25); }
+  .is-dark.input, .content kbd.input, #documenter .docs-sidebar form.docs-search > input.is-dark, .is-dark.textarea, .content kbd.textarea {
+    border-color: #363636; }
+    .is-dark.input:focus, .content kbd.input:focus, #documenter .docs-sidebar form.docs-search > input.is-dark:focus, .is-dark.textarea:focus, .content kbd.textarea:focus, .is-dark.is-focused.input, .content kbd.is-focused.input, #documenter .docs-sidebar form.docs-search > input.is-dark.is-focused, .is-dark.is-focused.textarea, .content kbd.is-focused.textarea, .is-dark.input:active, .content kbd.input:active, #documenter .docs-sidebar form.docs-search > input.is-dark:active, .is-dark.textarea:active, .content kbd.textarea:active, .is-dark.is-active.input, .content kbd.is-active.input, #documenter .docs-sidebar form.docs-search > input.is-dark.is-active, .is-dark.is-active.textarea, .content kbd.is-active.textarea {
+      box-shadow: 0 0 0 0.125em rgba(54, 54, 54, 0.25); }
+  .is-primary.input, .docstring > section > a.input.docs-sourcelink, #documenter .docs-sidebar form.docs-search > input.is-primary, .is-primary.textarea, .docstring > section > a.textarea.docs-sourcelink {
+    border-color: #4eb5de; }
+    .is-primary.input:focus, .docstring > section > a.input.docs-sourcelink:focus, #documenter .docs-sidebar form.docs-search > input.is-primary:focus, .is-primary.textarea:focus, .docstring > section > a.textarea.docs-sourcelink:focus, .is-primary.is-focused.input, .docstring > section > a.is-focused.input.docs-sourcelink, #documenter .docs-sidebar form.docs-search > input.is-primary.is-focused, .is-primary.is-focused.textarea, .docstring > section > a.is-focused.textarea.docs-sourcelink, .is-primary.input:active, .docstring > section > a.input.docs-sourcelink:active, #documenter .docs-sidebar form.docs-search > input.is-primary:active, .is-primary.textarea:active, .docstring > section > a.textarea.docs-sourcelink:active, .is-primary.is-active.input, .docstring > section > a.is-active.input.docs-sourcelink, #documenter .docs-sidebar form.docs-search > input.is-primary.is-active, .is-primary.is-active.textarea, .docstring > section > a.is-active.textarea.docs-sourcelink {
+      box-shadow: 0 0 0 0.125em rgba(78, 181, 222, 0.25); }
+  .is-link.input, #documenter .docs-sidebar form.docs-search > input.is-link, .is-link.textarea {
+    border-color: #2e63b8; }
+    .is-link.input:focus, #documenter .docs-sidebar form.docs-search > input.is-link:focus, .is-link.textarea:focus, .is-link.is-focused.input, #documenter .docs-sidebar form.docs-search > input.is-link.is-focused, .is-link.is-focused.textarea, .is-link.input:active, #documenter .docs-sidebar form.docs-search > input.is-link:active, .is-link.textarea:active, .is-link.is-active.input, #documenter .docs-sidebar form.docs-search > input.is-link.is-active, .is-link.is-active.textarea {
+      box-shadow: 0 0 0 0.125em rgba(46, 99, 184, 0.25); }
+  .is-info.input, #documenter .docs-sidebar form.docs-search > input.is-info, .is-info.textarea {
+    border-color: #209cee; }
+    .is-info.input:focus, #documenter .docs-sidebar form.docs-search > input.is-info:focus, .is-info.textarea:focus, .is-info.is-focused.input, #documenter .docs-sidebar form.docs-search > input.is-info.is-focused, .is-info.is-focused.textarea, .is-info.input:active, #documenter .docs-sidebar form.docs-search > input.is-info:active, .is-info.textarea:active, .is-info.is-active.input, #documenter .docs-sidebar form.docs-search > input.is-info.is-active, .is-info.is-active.textarea {
+      box-shadow: 0 0 0 0.125em rgba(32, 156, 238, 0.25); }
+  .is-success.input, #documenter .docs-sidebar form.docs-search > input.is-success, .is-success.textarea {
+    border-color: #22c35b; }
+    .is-success.input:focus, #documenter .docs-sidebar form.docs-search > input.is-success:focus, .is-success.textarea:focus, .is-success.is-focused.input, #documenter .docs-sidebar form.docs-search > input.is-success.is-focused, .is-success.is-focused.textarea, .is-success.input:active, #documenter .docs-sidebar form.docs-search > input.is-success:active, .is-success.textarea:active, .is-success.is-active.input, #documenter .docs-sidebar form.docs-search > input.is-success.is-active, .is-success.is-active.textarea {
+      box-shadow: 0 0 0 0.125em rgba(34, 195, 91, 0.25); }
+  .is-warning.input, #documenter .docs-sidebar form.docs-search > input.is-warning, .is-warning.textarea {
+    border-color: #ffdd57; }
+    .is-warning.input:focus, #documenter .docs-sidebar form.docs-search > input.is-warning:focus, .is-warning.textarea:focus, .is-warning.is-focused.input, #documenter .docs-sidebar form.docs-search > input.is-warning.is-focused, .is-warning.is-focused.textarea, .is-warning.input:active, #documenter .docs-sidebar form.docs-search > input.is-warning:active, .is-warning.textarea:active, .is-warning.is-active.input, #documenter .docs-sidebar form.docs-search > input.is-warning.is-active, .is-warning.is-active.textarea {
+      box-shadow: 0 0 0 0.125em rgba(255, 221, 87, 0.25); }
+  .is-danger.input, #documenter .docs-sidebar form.docs-search > input.is-danger, .is-danger.textarea {
+    border-color: #da0b00; }
+    .is-danger.input:focus, #documenter .docs-sidebar form.docs-search > input.is-danger:focus, .is-danger.textarea:focus, .is-danger.is-focused.input, #documenter .docs-sidebar form.docs-search > input.is-danger.is-focused, .is-danger.is-focused.textarea, .is-danger.input:active, #documenter .docs-sidebar form.docs-search > input.is-danger:active, .is-danger.textarea:active, .is-danger.is-active.input, #documenter .docs-sidebar form.docs-search > input.is-danger.is-active, .is-danger.is-active.textarea {
+      box-shadow: 0 0 0 0.125em rgba(218, 11, 0, 0.25); }
+  .is-small.input, #documenter .docs-sidebar form.docs-search > input, .is-small.textarea {
+    border-radius: 2px;
+    font-size: 0.75rem; }
+  .is-medium.input, #documenter .docs-sidebar form.docs-search > input.is-medium, .is-medium.textarea {
+    font-size: 1.25rem; }
+  .is-large.input, #documenter .docs-sidebar form.docs-search > input.is-large, .is-large.textarea {
+    font-size: 1.5rem; }
+  .is-fullwidth.input, #documenter .docs-sidebar form.docs-search > input.is-fullwidth, .is-fullwidth.textarea {
+    display: block;
+    width: 100%; }
+  .is-inline.input, #documenter .docs-sidebar form.docs-search > input.is-inline, .is-inline.textarea {
+    display: inline;
+    width: auto; }
+
+.input.is-rounded, #documenter .docs-sidebar form.docs-search > input {
+  border-radius: 290486px;
+  padding-left: 1em;
+  padding-right: 1em; }
+
+.input.is-static, #documenter .docs-sidebar form.docs-search > input.is-static {
+  background-color: transparent;
+  border-color: transparent;
+  box-shadow: none;
+  padding-left: 0;
+  padding-right: 0; }
+
+.textarea {
+  display: block;
+  max-width: 100%;
+  min-width: 100%;
+  padding: 0.625em;
+  resize: vertical; }
+  .textarea:not([rows]) {
+    max-height: 600px;
+    min-height: 120px; }
+  .textarea[rows] {
+    height: initial; }
+  .textarea.has-fixed-size {
+    resize: none; }
+
+.checkbox, .radio {
+  cursor: pointer;
+  display: inline-block;
+  line-height: 1.25;
+  position: relative; }
+  .checkbox input, .radio input {
+    cursor: pointer; }
+  .checkbox:hover, .radio:hover {
+    color: #363636; }
+  .checkbox[disabled], .radio[disabled],
+  fieldset[disabled] .checkbox,
+  fieldset[disabled] .radio {
+    color: #7a7a7a;
+    cursor: not-allowed; }
+
+.radio + .radio {
+  margin-left: 0.5em; }
+
+.select {
+  display: inline-block;
+  max-width: 100%;
+  position: relative;
+  vertical-align: top; }
+  .select:not(.is-multiple) {
+    height: 2.25em; }
+  .select:not(.is-multiple):not(.is-loading)::after {
+    border-color: #2e63b8;
+    right: 1.125em;
+    z-index: 4; }
+  .select.is-rounded select, #documenter .docs-sidebar form.docs-search > input.select select {
+    border-radius: 290486px;
+    padding-left: 1em; }
+  .select select {
+    cursor: pointer;
+    display: block;
+    font-size: 1em;
+    max-width: 100%;
+    outline: none; }
+    .select select::-ms-expand {
+      display: none; }
+    .select select[disabled]:hover,
+    fieldset[disabled] .select select:hover {
+      border-color: whitesmoke; }
+    .select select:not([multiple]) {
+      padding-right: 2.5em; }
+    .select select[multiple] {
+      height: auto;
+      padding: 0; }
+      .select select[multiple] option {
+        padding: 0.5em 1em; }
+  .select:not(.is-multiple):not(.is-loading):hover::after {
+    border-color: #363636; }
+  .select.is-white:not(:hover)::after {
+    border-color: white; }
+  .select.is-white select {
+    border-color: white; }
+    .select.is-white select:hover, .select.is-white select.is-hovered {
+      border-color: #f2f2f2; }
+    .select.is-white select:focus, .select.is-white select.is-focused, .select.is-white select:active, .select.is-white select.is-active {
+      box-shadow: 0 0 0 0.125em rgba(255, 255, 255, 0.25); }
+  .select.is-black:not(:hover)::after {
+    border-color: #0a0a0a; }
+  .select.is-black select {
+    border-color: #0a0a0a; }
+    .select.is-black select:hover, .select.is-black select.is-hovered {
+      border-color: black; }
+    .select.is-black select:focus, .select.is-black select.is-focused, .select.is-black select:active, .select.is-black select.is-active {
+      box-shadow: 0 0 0 0.125em rgba(10, 10, 10, 0.25); }
+  .select.is-light:not(:hover)::after {
+    border-color: whitesmoke; }
+  .select.is-light select {
+    border-color: whitesmoke; }
+    .select.is-light select:hover, .select.is-light select.is-hovered {
+      border-color: #e8e8e8; }
+    .select.is-light select:focus, .select.is-light select.is-focused, .select.is-light select:active, .select.is-light select.is-active {
+      box-shadow: 0 0 0 0.125em rgba(245, 245, 245, 0.25); }
+  .select.is-dark:not(:hover)::after, .content kbd.select:not(:hover)::after {
+    border-color: #363636; }
+  .select.is-dark select, .content kbd.select select {
+    border-color: #363636; }
+    .select.is-dark select:hover, .content kbd.select select:hover, .select.is-dark select.is-hovered, .content kbd.select select.is-hovered {
+      border-color: #292929; }
+    .select.is-dark select:focus, .content kbd.select select:focus, .select.is-dark select.is-focused, .content kbd.select select.is-focused, .select.is-dark select:active, .content kbd.select select:active, .select.is-dark select.is-active, .content kbd.select select.is-active {
+      box-shadow: 0 0 0 0.125em rgba(54, 54, 54, 0.25); }
+  .select.is-primary:not(:hover)::after, .docstring > section > a.select.docs-sourcelink:not(:hover)::after {
+    border-color: #4eb5de; }
+  .select.is-primary select, .docstring > section > a.select.docs-sourcelink select {
+    border-color: #4eb5de; }
+    .select.is-primary select:hover, .docstring > section > a.select.docs-sourcelink select:hover, .select.is-primary select.is-hovered, .docstring > section > a.select.docs-sourcelink select.is-hovered {
+      border-color: #39acda; }
+    .select.is-primary select:focus, .docstring > section > a.select.docs-sourcelink select:focus, .select.is-primary select.is-focused, .docstring > section > a.select.docs-sourcelink select.is-focused, .select.is-primary select:active, .docstring > section > a.select.docs-sourcelink select:active, .select.is-primary select.is-active, .docstring > section > a.select.docs-sourcelink select.is-active {
+      box-shadow: 0 0 0 0.125em rgba(78, 181, 222, 0.25); }
+  .select.is-link:not(:hover)::after {
+    border-color: #2e63b8; }
+  .select.is-link select {
+    border-color: #2e63b8; }
+    .select.is-link select:hover, .select.is-link select.is-hovered {
+      border-color: #2958a4; }
+    .select.is-link select:focus, .select.is-link select.is-focused, .select.is-link select:active, .select.is-link select.is-active {
+      box-shadow: 0 0 0 0.125em rgba(46, 99, 184, 0.25); }
+  .select.is-info:not(:hover)::after {
+    border-color: #209cee; }
+  .select.is-info select {
+    border-color: #209cee; }
+    .select.is-info select:hover, .select.is-info select.is-hovered {
+      border-color: #118fe4; }
+    .select.is-info select:focus, .select.is-info select.is-focused, .select.is-info select:active, .select.is-info select.is-active {
+      box-shadow: 0 0 0 0.125em rgba(32, 156, 238, 0.25); }
+  .select.is-success:not(:hover)::after {
+    border-color: #22c35b; }
+  .select.is-success select {
+    border-color: #22c35b; }
+    .select.is-success select:hover, .select.is-success select.is-hovered {
+      border-color: #1ead51; }
+    .select.is-success select:focus, .select.is-success select.is-focused, .select.is-success select:active, .select.is-success select.is-active {
+      box-shadow: 0 0 0 0.125em rgba(34, 195, 91, 0.25); }
+  .select.is-warning:not(:hover)::after {
+    border-color: #ffdd57; }
+  .select.is-warning select {
+    border-color: #ffdd57; }
+    .select.is-warning select:hover, .select.is-warning select.is-hovered {
+      border-color: #ffd83d; }
+    .select.is-warning select:focus, .select.is-warning select.is-focused, .select.is-warning select:active, .select.is-warning select.is-active {
+      box-shadow: 0 0 0 0.125em rgba(255, 221, 87, 0.25); }
+  .select.is-danger:not(:hover)::after {
+    border-color: #da0b00; }
+  .select.is-danger select {
+    border-color: #da0b00; }
+    .select.is-danger select:hover, .select.is-danger select.is-hovered {
+      border-color: #c10a00; }
+    .select.is-danger select:focus, .select.is-danger select.is-focused, .select.is-danger select:active, .select.is-danger select.is-active {
+      box-shadow: 0 0 0 0.125em rgba(218, 11, 0, 0.25); }
+  .select.is-small, #documenter .docs-sidebar form.docs-search > input.select {
+    border-radius: 2px;
+    font-size: 0.75rem; }
+  .select.is-medium {
+    font-size: 1.25rem; }
+  .select.is-large {
+    font-size: 1.5rem; }
+  .select.is-disabled::after {
+    border-color: #7a7a7a; }
+  .select.is-fullwidth {
+    width: 100%; }
+    .select.is-fullwidth select {
+      width: 100%; }
+  .select.is-loading::after {
+    margin-top: 0;
+    position: absolute;
+    right: 0.625em;
+    top: 0.625em;
+    transform: none; }
+  .select.is-loading.is-small:after, #documenter .docs-sidebar form.docs-search > input.select.is-loading:after {
+    font-size: 0.75rem; }
+  .select.is-loading.is-medium:after {
+    font-size: 1.25rem; }
+  .select.is-loading.is-large:after {
+    font-size: 1.5rem; }
+
+.file {
+  align-items: stretch;
+  display: flex;
+  justify-content: flex-start;
+  position: relative; }
+  .file.is-white .file-cta {
+    background-color: white;
+    border-color: transparent;
+    color: #0a0a0a; }
+  .file.is-white:hover .file-cta, .file.is-white.is-hovered .file-cta {
+    background-color: #f9f9f9;
+    border-color: transparent;
+    color: #0a0a0a; }
+  .file.is-white:focus .file-cta, .file.is-white.is-focused .file-cta {
+    border-color: transparent;
+    box-shadow: 0 0 0.5em rgba(255, 255, 255, 0.25);
+    color: #0a0a0a; }
+  .file.is-white:active .file-cta, .file.is-white.is-active .file-cta {
+    background-color: #f2f2f2;
+    border-color: transparent;
+    color: #0a0a0a; }
+  .file.is-black .file-cta {
+    background-color: #0a0a0a;
+    border-color: transparent;
+    color: white; }
+  .file.is-black:hover .file-cta, .file.is-black.is-hovered .file-cta {
+    background-color: #040404;
+    border-color: transparent;
+    color: white; }
+  .file.is-black:focus .file-cta, .file.is-black.is-focused .file-cta {
+    border-color: transparent;
+    box-shadow: 0 0 0.5em rgba(10, 10, 10, 0.25);
+    color: white; }
+  .file.is-black:active .file-cta, .file.is-black.is-active .file-cta {
+    background-color: black;
+    border-color: transparent;
+    color: white; }
+  .file.is-light .file-cta {
+    background-color: whitesmoke;
+    border-color: transparent;
+    color: #363636; }
+  .file.is-light:hover .file-cta, .file.is-light.is-hovered .file-cta {
+    background-color: #eeeeee;
+    border-color: transparent;
+    color: #363636; }
+  .file.is-light:focus .file-cta, .file.is-light.is-focused .file-cta {
+    border-color: transparent;
+    box-shadow: 0 0 0.5em rgba(245, 245, 245, 0.25);
+    color: #363636; }
+  .file.is-light:active .file-cta, .file.is-light.is-active .file-cta {
+    background-color: #e8e8e8;
+    border-color: transparent;
+    color: #363636; }
+  .file.is-dark .file-cta, .content kbd.file .file-cta {
+    background-color: #363636;
+    border-color: transparent;
+    color: whitesmoke; }
+  .file.is-dark:hover .file-cta, .content kbd.file:hover .file-cta, .file.is-dark.is-hovered .file-cta, .content kbd.file.is-hovered .file-cta {
+    background-color: #2f2f2f;
+    border-color: transparent;
+    color: whitesmoke; }
+  .file.is-dark:focus .file-cta, .content kbd.file:focus .file-cta, .file.is-dark.is-focused .file-cta, .content kbd.file.is-focused .file-cta {
+    border-color: transparent;
+    box-shadow: 0 0 0.5em rgba(54, 54, 54, 0.25);
+    color: whitesmoke; }
+  .file.is-dark:active .file-cta, .content kbd.file:active .file-cta, .file.is-dark.is-active .file-cta, .content kbd.file.is-active .file-cta {
+    background-color: #292929;
+    border-color: transparent;
+    color: whitesmoke; }
+  .file.is-primary .file-cta, .docstring > section > a.file.docs-sourcelink .file-cta {
+    background-color: #4eb5de;
+    border-color: transparent;
+    color: #fff; }
+  .file.is-primary:hover .file-cta, .docstring > section > a.file.docs-sourcelink:hover .file-cta, .file.is-primary.is-hovered .file-cta, .docstring > section > a.file.is-hovered.docs-sourcelink .file-cta {
+    background-color: #43b1dc;
+    border-color: transparent;
+    color: #fff; }
+  .file.is-primary:focus .file-cta, .docstring > section > a.file.docs-sourcelink:focus .file-cta, .file.is-primary.is-focused .file-cta, .docstring > section > a.file.is-focused.docs-sourcelink .file-cta {
+    border-color: transparent;
+    box-shadow: 0 0 0.5em rgba(78, 181, 222, 0.25);
+    color: #fff; }
+  .file.is-primary:active .file-cta, .docstring > section > a.file.docs-sourcelink:active .file-cta, .file.is-primary.is-active .file-cta, .docstring > section > a.file.is-active.docs-sourcelink .file-cta {
+    background-color: #39acda;
+    border-color: transparent;
+    color: #fff; }
+  .file.is-link .file-cta {
+    background-color: #2e63b8;
+    border-color: transparent;
+    color: #fff; }
+  .file.is-link:hover .file-cta, .file.is-link.is-hovered .file-cta {
+    background-color: #2b5eae;
+    border-color: transparent;
+    color: #fff; }
+  .file.is-link:focus .file-cta, .file.is-link.is-focused .file-cta {
+    border-color: transparent;
+    box-shadow: 0 0 0.5em rgba(46, 99, 184, 0.25);
+    color: #fff; }
+  .file.is-link:active .file-cta, .file.is-link.is-active .file-cta {
+    background-color: #2958a4;
+    border-color: transparent;
+    color: #fff; }
+  .file.is-info .file-cta {
+    background-color: #209cee;
+    border-color: transparent;
+    color: #fff; }
+  .file.is-info:hover .file-cta, .file.is-info.is-hovered .file-cta {
+    background-color: #1496ed;
+    border-color: transparent;
+    color: #fff; }
+  .file.is-info:focus .file-cta, .file.is-info.is-focused .file-cta {
+    border-color: transparent;
+    box-shadow: 0 0 0.5em rgba(32, 156, 238, 0.25);
+    color: #fff; }
+  .file.is-info:active .file-cta, .file.is-info.is-active .file-cta {
+    background-color: #118fe4;
+    border-color: transparent;
+    color: #fff; }
+  .file.is-success .file-cta {
+    background-color: #22c35b;
+    border-color: transparent;
+    color: #fff; }
+  .file.is-success:hover .file-cta, .file.is-success.is-hovered .file-cta {
+    background-color: #20b856;
+    border-color: transparent;
+    color: #fff; }
+  .file.is-success:focus .file-cta, .file.is-success.is-focused .file-cta {
+    border-color: transparent;
+    box-shadow: 0 0 0.5em rgba(34, 195, 91, 0.25);
+    color: #fff; }
+  .file.is-success:active .file-cta, .file.is-success.is-active .file-cta {
+    background-color: #1ead51;
+    border-color: transparent;
+    color: #fff; }
+  .file.is-warning .file-cta {
+    background-color: #ffdd57;
+    border-color: transparent;
+    color: rgba(0, 0, 0, 0.7); }
+  .file.is-warning:hover .file-cta, .file.is-warning.is-hovered .file-cta {
+    background-color: #ffdb4a;
+    border-color: transparent;
+    color: rgba(0, 0, 0, 0.7); }
+  .file.is-warning:focus .file-cta, .file.is-warning.is-focused .file-cta {
+    border-color: transparent;
+    box-shadow: 0 0 0.5em rgba(255, 221, 87, 0.25);
+    color: rgba(0, 0, 0, 0.7); }
+  .file.is-warning:active .file-cta, .file.is-warning.is-active .file-cta {
+    background-color: #ffd83d;
+    border-color: transparent;
+    color: rgba(0, 0, 0, 0.7); }
+  .file.is-danger .file-cta {
+    background-color: #da0b00;
+    border-color: transparent;
+    color: #fff; }
+  .file.is-danger:hover .file-cta, .file.is-danger.is-hovered .file-cta {
+    background-color: #cd0a00;
+    border-color: transparent;
+    color: #fff; }
+  .file.is-danger:focus .file-cta, .file.is-danger.is-focused .file-cta {
+    border-color: transparent;
+    box-shadow: 0 0 0.5em rgba(218, 11, 0, 0.25);
+    color: #fff; }
+  .file.is-danger:active .file-cta, .file.is-danger.is-active .file-cta {
+    background-color: #c10a00;
+    border-color: transparent;
+    color: #fff; }
+  .file.is-small, #documenter .docs-sidebar form.docs-search > input.file {
+    font-size: 0.75rem; }
+  .file.is-medium {
+    font-size: 1.25rem; }
+    .file.is-medium .file-icon .fa {
+      font-size: 21px; }
+  .file.is-large {
+    font-size: 1.5rem; }
+    .file.is-large .file-icon .fa {
+      font-size: 28px; }
+  .file.has-name .file-cta {
+    border-bottom-right-radius: 0;
+    border-top-right-radius: 0; }
+  .file.has-name .file-name {
+    border-bottom-left-radius: 0;
+    border-top-left-radius: 0; }
+  .file.has-name.is-empty .file-cta {
+    border-radius: 4px; }
+  .file.has-name.is-empty .file-name {
+    display: none; }
+  .file.is-boxed .file-label {
+    flex-direction: column; }
+  .file.is-boxed .file-cta {
+    flex-direction: column;
+    height: auto;
+    padding: 1em 3em; }
+  .file.is-boxed .file-name {
+    border-width: 0 1px 1px; }
+  .file.is-boxed .file-icon {
+    height: 1.5em;
+    width: 1.5em; }
+    .file.is-boxed .file-icon .fa {
+      font-size: 21px; }
+  .file.is-boxed.is-small .file-icon .fa, #documenter .docs-sidebar form.docs-search > input.file.is-boxed .file-icon .fa {
+    font-size: 14px; }
+  .file.is-boxed.is-medium .file-icon .fa {
+    font-size: 28px; }
+  .file.is-boxed.is-large .file-icon .fa {
+    font-size: 35px; }
+  .file.is-boxed.has-name .file-cta {
+    border-radius: 4px 4px 0 0; }
+  .file.is-boxed.has-name .file-name {
+    border-radius: 0 0 4px 4px;
+    border-width: 0 1px 1px; }
+  .file.is-centered {
+    justify-content: center; }
+  .file.is-fullwidth .file-label {
+    width: 100%; }
+  .file.is-fullwidth .file-name {
+    flex-grow: 1;
+    max-width: none; }
+  .file.is-right {
+    justify-content: flex-end; }
+    .file.is-right .file-cta {
+      border-radius: 0 4px 4px 0; }
+    .file.is-right .file-name {
+      border-radius: 4px 0 0 4px;
+      border-width: 1px 0 1px 1px;
+      order: -1; }
+
+.file-label {
+  align-items: stretch;
+  display: flex;
+  cursor: pointer;
+  justify-content: flex-start;
+  overflow: hidden;
+  position: relative; }
+  .file-label:hover .file-cta {
+    background-color: #eeeeee;
+    color: #363636; }
+  .file-label:hover .file-name {
+    border-color: #d5d5d5; }
+  .file-label:active .file-cta {
+    background-color: #e8e8e8;
+    color: #363636; }
+  .file-label:active .file-name {
+    border-color: #cfcfcf; }
+
+.file-input {
+  height: 100%;
+  left: 0;
+  opacity: 0;
+  outline: none;
+  position: absolute;
+  top: 0;
+  width: 100%; }
+
+.file-cta,
+.file-name {
+  border-color: #dbdbdb;
+  border-radius: 4px;
+  font-size: 1em;
+  padding-left: 1em;
+  padding-right: 1em;
+  white-space: nowrap; }
+
+.file-cta {
+  background-color: whitesmoke;
+  color: #4a4a4a; }
+
+.file-name {
+  border-color: #dbdbdb;
+  border-style: solid;
+  border-width: 1px 1px 1px 0;
+  display: block;
+  max-width: 16em;
+  overflow: hidden;
+  text-align: left;
+  text-overflow: ellipsis; }
+
+.file-icon {
+  align-items: center;
+  display: flex;
+  height: 1em;
+  justify-content: center;
+  margin-right: 0.5em;
+  width: 1em; }
+  .file-icon .fa {
+    font-size: 14px; }
+
+.label {
+  color: #363636;
+  display: block;
+  font-size: 1rem;
+  font-weight: 700; }
+  .label:not(:last-child) {
+    margin-bottom: 0.5em; }
+  .label.is-small, #documenter .docs-sidebar form.docs-search > input.label {
+    font-size: 0.75rem; }
+  .label.is-medium {
+    font-size: 1.25rem; }
+  .label.is-large {
+    font-size: 1.5rem; }
+
+.help {
+  display: block;
+  font-size: 0.75rem;
+  margin-top: 0.25rem; }
+  .help.is-white {
+    color: white; }
+  .help.is-black {
+    color: #0a0a0a; }
+  .help.is-light {
+    color: whitesmoke; }
+  .help.is-dark, .content kbd.help {
+    color: #363636; }
+  .help.is-primary, .docstring > section > a.help.docs-sourcelink {
+    color: #4eb5de; }
+  .help.is-link {
+    color: #2e63b8; }
+  .help.is-info {
+    color: #209cee; }
+  .help.is-success {
+    color: #22c35b; }
+  .help.is-warning {
+    color: #ffdd57; }
+  .help.is-danger {
+    color: #da0b00; }
+
+.field:not(:last-child) {
+  margin-bottom: 0.75rem; }
+
+.field.has-addons {
+  display: flex;
+  justify-content: flex-start; }
+  .field.has-addons .control:not(:last-child) {
+    margin-right: -1px; }
+  .field.has-addons .control:not(:first-child):not(:last-child) .button,
+  .field.has-addons .control:not(:first-child):not(:last-child) .input,
+  .field.has-addons .control:not(:first-child):not(:last-child) #documenter .docs-sidebar form.docs-search > input,
+  #documenter .docs-sidebar .field.has-addons .control:not(:first-child):not(:last-child) form.docs-search > input,
+  .field.has-addons .control:not(:first-child):not(:last-child) .select select {
+    border-radius: 0; }
+  .field.has-addons .control:first-child:not(:only-child) .button,
+  .field.has-addons .control:first-child:not(:only-child) .input,
+  .field.has-addons .control:first-child:not(:only-child) #documenter .docs-sidebar form.docs-search > input,
+  #documenter .docs-sidebar .field.has-addons .control:first-child:not(:only-child) form.docs-search > input,
+  .field.has-addons .control:first-child:not(:only-child) .select select {
+    border-bottom-right-radius: 0;
+    border-top-right-radius: 0; }
+  .field.has-addons .control:last-child:not(:only-child) .button,
+  .field.has-addons .control:last-child:not(:only-child) .input,
+  .field.has-addons .control:last-child:not(:only-child) #documenter .docs-sidebar form.docs-search > input,
+  #documenter .docs-sidebar .field.has-addons .control:last-child:not(:only-child) form.docs-search > input,
+  .field.has-addons .control:last-child:not(:only-child) .select select {
+    border-bottom-left-radius: 0;
+    border-top-left-radius: 0; }
+  .field.has-addons .control .button:not([disabled]):hover, .field.has-addons .control .button:not([disabled]).is-hovered,
+  .field.has-addons .control .input:not([disabled]):hover,
+  .field.has-addons .control #documenter .docs-sidebar form.docs-search > input:not([disabled]):hover,
+  #documenter .docs-sidebar .field.has-addons .control form.docs-search > input:not([disabled]):hover,
+  .field.has-addons .control .input:not([disabled]).is-hovered,
+  .field.has-addons .control #documenter .docs-sidebar form.docs-search > input:not([disabled]).is-hovered,
+  #documenter .docs-sidebar .field.has-addons .control form.docs-search > input:not([disabled]).is-hovered,
+  .field.has-addons .control .select select:not([disabled]):hover,
+  .field.has-addons .control .select select:not([disabled]).is-hovered {
+    z-index: 2; }
+  .field.has-addons .control .button:not([disabled]):focus, .field.has-addons .control .button:not([disabled]).is-focused, .field.has-addons .control .button:not([disabled]):active, .field.has-addons .control .button:not([disabled]).is-active,
+  .field.has-addons .control .input:not([disabled]):focus,
+  .field.has-addons .control #documenter .docs-sidebar form.docs-search > input:not([disabled]):focus,
+  #documenter .docs-sidebar .field.has-addons .control form.docs-search > input:not([disabled]):focus,
+  .field.has-addons .control .input:not([disabled]).is-focused,
+  .field.has-addons .control #documenter .docs-sidebar form.docs-search > input:not([disabled]).is-focused,
+  #documenter .docs-sidebar .field.has-addons .control form.docs-search > input:not([disabled]).is-focused,
+  .field.has-addons .control .input:not([disabled]):active,
+  .field.has-addons .control #documenter .docs-sidebar form.docs-search > input:not([disabled]):active,
+  #documenter .docs-sidebar .field.has-addons .control form.docs-search > input:not([disabled]):active,
+  .field.has-addons .control .input:not([disabled]).is-active,
+  .field.has-addons .control #documenter .docs-sidebar form.docs-search > input:not([disabled]).is-active,
+  #documenter .docs-sidebar .field.has-addons .control form.docs-search > input:not([disabled]).is-active,
+  .field.has-addons .control .select select:not([disabled]):focus,
+  .field.has-addons .control .select select:not([disabled]).is-focused,
+  .field.has-addons .control .select select:not([disabled]):active,
+  .field.has-addons .control .select select:not([disabled]).is-active {
+    z-index: 3; }
+    .field.has-addons .control .button:not([disabled]):focus:hover, .field.has-addons .control .button:not([disabled]).is-focused:hover, .field.has-addons .control .button:not([disabled]):active:hover, .field.has-addons .control .button:not([disabled]).is-active:hover,
+    .field.has-addons .control .input:not([disabled]):focus:hover,
+    .field.has-addons .control #documenter .docs-sidebar form.docs-search > input:not([disabled]):focus:hover,
+    #documenter .docs-sidebar .field.has-addons .control form.docs-search > input:not([disabled]):focus:hover,
+    .field.has-addons .control .input:not([disabled]).is-focused:hover,
+    .field.has-addons .control #documenter .docs-sidebar form.docs-search > input:not([disabled]).is-focused:hover,
+    #documenter .docs-sidebar .field.has-addons .control form.docs-search > input:not([disabled]).is-focused:hover,
+    .field.has-addons .control .input:not([disabled]):active:hover,
+    .field.has-addons .control #documenter .docs-sidebar form.docs-search > input:not([disabled]):active:hover,
+    #documenter .docs-sidebar .field.has-addons .control form.docs-search > input:not([disabled]):active:hover,
+    .field.has-addons .control .input:not([disabled]).is-active:hover,
+    .field.has-addons .control #documenter .docs-sidebar form.docs-search > input:not([disabled]).is-active:hover,
+    #documenter .docs-sidebar .field.has-addons .control form.docs-search > input:not([disabled]).is-active:hover,
+    .field.has-addons .control .select select:not([disabled]):focus:hover,
+    .field.has-addons .control .select select:not([disabled]).is-focused:hover,
+    .field.has-addons .control .select select:not([disabled]):active:hover,
+    .field.has-addons .control .select select:not([disabled]).is-active:hover {
+      z-index: 4; }
+  .field.has-addons .control.is-expanded {
+    flex-grow: 1;
+    flex-shrink: 1; }
+  .field.has-addons.has-addons-centered {
+    justify-content: center; }
+  .field.has-addons.has-addons-right {
+    justify-content: flex-end; }
+  .field.has-addons.has-addons-fullwidth .control {
+    flex-grow: 1;
+    flex-shrink: 0; }
+
+.field.is-grouped {
+  display: flex;
+  justify-content: flex-start; }
+  .field.is-grouped > .control {
+    flex-shrink: 0; }
+    .field.is-grouped > .control:not(:last-child) {
+      margin-bottom: 0;
+      margin-right: 0.75rem; }
+    .field.is-grouped > .control.is-expanded {
+      flex-grow: 1;
+      flex-shrink: 1; }
+  .field.is-grouped.is-grouped-centered {
+    justify-content: center; }
+  .field.is-grouped.is-grouped-right {
+    justify-content: flex-end; }
+  .field.is-grouped.is-grouped-multiline {
+    flex-wrap: wrap; }
+    .field.is-grouped.is-grouped-multiline > .control:last-child, .field.is-grouped.is-grouped-multiline > .control:not(:last-child) {
+      margin-bottom: 0.75rem; }
+    .field.is-grouped.is-grouped-multiline:last-child {
+      margin-bottom: -0.75rem; }
+    .field.is-grouped.is-grouped-multiline:not(:last-child) {
+      margin-bottom: 0; }
+
+@media screen and (min-width: 769px), print {
+  .field.is-horizontal {
+    display: flex; } }
+
+.field-label .label {
+  font-size: inherit; }
+
+@media screen and (max-width: 768px) {
+  .field-label {
+    margin-bottom: 0.5rem; } }
+
+@media screen and (min-width: 769px), print {
+  .field-label {
+    flex-basis: 0;
+    flex-grow: 1;
+    flex-shrink: 0;
+    margin-right: 1.5rem;
+    text-align: right; }
+    .field-label.is-small, #documenter .docs-sidebar form.docs-search > input.field-label {
+      font-size: 0.75rem;
+      padding-top: 0.375em; }
+    .field-label.is-normal {
+      padding-top: 0.375em; }
+    .field-label.is-medium {
+      font-size: 1.25rem;
+      padding-top: 0.375em; }
+    .field-label.is-large {
+      font-size: 1.5rem;
+      padding-top: 0.375em; } }
+
+.field-body .field .field {
+  margin-bottom: 0; }
+
+@media screen and (min-width: 769px), print {
+  .field-body {
+    display: flex;
+    flex-basis: 0;
+    flex-grow: 5;
+    flex-shrink: 1; }
+    .field-body .field {
+      margin-bottom: 0; }
+    .field-body > .field {
+      flex-shrink: 1; }
+      .field-body > .field:not(.is-narrow) {
+        flex-grow: 1; }
+      .field-body > .field:not(:last-child) {
+        margin-right: 0.75rem; } }
+
+.control {
+  box-sizing: border-box;
+  clear: both;
+  font-size: 1rem;
+  position: relative;
+  text-align: left; }
+  .control.has-icons-left .input:focus ~ .icon, .control.has-icons-left #documenter .docs-sidebar form.docs-search > input:focus ~ .icon, #documenter .docs-sidebar .control.has-icons-left form.docs-search > input:focus ~ .icon,
+  .control.has-icons-left .select:focus ~ .icon, .control.has-icons-right .input:focus ~ .icon, .control.has-icons-right #documenter .docs-sidebar form.docs-search > input:focus ~ .icon, #documenter .docs-sidebar .control.has-icons-right form.docs-search > input:focus ~ .icon,
+  .control.has-icons-right .select:focus ~ .icon {
+    color: #7a7a7a; }
+  .control.has-icons-left .input.is-small ~ .icon, .control.has-icons-left #documenter .docs-sidebar form.docs-search > input ~ .icon, #documenter .docs-sidebar .control.has-icons-left form.docs-search > input ~ .icon,
+  .control.has-icons-left .select.is-small ~ .icon,
+  .control.has-icons-left #documenter .docs-sidebar form.docs-search > input.select ~ .icon,
+  #documenter .docs-sidebar .control.has-icons-left form.docs-search > input.select ~ .icon, .control.has-icons-right .input.is-small ~ .icon, .control.has-icons-right #documenter .docs-sidebar form.docs-search > input ~ .icon, #documenter .docs-sidebar .control.has-icons-right form.docs-search > input ~ .icon,
+  .control.has-icons-right .select.is-small ~ .icon,
+  .control.has-icons-right #documenter .docs-sidebar form.docs-search > input.select ~ .icon,
+  #documenter .docs-sidebar .control.has-icons-right form.docs-search > input.select ~ .icon {
+    font-size: 0.75rem; }
+  .control.has-icons-left .input.is-medium ~ .icon, .control.has-icons-left #documenter .docs-sidebar form.docs-search > input.is-medium ~ .icon, #documenter .docs-sidebar .control.has-icons-left form.docs-search > input.is-medium ~ .icon,
+  .control.has-icons-left .select.is-medium ~ .icon, .control.has-icons-right .input.is-medium ~ .icon, .control.has-icons-right #documenter .docs-sidebar form.docs-search > input.is-medium ~ .icon, #documenter .docs-sidebar .control.has-icons-right form.docs-search > input.is-medium ~ .icon,
+  .control.has-icons-right .select.is-medium ~ .icon {
+    font-size: 1.25rem; }
+  .control.has-icons-left .input.is-large ~ .icon, .control.has-icons-left #documenter .docs-sidebar form.docs-search > input.is-large ~ .icon, #documenter .docs-sidebar .control.has-icons-left form.docs-search > input.is-large ~ .icon,
+  .control.has-icons-left .select.is-large ~ .icon, .control.has-icons-right .input.is-large ~ .icon, .control.has-icons-right #documenter .docs-sidebar form.docs-search > input.is-large ~ .icon, #documenter .docs-sidebar .control.has-icons-right form.docs-search > input.is-large ~ .icon,
+  .control.has-icons-right .select.is-large ~ .icon {
+    font-size: 1.5rem; }
+  .control.has-icons-left .icon, .control.has-icons-right .icon {
+    color: #dbdbdb;
+    height: 2.25em;
+    pointer-events: none;
+    position: absolute;
+    top: 0;
+    width: 2.25em;
+    z-index: 4; }
+  .control.has-icons-left .input, .control.has-icons-left #documenter .docs-sidebar form.docs-search > input, #documenter .docs-sidebar .control.has-icons-left form.docs-search > input,
+  .control.has-icons-left .select select {
+    padding-left: 2.25em; }
+  .control.has-icons-left .icon.is-left {
+    left: 0; }
+  .control.has-icons-right .input, .control.has-icons-right #documenter .docs-sidebar form.docs-search > input, #documenter .docs-sidebar .control.has-icons-right form.docs-search > input,
+  .control.has-icons-right .select select {
+    padding-right: 2.25em; }
+  .control.has-icons-right .icon.is-right {
+    right: 0; }
+  .control.is-loading::after {
+    position: absolute !important;
+    right: 0.625em;
+    top: 0.625em;
+    z-index: 4; }
+  .control.is-loading.is-small:after, #documenter .docs-sidebar form.docs-search > input.control.is-loading:after {
+    font-size: 0.75rem; }
+  .control.is-loading.is-medium:after {
+    font-size: 1.25rem; }
+  .control.is-loading.is-large:after {
+    font-size: 1.5rem; }
+
+.breadcrumb {
+  font-size: 1rem;
+  white-space: nowrap; }
+  .breadcrumb a {
+    align-items: center;
+    color: #2e63b8;
+    display: flex;
+    justify-content: center;
+    padding: 0 0.75em; }
+    .breadcrumb a:hover {
+      color: #363636; }
+  .breadcrumb li {
+    align-items: center;
+    display: flex; }
+    .breadcrumb li:first-child a {
+      padding-left: 0; }
+    .breadcrumb li.is-active a {
+      color: #222222;
+      cursor: default;
+      pointer-events: none; }
+    .breadcrumb li + li::before {
+      color: #b5b5b5;
+      content: "\0002f"; }
+  .breadcrumb ul,
+  .breadcrumb ol {
+    align-items: flex-start;
+    display: flex;
+    flex-wrap: wrap;
+    justify-content: flex-start; }
+  .breadcrumb .icon:first-child {
+    margin-right: 0.5em; }
+  .breadcrumb .icon:last-child {
+    margin-left: 0.5em; }
+  .breadcrumb.is-centered ol,
+  .breadcrumb.is-centered ul {
+    justify-content: center; }
+  .breadcrumb.is-right ol,
+  .breadcrumb.is-right ul {
+    justify-content: flex-end; }
+  .breadcrumb.is-small, #documenter .docs-sidebar form.docs-search > input.breadcrumb {
+    font-size: 0.75rem; }
+  .breadcrumb.is-medium {
+    font-size: 1.25rem; }
+  .breadcrumb.is-large {
+    font-size: 1.5rem; }
+  .breadcrumb.has-arrow-separator li + li::before {
+    content: "\02192"; }
+  .breadcrumb.has-bullet-separator li + li::before {
+    content: "\02022"; }
+  .breadcrumb.has-dot-separator li + li::before {
+    content: "\000b7"; }
+  .breadcrumb.has-succeeds-separator li + li::before {
+    content: "\0227B"; }
+
+.card {
+  background-color: white;
+  box-shadow: 0 2px 3px rgba(10, 10, 10, 0.1), 0 0 0 1px rgba(10, 10, 10, 0.1);
+  color: #222222;
+  max-width: 100%;
+  position: relative; }
+
+.card-header {
+  background-color: transparent;
+  align-items: stretch;
+  box-shadow: 0 1px 2px rgba(10, 10, 10, 0.1);
+  display: flex; }
+
+.card-header-title {
+  align-items: center;
+  color: #222222;
+  display: flex;
+  flex-grow: 1;
+  font-weight: 700;
+  padding: 0.75rem; }
+  .card-header-title.is-centered {
+    justify-content: center; }
+
+.card-header-icon {
+  align-items: center;
+  cursor: pointer;
+  display: flex;
+  justify-content: center;
+  padding: 0.75rem; }
+
+.card-image {
+  display: block;
+  position: relative; }
+
+.card-content {
+  background-color: transparent;
+  padding: 1rem 1.25rem; }
+
+.card-footer {
+  background-color: transparent;
+  border-top: 1px solid #dbdbdb;
+  align-items: stretch;
+  display: flex; }
+
+.card-footer-item {
+  align-items: center;
+  display: flex;
+  flex-basis: 0;
+  flex-grow: 1;
+  flex-shrink: 0;
+  justify-content: center;
+  padding: 0.75rem; }
+  .card-footer-item:not(:last-child) {
+    border-right: 1px solid #dbdbdb; }
+
+.card .media:not(:last-child) {
+  margin-bottom: 1.5rem; }
+
+.dropdown {
+  display: inline-flex;
+  position: relative;
+  vertical-align: top; }
+  .dropdown.is-active .dropdown-menu, .dropdown.is-hoverable:hover .dropdown-menu {
+    display: block; }
+  .dropdown.is-right .dropdown-menu {
+    left: auto;
+    right: 0; }
+  .dropdown.is-up .dropdown-menu {
+    bottom: 100%;
+    padding-bottom: 4px;
+    padding-top: initial;
+    top: auto; }
+
+.dropdown-menu {
+  display: none;
+  left: 0;
+  min-width: 12rem;
+  padding-top: 4px;
+  position: absolute;
+  top: 100%;
+  z-index: 20; }
+
+.dropdown-content {
+  background-color: white;
+  border-radius: 4px;
+  box-shadow: 0 2px 3px rgba(10, 10, 10, 0.1), 0 0 0 1px rgba(10, 10, 10, 0.1);
+  padding-bottom: 0.5rem;
+  padding-top: 0.5rem; }
+
+.dropdown-item {
+  color: #4a4a4a;
+  display: block;
+  font-size: 0.875rem;
+  line-height: 1.5;
+  padding: 0.375rem 1rem;
+  position: relative; }
+
+a.dropdown-item,
+button.dropdown-item {
+  padding-right: 3rem;
+  text-align: left;
+  white-space: nowrap;
+  width: 100%; }
+  a.dropdown-item:hover,
+  button.dropdown-item:hover {
+    background-color: whitesmoke;
+    color: #0a0a0a; }
+  a.dropdown-item.is-active,
+  button.dropdown-item.is-active {
+    background-color: #2e63b8;
+    color: #fff; }
+
+.dropdown-divider {
+  background-color: #dbdbdb;
+  border: none;
+  display: block;
+  height: 1px;
+  margin: 0.5rem 0; }
+
+.level {
+  align-items: center;
+  justify-content: space-between; }
+  .level code {
+    border-radius: 4px; }
+  .level img {
+    display: inline-block;
+    vertical-align: top; }
+  .level.is-mobile {
+    display: flex; }
+    .level.is-mobile .level-left,
+    .level.is-mobile .level-right {
+      display: flex; }
+    .level.is-mobile .level-left + .level-right {
+      margin-top: 0; }
+    .level.is-mobile .level-item:not(:last-child) {
+      margin-bottom: 0;
+      margin-right: 0.75rem; }
+    .level.is-mobile .level-item:not(.is-narrow) {
+      flex-grow: 1; }
+  @media screen and (min-width: 769px), print {
+    .level {
+      display: flex; }
+      .level > .level-item:not(.is-narrow) {
+        flex-grow: 1; } }
+
+.level-item {
+  align-items: center;
+  display: flex;
+  flex-basis: auto;
+  flex-grow: 0;
+  flex-shrink: 0;
+  justify-content: center; }
+  .level-item .title,
+  .level-item .subtitle {
+    margin-bottom: 0; }
+  @media screen and (max-width: 768px) {
+    .level-item:not(:last-child) {
+      margin-bottom: 0.75rem; } }
+
+.level-left,
+.level-right {
+  flex-basis: auto;
+  flex-grow: 0;
+  flex-shrink: 0; }
+  .level-left .level-item.is-flexible,
+  .level-right .level-item.is-flexible {
+    flex-grow: 1; }
+  @media screen and (min-width: 769px), print {
+    .level-left .level-item:not(:last-child),
+    .level-right .level-item:not(:last-child) {
+      margin-right: 0.75rem; } }
+
+.level-left {
+  align-items: center;
+  justify-content: flex-start; }
+  @media screen and (max-width: 768px) {
+    .level-left + .level-right {
+      margin-top: 1.5rem; } }
+  @media screen and (min-width: 769px), print {
+    .level-left {
+      display: flex; } }
+
+.level-right {
+  align-items: center;
+  justify-content: flex-end; }
+  @media screen and (min-width: 769px), print {
+    .level-right {
+      display: flex; } }
+
+.list {
+  background-color: white;
+  border-radius: 4px;
+  box-shadow: 0 2px 3px rgba(10, 10, 10, 0.1), 0 0 0 1px rgba(10, 10, 10, 0.1); }
+
+.list-item {
+  display: block;
+  padding: 0.5em 1em; }
+  .list-item:not(a) {
+    color: #222222; }
+  .list-item:first-child {
+    border-top-left-radius: 4px;
+    border-top-right-radius: 4px; }
+  .list-item:last-child {
+    border-bottom-left-radius: 4px;
+    border-bottom-right-radius: 4px; }
+  .list-item:not(:last-child) {
+    border-bottom: 1px solid #dbdbdb; }
+  .list-item.is-active {
+    background-color: #2e63b8;
+    color: #fff; }
+
+a.list-item {
+  background-color: whitesmoke;
+  cursor: pointer; }
+
+.media {
+  align-items: flex-start;
+  display: flex;
+  text-align: left; }
+  .media .content:not(:last-child) {
+    margin-bottom: 0.75rem; }
+  .media .media {
+    border-top: 1px solid rgba(219, 219, 219, 0.5);
+    display: flex;
+    padding-top: 0.75rem; }
+    .media .media .content:not(:last-child),
+    .media .media .control:not(:last-child) {
+      margin-bottom: 0.5rem; }
+    .media .media .media {
+      padding-top: 0.5rem; }
+      .media .media .media + .media {
+        margin-top: 0.5rem; }
+  .media + .media {
+    border-top: 1px solid rgba(219, 219, 219, 0.5);
+    margin-top: 1rem;
+    padding-top: 1rem; }
+  .media.is-large + .media {
+    margin-top: 1.5rem;
+    padding-top: 1.5rem; }
+
+.media-left,
+.media-right {
+  flex-basis: auto;
+  flex-grow: 0;
+  flex-shrink: 0; }
+
+.media-left {
+  margin-right: 1rem; }
+
+.media-right {
+  margin-left: 1rem; }
+
+.media-content {
+  flex-basis: auto;
+  flex-grow: 1;
+  flex-shrink: 1;
+  text-align: left; }
+
+@media screen and (max-width: 768px) {
+  .media-content {
+    overflow-x: auto; } }
+
+.menu {
+  font-size: 1rem; }
+  .menu.is-small, #documenter .docs-sidebar form.docs-search > input.menu {
+    font-size: 0.75rem; }
+  .menu.is-medium {
+    font-size: 1.25rem; }
+  .menu.is-large {
+    font-size: 1.5rem; }
+
+.menu-list {
+  line-height: 1.25; }
+  .menu-list a {
+    border-radius: 2px;
+    color: #222222;
+    display: block;
+    padding: 0.5em 0.75em; }
+    .menu-list a:hover {
+      background-color: whitesmoke;
+      color: #222222; }
+    .menu-list a.is-active {
+      background-color: #2e63b8;
+      color: #fff; }
+  .menu-list li ul {
+    border-left: 1px solid #dbdbdb;
+    margin: 0.75em;
+    padding-left: 0.75em; }
+
+.menu-label {
+  color: #7a7a7a;
+  font-size: 0.75em;
+  letter-spacing: 0.1em;
+  text-transform: uppercase; }
+  .menu-label:not(:first-child) {
+    margin-top: 1em; }
+  .menu-label:not(:last-child) {
+    margin-bottom: 1em; }
+
+.message {
+  background-color: whitesmoke;
+  border-radius: 4px;
+  font-size: 1rem; }
+  .message strong {
+    color: currentColor; }
+  .message a:not(.button):not(.tag):not(.dropdown-item) {
+    color: currentColor;
+    text-decoration: underline; }
+  .message.is-small, #documenter .docs-sidebar form.docs-search > input.message {
+    font-size: 0.75rem; }
+  .message.is-medium {
+    font-size: 1.25rem; }
+  .message.is-large {
+    font-size: 1.5rem; }
+  .message.is-white {
+    background-color: white; }
+    .message.is-white .message-header {
+      background-color: white;
+      color: #0a0a0a; }
+    .message.is-white .message-body {
+      border-color: white;
+      color: #4d4d4d; }
+  .message.is-black {
+    background-color: #fafafa; }
+    .message.is-black .message-header {
+      background-color: #0a0a0a;
+      color: white; }
+    .message.is-black .message-body {
+      border-color: #0a0a0a;
+      color: #090909; }
+  .message.is-light {
+    background-color: #fafafa; }
+    .message.is-light .message-header {
+      background-color: whitesmoke;
+      color: #363636; }
+    .message.is-light .message-body {
+      border-color: whitesmoke;
+      color: #505050; }
+  .message.is-dark, .content kbd.message {
+    background-color: #fafafa; }
+    .message.is-dark .message-header, .content kbd.message .message-header {
+      background-color: #363636;
+      color: whitesmoke; }
+    .message.is-dark .message-body, .content kbd.message .message-body {
+      border-color: #363636;
+      color: #2a2a2a; }
+  .message.is-primary, .docstring > section > a.message.docs-sourcelink {
+    background-color: #f6fbfd; }
+    .message.is-primary .message-header, .docstring > section > a.message.docs-sourcelink .message-header {
+      background-color: #4eb5de;
+      color: #fff; }
+    .message.is-primary .message-body, .docstring > section > a.message.docs-sourcelink .message-body {
+      border-color: #4eb5de;
+      color: #1f556a; }
+  .message.is-link {
+    background-color: #f7f9fd; }
+    .message.is-link .message-header {
+      background-color: #2e63b8;
+      color: #fff; }
+    .message.is-link .message-body {
+      border-color: #2e63b8;
+      color: #264981; }
+  .message.is-info {
+    background-color: #f6fbfe; }
+    .message.is-info .message-header {
+      background-color: #209cee;
+      color: #fff; }
+    .message.is-info .message-body {
+      border-color: #209cee;
+      color: #12537e; }
+  .message.is-success {
+    background-color: #f6fdf9; }
+    .message.is-success .message-header {
+      background-color: #22c35b;
+      color: #fff; }
+    .message.is-success .message-body {
+      border-color: #22c35b;
+      color: #0f361d; }
+  .message.is-warning {
+    background-color: #fffdf5; }
+    .message.is-warning .message-header {
+      background-color: #ffdd57;
+      color: rgba(0, 0, 0, 0.7); }
+    .message.is-warning .message-body {
+      border-color: #ffdd57;
+      color: #3b3108; }
+  .message.is-danger {
+    background-color: #fff5f5; }
+    .message.is-danger .message-header {
+      background-color: #da0b00;
+      color: #fff; }
+    .message.is-danger .message-body {
+      border-color: #da0b00;
+      color: #9b0c04; }
+
+.message-header {
+  align-items: center;
+  background-color: #222222;
+  border-radius: 4px 4px 0 0;
+  color: #fff;
+  display: flex;
+  font-weight: 700;
+  justify-content: space-between;
+  line-height: 1.25;
+  padding: 0.75em;
+  position: relative; }
+  .message-header .delete {
+    flex-grow: 0;
+    flex-shrink: 0;
+    margin-left: 0.75em; }
+  .message-header + .message-body {
+    border-width: 0;
+    border-top-left-radius: 0;
+    border-top-right-radius: 0; }
+
+.message-body {
+  border-color: #dbdbdb;
+  border-radius: 4px;
+  border-style: solid;
+  border-width: 0 0 0 4px;
+  color: #222222;
+  padding: 1em 1.25em; }
+  .message-body code,
+  .message-body pre {
+    background-color: white; }
+  .message-body pre code {
+    background-color: transparent; }
+
+.modal {
+  align-items: center;
+  display: none;
+  flex-direction: column;
+  justify-content: center;
+  overflow: hidden;
+  position: fixed;
+  z-index: 40; }
+  .modal.is-active {
+    display: flex; }
+
+.modal-background {
+  background-color: rgba(10, 10, 10, 0.86); }
+
+.modal-content,
+.modal-card {
+  margin: 0 20px;
+  max-height: calc(100vh - 160px);
+  overflow: auto;
+  position: relative;
+  width: 100%; }
+  @media screen and (min-width: 769px), print {
+    .modal-content,
+    .modal-card {
+      margin: 0 auto;
+      max-height: calc(100vh - 40px);
+      width: 640px; } }
+
+.modal-close {
+  background: none;
+  height: 40px;
+  position: fixed;
+  right: 20px;
+  top: 20px;
+  width: 40px; }
+
+.modal-card {
+  display: flex;
+  flex-direction: column;
+  max-height: calc(100vh - 40px);
+  overflow: hidden;
+  -ms-overflow-y: visible; }
+
+.modal-card-head,
+.modal-card-foot {
+  align-items: center;
+  background-color: whitesmoke;
+  display: flex;
+  flex-shrink: 0;
+  justify-content: flex-start;
+  padding: 20px;
+  position: relative; }
+
+.modal-card-head {
+  border-bottom: 1px solid #dbdbdb;
+  border-top-left-radius: 6px;
+  border-top-right-radius: 6px; }
+
+.modal-card-title {
+  color: #222222;
+  flex-grow: 1;
+  flex-shrink: 0;
+  font-size: 1.5rem;
+  line-height: 1; }
+
+.modal-card-foot {
+  border-bottom-left-radius: 6px;
+  border-bottom-right-radius: 6px;
+  border-top: 1px solid #dbdbdb; }
+  .modal-card-foot .button:not(:last-child) {
+    margin-right: 0.5em; }
+
+.modal-card-body {
+  -webkit-overflow-scrolling: touch;
+  background-color: white;
+  flex-grow: 1;
+  flex-shrink: 1;
+  overflow: auto;
+  padding: 20px; }
+
+.navbar {
+  background-color: white;
+  min-height: 3.25rem;
+  position: relative;
+  z-index: 30; }
+  .navbar.is-white {
+    background-color: white;
+    color: #0a0a0a; }
+    .navbar.is-white .navbar-brand > .navbar-item,
+    .navbar.is-white .navbar-brand .navbar-link {
+      color: #0a0a0a; }
+    .navbar.is-white .navbar-brand > a.navbar-item:focus, .navbar.is-white .navbar-brand > a.navbar-item:hover, .navbar.is-white .navbar-brand > a.navbar-item.is-active,
+    .navbar.is-white .navbar-brand .navbar-link:focus,
+    .navbar.is-white .navbar-brand .navbar-link:hover,
+    .navbar.is-white .navbar-brand .navbar-link.is-active {
+      background-color: #f2f2f2;
+      color: #0a0a0a; }
+    .navbar.is-white .navbar-brand .navbar-link::after {
+      border-color: #0a0a0a; }
+    .navbar.is-white .navbar-burger {
+      color: #0a0a0a; }
+    @media screen and (min-width: 1056px) {
+      .navbar.is-white .navbar-start > .navbar-item,
+      .navbar.is-white .navbar-start .navbar-link,
+      .navbar.is-white .navbar-end > .navbar-item,
+      .navbar.is-white .navbar-end .navbar-link {
+        color: #0a0a0a; }
+      .navbar.is-white .navbar-start > a.navbar-item:focus, .navbar.is-white .navbar-start > a.navbar-item:hover, .navbar.is-white .navbar-start > a.navbar-item.is-active,
+      .navbar.is-white .navbar-start .navbar-link:focus,
+      .navbar.is-white .navbar-start .navbar-link:hover,
+      .navbar.is-white .navbar-start .navbar-link.is-active,
+      .navbar.is-white .navbar-end > a.navbar-item:focus,
+      .navbar.is-white .navbar-end > a.navbar-item:hover,
+      .navbar.is-white .navbar-end > a.navbar-item.is-active,
+      .navbar.is-white .navbar-end .navbar-link:focus,
+      .navbar.is-white .navbar-end .navbar-link:hover,
+      .navbar.is-white .navbar-end .navbar-link.is-active {
+        background-color: #f2f2f2;
+        color: #0a0a0a; }
+      .navbar.is-white .navbar-start .navbar-link::after,
+      .navbar.is-white .navbar-end .navbar-link::after {
+        border-color: #0a0a0a; }
+      .navbar.is-white .navbar-item.has-dropdown:focus .navbar-link,
+      .navbar.is-white .navbar-item.has-dropdown:hover .navbar-link,
+      .navbar.is-white .navbar-item.has-dropdown.is-active .navbar-link {
+        background-color: #f2f2f2;
+        color: #0a0a0a; }
+      .navbar.is-white .navbar-dropdown a.navbar-item.is-active {
+        background-color: white;
+        color: #0a0a0a; } }
+  .navbar.is-black {
+    background-color: #0a0a0a;
+    color: white; }
+    .navbar.is-black .navbar-brand > .navbar-item,
+    .navbar.is-black .navbar-brand .navbar-link {
+      color: white; }
+    .navbar.is-black .navbar-brand > a.navbar-item:focus, .navbar.is-black .navbar-brand > a.navbar-item:hover, .navbar.is-black .navbar-brand > a.navbar-item.is-active,
+    .navbar.is-black .navbar-brand .navbar-link:focus,
+    .navbar.is-black .navbar-brand .navbar-link:hover,
+    .navbar.is-black .navbar-brand .navbar-link.is-active {
+      background-color: black;
+      color: white; }
+    .navbar.is-black .navbar-brand .navbar-link::after {
+      border-color: white; }
+    .navbar.is-black .navbar-burger {
+      color: white; }
+    @media screen and (min-width: 1056px) {
+      .navbar.is-black .navbar-start > .navbar-item,
+      .navbar.is-black .navbar-start .navbar-link,
+      .navbar.is-black .navbar-end > .navbar-item,
+      .navbar.is-black .navbar-end .navbar-link {
+        color: white; }
+      .navbar.is-black .navbar-start > a.navbar-item:focus, .navbar.is-black .navbar-start > a.navbar-item:hover, .navbar.is-black .navbar-start > a.navbar-item.is-active,
+      .navbar.is-black .navbar-start .navbar-link:focus,
+      .navbar.is-black .navbar-start .navbar-link:hover,
+      .navbar.is-black .navbar-start .navbar-link.is-active,
+      .navbar.is-black .navbar-end > a.navbar-item:focus,
+      .navbar.is-black .navbar-end > a.navbar-item:hover,
+      .navbar.is-black .navbar-end > a.navbar-item.is-active,
+      .navbar.is-black .navbar-end .navbar-link:focus,
+      .navbar.is-black .navbar-end .navbar-link:hover,
+      .navbar.is-black .navbar-end .navbar-link.is-active {
+        background-color: black;
+        color: white; }
+      .navbar.is-black .navbar-start .navbar-link::after,
+      .navbar.is-black .navbar-end .navbar-link::after {
+        border-color: white; }
+      .navbar.is-black .navbar-item.has-dropdown:focus .navbar-link,
+      .navbar.is-black .navbar-item.has-dropdown:hover .navbar-link,
+      .navbar.is-black .navbar-item.has-dropdown.is-active .navbar-link {
+        background-color: black;
+        color: white; }
+      .navbar.is-black .navbar-dropdown a.navbar-item.is-active {
+        background-color: #0a0a0a;
+        color: white; } }
+  .navbar.is-light {
+    background-color: whitesmoke;
+    color: #363636; }
+    .navbar.is-light .navbar-brand > .navbar-item,
+    .navbar.is-light .navbar-brand .navbar-link {
+      color: #363636; }
+    .navbar.is-light .navbar-brand > a.navbar-item:focus, .navbar.is-light .navbar-brand > a.navbar-item:hover, .navbar.is-light .navbar-brand > a.navbar-item.is-active,
+    .navbar.is-light .navbar-brand .navbar-link:focus,
+    .navbar.is-light .navbar-brand .navbar-link:hover,
+    .navbar.is-light .navbar-brand .navbar-link.is-active {
+      background-color: #e8e8e8;
+      color: #363636; }
+    .navbar.is-light .navbar-brand .navbar-link::after {
+      border-color: #363636; }
+    .navbar.is-light .navbar-burger {
+      color: #363636; }
+    @media screen and (min-width: 1056px) {
+      .navbar.is-light .navbar-start > .navbar-item,
+      .navbar.is-light .navbar-start .navbar-link,
+      .navbar.is-light .navbar-end > .navbar-item,
+      .navbar.is-light .navbar-end .navbar-link {
+        color: #363636; }
+      .navbar.is-light .navbar-start > a.navbar-item:focus, .navbar.is-light .navbar-start > a.navbar-item:hover, .navbar.is-light .navbar-start > a.navbar-item.is-active,
+      .navbar.is-light .navbar-start .navbar-link:focus,
+      .navbar.is-light .navbar-start .navbar-link:hover,
+      .navbar.is-light .navbar-start .navbar-link.is-active,
+      .navbar.is-light .navbar-end > a.navbar-item:focus,
+      .navbar.is-light .navbar-end > a.navbar-item:hover,
+      .navbar.is-light .navbar-end > a.navbar-item.is-active,
+      .navbar.is-light .navbar-end .navbar-link:focus,
+      .navbar.is-light .navbar-end .navbar-link:hover,
+      .navbar.is-light .navbar-end .navbar-link.is-active {
+        background-color: #e8e8e8;
+        color: #363636; }
+      .navbar.is-light .navbar-start .navbar-link::after,
+      .navbar.is-light .navbar-end .navbar-link::after {
+        border-color: #363636; }
+      .navbar.is-light .navbar-item.has-dropdown:focus .navbar-link,
+      .navbar.is-light .navbar-item.has-dropdown:hover .navbar-link,
+      .navbar.is-light .navbar-item.has-dropdown.is-active .navbar-link {
+        background-color: #e8e8e8;
+        color: #363636; }
+      .navbar.is-light .navbar-dropdown a.navbar-item.is-active {
+        background-color: whitesmoke;
+        color: #363636; } }
+  .navbar.is-dark, .content kbd.navbar {
+    background-color: #363636;
+    color: whitesmoke; }
+    .navbar.is-dark .navbar-brand > .navbar-item, .content kbd.navbar .navbar-brand > .navbar-item,
+    .navbar.is-dark .navbar-brand .navbar-link,
+    .content kbd.navbar .navbar-brand .navbar-link {
+      color: whitesmoke; }
+    .navbar.is-dark .navbar-brand > a.navbar-item:focus, .content kbd.navbar .navbar-brand > a.navbar-item:focus, .navbar.is-dark .navbar-brand > a.navbar-item:hover, .content kbd.navbar .navbar-brand > a.navbar-item:hover, .navbar.is-dark .navbar-brand > a.navbar-item.is-active, .content kbd.navbar .navbar-brand > a.navbar-item.is-active,
+    .navbar.is-dark .navbar-brand .navbar-link:focus,
+    .content kbd.navbar .navbar-brand .navbar-link:focus,
+    .navbar.is-dark .navbar-brand .navbar-link:hover,
+    .content kbd.navbar .navbar-brand .navbar-link:hover,
+    .navbar.is-dark .navbar-brand .navbar-link.is-active,
+    .content kbd.navbar .navbar-brand .navbar-link.is-active {
+      background-color: #292929;
+      color: whitesmoke; }
+    .navbar.is-dark .navbar-brand .navbar-link::after, .content kbd.navbar .navbar-brand .navbar-link::after {
+      border-color: whitesmoke; }
+    .navbar.is-dark .navbar-burger, .content kbd.navbar .navbar-burger {
+      color: whitesmoke; }
+    @media screen and (min-width: 1056px) {
+      .navbar.is-dark .navbar-start > .navbar-item, .content kbd.navbar .navbar-start > .navbar-item,
+      .navbar.is-dark .navbar-start .navbar-link,
+      .content kbd.navbar .navbar-start .navbar-link,
+      .navbar.is-dark .navbar-end > .navbar-item,
+      .content kbd.navbar .navbar-end > .navbar-item,
+      .navbar.is-dark .navbar-end .navbar-link,
+      .content kbd.navbar .navbar-end .navbar-link {
+        color: whitesmoke; }
+      .navbar.is-dark .navbar-start > a.navbar-item:focus, .content kbd.navbar .navbar-start > a.navbar-item:focus, .navbar.is-dark .navbar-start > a.navbar-item:hover, .content kbd.navbar .navbar-start > a.navbar-item:hover, .navbar.is-dark .navbar-start > a.navbar-item.is-active, .content kbd.navbar .navbar-start > a.navbar-item.is-active,
+      .navbar.is-dark .navbar-start .navbar-link:focus,
+      .content kbd.navbar .navbar-start .navbar-link:focus,
+      .navbar.is-dark .navbar-start .navbar-link:hover,
+      .content kbd.navbar .navbar-start .navbar-link:hover,
+      .navbar.is-dark .navbar-start .navbar-link.is-active,
+      .content kbd.navbar .navbar-start .navbar-link.is-active,
+      .navbar.is-dark .navbar-end > a.navbar-item:focus,
+      .content kbd.navbar .navbar-end > a.navbar-item:focus,
+      .navbar.is-dark .navbar-end > a.navbar-item:hover,
+      .content kbd.navbar .navbar-end > a.navbar-item:hover,
+      .navbar.is-dark .navbar-end > a.navbar-item.is-active,
+      .content kbd.navbar .navbar-end > a.navbar-item.is-active,
+      .navbar.is-dark .navbar-end .navbar-link:focus,
+      .content kbd.navbar .navbar-end .navbar-link:focus,
+      .navbar.is-dark .navbar-end .navbar-link:hover,
+      .content kbd.navbar .navbar-end .navbar-link:hover,
+      .navbar.is-dark .navbar-end .navbar-link.is-active,
+      .content kbd.navbar .navbar-end .navbar-link.is-active {
+        background-color: #292929;
+        color: whitesmoke; }
+      .navbar.is-dark .navbar-start .navbar-link::after, .content kbd.navbar .navbar-start .navbar-link::after,
+      .navbar.is-dark .navbar-end .navbar-link::after,
+      .content kbd.navbar .navbar-end .navbar-link::after {
+        border-color: whitesmoke; }
+      .navbar.is-dark .navbar-item.has-dropdown:focus .navbar-link, .content kbd.navbar .navbar-item.has-dropdown:focus .navbar-link,
+      .navbar.is-dark .navbar-item.has-dropdown:hover .navbar-link,
+      .content kbd.navbar .navbar-item.has-dropdown:hover .navbar-link,
+      .navbar.is-dark .navbar-item.has-dropdown.is-active .navbar-link,
+      .content kbd.navbar .navbar-item.has-dropdown.is-active .navbar-link {
+        background-color: #292929;
+        color: whitesmoke; }
+      .navbar.is-dark .navbar-dropdown a.navbar-item.is-active, .content kbd.navbar .navbar-dropdown a.navbar-item.is-active {
+        background-color: #363636;
+        color: whitesmoke; } }
+  .navbar.is-primary, .docstring > section > a.navbar.docs-sourcelink {
+    background-color: #4eb5de;
+    color: #fff; }
+    .navbar.is-primary .navbar-brand > .navbar-item, .docstring > section > a.navbar.docs-sourcelink .navbar-brand > .navbar-item,
+    .navbar.is-primary .navbar-brand .navbar-link,
+    .docstring > section > a.navbar.docs-sourcelink .navbar-brand .navbar-link {
+      color: #fff; }
+    .navbar.is-primary .navbar-brand > a.navbar-item:focus, .docstring > section > a.navbar.docs-sourcelink .navbar-brand > a.navbar-item:focus, .navbar.is-primary .navbar-brand > a.navbar-item:hover, .docstring > section > a.navbar.docs-sourcelink .navbar-brand > a.navbar-item:hover, .navbar.is-primary .navbar-brand > a.navbar-item.is-active, .docstring > section > a.navbar.docs-sourcelink .navbar-brand > a.navbar-item.is-active,
+    .navbar.is-primary .navbar-brand .navbar-link:focus,
+    .docstring > section > a.navbar.docs-sourcelink .navbar-brand .navbar-link:focus,
+    .navbar.is-primary .navbar-brand .navbar-link:hover,
+    .docstring > section > a.navbar.docs-sourcelink .navbar-brand .navbar-link:hover,
+    .navbar.is-primary .navbar-brand .navbar-link.is-active,
+    .docstring > section > a.navbar.docs-sourcelink .navbar-brand .navbar-link.is-active {
+      background-color: #39acda;
+      color: #fff; }
+    .navbar.is-primary .navbar-brand .navbar-link::after, .docstring > section > a.navbar.docs-sourcelink .navbar-brand .navbar-link::after {
+      border-color: #fff; }
+    .navbar.is-primary .navbar-burger, .docstring > section > a.navbar.docs-sourcelink .navbar-burger {
+      color: #fff; }
+    @media screen and (min-width: 1056px) {
+      .navbar.is-primary .navbar-start > .navbar-item, .docstring > section > a.navbar.docs-sourcelink .navbar-start > .navbar-item,
+      .navbar.is-primary .navbar-start .navbar-link,
+      .docstring > section > a.navbar.docs-sourcelink .navbar-start .navbar-link,
+      .navbar.is-primary .navbar-end > .navbar-item,
+      .docstring > section > a.navbar.docs-sourcelink .navbar-end > .navbar-item,
+      .navbar.is-primary .navbar-end .navbar-link,
+      .docstring > section > a.navbar.docs-sourcelink .navbar-end .navbar-link {
+        color: #fff; }
+      .navbar.is-primary .navbar-start > a.navbar-item:focus, .docstring > section > a.navbar.docs-sourcelink .navbar-start > a.navbar-item:focus, .navbar.is-primary .navbar-start > a.navbar-item:hover, .docstring > section > a.navbar.docs-sourcelink .navbar-start > a.navbar-item:hover, .navbar.is-primary .navbar-start > a.navbar-item.is-active, .docstring > section > a.navbar.docs-sourcelink .navbar-start > a.navbar-item.is-active,
+      .navbar.is-primary .navbar-start .navbar-link:focus,
+      .docstring > section > a.navbar.docs-sourcelink .navbar-start .navbar-link:focus,
+      .navbar.is-primary .navbar-start .navbar-link:hover,
+      .docstring > section > a.navbar.docs-sourcelink .navbar-start .navbar-link:hover,
+      .navbar.is-primary .navbar-start .navbar-link.is-active,
+      .docstring > section > a.navbar.docs-sourcelink .navbar-start .navbar-link.is-active,
+      .navbar.is-primary .navbar-end > a.navbar-item:focus,
+      .docstring > section > a.navbar.docs-sourcelink .navbar-end > a.navbar-item:focus,
+      .navbar.is-primary .navbar-end > a.navbar-item:hover,
+      .docstring > section > a.navbar.docs-sourcelink .navbar-end > a.navbar-item:hover,
+      .navbar.is-primary .navbar-end > a.navbar-item.is-active,
+      .docstring > section > a.navbar.docs-sourcelink .navbar-end > a.navbar-item.is-active,
+      .navbar.is-primary .navbar-end .navbar-link:focus,
+      .docstring > section > a.navbar.docs-sourcelink .navbar-end .navbar-link:focus,
+      .navbar.is-primary .navbar-end .navbar-link:hover,
+      .docstring > section > a.navbar.docs-sourcelink .navbar-end .navbar-link:hover,
+      .navbar.is-primary .navbar-end .navbar-link.is-active,
+      .docstring > section > a.navbar.docs-sourcelink .navbar-end .navbar-link.is-active {
+        background-color: #39acda;
+        color: #fff; }
+      .navbar.is-primary .navbar-start .navbar-link::after, .docstring > section > a.navbar.docs-sourcelink .navbar-start .navbar-link::after,
+      .navbar.is-primary .navbar-end .navbar-link::after,
+      .docstring > section > a.navbar.docs-sourcelink .navbar-end .navbar-link::after {
+        border-color: #fff; }
+      .navbar.is-primary .navbar-item.has-dropdown:focus .navbar-link, .docstring > section > a.navbar.docs-sourcelink .navbar-item.has-dropdown:focus .navbar-link,
+      .navbar.is-primary .navbar-item.has-dropdown:hover .navbar-link,
+      .docstring > section > a.navbar.docs-sourcelink .navbar-item.has-dropdown:hover .navbar-link,
+      .navbar.is-primary .navbar-item.has-dropdown.is-active .navbar-link,
+      .docstring > section > a.navbar.docs-sourcelink .navbar-item.has-dropdown.is-active .navbar-link {
+        background-color: #39acda;
+        color: #fff; }
+      .navbar.is-primary .navbar-dropdown a.navbar-item.is-active, .docstring > section > a.navbar.docs-sourcelink .navbar-dropdown a.navbar-item.is-active {
+        background-color: #4eb5de;
+        color: #fff; } }
+  .navbar.is-link {
+    background-color: #2e63b8;
+    color: #fff; }
+    .navbar.is-link .navbar-brand > .navbar-item,
+    .navbar.is-link .navbar-brand .navbar-link {
+      color: #fff; }
+    .navbar.is-link .navbar-brand > a.navbar-item:focus, .navbar.is-link .navbar-brand > a.navbar-item:hover, .navbar.is-link .navbar-brand > a.navbar-item.is-active,
+    .navbar.is-link .navbar-brand .navbar-link:focus,
+    .navbar.is-link .navbar-brand .navbar-link:hover,
+    .navbar.is-link .navbar-brand .navbar-link.is-active {
+      background-color: #2958a4;
+      color: #fff; }
+    .navbar.is-link .navbar-brand .navbar-link::after {
+      border-color: #fff; }
+    .navbar.is-link .navbar-burger {
+      color: #fff; }
+    @media screen and (min-width: 1056px) {
+      .navbar.is-link .navbar-start > .navbar-item,
+      .navbar.is-link .navbar-start .navbar-link,
+      .navbar.is-link .navbar-end > .navbar-item,
+      .navbar.is-link .navbar-end .navbar-link {
+        color: #fff; }
+      .navbar.is-link .navbar-start > a.navbar-item:focus, .navbar.is-link .navbar-start > a.navbar-item:hover, .navbar.is-link .navbar-start > a.navbar-item.is-active,
+      .navbar.is-link .navbar-start .navbar-link:focus,
+      .navbar.is-link .navbar-start .navbar-link:hover,
+      .navbar.is-link .navbar-start .navbar-link.is-active,
+      .navbar.is-link .navbar-end > a.navbar-item:focus,
+      .navbar.is-link .navbar-end > a.navbar-item:hover,
+      .navbar.is-link .navbar-end > a.navbar-item.is-active,
+      .navbar.is-link .navbar-end .navbar-link:focus,
+      .navbar.is-link .navbar-end .navbar-link:hover,
+      .navbar.is-link .navbar-end .navbar-link.is-active {
+        background-color: #2958a4;
+        color: #fff; }
+      .navbar.is-link .navbar-start .navbar-link::after,
+      .navbar.is-link .navbar-end .navbar-link::after {
+        border-color: #fff; }
+      .navbar.is-link .navbar-item.has-dropdown:focus .navbar-link,
+      .navbar.is-link .navbar-item.has-dropdown:hover .navbar-link,
+      .navbar.is-link .navbar-item.has-dropdown.is-active .navbar-link {
+        background-color: #2958a4;
+        color: #fff; }
+      .navbar.is-link .navbar-dropdown a.navbar-item.is-active {
+        background-color: #2e63b8;
+        color: #fff; } }
+  .navbar.is-info {
+    background-color: #209cee;
+    color: #fff; }
+    .navbar.is-info .navbar-brand > .navbar-item,
+    .navbar.is-info .navbar-brand .navbar-link {
+      color: #fff; }
+    .navbar.is-info .navbar-brand > a.navbar-item:focus, .navbar.is-info .navbar-brand > a.navbar-item:hover, .navbar.is-info .navbar-brand > a.navbar-item.is-active,
+    .navbar.is-info .navbar-brand .navbar-link:focus,
+    .navbar.is-info .navbar-brand .navbar-link:hover,
+    .navbar.is-info .navbar-brand .navbar-link.is-active {
+      background-color: #118fe4;
+      color: #fff; }
+    .navbar.is-info .navbar-brand .navbar-link::after {
+      border-color: #fff; }
+    .navbar.is-info .navbar-burger {
+      color: #fff; }
+    @media screen and (min-width: 1056px) {
+      .navbar.is-info .navbar-start > .navbar-item,
+      .navbar.is-info .navbar-start .navbar-link,
+      .navbar.is-info .navbar-end > .navbar-item,
+      .navbar.is-info .navbar-end .navbar-link {
+        color: #fff; }
+      .navbar.is-info .navbar-start > a.navbar-item:focus, .navbar.is-info .navbar-start > a.navbar-item:hover, .navbar.is-info .navbar-start > a.navbar-item.is-active,
+      .navbar.is-info .navbar-start .navbar-link:focus,
+      .navbar.is-info .navbar-start .navbar-link:hover,
+      .navbar.is-info .navbar-start .navbar-link.is-active,
+      .navbar.is-info .navbar-end > a.navbar-item:focus,
+      .navbar.is-info .navbar-end > a.navbar-item:hover,
+      .navbar.is-info .navbar-end > a.navbar-item.is-active,
+      .navbar.is-info .navbar-end .navbar-link:focus,
+      .navbar.is-info .navbar-end .navbar-link:hover,
+      .navbar.is-info .navbar-end .navbar-link.is-active {
+        background-color: #118fe4;
+        color: #fff; }
+      .navbar.is-info .navbar-start .navbar-link::after,
+      .navbar.is-info .navbar-end .navbar-link::after {
+        border-color: #fff; }
+      .navbar.is-info .navbar-item.has-dropdown:focus .navbar-link,
+      .navbar.is-info .navbar-item.has-dropdown:hover .navbar-link,
+      .navbar.is-info .navbar-item.has-dropdown.is-active .navbar-link {
+        background-color: #118fe4;
+        color: #fff; }
+      .navbar.is-info .navbar-dropdown a.navbar-item.is-active {
+        background-color: #209cee;
+        color: #fff; } }
+  .navbar.is-success {
+    background-color: #22c35b;
+    color: #fff; }
+    .navbar.is-success .navbar-brand > .navbar-item,
+    .navbar.is-success .navbar-brand .navbar-link {
+      color: #fff; }
+    .navbar.is-success .navbar-brand > a.navbar-item:focus, .navbar.is-success .navbar-brand > a.navbar-item:hover, .navbar.is-success .navbar-brand > a.navbar-item.is-active,
+    .navbar.is-success .navbar-brand .navbar-link:focus,
+    .navbar.is-success .navbar-brand .navbar-link:hover,
+    .navbar.is-success .navbar-brand .navbar-link.is-active {
+      background-color: #1ead51;
+      color: #fff; }
+    .navbar.is-success .navbar-brand .navbar-link::after {
+      border-color: #fff; }
+    .navbar.is-success .navbar-burger {
+      color: #fff; }
+    @media screen and (min-width: 1056px) {
+      .navbar.is-success .navbar-start > .navbar-item,
+      .navbar.is-success .navbar-start .navbar-link,
+      .navbar.is-success .navbar-end > .navbar-item,
+      .navbar.is-success .navbar-end .navbar-link {
+        color: #fff; }
+      .navbar.is-success .navbar-start > a.navbar-item:focus, .navbar.is-success .navbar-start > a.navbar-item:hover, .navbar.is-success .navbar-start > a.navbar-item.is-active,
+      .navbar.is-success .navbar-start .navbar-link:focus,
+      .navbar.is-success .navbar-start .navbar-link:hover,
+      .navbar.is-success .navbar-start .navbar-link.is-active,
+      .navbar.is-success .navbar-end > a.navbar-item:focus,
+      .navbar.is-success .navbar-end > a.navbar-item:hover,
+      .navbar.is-success .navbar-end > a.navbar-item.is-active,
+      .navbar.is-success .navbar-end .navbar-link:focus,
+      .navbar.is-success .navbar-end .navbar-link:hover,
+      .navbar.is-success .navbar-end .navbar-link.is-active {
+        background-color: #1ead51;
+        color: #fff; }
+      .navbar.is-success .navbar-start .navbar-link::after,
+      .navbar.is-success .navbar-end .navbar-link::after {
+        border-color: #fff; }
+      .navbar.is-success .navbar-item.has-dropdown:focus .navbar-link,
+      .navbar.is-success .navbar-item.has-dropdown:hover .navbar-link,
+      .navbar.is-success .navbar-item.has-dropdown.is-active .navbar-link {
+        background-color: #1ead51;
+        color: #fff; }
+      .navbar.is-success .navbar-dropdown a.navbar-item.is-active {
+        background-color: #22c35b;
+        color: #fff; } }
+  .navbar.is-warning {
+    background-color: #ffdd57;
+    color: rgba(0, 0, 0, 0.7); }
+    .navbar.is-warning .navbar-brand > .navbar-item,
+    .navbar.is-warning .navbar-brand .navbar-link {
+      color: rgba(0, 0, 0, 0.7); }
+    .navbar.is-warning .navbar-brand > a.navbar-item:focus, .navbar.is-warning .navbar-brand > a.navbar-item:hover, .navbar.is-warning .navbar-brand > a.navbar-item.is-active,
+    .navbar.is-warning .navbar-brand .navbar-link:focus,
+    .navbar.is-warning .navbar-brand .navbar-link:hover,
+    .navbar.is-warning .navbar-brand .navbar-link.is-active {
+      background-color: #ffd83d;
+      color: rgba(0, 0, 0, 0.7); }
+    .navbar.is-warning .navbar-brand .navbar-link::after {
+      border-color: rgba(0, 0, 0, 0.7); }
+    .navbar.is-warning .navbar-burger {
+      color: rgba(0, 0, 0, 0.7); }
+    @media screen and (min-width: 1056px) {
+      .navbar.is-warning .navbar-start > .navbar-item,
+      .navbar.is-warning .navbar-start .navbar-link,
+      .navbar.is-warning .navbar-end > .navbar-item,
+      .navbar.is-warning .navbar-end .navbar-link {
+        color: rgba(0, 0, 0, 0.7); }
+      .navbar.is-warning .navbar-start > a.navbar-item:focus, .navbar.is-warning .navbar-start > a.navbar-item:hover, .navbar.is-warning .navbar-start > a.navbar-item.is-active,
+      .navbar.is-warning .navbar-start .navbar-link:focus,
+      .navbar.is-warning .navbar-start .navbar-link:hover,
+      .navbar.is-warning .navbar-start .navbar-link.is-active,
+      .navbar.is-warning .navbar-end > a.navbar-item:focus,
+      .navbar.is-warning .navbar-end > a.navbar-item:hover,
+      .navbar.is-warning .navbar-end > a.navbar-item.is-active,
+      .navbar.is-warning .navbar-end .navbar-link:focus,
+      .navbar.is-warning .navbar-end .navbar-link:hover,
+      .navbar.is-warning .navbar-end .navbar-link.is-active {
+        background-color: #ffd83d;
+        color: rgba(0, 0, 0, 0.7); }
+      .navbar.is-warning .navbar-start .navbar-link::after,
+      .navbar.is-warning .navbar-end .navbar-link::after {
+        border-color: rgba(0, 0, 0, 0.7); }
+      .navbar.is-warning .navbar-item.has-dropdown:focus .navbar-link,
+      .navbar.is-warning .navbar-item.has-dropdown:hover .navbar-link,
+      .navbar.is-warning .navbar-item.has-dropdown.is-active .navbar-link {
+        background-color: #ffd83d;
+        color: rgba(0, 0, 0, 0.7); }
+      .navbar.is-warning .navbar-dropdown a.navbar-item.is-active {
+        background-color: #ffdd57;
+        color: rgba(0, 0, 0, 0.7); } }
+  .navbar.is-danger {
+    background-color: #da0b00;
+    color: #fff; }
+    .navbar.is-danger .navbar-brand > .navbar-item,
+    .navbar.is-danger .navbar-brand .navbar-link {
+      color: #fff; }
+    .navbar.is-danger .navbar-brand > a.navbar-item:focus, .navbar.is-danger .navbar-brand > a.navbar-item:hover, .navbar.is-danger .navbar-brand > a.navbar-item.is-active,
+    .navbar.is-danger .navbar-brand .navbar-link:focus,
+    .navbar.is-danger .navbar-brand .navbar-link:hover,
+    .navbar.is-danger .navbar-brand .navbar-link.is-active {
+      background-color: #c10a00;
+      color: #fff; }
+    .navbar.is-danger .navbar-brand .navbar-link::after {
+      border-color: #fff; }
+    .navbar.is-danger .navbar-burger {
+      color: #fff; }
+    @media screen and (min-width: 1056px) {
+      .navbar.is-danger .navbar-start > .navbar-item,
+      .navbar.is-danger .navbar-start .navbar-link,
+      .navbar.is-danger .navbar-end > .navbar-item,
+      .navbar.is-danger .navbar-end .navbar-link {
+        color: #fff; }
+      .navbar.is-danger .navbar-start > a.navbar-item:focus, .navbar.is-danger .navbar-start > a.navbar-item:hover, .navbar.is-danger .navbar-start > a.navbar-item.is-active,
+      .navbar.is-danger .navbar-start .navbar-link:focus,
+      .navbar.is-danger .navbar-start .navbar-link:hover,
+      .navbar.is-danger .navbar-start .navbar-link.is-active,
+      .navbar.is-danger .navbar-end > a.navbar-item:focus,
+      .navbar.is-danger .navbar-end > a.navbar-item:hover,
+      .navbar.is-danger .navbar-end > a.navbar-item.is-active,
+      .navbar.is-danger .navbar-end .navbar-link:focus,
+      .navbar.is-danger .navbar-end .navbar-link:hover,
+      .navbar.is-danger .navbar-end .navbar-link.is-active {
+        background-color: #c10a00;
+        color: #fff; }
+      .navbar.is-danger .navbar-start .navbar-link::after,
+      .navbar.is-danger .navbar-end .navbar-link::after {
+        border-color: #fff; }
+      .navbar.is-danger .navbar-item.has-dropdown:focus .navbar-link,
+      .navbar.is-danger .navbar-item.has-dropdown:hover .navbar-link,
+      .navbar.is-danger .navbar-item.has-dropdown.is-active .navbar-link {
+        background-color: #c10a00;
+        color: #fff; }
+      .navbar.is-danger .navbar-dropdown a.navbar-item.is-active {
+        background-color: #da0b00;
+        color: #fff; } }
+  .navbar > .container {
+    align-items: stretch;
+    display: flex;
+    min-height: 3.25rem;
+    width: 100%; }
+  .navbar.has-shadow {
+    box-shadow: 0 2px 0 0 whitesmoke; }
+  .navbar.is-fixed-bottom, .navbar.is-fixed-top {
+    left: 0;
+    position: fixed;
+    right: 0;
+    z-index: 30; }
+  .navbar.is-fixed-bottom {
+    bottom: 0; }
+    .navbar.is-fixed-bottom.has-shadow {
+      box-shadow: 0 -2px 0 0 whitesmoke; }
+  .navbar.is-fixed-top {
+    top: 0; }
+
+html.has-navbar-fixed-top,
+body.has-navbar-fixed-top {
+  padding-top: 3.25rem; }
+
+html.has-navbar-fixed-bottom,
+body.has-navbar-fixed-bottom {
+  padding-bottom: 3.25rem; }
+
+.navbar-brand,
+.navbar-tabs {
+  align-items: stretch;
+  display: flex;
+  flex-shrink: 0;
+  min-height: 3.25rem; }
+
+.navbar-brand a.navbar-item:focus, .navbar-brand a.navbar-item:hover {
+  background-color: transparent; }
+
+.navbar-tabs {
+  -webkit-overflow-scrolling: touch;
+  max-width: 100vw;
+  overflow-x: auto;
+  overflow-y: hidden; }
+
+.navbar-burger {
+  color: #4a4a4a;
+  cursor: pointer;
+  display: block;
+  height: 3.25rem;
+  position: relative;
+  width: 3.25rem;
+  margin-left: auto; }
+  .navbar-burger span {
+    background-color: currentColor;
+    display: block;
+    height: 1px;
+    left: calc(50% - 8px);
+    position: absolute;
+    transform-origin: center;
+    transition-duration: 86ms;
+    transition-property: background-color, opacity, transform;
+    transition-timing-function: ease-out;
+    width: 16px; }
+    .navbar-burger span:nth-child(1) {
+      top: calc(50% - 6px); }
+    .navbar-burger span:nth-child(2) {
+      top: calc(50% - 1px); }
+    .navbar-burger span:nth-child(3) {
+      top: calc(50% + 4px); }
+  .navbar-burger:hover {
+    background-color: rgba(0, 0, 0, 0.05); }
+  .navbar-burger.is-active span:nth-child(1) {
+    transform: translateY(5px) rotate(45deg); }
+  .navbar-burger.is-active span:nth-child(2) {
+    opacity: 0; }
+  .navbar-burger.is-active span:nth-child(3) {
+    transform: translateY(-5px) rotate(-45deg); }
+
+.navbar-menu {
+  display: none; }
+
+.navbar-item,
+.navbar-link {
+  color: #4a4a4a;
+  display: block;
+  line-height: 1.5;
+  padding: 0.5rem 0.75rem;
+  position: relative; }
+  .navbar-item .icon:only-child,
+  .navbar-link .icon:only-child {
+    margin-left: -0.25rem;
+    margin-right: -0.25rem; }
+
+a.navbar-item,
+.navbar-link {
+  cursor: pointer; }
+  a.navbar-item:focus, a.navbar-item:focus-within, a.navbar-item:hover, a.navbar-item.is-active,
+  .navbar-link:focus,
+  .navbar-link:focus-within,
+  .navbar-link:hover,
+  .navbar-link.is-active {
+    background-color: #fafafa;
+    color: #2e63b8; }
+
+.navbar-item {
+  display: block;
+  flex-grow: 0;
+  flex-shrink: 0; }
+  .navbar-item img {
+    max-height: 1.75rem; }
+  .navbar-item.has-dropdown {
+    padding: 0; }
+  .navbar-item.is-expanded {
+    flex-grow: 1;
+    flex-shrink: 1; }
+  .navbar-item.is-tab {
+    border-bottom: 1px solid transparent;
+    min-height: 3.25rem;
+    padding-bottom: calc(0.5rem - 1px); }
+    .navbar-item.is-tab:focus, .navbar-item.is-tab:hover {
+      background-color: transparent;
+      border-bottom-color: #2e63b8; }
+    .navbar-item.is-tab.is-active {
+      background-color: transparent;
+      border-bottom-color: #2e63b8;
+      border-bottom-style: solid;
+      border-bottom-width: 3px;
+      color: #2e63b8;
+      padding-bottom: calc(0.5rem - 3px); }
+
+.navbar-content {
+  flex-grow: 1;
+  flex-shrink: 1; }
+
+.navbar-link:not(.is-arrowless) {
+  padding-right: 2.5em; }
+  .navbar-link:not(.is-arrowless)::after {
+    border-color: #2e63b8;
+    margin-top: -0.375em;
+    right: 1.125em; }
+
+.navbar-dropdown {
+  font-size: 0.875rem;
+  padding-bottom: 0.5rem;
+  padding-top: 0.5rem; }
+  .navbar-dropdown .navbar-item {
+    padding-left: 1.5rem;
+    padding-right: 1.5rem; }
+
+.navbar-divider {
+  background-color: whitesmoke;
+  border: none;
+  display: none;
+  height: 2px;
+  margin: 0.5rem 0; }
+
+@media screen and (max-width: 1055px) {
+  .navbar > .container {
+    display: block; }
+  .navbar-brand .navbar-item,
+  .navbar-tabs .navbar-item {
+    align-items: center;
+    display: flex; }
+  .navbar-link::after {
+    display: none; }
+  .navbar-menu {
+    background-color: white;
+    box-shadow: 0 8px 16px rgba(10, 10, 10, 0.1);
+    padding: 0.5rem 0; }
+    .navbar-menu.is-active {
+      display: block; }
+  .navbar.is-fixed-bottom-touch, .navbar.is-fixed-top-touch {
+    left: 0;
+    position: fixed;
+    right: 0;
+    z-index: 30; }
+  .navbar.is-fixed-bottom-touch {
+    bottom: 0; }
+    .navbar.is-fixed-bottom-touch.has-shadow {
+      box-shadow: 0 -2px 3px rgba(10, 10, 10, 0.1); }
+  .navbar.is-fixed-top-touch {
+    top: 0; }
+  .navbar.is-fixed-top .navbar-menu, .navbar.is-fixed-top-touch .navbar-menu {
+    -webkit-overflow-scrolling: touch;
+    max-height: calc(100vh - 3.25rem);
+    overflow: auto; }
+  html.has-navbar-fixed-top-touch,
+  body.has-navbar-fixed-top-touch {
+    padding-top: 3.25rem; }
+  html.has-navbar-fixed-bottom-touch,
+  body.has-navbar-fixed-bottom-touch {
+    padding-bottom: 3.25rem; } }
+
+@media screen and (min-width: 1056px) {
+  .navbar,
+  .navbar-menu,
+  .navbar-start,
+  .navbar-end {
+    align-items: stretch;
+    display: flex; }
+  .navbar {
+    min-height: 3.25rem; }
+    .navbar.is-spaced {
+      padding: 1rem 2rem; }
+      .navbar.is-spaced .navbar-start,
+      .navbar.is-spaced .navbar-end {
+        align-items: center; }
+      .navbar.is-spaced a.navbar-item,
+      .navbar.is-spaced .navbar-link {
+        border-radius: 4px; }
+    .navbar.is-transparent a.navbar-item:focus, .navbar.is-transparent a.navbar-item:hover, .navbar.is-transparent a.navbar-item.is-active,
+    .navbar.is-transparent .navbar-link:focus,
+    .navbar.is-transparent .navbar-link:hover,
+    .navbar.is-transparent .navbar-link.is-active {
+      background-color: transparent !important; }
+    .navbar.is-transparent .navbar-item.has-dropdown.is-active .navbar-link, .navbar.is-transparent .navbar-item.has-dropdown.is-hoverable:focus .navbar-link, .navbar.is-transparent .navbar-item.has-dropdown.is-hoverable:focus-within .navbar-link, .navbar.is-transparent .navbar-item.has-dropdown.is-hoverable:hover .navbar-link {
+      background-color: transparent !important; }
+    .navbar.is-transparent .navbar-dropdown a.navbar-item:focus, .navbar.is-transparent .navbar-dropdown a.navbar-item:hover {
+      background-color: whitesmoke;
+      color: #0a0a0a; }
+    .navbar.is-transparent .navbar-dropdown a.navbar-item.is-active {
+      background-color: whitesmoke;
+      color: #2e63b8; }
+  .navbar-burger {
+    display: none; }
+  .navbar-item,
+  .navbar-link {
+    align-items: center;
+    display: flex; }
+  .navbar-item {
+    display: flex; }
+    .navbar-item.has-dropdown {
+      align-items: stretch; }
+    .navbar-item.has-dropdown-up .navbar-link::after {
+      transform: rotate(135deg) translate(0.25em, -0.25em); }
+    .navbar-item.has-dropdown-up .navbar-dropdown {
+      border-bottom: 2px solid #dbdbdb;
+      border-radius: 6px 6px 0 0;
+      border-top: none;
+      bottom: 100%;
+      box-shadow: 0 -8px 8px rgba(10, 10, 10, 0.1);
+      top: auto; }
+    .navbar-item.is-active .navbar-dropdown, .navbar-item.is-hoverable:focus .navbar-dropdown, .navbar-item.is-hoverable:focus-within .navbar-dropdown, .navbar-item.is-hoverable:hover .navbar-dropdown {
+      display: block; }
+      .navbar.is-spaced .navbar-item.is-active .navbar-dropdown, .navbar-item.is-active .navbar-dropdown.is-boxed, .navbar.is-spaced .navbar-item.is-hoverable:focus .navbar-dropdown, .navbar-item.is-hoverable:focus .navbar-dropdown.is-boxed, .navbar.is-spaced .navbar-item.is-hoverable:focus-within .navbar-dropdown, .navbar-item.is-hoverable:focus-within .navbar-dropdown.is-boxed, .navbar.is-spaced .navbar-item.is-hoverable:hover .navbar-dropdown, .navbar-item.is-hoverable:hover .navbar-dropdown.is-boxed {
+        opacity: 1;
+        pointer-events: auto;
+        transform: translateY(0); }
+  .navbar-menu {
+    flex-grow: 1;
+    flex-shrink: 0; }
+  .navbar-start {
+    justify-content: flex-start;
+    margin-right: auto; }
+  .navbar-end {
+    justify-content: flex-end;
+    margin-left: auto; }
+  .navbar-dropdown {
+    background-color: white;
+    border-bottom-left-radius: 6px;
+    border-bottom-right-radius: 6px;
+    border-top: 2px solid #dbdbdb;
+    box-shadow: 0 8px 8px rgba(10, 10, 10, 0.1);
+    display: none;
+    font-size: 0.875rem;
+    left: 0;
+    min-width: 100%;
+    position: absolute;
+    top: 100%;
+    z-index: 20; }
+    .navbar-dropdown .navbar-item {
+      padding: 0.375rem 1rem;
+      white-space: nowrap; }
+    .navbar-dropdown a.navbar-item {
+      padding-right: 3rem; }
+      .navbar-dropdown a.navbar-item:focus, .navbar-dropdown a.navbar-item:hover {
+        background-color: whitesmoke;
+        color: #0a0a0a; }
+      .navbar-dropdown a.navbar-item.is-active {
+        background-color: whitesmoke;
+        color: #2e63b8; }
+    .navbar.is-spaced .navbar-dropdown, .navbar-dropdown.is-boxed {
+      border-radius: 6px;
+      border-top: none;
+      box-shadow: 0 8px 8px rgba(10, 10, 10, 0.1), 0 0 0 1px rgba(10, 10, 10, 0.1);
+      display: block;
+      opacity: 0;
+      pointer-events: none;
+      top: calc(100% + (-4px));
+      transform: translateY(-5px);
+      transition-duration: 86ms;
+      transition-property: opacity, transform; }
+    .navbar-dropdown.is-right {
+      left: auto;
+      right: 0; }
+  .navbar-divider {
+    display: block; }
+  .navbar > .container .navbar-brand,
+  .container > .navbar .navbar-brand {
+    margin-left: -.75rem; }
+  .navbar > .container .navbar-menu,
+  .container > .navbar .navbar-menu {
+    margin-right: -.75rem; }
+  .navbar.is-fixed-bottom-desktop, .navbar.is-fixed-top-desktop {
+    left: 0;
+    position: fixed;
+    right: 0;
+    z-index: 30; }
+  .navbar.is-fixed-bottom-desktop {
+    bottom: 0; }
+    .navbar.is-fixed-bottom-desktop.has-shadow {
+      box-shadow: 0 -2px 3px rgba(10, 10, 10, 0.1); }
+  .navbar.is-fixed-top-desktop {
+    top: 0; }
+  html.has-navbar-fixed-top-desktop,
+  body.has-navbar-fixed-top-desktop {
+    padding-top: 3.25rem; }
+  html.has-navbar-fixed-bottom-desktop,
+  body.has-navbar-fixed-bottom-desktop {
+    padding-bottom: 3.25rem; }
+  html.has-spaced-navbar-fixed-top,
+  body.has-spaced-navbar-fixed-top {
+    padding-top: 5.25rem; }
+  html.has-spaced-navbar-fixed-bottom,
+  body.has-spaced-navbar-fixed-bottom {
+    padding-bottom: 5.25rem; }
+  a.navbar-item.is-active,
+  .navbar-link.is-active {
+    color: #0a0a0a; }
+  a.navbar-item.is-active:not(:focus):not(:hover),
+  .navbar-link.is-active:not(:focus):not(:hover) {
+    background-color: transparent; }
+  .navbar-item.has-dropdown:focus .navbar-link, .navbar-item.has-dropdown:hover .navbar-link, .navbar-item.has-dropdown.is-active .navbar-link {
+    background-color: #fafafa; } }
+
+.hero.is-fullheight-with-navbar {
+  min-height: calc(100vh - 3.25rem); }
+
+.pagination {
+  font-size: 1rem;
+  margin: -0.25rem; }
+  .pagination.is-small, #documenter .docs-sidebar form.docs-search > input.pagination {
+    font-size: 0.75rem; }
+  .pagination.is-medium {
+    font-size: 1.25rem; }
+  .pagination.is-large {
+    font-size: 1.5rem; }
+  .pagination.is-rounded .pagination-previous, #documenter .docs-sidebar form.docs-search > input.pagination .pagination-previous,
+  .pagination.is-rounded .pagination-next,
+  #documenter .docs-sidebar form.docs-search > input.pagination .pagination-next {
+    padding-left: 1em;
+    padding-right: 1em;
+    border-radius: 290486px; }
+  .pagination.is-rounded .pagination-link, #documenter .docs-sidebar form.docs-search > input.pagination .pagination-link {
+    border-radius: 290486px; }
+
+.pagination,
+.pagination-list {
+  align-items: center;
+  display: flex;
+  justify-content: center;
+  text-align: center; }
+
+.pagination-previous,
+.pagination-next,
+.pagination-link,
+.pagination-ellipsis {
+  font-size: 1em;
+  justify-content: center;
+  margin: 0.25rem;
+  padding-left: 0.5em;
+  padding-right: 0.5em;
+  text-align: center; }
+
+.pagination-previous,
+.pagination-next,
+.pagination-link {
+  border-color: #dbdbdb;
+  color: #363636;
+  min-width: 2.25em; }
+  .pagination-previous:hover,
+  .pagination-next:hover,
+  .pagination-link:hover {
+    border-color: #b5b5b5;
+    color: #363636; }
+  .pagination-previous:focus,
+  .pagination-next:focus,
+  .pagination-link:focus {
+    border-color: #2e63b8; }
+  .pagination-previous:active,
+  .pagination-next:active,
+  .pagination-link:active {
+    box-shadow: inset 0 1px 2px rgba(10, 10, 10, 0.2); }
+  .pagination-previous[disabled],
+  .pagination-next[disabled],
+  .pagination-link[disabled] {
+    background-color: #dbdbdb;
+    border-color: #dbdbdb;
+    box-shadow: none;
+    color: #7a7a7a;
+    opacity: 0.5; }
+
+.pagination-previous,
+.pagination-next {
+  padding-left: 0.75em;
+  padding-right: 0.75em;
+  white-space: nowrap; }
+
+.pagination-link.is-current {
+  background-color: #2e63b8;
+  border-color: #2e63b8;
+  color: #fff; }
+
+.pagination-ellipsis {
+  color: #b5b5b5;
+  pointer-events: none; }
+
+.pagination-list {
+  flex-wrap: wrap; }
+
+@media screen and (max-width: 768px) {
+  .pagination {
+    flex-wrap: wrap; }
+  .pagination-previous,
+  .pagination-next {
+    flex-grow: 1;
+    flex-shrink: 1; }
+  .pagination-list li {
+    flex-grow: 1;
+    flex-shrink: 1; } }
+
+@media screen and (min-width: 769px), print {
+  .pagination-list {
+    flex-grow: 1;
+    flex-shrink: 1;
+    justify-content: flex-start;
+    order: 1; }
+  .pagination-previous {
+    order: 2; }
+  .pagination-next {
+    order: 3; }
+  .pagination {
+    justify-content: space-between; }
+    .pagination.is-centered .pagination-previous {
+      order: 1; }
+    .pagination.is-centered .pagination-list {
+      justify-content: center;
+      order: 2; }
+    .pagination.is-centered .pagination-next {
+      order: 3; }
+    .pagination.is-right .pagination-previous {
+      order: 1; }
+    .pagination.is-right .pagination-next {
+      order: 2; }
+    .pagination.is-right .pagination-list {
+      justify-content: flex-end;
+      order: 3; } }
+
+.panel {
+  font-size: 1rem; }
+  .panel:not(:last-child) {
+    margin-bottom: 1.5rem; }
+
+.panel-heading,
+.panel-tabs,
+.panel-block {
+  border-bottom: 1px solid #dbdbdb;
+  border-left: 1px solid #dbdbdb;
+  border-right: 1px solid #dbdbdb; }
+  .panel-heading:first-child,
+  .panel-tabs:first-child,
+  .panel-block:first-child {
+    border-top: 1px solid #dbdbdb; }
+
+.panel-heading {
+  background-color: whitesmoke;
+  border-radius: 4px 4px 0 0;
+  color: #222222;
+  font-size: 1.25em;
+  font-weight: 300;
+  line-height: 1.25;
+  padding: 0.5em 0.75em; }
+
+.panel-tabs {
+  align-items: flex-end;
+  display: flex;
+  font-size: 0.875em;
+  justify-content: center; }
+  .panel-tabs a {
+    border-bottom: 1px solid #dbdbdb;
+    margin-bottom: -1px;
+    padding: 0.5em; }
+    .panel-tabs a.is-active {
+      border-bottom-color: #4a4a4a;
+      color: #363636; }
+
+.panel-list a {
+  color: #222222; }
+  .panel-list a:hover {
+    color: #2e63b8; }
+
+.panel-block {
+  align-items: center;
+  color: #222222;
+  display: flex;
+  justify-content: flex-start;
+  padding: 0.5em 0.75em; }
+  .panel-block input[type="checkbox"] {
+    margin-right: 0.75em; }
+  .panel-block > .control {
+    flex-grow: 1;
+    flex-shrink: 1;
+    width: 100%; }
+  .panel-block.is-wrapped {
+    flex-wrap: wrap; }
+  .panel-block.is-active {
+    border-left-color: #2e63b8;
+    color: #363636; }
+    .panel-block.is-active .panel-icon {
+      color: #2e63b8; }
+
+a.panel-block,
+label.panel-block {
+  cursor: pointer; }
+  a.panel-block:hover,
+  label.panel-block:hover {
+    background-color: whitesmoke; }
+
+.panel-icon {
+  display: inline-block;
+  font-size: 14px;
+  height: 1em;
+  line-height: 1em;
+  text-align: center;
+  vertical-align: top;
+  width: 1em;
+  color: #7a7a7a;
+  margin-right: 0.75em; }
+  .panel-icon .fa {
+    font-size: inherit;
+    line-height: inherit; }
+
+.tabs {
+  -webkit-overflow-scrolling: touch;
+  align-items: stretch;
+  display: flex;
+  font-size: 1rem;
+  justify-content: space-between;
+  overflow: hidden;
+  overflow-x: auto;
+  white-space: nowrap; }
+  .tabs a {
+    align-items: center;
+    border-bottom-color: #dbdbdb;
+    border-bottom-style: solid;
+    border-bottom-width: 1px;
+    color: #222222;
+    display: flex;
+    justify-content: center;
+    margin-bottom: -1px;
+    padding: 0.5em 1em;
+    vertical-align: top; }
+    .tabs a:hover {
+      border-bottom-color: #222222;
+      color: #222222; }
+  .tabs li {
+    display: block; }
+    .tabs li.is-active a {
+      border-bottom-color: #2e63b8;
+      color: #2e63b8; }
+  .tabs ul {
+    align-items: center;
+    border-bottom-color: #dbdbdb;
+    border-bottom-style: solid;
+    border-bottom-width: 1px;
+    display: flex;
+    flex-grow: 1;
+    flex-shrink: 0;
+    justify-content: flex-start; }
+    .tabs ul.is-left {
+      padding-right: 0.75em; }
+    .tabs ul.is-center {
+      flex: none;
+      justify-content: center;
+      padding-left: 0.75em;
+      padding-right: 0.75em; }
+    .tabs ul.is-right {
+      justify-content: flex-end;
+      padding-left: 0.75em; }
+  .tabs .icon:first-child {
+    margin-right: 0.5em; }
+  .tabs .icon:last-child {
+    margin-left: 0.5em; }
+  .tabs.is-centered ul {
+    justify-content: center; }
+  .tabs.is-right ul {
+    justify-content: flex-end; }
+  .tabs.is-boxed a {
+    border: 1px solid transparent;
+    border-radius: 4px 4px 0 0; }
+    .tabs.is-boxed a:hover {
+      background-color: whitesmoke;
+      border-bottom-color: #dbdbdb; }
+  .tabs.is-boxed li.is-active a {
+    background-color: white;
+    border-color: #dbdbdb;
+    border-bottom-color: transparent !important; }
+  .tabs.is-fullwidth li {
+    flex-grow: 1;
+    flex-shrink: 0; }
+  .tabs.is-toggle a {
+    border-color: #dbdbdb;
+    border-style: solid;
+    border-width: 1px;
+    margin-bottom: 0;
+    position: relative; }
+    .tabs.is-toggle a:hover {
+      background-color: whitesmoke;
+      border-color: #b5b5b5;
+      z-index: 2; }
+  .tabs.is-toggle li + li {
+    margin-left: -1px; }
+  .tabs.is-toggle li:first-child a {
+    border-radius: 4px 0 0 4px; }
+  .tabs.is-toggle li:last-child a {
+    border-radius: 0 4px 4px 0; }
+  .tabs.is-toggle li.is-active a {
+    background-color: #2e63b8;
+    border-color: #2e63b8;
+    color: #fff;
+    z-index: 1; }
+  .tabs.is-toggle ul {
+    border-bottom: none; }
+  .tabs.is-toggle.is-toggle-rounded li:first-child a {
+    border-bottom-left-radius: 290486px;
+    border-top-left-radius: 290486px;
+    padding-left: 1.25em; }
+  .tabs.is-toggle.is-toggle-rounded li:last-child a {
+    border-bottom-right-radius: 290486px;
+    border-top-right-radius: 290486px;
+    padding-right: 1.25em; }
+  .tabs.is-small, #documenter .docs-sidebar form.docs-search > input.tabs {
+    font-size: 0.75rem; }
+  .tabs.is-medium {
+    font-size: 1.25rem; }
+  .tabs.is-large {
+    font-size: 1.5rem; }
+
+.column {
+  display: block;
+  flex-basis: 0;
+  flex-grow: 1;
+  flex-shrink: 1;
+  padding: 0.75rem; }
+  .columns.is-mobile > .column.is-narrow {
+    flex: none; }
+  .columns.is-mobile > .column.is-full {
+    flex: none;
+    width: 100%; }
+  .columns.is-mobile > .column.is-three-quarters {
+    flex: none;
+    width: 75%; }
+  .columns.is-mobile > .column.is-two-thirds {
+    flex: none;
+    width: 66.6666%; }
+  .columns.is-mobile > .column.is-half {
+    flex: none;
+    width: 50%; }
+  .columns.is-mobile > .column.is-one-third {
+    flex: none;
+    width: 33.3333%; }
+  .columns.is-mobile > .column.is-one-quarter {
+    flex: none;
+    width: 25%; }
+  .columns.is-mobile > .column.is-one-fifth {
+    flex: none;
+    width: 20%; }
+  .columns.is-mobile > .column.is-two-fifths {
+    flex: none;
+    width: 40%; }
+  .columns.is-mobile > .column.is-three-fifths {
+    flex: none;
+    width: 60%; }
+  .columns.is-mobile > .column.is-four-fifths {
+    flex: none;
+    width: 80%; }
+  .columns.is-mobile > .column.is-offset-three-quarters {
+    margin-left: 75%; }
+  .columns.is-mobile > .column.is-offset-two-thirds {
+    margin-left: 66.6666%; }
+  .columns.is-mobile > .column.is-offset-half {
+    margin-left: 50%; }
+  .columns.is-mobile > .column.is-offset-one-third {
+    margin-left: 33.3333%; }
+  .columns.is-mobile > .column.is-offset-one-quarter {
+    margin-left: 25%; }
+  .columns.is-mobile > .column.is-offset-one-fifth {
+    margin-left: 20%; }
+  .columns.is-mobile > .column.is-offset-two-fifths {
+    margin-left: 40%; }
+  .columns.is-mobile > .column.is-offset-three-fifths {
+    margin-left: 60%; }
+  .columns.is-mobile > .column.is-offset-four-fifths {
+    margin-left: 80%; }
+  .columns.is-mobile > .column.is-0 {
+    flex: none;
+    width: 0%; }
+  .columns.is-mobile > .column.is-offset-0 {
+    margin-left: 0%; }
+  .columns.is-mobile > .column.is-1 {
+    flex: none;
+    width: 8.33333%; }
+  .columns.is-mobile > .column.is-offset-1 {
+    margin-left: 8.33333%; }
+  .columns.is-mobile > .column.is-2 {
+    flex: none;
+    width: 16.66667%; }
+  .columns.is-mobile > .column.is-offset-2 {
+    margin-left: 16.66667%; }
+  .columns.is-mobile > .column.is-3 {
+    flex: none;
+    width: 25%; }
+  .columns.is-mobile > .column.is-offset-3 {
+    margin-left: 25%; }
+  .columns.is-mobile > .column.is-4 {
+    flex: none;
+    width: 33.33333%; }
+  .columns.is-mobile > .column.is-offset-4 {
+    margin-left: 33.33333%; }
+  .columns.is-mobile > .column.is-5 {
+    flex: none;
+    width: 41.66667%; }
+  .columns.is-mobile > .column.is-offset-5 {
+    margin-left: 41.66667%; }
+  .columns.is-mobile > .column.is-6 {
+    flex: none;
+    width: 50%; }
+  .columns.is-mobile > .column.is-offset-6 {
+    margin-left: 50%; }
+  .columns.is-mobile > .column.is-7 {
+    flex: none;
+    width: 58.33333%; }
+  .columns.is-mobile > .column.is-offset-7 {
+    margin-left: 58.33333%; }
+  .columns.is-mobile > .column.is-8 {
+    flex: none;
+    width: 66.66667%; }
+  .columns.is-mobile > .column.is-offset-8 {
+    margin-left: 66.66667%; }
+  .columns.is-mobile > .column.is-9 {
+    flex: none;
+    width: 75%; }
+  .columns.is-mobile > .column.is-offset-9 {
+    margin-left: 75%; }
+  .columns.is-mobile > .column.is-10 {
+    flex: none;
+    width: 83.33333%; }
+  .columns.is-mobile > .column.is-offset-10 {
+    margin-left: 83.33333%; }
+  .columns.is-mobile > .column.is-11 {
+    flex: none;
+    width: 91.66667%; }
+  .columns.is-mobile > .column.is-offset-11 {
+    margin-left: 91.66667%; }
+  .columns.is-mobile > .column.is-12 {
+    flex: none;
+    width: 100%; }
+  .columns.is-mobile > .column.is-offset-12 {
+    margin-left: 100%; }
+  @media screen and (max-width: 768px) {
+    .column.is-narrow-mobile {
+      flex: none; }
+    .column.is-full-mobile {
+      flex: none;
+      width: 100%; }
+    .column.is-three-quarters-mobile {
+      flex: none;
+      width: 75%; }
+    .column.is-two-thirds-mobile {
+      flex: none;
+      width: 66.6666%; }
+    .column.is-half-mobile {
+      flex: none;
+      width: 50%; }
+    .column.is-one-third-mobile {
+      flex: none;
+      width: 33.3333%; }
+    .column.is-one-quarter-mobile {
+      flex: none;
+      width: 25%; }
+    .column.is-one-fifth-mobile {
+      flex: none;
+      width: 20%; }
+    .column.is-two-fifths-mobile {
+      flex: none;
+      width: 40%; }
+    .column.is-three-fifths-mobile {
+      flex: none;
+      width: 60%; }
+    .column.is-four-fifths-mobile {
+      flex: none;
+      width: 80%; }
+    .column.is-offset-three-quarters-mobile {
+      margin-left: 75%; }
+    .column.is-offset-two-thirds-mobile {
+      margin-left: 66.6666%; }
+    .column.is-offset-half-mobile {
+      margin-left: 50%; }
+    .column.is-offset-one-third-mobile {
+      margin-left: 33.3333%; }
+    .column.is-offset-one-quarter-mobile {
+      margin-left: 25%; }
+    .column.is-offset-one-fifth-mobile {
+      margin-left: 20%; }
+    .column.is-offset-two-fifths-mobile {
+      margin-left: 40%; }
+    .column.is-offset-three-fifths-mobile {
+      margin-left: 60%; }
+    .column.is-offset-four-fifths-mobile {
+      margin-left: 80%; }
+    .column.is-0-mobile {
+      flex: none;
+      width: 0%; }
+    .column.is-offset-0-mobile {
+      margin-left: 0%; }
+    .column.is-1-mobile {
+      flex: none;
+      width: 8.33333%; }
+    .column.is-offset-1-mobile {
+      margin-left: 8.33333%; }
+    .column.is-2-mobile {
+      flex: none;
+      width: 16.66667%; }
+    .column.is-offset-2-mobile {
+      margin-left: 16.66667%; }
+    .column.is-3-mobile {
+      flex: none;
+      width: 25%; }
+    .column.is-offset-3-mobile {
+      margin-left: 25%; }
+    .column.is-4-mobile {
+      flex: none;
+      width: 33.33333%; }
+    .column.is-offset-4-mobile {
+      margin-left: 33.33333%; }
+    .column.is-5-mobile {
+      flex: none;
+      width: 41.66667%; }
+    .column.is-offset-5-mobile {
+      margin-left: 41.66667%; }
+    .column.is-6-mobile {
+      flex: none;
+      width: 50%; }
+    .column.is-offset-6-mobile {
+      margin-left: 50%; }
+    .column.is-7-mobile {
+      flex: none;
+      width: 58.33333%; }
+    .column.is-offset-7-mobile {
+      margin-left: 58.33333%; }
+    .column.is-8-mobile {
+      flex: none;
+      width: 66.66667%; }
+    .column.is-offset-8-mobile {
+      margin-left: 66.66667%; }
+    .column.is-9-mobile {
+      flex: none;
+      width: 75%; }
+    .column.is-offset-9-mobile {
+      margin-left: 75%; }
+    .column.is-10-mobile {
+      flex: none;
+      width: 83.33333%; }
+    .column.is-offset-10-mobile {
+      margin-left: 83.33333%; }
+    .column.is-11-mobile {
+      flex: none;
+      width: 91.66667%; }
+    .column.is-offset-11-mobile {
+      margin-left: 91.66667%; }
+    .column.is-12-mobile {
+      flex: none;
+      width: 100%; }
+    .column.is-offset-12-mobile {
+      margin-left: 100%; } }
+  @media screen and (min-width: 769px), print {
+    .column.is-narrow, .column.is-narrow-tablet {
+      flex: none; }
+    .column.is-full, .column.is-full-tablet {
+      flex: none;
+      width: 100%; }
+    .column.is-three-quarters, .column.is-three-quarters-tablet {
+      flex: none;
+      width: 75%; }
+    .column.is-two-thirds, .column.is-two-thirds-tablet {
+      flex: none;
+      width: 66.6666%; }
+    .column.is-half, .column.is-half-tablet {
+      flex: none;
+      width: 50%; }
+    .column.is-one-third, .column.is-one-third-tablet {
+      flex: none;
+      width: 33.3333%; }
+    .column.is-one-quarter, .column.is-one-quarter-tablet {
+      flex: none;
+      width: 25%; }
+    .column.is-one-fifth, .column.is-one-fifth-tablet {
+      flex: none;
+      width: 20%; }
+    .column.is-two-fifths, .column.is-two-fifths-tablet {
+      flex: none;
+      width: 40%; }
+    .column.is-three-fifths, .column.is-three-fifths-tablet {
+      flex: none;
+      width: 60%; }
+    .column.is-four-fifths, .column.is-four-fifths-tablet {
+      flex: none;
+      width: 80%; }
+    .column.is-offset-three-quarters, .column.is-offset-three-quarters-tablet {
+      margin-left: 75%; }
+    .column.is-offset-two-thirds, .column.is-offset-two-thirds-tablet {
+      margin-left: 66.6666%; }
+    .column.is-offset-half, .column.is-offset-half-tablet {
+      margin-left: 50%; }
+    .column.is-offset-one-third, .column.is-offset-one-third-tablet {
+      margin-left: 33.3333%; }
+    .column.is-offset-one-quarter, .column.is-offset-one-quarter-tablet {
+      margin-left: 25%; }
+    .column.is-offset-one-fifth, .column.is-offset-one-fifth-tablet {
+      margin-left: 20%; }
+    .column.is-offset-two-fifths, .column.is-offset-two-fifths-tablet {
+      margin-left: 40%; }
+    .column.is-offset-three-fifths, .column.is-offset-three-fifths-tablet {
+      margin-left: 60%; }
+    .column.is-offset-four-fifths, .column.is-offset-four-fifths-tablet {
+      margin-left: 80%; }
+    .column.is-0, .column.is-0-tablet {
+      flex: none;
+      width: 0%; }
+    .column.is-offset-0, .column.is-offset-0-tablet {
+      margin-left: 0%; }
+    .column.is-1, .column.is-1-tablet {
+      flex: none;
+      width: 8.33333%; }
+    .column.is-offset-1, .column.is-offset-1-tablet {
+      margin-left: 8.33333%; }
+    .column.is-2, .column.is-2-tablet {
+      flex: none;
+      width: 16.66667%; }
+    .column.is-offset-2, .column.is-offset-2-tablet {
+      margin-left: 16.66667%; }
+    .column.is-3, .column.is-3-tablet {
+      flex: none;
+      width: 25%; }
+    .column.is-offset-3, .column.is-offset-3-tablet {
+      margin-left: 25%; }
+    .column.is-4, .column.is-4-tablet {
+      flex: none;
+      width: 33.33333%; }
+    .column.is-offset-4, .column.is-offset-4-tablet {
+      margin-left: 33.33333%; }
+    .column.is-5, .column.is-5-tablet {
+      flex: none;
+      width: 41.66667%; }
+    .column.is-offset-5, .column.is-offset-5-tablet {
+      margin-left: 41.66667%; }
+    .column.is-6, .column.is-6-tablet {
+      flex: none;
+      width: 50%; }
+    .column.is-offset-6, .column.is-offset-6-tablet {
+      margin-left: 50%; }
+    .column.is-7, .column.is-7-tablet {
+      flex: none;
+      width: 58.33333%; }
+    .column.is-offset-7, .column.is-offset-7-tablet {
+      margin-left: 58.33333%; }
+    .column.is-8, .column.is-8-tablet {
+      flex: none;
+      width: 66.66667%; }
+    .column.is-offset-8, .column.is-offset-8-tablet {
+      margin-left: 66.66667%; }
+    .column.is-9, .column.is-9-tablet {
+      flex: none;
+      width: 75%; }
+    .column.is-offset-9, .column.is-offset-9-tablet {
+      margin-left: 75%; }
+    .column.is-10, .column.is-10-tablet {
+      flex: none;
+      width: 83.33333%; }
+    .column.is-offset-10, .column.is-offset-10-tablet {
+      margin-left: 83.33333%; }
+    .column.is-11, .column.is-11-tablet {
+      flex: none;
+      width: 91.66667%; }
+    .column.is-offset-11, .column.is-offset-11-tablet {
+      margin-left: 91.66667%; }
+    .column.is-12, .column.is-12-tablet {
+      flex: none;
+      width: 100%; }
+    .column.is-offset-12, .column.is-offset-12-tablet {
+      margin-left: 100%; } }
+  @media screen and (max-width: 1055px) {
+    .column.is-narrow-touch {
+      flex: none; }
+    .column.is-full-touch {
+      flex: none;
+      width: 100%; }
+    .column.is-three-quarters-touch {
+      flex: none;
+      width: 75%; }
+    .column.is-two-thirds-touch {
+      flex: none;
+      width: 66.6666%; }
+    .column.is-half-touch {
+      flex: none;
+      width: 50%; }
+    .column.is-one-third-touch {
+      flex: none;
+      width: 33.3333%; }
+    .column.is-one-quarter-touch {
+      flex: none;
+      width: 25%; }
+    .column.is-one-fifth-touch {
+      flex: none;
+      width: 20%; }
+    .column.is-two-fifths-touch {
+      flex: none;
+      width: 40%; }
+    .column.is-three-fifths-touch {
+      flex: none;
+      width: 60%; }
+    .column.is-four-fifths-touch {
+      flex: none;
+      width: 80%; }
+    .column.is-offset-three-quarters-touch {
+      margin-left: 75%; }
+    .column.is-offset-two-thirds-touch {
+      margin-left: 66.6666%; }
+    .column.is-offset-half-touch {
+      margin-left: 50%; }
+    .column.is-offset-one-third-touch {
+      margin-left: 33.3333%; }
+    .column.is-offset-one-quarter-touch {
+      margin-left: 25%; }
+    .column.is-offset-one-fifth-touch {
+      margin-left: 20%; }
+    .column.is-offset-two-fifths-touch {
+      margin-left: 40%; }
+    .column.is-offset-three-fifths-touch {
+      margin-left: 60%; }
+    .column.is-offset-four-fifths-touch {
+      margin-left: 80%; }
+    .column.is-0-touch {
+      flex: none;
+      width: 0%; }
+    .column.is-offset-0-touch {
+      margin-left: 0%; }
+    .column.is-1-touch {
+      flex: none;
+      width: 8.33333%; }
+    .column.is-offset-1-touch {
+      margin-left: 8.33333%; }
+    .column.is-2-touch {
+      flex: none;
+      width: 16.66667%; }
+    .column.is-offset-2-touch {
+      margin-left: 16.66667%; }
+    .column.is-3-touch {
+      flex: none;
+      width: 25%; }
+    .column.is-offset-3-touch {
+      margin-left: 25%; }
+    .column.is-4-touch {
+      flex: none;
+      width: 33.33333%; }
+    .column.is-offset-4-touch {
+      margin-left: 33.33333%; }
+    .column.is-5-touch {
+      flex: none;
+      width: 41.66667%; }
+    .column.is-offset-5-touch {
+      margin-left: 41.66667%; }
+    .column.is-6-touch {
+      flex: none;
+      width: 50%; }
+    .column.is-offset-6-touch {
+      margin-left: 50%; }
+    .column.is-7-touch {
+      flex: none;
+      width: 58.33333%; }
+    .column.is-offset-7-touch {
+      margin-left: 58.33333%; }
+    .column.is-8-touch {
+      flex: none;
+      width: 66.66667%; }
+    .column.is-offset-8-touch {
+      margin-left: 66.66667%; }
+    .column.is-9-touch {
+      flex: none;
+      width: 75%; }
+    .column.is-offset-9-touch {
+      margin-left: 75%; }
+    .column.is-10-touch {
+      flex: none;
+      width: 83.33333%; }
+    .column.is-offset-10-touch {
+      margin-left: 83.33333%; }
+    .column.is-11-touch {
+      flex: none;
+      width: 91.66667%; }
+    .column.is-offset-11-touch {
+      margin-left: 91.66667%; }
+    .column.is-12-touch {
+      flex: none;
+      width: 100%; }
+    .column.is-offset-12-touch {
+      margin-left: 100%; } }
+  @media screen and (min-width: 1056px) {
+    .column.is-narrow-desktop {
+      flex: none; }
+    .column.is-full-desktop {
+      flex: none;
+      width: 100%; }
+    .column.is-three-quarters-desktop {
+      flex: none;
+      width: 75%; }
+    .column.is-two-thirds-desktop {
+      flex: none;
+      width: 66.6666%; }
+    .column.is-half-desktop {
+      flex: none;
+      width: 50%; }
+    .column.is-one-third-desktop {
+      flex: none;
+      width: 33.3333%; }
+    .column.is-one-quarter-desktop {
+      flex: none;
+      width: 25%; }
+    .column.is-one-fifth-desktop {
+      flex: none;
+      width: 20%; }
+    .column.is-two-fifths-desktop {
+      flex: none;
+      width: 40%; }
+    .column.is-three-fifths-desktop {
+      flex: none;
+      width: 60%; }
+    .column.is-four-fifths-desktop {
+      flex: none;
+      width: 80%; }
+    .column.is-offset-three-quarters-desktop {
+      margin-left: 75%; }
+    .column.is-offset-two-thirds-desktop {
+      margin-left: 66.6666%; }
+    .column.is-offset-half-desktop {
+      margin-left: 50%; }
+    .column.is-offset-one-third-desktop {
+      margin-left: 33.3333%; }
+    .column.is-offset-one-quarter-desktop {
+      margin-left: 25%; }
+    .column.is-offset-one-fifth-desktop {
+      margin-left: 20%; }
+    .column.is-offset-two-fifths-desktop {
+      margin-left: 40%; }
+    .column.is-offset-three-fifths-desktop {
+      margin-left: 60%; }
+    .column.is-offset-four-fifths-desktop {
+      margin-left: 80%; }
+    .column.is-0-desktop {
+      flex: none;
+      width: 0%; }
+    .column.is-offset-0-desktop {
+      margin-left: 0%; }
+    .column.is-1-desktop {
+      flex: none;
+      width: 8.33333%; }
+    .column.is-offset-1-desktop {
+      margin-left: 8.33333%; }
+    .column.is-2-desktop {
+      flex: none;
+      width: 16.66667%; }
+    .column.is-offset-2-desktop {
+      margin-left: 16.66667%; }
+    .column.is-3-desktop {
+      flex: none;
+      width: 25%; }
+    .column.is-offset-3-desktop {
+      margin-left: 25%; }
+    .column.is-4-desktop {
+      flex: none;
+      width: 33.33333%; }
+    .column.is-offset-4-desktop {
+      margin-left: 33.33333%; }
+    .column.is-5-desktop {
+      flex: none;
+      width: 41.66667%; }
+    .column.is-offset-5-desktop {
+      margin-left: 41.66667%; }
+    .column.is-6-desktop {
+      flex: none;
+      width: 50%; }
+    .column.is-offset-6-desktop {
+      margin-left: 50%; }
+    .column.is-7-desktop {
+      flex: none;
+      width: 58.33333%; }
+    .column.is-offset-7-desktop {
+      margin-left: 58.33333%; }
+    .column.is-8-desktop {
+      flex: none;
+      width: 66.66667%; }
+    .column.is-offset-8-desktop {
+      margin-left: 66.66667%; }
+    .column.is-9-desktop {
+      flex: none;
+      width: 75%; }
+    .column.is-offset-9-desktop {
+      margin-left: 75%; }
+    .column.is-10-desktop {
+      flex: none;
+      width: 83.33333%; }
+    .column.is-offset-10-desktop {
+      margin-left: 83.33333%; }
+    .column.is-11-desktop {
+      flex: none;
+      width: 91.66667%; }
+    .column.is-offset-11-desktop {
+      margin-left: 91.66667%; }
+    .column.is-12-desktop {
+      flex: none;
+      width: 100%; }
+    .column.is-offset-12-desktop {
+      margin-left: 100%; } }
+  @media screen and (min-width: 1216px) {
+    .column.is-narrow-widescreen {
+      flex: none; }
+    .column.is-full-widescreen {
+      flex: none;
+      width: 100%; }
+    .column.is-three-quarters-widescreen {
+      flex: none;
+      width: 75%; }
+    .column.is-two-thirds-widescreen {
+      flex: none;
+      width: 66.6666%; }
+    .column.is-half-widescreen {
+      flex: none;
+      width: 50%; }
+    .column.is-one-third-widescreen {
+      flex: none;
+      width: 33.3333%; }
+    .column.is-one-quarter-widescreen {
+      flex: none;
+      width: 25%; }
+    .column.is-one-fifth-widescreen {
+      flex: none;
+      width: 20%; }
+    .column.is-two-fifths-widescreen {
+      flex: none;
+      width: 40%; }
+    .column.is-three-fifths-widescreen {
+      flex: none;
+      width: 60%; }
+    .column.is-four-fifths-widescreen {
+      flex: none;
+      width: 80%; }
+    .column.is-offset-three-quarters-widescreen {
+      margin-left: 75%; }
+    .column.is-offset-two-thirds-widescreen {
+      margin-left: 66.6666%; }
+    .column.is-offset-half-widescreen {
+      margin-left: 50%; }
+    .column.is-offset-one-third-widescreen {
+      margin-left: 33.3333%; }
+    .column.is-offset-one-quarter-widescreen {
+      margin-left: 25%; }
+    .column.is-offset-one-fifth-widescreen {
+      margin-left: 20%; }
+    .column.is-offset-two-fifths-widescreen {
+      margin-left: 40%; }
+    .column.is-offset-three-fifths-widescreen {
+      margin-left: 60%; }
+    .column.is-offset-four-fifths-widescreen {
+      margin-left: 80%; }
+    .column.is-0-widescreen {
+      flex: none;
+      width: 0%; }
+    .column.is-offset-0-widescreen {
+      margin-left: 0%; }
+    .column.is-1-widescreen {
+      flex: none;
+      width: 8.33333%; }
+    .column.is-offset-1-widescreen {
+      margin-left: 8.33333%; }
+    .column.is-2-widescreen {
+      flex: none;
+      width: 16.66667%; }
+    .column.is-offset-2-widescreen {
+      margin-left: 16.66667%; }
+    .column.is-3-widescreen {
+      flex: none;
+      width: 25%; }
+    .column.is-offset-3-widescreen {
+      margin-left: 25%; }
+    .column.is-4-widescreen {
+      flex: none;
+      width: 33.33333%; }
+    .column.is-offset-4-widescreen {
+      margin-left: 33.33333%; }
+    .column.is-5-widescreen {
+      flex: none;
+      width: 41.66667%; }
+    .column.is-offset-5-widescreen {
+      margin-left: 41.66667%; }
+    .column.is-6-widescreen {
+      flex: none;
+      width: 50%; }
+    .column.is-offset-6-widescreen {
+      margin-left: 50%; }
+    .column.is-7-widescreen {
+      flex: none;
+      width: 58.33333%; }
+    .column.is-offset-7-widescreen {
+      margin-left: 58.33333%; }
+    .column.is-8-widescreen {
+      flex: none;
+      width: 66.66667%; }
+    .column.is-offset-8-widescreen {
+      margin-left: 66.66667%; }
+    .column.is-9-widescreen {
+      flex: none;
+      width: 75%; }
+    .column.is-offset-9-widescreen {
+      margin-left: 75%; }
+    .column.is-10-widescreen {
+      flex: none;
+      width: 83.33333%; }
+    .column.is-offset-10-widescreen {
+      margin-left: 83.33333%; }
+    .column.is-11-widescreen {
+      flex: none;
+      width: 91.66667%; }
+    .column.is-offset-11-widescreen {
+      margin-left: 91.66667%; }
+    .column.is-12-widescreen {
+      flex: none;
+      width: 100%; }
+    .column.is-offset-12-widescreen {
+      margin-left: 100%; } }
+  @media screen and (min-width: 1408px) {
+    .column.is-narrow-fullhd {
+      flex: none; }
+    .column.is-full-fullhd {
+      flex: none;
+      width: 100%; }
+    .column.is-three-quarters-fullhd {
+      flex: none;
+      width: 75%; }
+    .column.is-two-thirds-fullhd {
+      flex: none;
+      width: 66.6666%; }
+    .column.is-half-fullhd {
+      flex: none;
+      width: 50%; }
+    .column.is-one-third-fullhd {
+      flex: none;
+      width: 33.3333%; }
+    .column.is-one-quarter-fullhd {
+      flex: none;
+      width: 25%; }
+    .column.is-one-fifth-fullhd {
+      flex: none;
+      width: 20%; }
+    .column.is-two-fifths-fullhd {
+      flex: none;
+      width: 40%; }
+    .column.is-three-fifths-fullhd {
+      flex: none;
+      width: 60%; }
+    .column.is-four-fifths-fullhd {
+      flex: none;
+      width: 80%; }
+    .column.is-offset-three-quarters-fullhd {
+      margin-left: 75%; }
+    .column.is-offset-two-thirds-fullhd {
+      margin-left: 66.6666%; }
+    .column.is-offset-half-fullhd {
+      margin-left: 50%; }
+    .column.is-offset-one-third-fullhd {
+      margin-left: 33.3333%; }
+    .column.is-offset-one-quarter-fullhd {
+      margin-left: 25%; }
+    .column.is-offset-one-fifth-fullhd {
+      margin-left: 20%; }
+    .column.is-offset-two-fifths-fullhd {
+      margin-left: 40%; }
+    .column.is-offset-three-fifths-fullhd {
+      margin-left: 60%; }
+    .column.is-offset-four-fifths-fullhd {
+      margin-left: 80%; }
+    .column.is-0-fullhd {
+      flex: none;
+      width: 0%; }
+    .column.is-offset-0-fullhd {
+      margin-left: 0%; }
+    .column.is-1-fullhd {
+      flex: none;
+      width: 8.33333%; }
+    .column.is-offset-1-fullhd {
+      margin-left: 8.33333%; }
+    .column.is-2-fullhd {
+      flex: none;
+      width: 16.66667%; }
+    .column.is-offset-2-fullhd {
+      margin-left: 16.66667%; }
+    .column.is-3-fullhd {
+      flex: none;
+      width: 25%; }
+    .column.is-offset-3-fullhd {
+      margin-left: 25%; }
+    .column.is-4-fullhd {
+      flex: none;
+      width: 33.33333%; }
+    .column.is-offset-4-fullhd {
+      margin-left: 33.33333%; }
+    .column.is-5-fullhd {
+      flex: none;
+      width: 41.66667%; }
+    .column.is-offset-5-fullhd {
+      margin-left: 41.66667%; }
+    .column.is-6-fullhd {
+      flex: none;
+      width: 50%; }
+    .column.is-offset-6-fullhd {
+      margin-left: 50%; }
+    .column.is-7-fullhd {
+      flex: none;
+      width: 58.33333%; }
+    .column.is-offset-7-fullhd {
+      margin-left: 58.33333%; }
+    .column.is-8-fullhd {
+      flex: none;
+      width: 66.66667%; }
+    .column.is-offset-8-fullhd {
+      margin-left: 66.66667%; }
+    .column.is-9-fullhd {
+      flex: none;
+      width: 75%; }
+    .column.is-offset-9-fullhd {
+      margin-left: 75%; }
+    .column.is-10-fullhd {
+      flex: none;
+      width: 83.33333%; }
+    .column.is-offset-10-fullhd {
+      margin-left: 83.33333%; }
+    .column.is-11-fullhd {
+      flex: none;
+      width: 91.66667%; }
+    .column.is-offset-11-fullhd {
+      margin-left: 91.66667%; }
+    .column.is-12-fullhd {
+      flex: none;
+      width: 100%; }
+    .column.is-offset-12-fullhd {
+      margin-left: 100%; } }
+
+.columns {
+  margin-left: -0.75rem;
+  margin-right: -0.75rem;
+  margin-top: -0.75rem; }
+  .columns:last-child {
+    margin-bottom: -0.75rem; }
+  .columns:not(:last-child) {
+    margin-bottom: calc(1.5rem - 0.75rem); }
+  .columns.is-centered {
+    justify-content: center; }
+  .columns.is-gapless {
+    margin-left: 0;
+    margin-right: 0;
+    margin-top: 0; }
+    .columns.is-gapless > .column {
+      margin: 0;
+      padding: 0 !important; }
+    .columns.is-gapless:not(:last-child) {
+      margin-bottom: 1.5rem; }
+    .columns.is-gapless:last-child {
+      margin-bottom: 0; }
+  .columns.is-mobile {
+    display: flex; }
+  .columns.is-multiline {
+    flex-wrap: wrap; }
+  .columns.is-vcentered {
+    align-items: center; }
+  @media screen and (min-width: 769px), print {
+    .columns:not(.is-desktop) {
+      display: flex; } }
+  @media screen and (min-width: 1056px) {
+    .columns.is-desktop {
+      display: flex; } }
+
+.columns.is-variable {
+  --columnGap: 0.75rem;
+  margin-left: calc(-1 * var(--columnGap));
+  margin-right: calc(-1 * var(--columnGap)); }
+  .columns.is-variable .column {
+    padding-left: var(--columnGap);
+    padding-right: var(--columnGap); }
+  .columns.is-variable.is-0 {
+    --columnGap: 0rem; }
+  @media screen and (max-width: 768px) {
+    .columns.is-variable.is-0-mobile {
+      --columnGap: 0rem; } }
+  @media screen and (min-width: 769px), print {
+    .columns.is-variable.is-0-tablet {
+      --columnGap: 0rem; } }
+  @media screen and (min-width: 769px) and (max-width: 1055px) {
+    .columns.is-variable.is-0-tablet-only {
+      --columnGap: 0rem; } }
+  @media screen and (max-width: 1055px) {
+    .columns.is-variable.is-0-touch {
+      --columnGap: 0rem; } }
+  @media screen and (min-width: 1056px) {
+    .columns.is-variable.is-0-desktop {
+      --columnGap: 0rem; } }
+  @media screen and (min-width: 1056px) and (max-width: 1215px) {
+    .columns.is-variable.is-0-desktop-only {
+      --columnGap: 0rem; } }
+  @media screen and (min-width: 1216px) {
+    .columns.is-variable.is-0-widescreen {
+      --columnGap: 0rem; } }
+  @media screen and (min-width: 1216px) and (max-width: 1407px) {
+    .columns.is-variable.is-0-widescreen-only {
+      --columnGap: 0rem; } }
+  @media screen and (min-width: 1408px) {
+    .columns.is-variable.is-0-fullhd {
+      --columnGap: 0rem; } }
+  .columns.is-variable.is-1 {
+    --columnGap: 0.25rem; }
+  @media screen and (max-width: 768px) {
+    .columns.is-variable.is-1-mobile {
+      --columnGap: 0.25rem; } }
+  @media screen and (min-width: 769px), print {
+    .columns.is-variable.is-1-tablet {
+      --columnGap: 0.25rem; } }
+  @media screen and (min-width: 769px) and (max-width: 1055px) {
+    .columns.is-variable.is-1-tablet-only {
+      --columnGap: 0.25rem; } }
+  @media screen and (max-width: 1055px) {
+    .columns.is-variable.is-1-touch {
+      --columnGap: 0.25rem; } }
+  @media screen and (min-width: 1056px) {
+    .columns.is-variable.is-1-desktop {
+      --columnGap: 0.25rem; } }
+  @media screen and (min-width: 1056px) and (max-width: 1215px) {
+    .columns.is-variable.is-1-desktop-only {
+      --columnGap: 0.25rem; } }
+  @media screen and (min-width: 1216px) {
+    .columns.is-variable.is-1-widescreen {
+      --columnGap: 0.25rem; } }
+  @media screen and (min-width: 1216px) and (max-width: 1407px) {
+    .columns.is-variable.is-1-widescreen-only {
+      --columnGap: 0.25rem; } }
+  @media screen and (min-width: 1408px) {
+    .columns.is-variable.is-1-fullhd {
+      --columnGap: 0.25rem; } }
+  .columns.is-variable.is-2 {
+    --columnGap: 0.5rem; }
+  @media screen and (max-width: 768px) {
+    .columns.is-variable.is-2-mobile {
+      --columnGap: 0.5rem; } }
+  @media screen and (min-width: 769px), print {
+    .columns.is-variable.is-2-tablet {
+      --columnGap: 0.5rem; } }
+  @media screen and (min-width: 769px) and (max-width: 1055px) {
+    .columns.is-variable.is-2-tablet-only {
+      --columnGap: 0.5rem; } }
+  @media screen and (max-width: 1055px) {
+    .columns.is-variable.is-2-touch {
+      --columnGap: 0.5rem; } }
+  @media screen and (min-width: 1056px) {
+    .columns.is-variable.is-2-desktop {
+      --columnGap: 0.5rem; } }
+  @media screen and (min-width: 1056px) and (max-width: 1215px) {
+    .columns.is-variable.is-2-desktop-only {
+      --columnGap: 0.5rem; } }
+  @media screen and (min-width: 1216px) {
+    .columns.is-variable.is-2-widescreen {
+      --columnGap: 0.5rem; } }
+  @media screen and (min-width: 1216px) and (max-width: 1407px) {
+    .columns.is-variable.is-2-widescreen-only {
+      --columnGap: 0.5rem; } }
+  @media screen and (min-width: 1408px) {
+    .columns.is-variable.is-2-fullhd {
+      --columnGap: 0.5rem; } }
+  .columns.is-variable.is-3 {
+    --columnGap: 0.75rem; }
+  @media screen and (max-width: 768px) {
+    .columns.is-variable.is-3-mobile {
+      --columnGap: 0.75rem; } }
+  @media screen and (min-width: 769px), print {
+    .columns.is-variable.is-3-tablet {
+      --columnGap: 0.75rem; } }
+  @media screen and (min-width: 769px) and (max-width: 1055px) {
+    .columns.is-variable.is-3-tablet-only {
+      --columnGap: 0.75rem; } }
+  @media screen and (max-width: 1055px) {
+    .columns.is-variable.is-3-touch {
+      --columnGap: 0.75rem; } }
+  @media screen and (min-width: 1056px) {
+    .columns.is-variable.is-3-desktop {
+      --columnGap: 0.75rem; } }
+  @media screen and (min-width: 1056px) and (max-width: 1215px) {
+    .columns.is-variable.is-3-desktop-only {
+      --columnGap: 0.75rem; } }
+  @media screen and (min-width: 1216px) {
+    .columns.is-variable.is-3-widescreen {
+      --columnGap: 0.75rem; } }
+  @media screen and (min-width: 1216px) and (max-width: 1407px) {
+    .columns.is-variable.is-3-widescreen-only {
+      --columnGap: 0.75rem; } }
+  @media screen and (min-width: 1408px) {
+    .columns.is-variable.is-3-fullhd {
+      --columnGap: 0.75rem; } }
+  .columns.is-variable.is-4 {
+    --columnGap: 1rem; }
+  @media screen and (max-width: 768px) {
+    .columns.is-variable.is-4-mobile {
+      --columnGap: 1rem; } }
+  @media screen and (min-width: 769px), print {
+    .columns.is-variable.is-4-tablet {
+      --columnGap: 1rem; } }
+  @media screen and (min-width: 769px) and (max-width: 1055px) {
+    .columns.is-variable.is-4-tablet-only {
+      --columnGap: 1rem; } }
+  @media screen and (max-width: 1055px) {
+    .columns.is-variable.is-4-touch {
+      --columnGap: 1rem; } }
+  @media screen and (min-width: 1056px) {
+    .columns.is-variable.is-4-desktop {
+      --columnGap: 1rem; } }
+  @media screen and (min-width: 1056px) and (max-width: 1215px) {
+    .columns.is-variable.is-4-desktop-only {
+      --columnGap: 1rem; } }
+  @media screen and (min-width: 1216px) {
+    .columns.is-variable.is-4-widescreen {
+      --columnGap: 1rem; } }
+  @media screen and (min-width: 1216px) and (max-width: 1407px) {
+    .columns.is-variable.is-4-widescreen-only {
+      --columnGap: 1rem; } }
+  @media screen and (min-width: 1408px) {
+    .columns.is-variable.is-4-fullhd {
+      --columnGap: 1rem; } }
+  .columns.is-variable.is-5 {
+    --columnGap: 1.25rem; }
+  @media screen and (max-width: 768px) {
+    .columns.is-variable.is-5-mobile {
+      --columnGap: 1.25rem; } }
+  @media screen and (min-width: 769px), print {
+    .columns.is-variable.is-5-tablet {
+      --columnGap: 1.25rem; } }
+  @media screen and (min-width: 769px) and (max-width: 1055px) {
+    .columns.is-variable.is-5-tablet-only {
+      --columnGap: 1.25rem; } }
+  @media screen and (max-width: 1055px) {
+    .columns.is-variable.is-5-touch {
+      --columnGap: 1.25rem; } }
+  @media screen and (min-width: 1056px) {
+    .columns.is-variable.is-5-desktop {
+      --columnGap: 1.25rem; } }
+  @media screen and (min-width: 1056px) and (max-width: 1215px) {
+    .columns.is-variable.is-5-desktop-only {
+      --columnGap: 1.25rem; } }
+  @media screen and (min-width: 1216px) {
+    .columns.is-variable.is-5-widescreen {
+      --columnGap: 1.25rem; } }
+  @media screen and (min-width: 1216px) and (max-width: 1407px) {
+    .columns.is-variable.is-5-widescreen-only {
+      --columnGap: 1.25rem; } }
+  @media screen and (min-width: 1408px) {
+    .columns.is-variable.is-5-fullhd {
+      --columnGap: 1.25rem; } }
+  .columns.is-variable.is-6 {
+    --columnGap: 1.5rem; }
+  @media screen and (max-width: 768px) {
+    .columns.is-variable.is-6-mobile {
+      --columnGap: 1.5rem; } }
+  @media screen and (min-width: 769px), print {
+    .columns.is-variable.is-6-tablet {
+      --columnGap: 1.5rem; } }
+  @media screen and (min-width: 769px) and (max-width: 1055px) {
+    .columns.is-variable.is-6-tablet-only {
+      --columnGap: 1.5rem; } }
+  @media screen and (max-width: 1055px) {
+    .columns.is-variable.is-6-touch {
+      --columnGap: 1.5rem; } }
+  @media screen and (min-width: 1056px) {
+    .columns.is-variable.is-6-desktop {
+      --columnGap: 1.5rem; } }
+  @media screen and (min-width: 1056px) and (max-width: 1215px) {
+    .columns.is-variable.is-6-desktop-only {
+      --columnGap: 1.5rem; } }
+  @media screen and (min-width: 1216px) {
+    .columns.is-variable.is-6-widescreen {
+      --columnGap: 1.5rem; } }
+  @media screen and (min-width: 1216px) and (max-width: 1407px) {
+    .columns.is-variable.is-6-widescreen-only {
+      --columnGap: 1.5rem; } }
+  @media screen and (min-width: 1408px) {
+    .columns.is-variable.is-6-fullhd {
+      --columnGap: 1.5rem; } }
+  .columns.is-variable.is-7 {
+    --columnGap: 1.75rem; }
+  @media screen and (max-width: 768px) {
+    .columns.is-variable.is-7-mobile {
+      --columnGap: 1.75rem; } }
+  @media screen and (min-width: 769px), print {
+    .columns.is-variable.is-7-tablet {
+      --columnGap: 1.75rem; } }
+  @media screen and (min-width: 769px) and (max-width: 1055px) {
+    .columns.is-variable.is-7-tablet-only {
+      --columnGap: 1.75rem; } }
+  @media screen and (max-width: 1055px) {
+    .columns.is-variable.is-7-touch {
+      --columnGap: 1.75rem; } }
+  @media screen and (min-width: 1056px) {
+    .columns.is-variable.is-7-desktop {
+      --columnGap: 1.75rem; } }
+  @media screen and (min-width: 1056px) and (max-width: 1215px) {
+    .columns.is-variable.is-7-desktop-only {
+      --columnGap: 1.75rem; } }
+  @media screen and (min-width: 1216px) {
+    .columns.is-variable.is-7-widescreen {
+      --columnGap: 1.75rem; } }
+  @media screen and (min-width: 1216px) and (max-width: 1407px) {
+    .columns.is-variable.is-7-widescreen-only {
+      --columnGap: 1.75rem; } }
+  @media screen and (min-width: 1408px) {
+    .columns.is-variable.is-7-fullhd {
+      --columnGap: 1.75rem; } }
+  .columns.is-variable.is-8 {
+    --columnGap: 2rem; }
+  @media screen and (max-width: 768px) {
+    .columns.is-variable.is-8-mobile {
+      --columnGap: 2rem; } }
+  @media screen and (min-width: 769px), print {
+    .columns.is-variable.is-8-tablet {
+      --columnGap: 2rem; } }
+  @media screen and (min-width: 769px) and (max-width: 1055px) {
+    .columns.is-variable.is-8-tablet-only {
+      --columnGap: 2rem; } }
+  @media screen and (max-width: 1055px) {
+    .columns.is-variable.is-8-touch {
+      --columnGap: 2rem; } }
+  @media screen and (min-width: 1056px) {
+    .columns.is-variable.is-8-desktop {
+      --columnGap: 2rem; } }
+  @media screen and (min-width: 1056px) and (max-width: 1215px) {
+    .columns.is-variable.is-8-desktop-only {
+      --columnGap: 2rem; } }
+  @media screen and (min-width: 1216px) {
+    .columns.is-variable.is-8-widescreen {
+      --columnGap: 2rem; } }
+  @media screen and (min-width: 1216px) and (max-width: 1407px) {
+    .columns.is-variable.is-8-widescreen-only {
+      --columnGap: 2rem; } }
+  @media screen and (min-width: 1408px) {
+    .columns.is-variable.is-8-fullhd {
+      --columnGap: 2rem; } }
+
+.tile {
+  align-items: stretch;
+  display: block;
+  flex-basis: 0;
+  flex-grow: 1;
+  flex-shrink: 1;
+  min-height: min-content; }
+  .tile.is-ancestor {
+    margin-left: -0.75rem;
+    margin-right: -0.75rem;
+    margin-top: -0.75rem; }
+    .tile.is-ancestor:last-child {
+      margin-bottom: -0.75rem; }
+    .tile.is-ancestor:not(:last-child) {
+      margin-bottom: 0.75rem; }
+  .tile.is-child {
+    margin: 0 !important; }
+  .tile.is-parent {
+    padding: 0.75rem; }
+  .tile.is-vertical {
+    flex-direction: column; }
+    .tile.is-vertical > .tile.is-child:not(:last-child) {
+      margin-bottom: 1.5rem !important; }
+  @media screen and (min-width: 769px), print {
+    .tile:not(.is-child) {
+      display: flex; }
+    .tile.is-1 {
+      flex: none;
+      width: 8.33333%; }
+    .tile.is-2 {
+      flex: none;
+      width: 16.66667%; }
+    .tile.is-3 {
+      flex: none;
+      width: 25%; }
+    .tile.is-4 {
+      flex: none;
+      width: 33.33333%; }
+    .tile.is-5 {
+      flex: none;
+      width: 41.66667%; }
+    .tile.is-6 {
+      flex: none;
+      width: 50%; }
+    .tile.is-7 {
+      flex: none;
+      width: 58.33333%; }
+    .tile.is-8 {
+      flex: none;
+      width: 66.66667%; }
+    .tile.is-9 {
+      flex: none;
+      width: 75%; }
+    .tile.is-10 {
+      flex: none;
+      width: 83.33333%; }
+    .tile.is-11 {
+      flex: none;
+      width: 91.66667%; }
+    .tile.is-12 {
+      flex: none;
+      width: 100%; } }
+
+.hero {
+  align-items: stretch;
+  display: flex;
+  flex-direction: column;
+  justify-content: space-between; }
+  .hero .navbar {
+    background: none; }
+  .hero .tabs ul {
+    border-bottom: none; }
+  .hero.is-white {
+    background-color: white;
+    color: #0a0a0a; }
+    .hero.is-white a:not(.button):not(.dropdown-item):not(.tag):not(.pagination-link.is-current),
+    .hero.is-white strong {
+      color: inherit; }
+    .hero.is-white .title {
+      color: #0a0a0a; }
+    .hero.is-white .subtitle {
+      color: rgba(10, 10, 10, 0.9); }
+      .hero.is-white .subtitle a:not(.button),
+      .hero.is-white .subtitle strong {
+        color: #0a0a0a; }
+    @media screen and (max-width: 1055px) {
+      .hero.is-white .navbar-menu {
+        background-color: white; } }
+    .hero.is-white .navbar-item,
+    .hero.is-white .navbar-link {
+      color: rgba(10, 10, 10, 0.7); }
+    .hero.is-white a.navbar-item:hover, .hero.is-white a.navbar-item.is-active,
+    .hero.is-white .navbar-link:hover,
+    .hero.is-white .navbar-link.is-active {
+      background-color: #f2f2f2;
+      color: #0a0a0a; }
+    .hero.is-white .tabs a {
+      color: #0a0a0a;
+      opacity: 0.9; }
+      .hero.is-white .tabs a:hover {
+        opacity: 1; }
+    .hero.is-white .tabs li.is-active a {
+      opacity: 1; }
+    .hero.is-white .tabs.is-boxed a, .hero.is-white .tabs.is-toggle a {
+      color: #0a0a0a; }
+      .hero.is-white .tabs.is-boxed a:hover, .hero.is-white .tabs.is-toggle a:hover {
+        background-color: rgba(10, 10, 10, 0.1); }
+    .hero.is-white .tabs.is-boxed li.is-active a, .hero.is-white .tabs.is-boxed li.is-active a:hover, .hero.is-white .tabs.is-toggle li.is-active a, .hero.is-white .tabs.is-toggle li.is-active a:hover {
+      background-color: #0a0a0a;
+      border-color: #0a0a0a;
+      color: white; }
+    .hero.is-white.is-bold {
+      background-image: linear-gradient(141deg, #e6e6e6 0%, white 71%, white 100%); }
+      @media screen and (max-width: 768px) {
+        .hero.is-white.is-bold .navbar-menu {
+          background-image: linear-gradient(141deg, #e6e6e6 0%, white 71%, white 100%); } }
+  .hero.is-black {
+    background-color: #0a0a0a;
+    color: white; }
+    .hero.is-black a:not(.button):not(.dropdown-item):not(.tag):not(.pagination-link.is-current),
+    .hero.is-black strong {
+      color: inherit; }
+    .hero.is-black .title {
+      color: white; }
+    .hero.is-black .subtitle {
+      color: rgba(255, 255, 255, 0.9); }
+      .hero.is-black .subtitle a:not(.button),
+      .hero.is-black .subtitle strong {
+        color: white; }
+    @media screen and (max-width: 1055px) {
+      .hero.is-black .navbar-menu {
+        background-color: #0a0a0a; } }
+    .hero.is-black .navbar-item,
+    .hero.is-black .navbar-link {
+      color: rgba(255, 255, 255, 0.7); }
+    .hero.is-black a.navbar-item:hover, .hero.is-black a.navbar-item.is-active,
+    .hero.is-black .navbar-link:hover,
+    .hero.is-black .navbar-link.is-active {
+      background-color: black;
+      color: white; }
+    .hero.is-black .tabs a {
+      color: white;
+      opacity: 0.9; }
+      .hero.is-black .tabs a:hover {
+        opacity: 1; }
+    .hero.is-black .tabs li.is-active a {
+      opacity: 1; }
+    .hero.is-black .tabs.is-boxed a, .hero.is-black .tabs.is-toggle a {
+      color: white; }
+      .hero.is-black .tabs.is-boxed a:hover, .hero.is-black .tabs.is-toggle a:hover {
+        background-color: rgba(10, 10, 10, 0.1); }
+    .hero.is-black .tabs.is-boxed li.is-active a, .hero.is-black .tabs.is-boxed li.is-active a:hover, .hero.is-black .tabs.is-toggle li.is-active a, .hero.is-black .tabs.is-toggle li.is-active a:hover {
+      background-color: white;
+      border-color: white;
+      color: #0a0a0a; }
+    .hero.is-black.is-bold {
+      background-image: linear-gradient(141deg, black 0%, #0a0a0a 71%, #181616 100%); }
+      @media screen and (max-width: 768px) {
+        .hero.is-black.is-bold .navbar-menu {
+          background-image: linear-gradient(141deg, black 0%, #0a0a0a 71%, #181616 100%); } }
+  .hero.is-light {
+    background-color: whitesmoke;
+    color: #363636; }
+    .hero.is-light a:not(.button):not(.dropdown-item):not(.tag):not(.pagination-link.is-current),
+    .hero.is-light strong {
+      color: inherit; }
+    .hero.is-light .title {
+      color: #363636; }
+    .hero.is-light .subtitle {
+      color: rgba(54, 54, 54, 0.9); }
+      .hero.is-light .subtitle a:not(.button),
+      .hero.is-light .subtitle strong {
+        color: #363636; }
+    @media screen and (max-width: 1055px) {
+      .hero.is-light .navbar-menu {
+        background-color: whitesmoke; } }
+    .hero.is-light .navbar-item,
+    .hero.is-light .navbar-link {
+      color: rgba(54, 54, 54, 0.7); }
+    .hero.is-light a.navbar-item:hover, .hero.is-light a.navbar-item.is-active,
+    .hero.is-light .navbar-link:hover,
+    .hero.is-light .navbar-link.is-active {
+      background-color: #e8e8e8;
+      color: #363636; }
+    .hero.is-light .tabs a {
+      color: #363636;
+      opacity: 0.9; }
+      .hero.is-light .tabs a:hover {
+        opacity: 1; }
+    .hero.is-light .tabs li.is-active a {
+      opacity: 1; }
+    .hero.is-light .tabs.is-boxed a, .hero.is-light .tabs.is-toggle a {
+      color: #363636; }
+      .hero.is-light .tabs.is-boxed a:hover, .hero.is-light .tabs.is-toggle a:hover {
+        background-color: rgba(10, 10, 10, 0.1); }
+    .hero.is-light .tabs.is-boxed li.is-active a, .hero.is-light .tabs.is-boxed li.is-active a:hover, .hero.is-light .tabs.is-toggle li.is-active a, .hero.is-light .tabs.is-toggle li.is-active a:hover {
+      background-color: #363636;
+      border-color: #363636;
+      color: whitesmoke; }
+    .hero.is-light.is-bold {
+      background-image: linear-gradient(141deg, #dfd8d9 0%, whitesmoke 71%, white 100%); }
+      @media screen and (max-width: 768px) {
+        .hero.is-light.is-bold .navbar-menu {
+          background-image: linear-gradient(141deg, #dfd8d9 0%, whitesmoke 71%, white 100%); } }
+  .hero.is-dark, .content kbd.hero {
+    background-color: #363636;
+    color: whitesmoke; }
+    .hero.is-dark a:not(.button):not(.dropdown-item):not(.tag):not(.pagination-link.is-current), .content kbd.hero a:not(.button):not(.dropdown-item):not(.tag):not(.pagination-link.is-current),
+    .hero.is-dark strong,
+    .content kbd.hero strong {
+      color: inherit; }
+    .hero.is-dark .title, .content kbd.hero .title {
+      color: whitesmoke; }
+    .hero.is-dark .subtitle, .content kbd.hero .subtitle {
+      color: rgba(245, 245, 245, 0.9); }
+      .hero.is-dark .subtitle a:not(.button), .content kbd.hero .subtitle a:not(.button),
+      .hero.is-dark .subtitle strong,
+      .content kbd.hero .subtitle strong {
+        color: whitesmoke; }
+    @media screen and (max-width: 1055px) {
+      .hero.is-dark .navbar-menu, .content kbd.hero .navbar-menu {
+        background-color: #363636; } }
+    .hero.is-dark .navbar-item, .content kbd.hero .navbar-item,
+    .hero.is-dark .navbar-link,
+    .content kbd.hero .navbar-link {
+      color: rgba(245, 245, 245, 0.7); }
+    .hero.is-dark a.navbar-item:hover, .content kbd.hero a.navbar-item:hover, .hero.is-dark a.navbar-item.is-active, .content kbd.hero a.navbar-item.is-active,
+    .hero.is-dark .navbar-link:hover,
+    .content kbd.hero .navbar-link:hover,
+    .hero.is-dark .navbar-link.is-active,
+    .content kbd.hero .navbar-link.is-active {
+      background-color: #292929;
+      color: whitesmoke; }
+    .hero.is-dark .tabs a, .content kbd.hero .tabs a {
+      color: whitesmoke;
+      opacity: 0.9; }
+      .hero.is-dark .tabs a:hover, .content kbd.hero .tabs a:hover {
+        opacity: 1; }
+    .hero.is-dark .tabs li.is-active a, .content kbd.hero .tabs li.is-active a {
+      opacity: 1; }
+    .hero.is-dark .tabs.is-boxed a, .content kbd.hero .tabs.is-boxed a, .hero.is-dark .tabs.is-toggle a, .content kbd.hero .tabs.is-toggle a {
+      color: whitesmoke; }
+      .hero.is-dark .tabs.is-boxed a:hover, .content kbd.hero .tabs.is-boxed a:hover, .hero.is-dark .tabs.is-toggle a:hover, .content kbd.hero .tabs.is-toggle a:hover {
+        background-color: rgba(10, 10, 10, 0.1); }
+    .hero.is-dark .tabs.is-boxed li.is-active a, .content kbd.hero .tabs.is-boxed li.is-active a, .hero.is-dark .tabs.is-boxed li.is-active a:hover, .content kbd.hero .tabs.is-boxed li.is-active a:hover, .hero.is-dark .tabs.is-toggle li.is-active a, .content kbd.hero .tabs.is-toggle li.is-active a, .hero.is-dark .tabs.is-toggle li.is-active a:hover, .content kbd.hero .tabs.is-toggle li.is-active a:hover {
+      background-color: whitesmoke;
+      border-color: whitesmoke;
+      color: #363636; }
+    .hero.is-dark.is-bold, .content kbd.hero.is-bold {
+      background-image: linear-gradient(141deg, #1f191a 0%, #363636 71%, #46403f 100%); }
+      @media screen and (max-width: 768px) {
+        .hero.is-dark.is-bold .navbar-menu, .content kbd.hero.is-bold .navbar-menu {
+          background-image: linear-gradient(141deg, #1f191a 0%, #363636 71%, #46403f 100%); } }
+  .hero.is-primary, .docstring > section > a.hero.docs-sourcelink {
+    background-color: #4eb5de;
+    color: #fff; }
+    .hero.is-primary a:not(.button):not(.dropdown-item):not(.tag):not(.pagination-link.is-current), .docstring > section > a.hero.docs-sourcelink a:not(.button):not(.dropdown-item):not(.tag):not(.pagination-link.is-current),
+    .hero.is-primary strong,
+    .docstring > section > a.hero.docs-sourcelink strong {
+      color: inherit; }
+    .hero.is-primary .title, .docstring > section > a.hero.docs-sourcelink .title {
+      color: #fff; }
+    .hero.is-primary .subtitle, .docstring > section > a.hero.docs-sourcelink .subtitle {
+      color: rgba(255, 255, 255, 0.9); }
+      .hero.is-primary .subtitle a:not(.button), .docstring > section > a.hero.docs-sourcelink .subtitle a:not(.button),
+      .hero.is-primary .subtitle strong,
+      .docstring > section > a.hero.docs-sourcelink .subtitle strong {
+        color: #fff; }
+    @media screen and (max-width: 1055px) {
+      .hero.is-primary .navbar-menu, .docstring > section > a.hero.docs-sourcelink .navbar-menu {
+        background-color: #4eb5de; } }
+    .hero.is-primary .navbar-item, .docstring > section > a.hero.docs-sourcelink .navbar-item,
+    .hero.is-primary .navbar-link,
+    .docstring > section > a.hero.docs-sourcelink .navbar-link {
+      color: rgba(255, 255, 255, 0.7); }
+    .hero.is-primary a.navbar-item:hover, .docstring > section > a.hero.docs-sourcelink a.navbar-item:hover, .hero.is-primary a.navbar-item.is-active, .docstring > section > a.hero.docs-sourcelink a.navbar-item.is-active,
+    .hero.is-primary .navbar-link:hover,
+    .docstring > section > a.hero.docs-sourcelink .navbar-link:hover,
+    .hero.is-primary .navbar-link.is-active,
+    .docstring > section > a.hero.docs-sourcelink .navbar-link.is-active {
+      background-color: #39acda;
+      color: #fff; }
+    .hero.is-primary .tabs a, .docstring > section > a.hero.docs-sourcelink .tabs a {
+      color: #fff;
+      opacity: 0.9; }
+      .hero.is-primary .tabs a:hover, .docstring > section > a.hero.docs-sourcelink .tabs a:hover {
+        opacity: 1; }
+    .hero.is-primary .tabs li.is-active a, .docstring > section > a.hero.docs-sourcelink .tabs li.is-active a {
+      opacity: 1; }
+    .hero.is-primary .tabs.is-boxed a, .docstring > section > a.hero.docs-sourcelink .tabs.is-boxed a, .hero.is-primary .tabs.is-toggle a, .docstring > section > a.hero.docs-sourcelink .tabs.is-toggle a {
+      color: #fff; }
+      .hero.is-primary .tabs.is-boxed a:hover, .docstring > section > a.hero.docs-sourcelink .tabs.is-boxed a:hover, .hero.is-primary .tabs.is-toggle a:hover, .docstring > section > a.hero.docs-sourcelink .tabs.is-toggle a:hover {
+        background-color: rgba(10, 10, 10, 0.1); }
+    .hero.is-primary .tabs.is-boxed li.is-active a, .docstring > section > a.hero.docs-sourcelink .tabs.is-boxed li.is-active a, .hero.is-primary .tabs.is-boxed li.is-active a:hover, .docstring > section > a.hero.docs-sourcelink .tabs.is-boxed li.is-active a:hover, .hero.is-primary .tabs.is-toggle li.is-active a, .docstring > section > a.hero.docs-sourcelink .tabs.is-toggle li.is-active a, .hero.is-primary .tabs.is-toggle li.is-active a:hover, .docstring > section > a.hero.docs-sourcelink .tabs.is-toggle li.is-active a:hover {
+      background-color: #fff;
+      border-color: #fff;
+      color: #4eb5de; }
+    .hero.is-primary.is-bold, .docstring > section > a.hero.is-bold.docs-sourcelink {
+      background-image: linear-gradient(141deg, #1bc7de 0%, #4eb5de 71%, #5fa9e7 100%); }
+      @media screen and (max-width: 768px) {
+        .hero.is-primary.is-bold .navbar-menu, .docstring > section > a.hero.is-bold.docs-sourcelink .navbar-menu {
+          background-image: linear-gradient(141deg, #1bc7de 0%, #4eb5de 71%, #5fa9e7 100%); } }
+  .hero.is-link {
+    background-color: #2e63b8;
+    color: #fff; }
+    .hero.is-link a:not(.button):not(.dropdown-item):not(.tag):not(.pagination-link.is-current),
+    .hero.is-link strong {
+      color: inherit; }
+    .hero.is-link .title {
+      color: #fff; }
+    .hero.is-link .subtitle {
+      color: rgba(255, 255, 255, 0.9); }
+      .hero.is-link .subtitle a:not(.button),
+      .hero.is-link .subtitle strong {
+        color: #fff; }
+    @media screen and (max-width: 1055px) {
+      .hero.is-link .navbar-menu {
+        background-color: #2e63b8; } }
+    .hero.is-link .navbar-item,
+    .hero.is-link .navbar-link {
+      color: rgba(255, 255, 255, 0.7); }
+    .hero.is-link a.navbar-item:hover, .hero.is-link a.navbar-item.is-active,
+    .hero.is-link .navbar-link:hover,
+    .hero.is-link .navbar-link.is-active {
+      background-color: #2958a4;
+      color: #fff; }
+    .hero.is-link .tabs a {
+      color: #fff;
+      opacity: 0.9; }
+      .hero.is-link .tabs a:hover {
+        opacity: 1; }
+    .hero.is-link .tabs li.is-active a {
+      opacity: 1; }
+    .hero.is-link .tabs.is-boxed a, .hero.is-link .tabs.is-toggle a {
+      color: #fff; }
+      .hero.is-link .tabs.is-boxed a:hover, .hero.is-link .tabs.is-toggle a:hover {
+        background-color: rgba(10, 10, 10, 0.1); }
+    .hero.is-link .tabs.is-boxed li.is-active a, .hero.is-link .tabs.is-boxed li.is-active a:hover, .hero.is-link .tabs.is-toggle li.is-active a, .hero.is-link .tabs.is-toggle li.is-active a:hover {
+      background-color: #fff;
+      border-color: #fff;
+      color: #2e63b8; }
+    .hero.is-link.is-bold {
+      background-image: linear-gradient(141deg, #1b6098 0%, #2e63b8 71%, #2d51d2 100%); }
+      @media screen and (max-width: 768px) {
+        .hero.is-link.is-bold .navbar-menu {
+          background-image: linear-gradient(141deg, #1b6098 0%, #2e63b8 71%, #2d51d2 100%); } }
+  .hero.is-info {
+    background-color: #209cee;
+    color: #fff; }
+    .hero.is-info a:not(.button):not(.dropdown-item):not(.tag):not(.pagination-link.is-current),
+    .hero.is-info strong {
+      color: inherit; }
+    .hero.is-info .title {
+      color: #fff; }
+    .hero.is-info .subtitle {
+      color: rgba(255, 255, 255, 0.9); }
+      .hero.is-info .subtitle a:not(.button),
+      .hero.is-info .subtitle strong {
+        color: #fff; }
+    @media screen and (max-width: 1055px) {
+      .hero.is-info .navbar-menu {
+        background-color: #209cee; } }
+    .hero.is-info .navbar-item,
+    .hero.is-info .navbar-link {
+      color: rgba(255, 255, 255, 0.7); }
+    .hero.is-info a.navbar-item:hover, .hero.is-info a.navbar-item.is-active,
+    .hero.is-info .navbar-link:hover,
+    .hero.is-info .navbar-link.is-active {
+      background-color: #118fe4;
+      color: #fff; }
+    .hero.is-info .tabs a {
+      color: #fff;
+      opacity: 0.9; }
+      .hero.is-info .tabs a:hover {
+        opacity: 1; }
+    .hero.is-info .tabs li.is-active a {
+      opacity: 1; }
+    .hero.is-info .tabs.is-boxed a, .hero.is-info .tabs.is-toggle a {
+      color: #fff; }
+      .hero.is-info .tabs.is-boxed a:hover, .hero.is-info .tabs.is-toggle a:hover {
+        background-color: rgba(10, 10, 10, 0.1); }
+    .hero.is-info .tabs.is-boxed li.is-active a, .hero.is-info .tabs.is-boxed li.is-active a:hover, .hero.is-info .tabs.is-toggle li.is-active a, .hero.is-info .tabs.is-toggle li.is-active a:hover {
+      background-color: #fff;
+      border-color: #fff;
+      color: #209cee; }
+    .hero.is-info.is-bold {
+      background-image: linear-gradient(141deg, #04a6d7 0%, #209cee 71%, #3287f5 100%); }
+      @media screen and (max-width: 768px) {
+        .hero.is-info.is-bold .navbar-menu {
+          background-image: linear-gradient(141deg, #04a6d7 0%, #209cee 71%, #3287f5 100%); } }
+  .hero.is-success {
+    background-color: #22c35b;
+    color: #fff; }
+    .hero.is-success a:not(.button):not(.dropdown-item):not(.tag):not(.pagination-link.is-current),
+    .hero.is-success strong {
+      color: inherit; }
+    .hero.is-success .title {
+      color: #fff; }
+    .hero.is-success .subtitle {
+      color: rgba(255, 255, 255, 0.9); }
+      .hero.is-success .subtitle a:not(.button),
+      .hero.is-success .subtitle strong {
+        color: #fff; }
+    @media screen and (max-width: 1055px) {
+      .hero.is-success .navbar-menu {
+        background-color: #22c35b; } }
+    .hero.is-success .navbar-item,
+    .hero.is-success .navbar-link {
+      color: rgba(255, 255, 255, 0.7); }
+    .hero.is-success a.navbar-item:hover, .hero.is-success a.navbar-item.is-active,
+    .hero.is-success .navbar-link:hover,
+    .hero.is-success .navbar-link.is-active {
+      background-color: #1ead51;
+      color: #fff; }
+    .hero.is-success .tabs a {
+      color: #fff;
+      opacity: 0.9; }
+      .hero.is-success .tabs a:hover {
+        opacity: 1; }
+    .hero.is-success .tabs li.is-active a {
+      opacity: 1; }
+    .hero.is-success .tabs.is-boxed a, .hero.is-success .tabs.is-toggle a {
+      color: #fff; }
+      .hero.is-success .tabs.is-boxed a:hover, .hero.is-success .tabs.is-toggle a:hover {
+        background-color: rgba(10, 10, 10, 0.1); }
+    .hero.is-success .tabs.is-boxed li.is-active a, .hero.is-success .tabs.is-boxed li.is-active a:hover, .hero.is-success .tabs.is-toggle li.is-active a, .hero.is-success .tabs.is-toggle li.is-active a:hover {
+      background-color: #fff;
+      border-color: #fff;
+      color: #22c35b; }
+    .hero.is-success.is-bold {
+      background-image: linear-gradient(141deg, #12a02c 0%, #22c35b 71%, #1fdf83 100%); }
+      @media screen and (max-width: 768px) {
+        .hero.is-success.is-bold .navbar-menu {
+          background-image: linear-gradient(141deg, #12a02c 0%, #22c35b 71%, #1fdf83 100%); } }
+  .hero.is-warning {
+    background-color: #ffdd57;
+    color: rgba(0, 0, 0, 0.7); }
+    .hero.is-warning a:not(.button):not(.dropdown-item):not(.tag):not(.pagination-link.is-current),
+    .hero.is-warning strong {
+      color: inherit; }
+    .hero.is-warning .title {
+      color: rgba(0, 0, 0, 0.7); }
+    .hero.is-warning .subtitle {
+      color: rgba(0, 0, 0, 0.9); }
+      .hero.is-warning .subtitle a:not(.button),
+      .hero.is-warning .subtitle strong {
+        color: rgba(0, 0, 0, 0.7); }
+    @media screen and (max-width: 1055px) {
+      .hero.is-warning .navbar-menu {
+        background-color: #ffdd57; } }
+    .hero.is-warning .navbar-item,
+    .hero.is-warning .navbar-link {
+      color: rgba(0, 0, 0, 0.7); }
+    .hero.is-warning a.navbar-item:hover, .hero.is-warning a.navbar-item.is-active,
+    .hero.is-warning .navbar-link:hover,
+    .hero.is-warning .navbar-link.is-active {
+      background-color: #ffd83d;
+      color: rgba(0, 0, 0, 0.7); }
+    .hero.is-warning .tabs a {
+      color: rgba(0, 0, 0, 0.7);
+      opacity: 0.9; }
+      .hero.is-warning .tabs a:hover {
+        opacity: 1; }
+    .hero.is-warning .tabs li.is-active a {
+      opacity: 1; }
+    .hero.is-warning .tabs.is-boxed a, .hero.is-warning .tabs.is-toggle a {
+      color: rgba(0, 0, 0, 0.7); }
+      .hero.is-warning .tabs.is-boxed a:hover, .hero.is-warning .tabs.is-toggle a:hover {
+        background-color: rgba(10, 10, 10, 0.1); }
+    .hero.is-warning .tabs.is-boxed li.is-active a, .hero.is-warning .tabs.is-boxed li.is-active a:hover, .hero.is-warning .tabs.is-toggle li.is-active a, .hero.is-warning .tabs.is-toggle li.is-active a:hover {
+      background-color: rgba(0, 0, 0, 0.7);
+      border-color: rgba(0, 0, 0, 0.7);
+      color: #ffdd57; }
+    .hero.is-warning.is-bold {
+      background-image: linear-gradient(141deg, #ffaf24 0%, #ffdd57 71%, #fffa70 100%); }
+      @media screen and (max-width: 768px) {
+        .hero.is-warning.is-bold .navbar-menu {
+          background-image: linear-gradient(141deg, #ffaf24 0%, #ffdd57 71%, #fffa70 100%); } }
+  .hero.is-danger {
+    background-color: #da0b00;
+    color: #fff; }
+    .hero.is-danger a:not(.button):not(.dropdown-item):not(.tag):not(.pagination-link.is-current),
+    .hero.is-danger strong {
+      color: inherit; }
+    .hero.is-danger .title {
+      color: #fff; }
+    .hero.is-danger .subtitle {
+      color: rgba(255, 255, 255, 0.9); }
+      .hero.is-danger .subtitle a:not(.button),
+      .hero.is-danger .subtitle strong {
+        color: #fff; }
+    @media screen and (max-width: 1055px) {
+      .hero.is-danger .navbar-menu {
+        background-color: #da0b00; } }
+    .hero.is-danger .navbar-item,
+    .hero.is-danger .navbar-link {
+      color: rgba(255, 255, 255, 0.7); }
+    .hero.is-danger a.navbar-item:hover, .hero.is-danger a.navbar-item.is-active,
+    .hero.is-danger .navbar-link:hover,
+    .hero.is-danger .navbar-link.is-active {
+      background-color: #c10a00;
+      color: #fff; }
+    .hero.is-danger .tabs a {
+      color: #fff;
+      opacity: 0.9; }
+      .hero.is-danger .tabs a:hover {
+        opacity: 1; }
+    .hero.is-danger .tabs li.is-active a {
+      opacity: 1; }
+    .hero.is-danger .tabs.is-boxed a, .hero.is-danger .tabs.is-toggle a {
+      color: #fff; }
+      .hero.is-danger .tabs.is-boxed a:hover, .hero.is-danger .tabs.is-toggle a:hover {
+        background-color: rgba(10, 10, 10, 0.1); }
+    .hero.is-danger .tabs.is-boxed li.is-active a, .hero.is-danger .tabs.is-boxed li.is-active a:hover, .hero.is-danger .tabs.is-toggle li.is-active a, .hero.is-danger .tabs.is-toggle li.is-active a:hover {
+      background-color: #fff;
+      border-color: #fff;
+      color: #da0b00; }
+    .hero.is-danger.is-bold {
+      background-image: linear-gradient(141deg, #a70013 0%, #da0b00 71%, #f43500 100%); }
+      @media screen and (max-width: 768px) {
+        .hero.is-danger.is-bold .navbar-menu {
+          background-image: linear-gradient(141deg, #a70013 0%, #da0b00 71%, #f43500 100%); } }
+  .hero.is-small .hero-body, #documenter .docs-sidebar form.docs-search > input.hero .hero-body {
+    padding-bottom: 1.5rem;
+    padding-top: 1.5rem; }
+  @media screen and (min-width: 769px), print {
+    .hero.is-medium .hero-body {
+      padding-bottom: 9rem;
+      padding-top: 9rem; } }
+  @media screen and (min-width: 769px), print {
+    .hero.is-large .hero-body {
+      padding-bottom: 18rem;
+      padding-top: 18rem; } }
+  .hero.is-halfheight .hero-body, .hero.is-fullheight .hero-body, .hero.is-fullheight-with-navbar .hero-body {
+    align-items: center;
+    display: flex; }
+    .hero.is-halfheight .hero-body > .container, .hero.is-fullheight .hero-body > .container, .hero.is-fullheight-with-navbar .hero-body > .container {
+      flex-grow: 1;
+      flex-shrink: 1; }
+  .hero.is-halfheight {
+    min-height: 50vh; }
+  .hero.is-fullheight {
+    min-height: 100vh; }
+
+.hero-video {
+  overflow: hidden; }
+  .hero-video video {
+    left: 50%;
+    min-height: 100%;
+    min-width: 100%;
+    position: absolute;
+    top: 50%;
+    transform: translate3d(-50%, -50%, 0); }
+  .hero-video.is-transparent {
+    opacity: 0.3; }
+  @media screen and (max-width: 768px) {
+    .hero-video {
+      display: none; } }
+
+.hero-buttons {
+  margin-top: 1.5rem; }
+  @media screen and (max-width: 768px) {
+    .hero-buttons .button {
+      display: flex; }
+      .hero-buttons .button:not(:last-child) {
+        margin-bottom: 0.75rem; } }
+  @media screen and (min-width: 769px), print {
+    .hero-buttons {
+      display: flex;
+      justify-content: center; }
+      .hero-buttons .button:not(:last-child) {
+        margin-right: 1.5rem; } }
+
+.hero-head,
+.hero-foot {
+  flex-grow: 0;
+  flex-shrink: 0; }
+
+.hero-body {
+  flex-grow: 1;
+  flex-shrink: 0;
+  padding: 3rem 1.5rem; }
+
+.section {
+  padding: 3rem 1.5rem; }
+  @media screen and (min-width: 1056px) {
+    .section.is-medium {
+      padding: 9rem 1.5rem; }
+    .section.is-large {
+      padding: 18rem 1.5rem; } }
+
+.footer {
+  background-color: #fafafa;
+  padding: 3rem 1.5rem 6rem; }
+
+h1 .docs-heading-anchor, h1 .docs-heading-anchor:hover, h1 .docs-heading-anchor:visited, h2 .docs-heading-anchor, h2 .docs-heading-anchor:hover, h2 .docs-heading-anchor:visited, h3 .docs-heading-anchor, h3 .docs-heading-anchor:hover, h3 .docs-heading-anchor:visited, h4 .docs-heading-anchor, h4 .docs-heading-anchor:hover, h4 .docs-heading-anchor:visited, h5 .docs-heading-anchor, h5 .docs-heading-anchor:hover, h5 .docs-heading-anchor:visited, h6 .docs-heading-anchor, h6 .docs-heading-anchor:hover, h6 .docs-heading-anchor:visited {
+  color: #222222; }
+
+h1 .docs-heading-anchor-permalink, h2 .docs-heading-anchor-permalink, h3 .docs-heading-anchor-permalink, h4 .docs-heading-anchor-permalink, h5 .docs-heading-anchor-permalink, h6 .docs-heading-anchor-permalink {
+  visibility: hidden;
+  vertical-align: middle;
+  margin-left: 0.5em;
+  font-size: 0.7rem; }
+  h1 .docs-heading-anchor-permalink::before, h2 .docs-heading-anchor-permalink::before, h3 .docs-heading-anchor-permalink::before, h4 .docs-heading-anchor-permalink::before, h5 .docs-heading-anchor-permalink::before, h6 .docs-heading-anchor-permalink::before {
+    font-family: "Font Awesome 5 Free";
+    font-weight: 900;
+    content: "\f0c1"; }
+
+h1:hover .docs-heading-anchor-permalink, h2:hover .docs-heading-anchor-permalink, h3:hover .docs-heading-anchor-permalink, h4:hover .docs-heading-anchor-permalink, h5:hover .docs-heading-anchor-permalink, h6:hover .docs-heading-anchor-permalink {
+  visibility: visible; }
+
+.docs-dark-only {
+  display: none !important; }
+
+.admonition {
+  background-color: #b5b5b5;
+  border-style: solid;
+  border-width: 1px;
+  border-color: #363636;
+  border-radius: 4px;
+  font-size: 1rem; }
+  .admonition strong {
+    color: currentColor; }
+  .admonition.is-small, #documenter .docs-sidebar form.docs-search > input.admonition {
+    font-size: 0.75rem; }
+  .admonition.is-medium {
+    font-size: 1.25rem; }
+  .admonition.is-large {
+    font-size: 1.5rem; }
+  .admonition.is-default {
+    background-color: #b5b5b5;
+    border-color: #363636; }
+    .admonition.is-default > .admonition-header {
+      background-color: #363636;
+      color: #fff; }
+    .admonition.is-default > .admonition-body {
+      color: #fff; }
+  .admonition.is-info {
+    background-color: #b8dffa;
+    border-color: #209cee; }
+    .admonition.is-info > .admonition-header {
+      background-color: #209cee;
+      color: #fff; }
+    .admonition.is-info > .admonition-body {
+      color: rgba(0, 0, 0, 0.7); }
+  .admonition.is-success {
+    background-color: #9beeb8;
+    border-color: #22c35b; }
+    .admonition.is-success > .admonition-header {
+      background-color: #22c35b;
+      color: #fff; }
+    .admonition.is-success > .admonition-body {
+      color: rgba(0, 0, 0, 0.7); }
+  .admonition.is-warning {
+    background-color: #fff3c5;
+    border-color: #ffdd57; }
+    .admonition.is-warning > .admonition-header {
+      background-color: #ffdd57;
+      color: rgba(0, 0, 0, 0.7); }
+    .admonition.is-warning > .admonition-body {
+      color: rgba(0, 0, 0, 0.7); }
+  .admonition.is-danger {
+    background-color: #ff857e;
+    border-color: #da0b00; }
+    .admonition.is-danger > .admonition-header {
+      background-color: #da0b00;
+      color: #fff; }
+    .admonition.is-danger > .admonition-body {
+      color: #fff; }
+  .admonition.is-compat {
+    background-color: #99e6f0;
+    border-color: #1db5c9; }
+    .admonition.is-compat > .admonition-header {
+      background-color: #1db5c9;
+      color: #fff; }
+    .admonition.is-compat > .admonition-body {
+      color: rgba(0, 0, 0, 0.7); }
+
+.admonition-header {
+  color: #fff;
+  background-color: #363636;
+  align-items: center;
+  font-weight: 700;
+  justify-content: space-between;
+  line-height: 1.25;
+  padding: 0.75em;
+  position: relative; }
+  .admonition-header:before {
+    font-family: "Font Awesome 5 Free";
+    font-weight: 900;
+    margin-right: 0.75em;
+    content: "\f06a"; }
+
+.admonition-body {
+  color: #222222;
+  padding: 1em 1.25em; }
+  .admonition-body pre {
+    background-color: whitesmoke; }
+  .admonition-body code {
+    background-color: rgba(0, 0, 0, 0.05); }
+
+.docstring {
+  margin-bottom: 1em;
+  background-color: transparent;
+  border: 1px solid #dbdbdb;
+  box-shadow: 2px 2px 3px rgba(10, 10, 10, 0.1);
+  max-width: 100%; }
+  .docstring > header {
+    display: flex;
+    flex-grow: 1;
+    align-items: stretch;
+    padding: 0.75rem;
+    background-color: whitesmoke;
+    box-shadow: 0 1px 2px rgba(10, 10, 10, 0.1);
+    box-shadow: none;
+    border-bottom: 1px solid #dbdbdb; }
+    .docstring > header code {
+      background-color: transparent; }
+    .docstring > header .docstring-binding {
+      margin-right: 0.3em; }
+    .docstring > header .docstring-category {
+      margin-left: 0.3em; }
+  .docstring > section {
+    position: relative;
+    padding: 1rem 1.25rem;
+    border-bottom: 1px solid #dbdbdb; }
+    .docstring > section:last-child {
+      border-bottom: none; }
+    .docstring > section > a.docs-sourcelink {
+      transition: opacity 0.3s;
+      opacity: 0;
+      position: absolute;
+      right: 0.625rem;
+      bottom: 0.5rem; }
+  .docstring:hover > section > a.docs-sourcelink {
+    opacity: 0.2; }
+  .docstring > section:hover a.docs-sourcelink {
+    opacity: 1; }
+
+.content pre {
+  border: 1px solid #dbdbdb; }
+
+.content code {
+  font-weight: inherit; }
+
+.content a code {
+  color: #2e63b8; }
+
+.content h1 code, .content h2 code, .content h3 code, .content h4 code, .content h5 code, .content h6 code {
+  color: #222222; }
+
+.content table {
+  display: block;
+  width: initial;
+  max-width: 100%;
+  overflow-x: auto; }
+
+.content blockquote > ul:first-child, .content blockquote > ol:first-child, .content .admonition-body > ul:first-child, .content .admonition-body > ol:first-child {
+  margin-top: 0; }
+
+.breadcrumb a.is-disabled {
+  cursor: default;
+  pointer-events: none; }
+  .breadcrumb a.is-disabled, .breadcrumb a.is-disabled:hover {
+    color: #222222; }
+
+.hljs {
+  background: initial !important;
+  padding: initial !important; }
+
+.katex .katex-mathml {
+  top: 0;
+  right: 0; }
+
+html {
+  -moz-osx-font-smoothing: auto;
+  -webkit-font-smoothing: auto; }
+
+/* This file contain the overall layout.
+ *
+ * The main container is <div> that is identified by id #documenter.
+ */
+#documenter .docs-main > article {
+  overflow-wrap: break-word; }
+
+@media screen and (min-width: 1056px) {
+  #documenter .docs-main {
+    max-width: 52rem;
+    margin-left: 20rem;
+    padding-right: 1rem; } }
+
+@media screen and (max-width: 1055px) {
+  #documenter .docs-main {
+    width: 100%; }
+    #documenter .docs-main > article {
+      max-width: 52rem;
+      margin-left: auto;
+      margin-right: auto;
+      margin-bottom: 1rem;
+      padding: 0 1rem; }
+    #documenter .docs-main > header, #documenter .docs-main > nav {
+      max-width: 100%;
+      width: 100%;
+      margin: 0; } }
+
+#documenter .docs-main header.docs-navbar {
+  background-color: white;
+  border-bottom: 1px solid #dbdbdb;
+  z-index: 2;
+  min-height: 4rem;
+  margin-bottom: 1rem;
+  display: flex; }
+  #documenter .docs-main header.docs-navbar .breadcrumb {
+    flex-grow: 1; }
+  #documenter .docs-main header.docs-navbar .docs-right {
+    display: flex;
+    white-space: nowrap; }
+    #documenter .docs-main header.docs-navbar .docs-right .docs-icon, #documenter .docs-main header.docs-navbar .docs-right .docs-label, #documenter .docs-main header.docs-navbar .docs-right .docs-sidebar-button {
+      display: inline-block; }
+    #documenter .docs-main header.docs-navbar .docs-right .docs-label {
+      padding: 0;
+      margin-left: 0.3em; }
+    #documenter .docs-main header.docs-navbar .docs-right .docs-settings-button {
+      margin: auto 0 auto 1rem; }
+    #documenter .docs-main header.docs-navbar .docs-right .docs-sidebar-button {
+      font-size: 1.5rem;
+      margin: auto 0 auto 1rem; }
+  #documenter .docs-main header.docs-navbar > * {
+    margin: auto 0; }
+  @media screen and (max-width: 1055px) {
+    #documenter .docs-main header.docs-navbar {
+      position: sticky;
+      top: 0;
+      padding: 0 1rem;
+      /* For Headroom.js */
+      transition-property: top, box-shadow;
+      -webkit-transition-property: top, box-shadow;
+      /* Safari */
+      transition-duration: 0.3s;
+      -webkit-transition-duration: 0.3s;
+      /* Safari */ }
+      #documenter .docs-main header.docs-navbar.headroom--not-top {
+        box-shadow: 0.2rem 0rem 0.4rem #bbb;
+        transition-duration: 0.7s;
+        -webkit-transition-duration: 0.7s;
+        /* Safari */ }
+      #documenter .docs-main header.docs-navbar.headroom--unpinned.headroom--not-top.headroom--not-bottom {
+        top: -4.5rem;
+        transition-duration: 0.7s;
+        -webkit-transition-duration: 0.7s;
+        /* Safari */ } }
+
+#documenter .docs-main section.footnotes {
+  border-top: 1px solid #dbdbdb; }
+  #documenter .docs-main section.footnotes li .tag:first-child, #documenter .docs-main section.footnotes li .docstring > section > a.docs-sourcelink:first-child, #documenter .docs-main section.footnotes li .content kbd:first-child, .content #documenter .docs-main section.footnotes li kbd:first-child {
+    margin-right: 1em;
+    margin-bottom: 0.4em; }
+
+#documenter .docs-main .docs-footer {
+  display: flex;
+  margin-left: 0;
+  margin-right: 0;
+  border-top: 1px solid #dbdbdb;
+  padding-top: 1rem;
+  padding-bottom: 1rem; }
+  @media screen and (max-width: 1055px) {
+    #documenter .docs-main .docs-footer {
+      padding-left: 1rem;
+      padding-right: 1rem; } }
+  #documenter .docs-main .docs-footer .docs-footer-nextpage, #documenter .docs-main .docs-footer .docs-footer-prevpage {
+    flex-grow: 1; }
+  #documenter .docs-main .docs-footer .docs-footer-nextpage {
+    text-align: right; }
+
+#documenter .docs-sidebar {
+  display: flex;
+  flex-direction: column;
+  color: #0a0a0a;
+  background-color: whitesmoke;
+  border-right: 1px solid #dbdbdb;
+  padding: 0;
+  flex: 0 0 18rem;
+  z-index: 5;
+  position: fixed;
+  left: -18rem;
+  width: 18rem;
+  height: 100%;
+  transition: left 0.3s;
+  /* Setting up a nicer theme style for the scrollbar */ }
+  #documenter .docs-sidebar.visible {
+    left: 0;
+    box-shadow: 0.4rem 0rem 0.8rem #bbb; }
+    @media screen and (min-width: 1056px) {
+      #documenter .docs-sidebar.visible {
+        box-shadow: none; } }
+  @media screen and (min-width: 1056px) {
+    #documenter .docs-sidebar {
+      left: 0;
+      top: 0; } }
+  #documenter .docs-sidebar .docs-logo {
+    margin-top: 1rem;
+    padding: 0 1rem; }
+    #documenter .docs-sidebar .docs-logo > img {
+      max-height: 6rem;
+      margin: auto; }
+  #documenter .docs-sidebar .docs-package-name {
+    flex-shrink: 0;
+    font-size: 1.5rem;
+    font-weight: 700;
+    text-align: center;
+    white-space: nowrap;
+    overflow: hidden;
+    padding: 0.5rem 0; }
+    #documenter .docs-sidebar .docs-package-name .docs-autofit {
+      max-width: 16.2rem; }
+  #documenter .docs-sidebar .docs-version-selector {
+    border-top: 1px solid #dbdbdb;
+    display: none;
+    padding: 0.5rem; }
+    #documenter .docs-sidebar .docs-version-selector.visible {
+      display: flex; }
+  #documenter .docs-sidebar ul.docs-menu {
+    flex-grow: 1;
+    user-select: none;
+    font-size: 1rem;
+    border-top: 1px solid #dbdbdb;
+    padding-bottom: 1.5rem;
+    /* Managing collapsible submenus */ }
+    #documenter .docs-sidebar ul.docs-menu > li > .tocitem {
+      font-weight: bold; }
+    #documenter .docs-sidebar ul.docs-menu > li li {
+      font-size: 0.95rem;
+      margin-left: 1em;
+      border-left: 1px solid #dbdbdb; }
+    #documenter .docs-sidebar ul.docs-menu input.collapse-toggle {
+      display: none; }
+    #documenter .docs-sidebar ul.docs-menu ul.collapsed {
+      display: none; }
+    #documenter .docs-sidebar ul.docs-menu input:checked ~ ul.collapsed {
+      display: block; }
+    #documenter .docs-sidebar ul.docs-menu label.tocitem {
+      display: flex; }
+      #documenter .docs-sidebar ul.docs-menu label.tocitem .docs-label {
+        flex-grow: 2; }
+      #documenter .docs-sidebar ul.docs-menu label.tocitem .docs-chevron {
+        display: inline-block;
+        font-style: normal;
+        font-variant: normal;
+        text-rendering: auto;
+        line-height: 1;
+        font-size: 0.75rem;
+        margin-left: 1rem;
+        margin-top: auto;
+        margin-bottom: auto; }
+        #documenter .docs-sidebar ul.docs-menu label.tocitem .docs-chevron::before {
+          font-family: "Font Awesome 5 Free";
+          font-weight: 900;
+          content: "\f054"; }
+    #documenter .docs-sidebar ul.docs-menu input:checked ~ label.tocitem .docs-chevron::before {
+      content: "\f078"; }
+    #documenter .docs-sidebar ul.docs-menu .tocitem {
+      display: block;
+      padding: 0.5rem 0.5rem; }
+      #documenter .docs-sidebar ul.docs-menu .tocitem, #documenter .docs-sidebar ul.docs-menu .tocitem:hover {
+        color: #0a0a0a; }
+    #documenter .docs-sidebar ul.docs-menu a.tocitem:hover, #documenter .docs-sidebar ul.docs-menu label.tocitem:hover {
+      background-color: #ebebeb; }
+    #documenter .docs-sidebar ul.docs-menu li.is-active {
+      border-top: 1px solid #c7c7c7;
+      border-bottom: 1px solid #dbdbdb;
+      background-color: white; }
+      #documenter .docs-sidebar ul.docs-menu li.is-active > .tocitem, #documenter .docs-sidebar ul.docs-menu li.is-active > .tocitem:hover {
+        background-color: white;
+        color: #0a0a0a; }
+    #documenter .docs-sidebar ul.docs-menu > li.is-active:first-child {
+      border-top: none; }
+    #documenter .docs-sidebar ul.docs-menu ul.internal {
+      margin: 0 0.5rem 0.5rem;
+      border-top: 1px solid #dbdbdb; }
+      #documenter .docs-sidebar ul.docs-menu ul.internal li {
+        font-size: 0.85rem;
+        border-left: none;
+        margin-left: 0;
+        margin-top: 0.5rem; }
+      #documenter .docs-sidebar ul.docs-menu ul.internal .tocitem {
+        width: 100%;
+        padding: 0; }
+        #documenter .docs-sidebar ul.docs-menu ul.internal .tocitem::before {
+          content: "⚬";
+          margin-right: 0.4em; }
+  #documenter .docs-sidebar form.docs-search {
+    margin: auto;
+    margin-top: 0.5rem;
+    margin-bottom: 0.5rem; }
+    #documenter .docs-sidebar form.docs-search > input {
+      width: 14.4rem; }
+  @media screen and (min-width: 1056px) {
+    #documenter .docs-sidebar ul.docs-menu {
+      overflow-y: auto;
+      -webkit-overflow-scroll: touch; }
+      #documenter .docs-sidebar ul.docs-menu::-webkit-scrollbar {
+        width: .3rem;
+        background: none; }
+      #documenter .docs-sidebar ul.docs-menu::-webkit-scrollbar-thumb {
+        border-radius: 5px 0px 0px 5px;
+        background: #e0e0e0; }
+      #documenter .docs-sidebar ul.docs-menu::-webkit-scrollbar-thumb:hover {
+        background: #cccccc; } }
+  @media screen and (max-width: 1055px) {
+    #documenter .docs-sidebar {
+      overflow-y: auto;
+      -webkit-overflow-scroll: touch; }
+      #documenter .docs-sidebar::-webkit-scrollbar {
+        width: .3rem;
+        background: none; }
+      #documenter .docs-sidebar::-webkit-scrollbar-thumb {
+        border-radius: 5px 0px 0px 5px;
+        background: #e0e0e0; }
+      #documenter .docs-sidebar::-webkit-scrollbar-thumb:hover {
+        background: #cccccc; } }
+
+#documenter .docs-main #documenter-search-info {
+  margin-bottom: 1rem; }
+
+#documenter .docs-main #documenter-search-results {
+  list-style-type: circle;
+  list-style-position: outside; }
+  #documenter .docs-main #documenter-search-results li {
+    margin-left: 2rem; }
+  #documenter .docs-main #documenter-search-results .docs-highlight {
+    background-color: yellow; }
+
+/*
+
+Original highlight.js style (c) Ivan Sagalaev <maniac@softwaremaniacs.org>
+
+*/
+.hljs {
+  display: block;
+  overflow-x: auto;
+  padding: 0.5em;
+  background: #F0F0F0; }
+
+/* Base color: saturation 0; */
+.hljs,
+.hljs-subst {
+  color: #444; }
+
+.hljs-comment {
+  color: #888888; }
+
+.hljs-keyword,
+.hljs-attribute,
+.hljs-selector-tag,
+.hljs-meta-keyword,
+.hljs-doctag,
+.hljs-name {
+  font-weight: bold; }
+
+/* User color: hue: 0 */
+.hljs-type,
+.hljs-string,
+.hljs-number,
+.hljs-selector-id,
+.hljs-selector-class,
+.hljs-quote,
+.hljs-template-tag,
+.hljs-deletion {
+  color: #880000; }
+
+.hljs-title,
+.hljs-section {
+  color: #880000;
+  font-weight: bold; }
+
+.hljs-regexp,
+.hljs-symbol,
+.hljs-variable,
+.hljs-template-variable,
+.hljs-link,
+.hljs-selector-attr,
+.hljs-selector-pseudo {
+  color: #BC6060; }
+
+/* Language color: hue: 90; */
+.hljs-literal {
+  color: #78A960; }
+
+.hljs-built_in,
+.hljs-bullet,
+.hljs-code,
+.hljs-addition {
+  color: #397300; }
+
+/* Meta color: hue: 200 */
+.hljs-meta {
+  color: #1f7199; }
+
+.hljs-meta-string {
+  color: #4d99bf; }
+
+/* Misc effects */
+.hljs-emphasis {
+  font-style: italic; }
+
+.hljs-strong {
+  font-weight: bold; }
diff -pruN 1.3.1+dfsg-1/debian/embedded/Documenter/assets/html/themeswap.js 1.4.0+dfsg-1/debian/embedded/Documenter/assets/html/themeswap.js
--- 1.3.1+dfsg-1/debian/embedded/Documenter/assets/html/themeswap.js	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/debian/embedded/Documenter/assets/html/themeswap.js	2020-03-30 16:16:04.000000000 +0000
@@ -0,0 +1,42 @@
+// Small function to quickly swap out themes. Gets put into the <head> tag..
+function set_theme_from_local_storage() {
+  // Browser does not support Web Storage, bail early.
+  if(typeof(window.localStorage) === "undefined") return;
+  // Get the user-picked theme from localStorage. May be `null`, which means the default
+  // theme.
+  var theme =  window.localStorage.getItem("documenter-theme");
+  // Initialize a few variables for the loop:
+  //
+  //  - active: will contain the index of the theme that should be active. Note that there
+  //    is no guarantee that localStorage contains sane values. If `active` stays `null`
+  //    we either could not find the theme or it is the default (primary) theme anyway.
+  //    Either way, we then need to stick to the primary theme.
+  //
+  //  - disabled: style sheets that should be disabled (i.e. all the theme style sheets
+  //    that are not the currently active theme)
+  var active = null; var disabled = [];
+  for (var i = 0; i < document.styleSheets.length; i++) {
+    var ss = document.styleSheets[i];
+    // The <link> tag of each style sheet is expected to have a data-theme-name attribute
+    // which must contain the name of the theme. The names in localStorage much match this.
+    var themename = ss.ownerNode.getAttribute("data-theme-name");
+    // attribute not set => non-theme stylesheet => ignore
+    if(themename === null) continue;
+    // To distinguish the default (primary) theme, it needs to have the data-theme-primary
+    // attribute set.
+    var isprimary = (ss.ownerNode.getAttribute("data-theme-primary") !== null);
+    // If we find a matching theme (and it's not the default), we'll set active to non-null
+    if(!isprimary && themename === theme) active = i;
+    // Store the style sheets of inactive themes so that we could disable them
+    if(themename !== theme) disabled.push(ss);
+  }
+  if(active !== null) {
+    // If we did find an active theme, we'll (1) add the theme--$(theme) class to <html>
+    document.getElementsByTagName('html')[0].className = "theme--" + theme;
+    // and (2) disable all the other theme stylesheets
+    disabled.forEach(function(ss){
+      ss.disabled = true;
+    });
+  }
+}
+set_theme_from_local_storage();
diff -pruN 1.3.1+dfsg-1/debian/embedded/Documenter/assets/latex/documenter.sty 1.4.0+dfsg-1/debian/embedded/Documenter/assets/latex/documenter.sty
--- 1.3.1+dfsg-1/debian/embedded/Documenter/assets/latex/documenter.sty	2019-11-28 04:21:05.000000000 +0000
+++ 1.4.0+dfsg-1/debian/embedded/Documenter/assets/latex/documenter.sty	2020-03-30 16:16:04.000000000 +0000
@@ -83,4 +83,5 @@
 
 % images etc.
 \usepackage{graphicx}
+\usepackage[export]{adjustbox}
 %
diff -pruN 1.3.1+dfsg-1/debian/embedded/Documenter/CHANGELOG.md 1.4.0+dfsg-1/debian/embedded/Documenter/CHANGELOG.md
--- 1.3.1+dfsg-1/debian/embedded/Documenter/CHANGELOG.md	2019-11-28 04:21:05.000000000 +0000
+++ 1.4.0+dfsg-1/debian/embedded/Documenter/CHANGELOG.md	2020-03-30 16:16:04.000000000 +0000
@@ -1,5 +1,93 @@
 # Documenter.jl changelog
 
+## Version `v0.24.4`
+
+* ![Enhancement][badge-enhancement] Change the inline code to less distracting black color in the HTML light theme. ([#1212][github-1212], [#1222][github-1222])
+
+* ![Enhancement][badge-enhancement] Add the ability specify the `lang` attribute of the `html` tag in the HTML output, to better support documentation pages in other languages. By default Documenter now defaults to `lang="en"`. ([#1223][github-1223])
+
+## Version `v0.24.3`
+
+* ![Bugfix][badge-bugfix] Fix a case where Documenter's deployment would fail due to git picking up the wrong ssh config file on non-standard systems. ([#1216][github-1216])
+
+## Version `v0.24.2`
+
+* ![Maintenance][badge-maintenance] Improvements to logging in `deploydocs`. ([#1195][github-1195])
+
+## Version `v0.24.1`
+
+* ![Bugfix][badge-bugfix] Fix a bad `mktempdir` incantation in `LaTeXWriter`. ([#1194][github-1194])
+
+## Version `v0.24.0`
+
+* ![BREAKING][badge-breaking] Documenter no longer creates a symlink between the old `latest` url to specified `devurl`. ([#1151][github-1151])
+
+  **For upgrading:** Make sure that links to the latest documentation have been updated (e.g. the package README).
+
+* ![BREAKING][badge-breaking] The deprecated `makedocs` keywords (`html_prettyurls`, `html_disable_git`, `html_edit_branch`, `html_canonical`, `assets`, `analytics`) have been removed. ([#1107][github-1107])
+
+  **For upgrading:** Pass the corresponding values to the `HTML` constructor when settings the `format` keyword.
+
+* ![Feature][badge-feature] Documenter can now deploy preview documentation from pull requests (with head branch in the same repository, i.e. not from forks). This is enabled by passing `push_preview=true` to `deploydocs`. ([#1180][github-1180])
+
+* ![Enhancement][badge-enhancement] The Documenter HTML front end now uses [KaTeX](https://katex.org/) as the default math rendering engine. ([#1097][github-1097])
+
+  **Possible breakage:** This may break the rendering of equations that use some more esoteric features that are only supported in MathJax. It is possible to switch back to MathJax by passing `mathengine = Documenter.MathJax()` to the `HTML` constructor in the `format` keyword.
+
+* ![Enhancement][badge-enhancement] The HTML front end generated by Documenter has been redesigned and now uses the [Bulma CSS framework](https://bulma.io/). ([#1043][github-1043])
+
+  **Possible breakage:** Packages overriding the default Documenter CSS file, relying on some external CSS or relying on Documenter's CSS working in a particular way will not build correct-looking sites. Custom themes should now be developed as Sass files and compiled together with the Documenter and Bulma Sass dependencies (under `assets/html/scss`).
+
+* ![Deprecation][badge-deprecation] ![Enhancement][badge-enhancement] The `edit_branch` keyword to `Documenter.HTML` has been deprecated in favor of the new `edit_link` keyword. As a new feature, passing `edit_link = nothing` disables the "Edit on GitHub" links altogether. ([#1173][github-1173])
+
+  **For upgrading:** If using `edit_branch = nothing`, use `edit_link = :commit` instead. If passing a `String` to `edit_branch`, pass that to `edit_link` instead.
+
+* ![Feature][badge-feature] Deployment is now more customizable and thus not as tied to Travis CI as before. ([#1147][github-1147], [#1171][github-1171], [#1180][github-1180])
+
+* ![Feature][badge-feature] Documenter now has builtin support for deploying from GitHub Actions. Documenter will autodetect the running system, unless explicitly specified. ([#1144][github-1144], [#1152][github-1152])
+
+* ![Feature][badge-feature] When using GitHub Actions Documenter will (try to) post a GitHub status with a link to the generated documentation. This is especially useful for pull request preview builds (see above). ([#1186][github-1186])
+
+* ![Enhancement][badge-enhancement] The handling of JS and CSS assets is now more customizable:
+
+  * The `asset` function can now be used to declare remote JS and CSS assets in the `assets` keyword. ([#1108][github-1108])
+  * The `highlights` keyword to `HTML` can be used to declare additional languages that should be highlighted in code blocks. ([#1094][github-1094])
+  * It is now possible to choose between MathJax and KaTeX as the math rendering engine with the `mathengine` keyword to `HTML` and to set their configuration in the `make.jl` script directly. ([#1097][github-1097])
+
+* ![Enhancement][badge-enhancement] The JS and CSS dependencies of the front end have been updated to the latest versions. ([#1189][github-1189])
+
+* ![Enhancement][badge-enhancement] Displaying of the site name at the top of the sidebar can now be disabled by passing `sidebar_sitename = false` to `HTML` in the `format` keyword. ([#1089][github-1089])
+
+* ![Enhancement][badge-enhancement] For deployments that have Google Analytics enabled, the URL fragment (i.e. the in-page `#` target) also stored in analytics. ([#1121][github-1121])
+
+* ![Enhancement][badge-enhancement] Page titles are now boosted in the search, yielding better search results. ([#631][github-631], [#1112][github-1112], [#1113][github-1113])
+
+* ![Enhancement][badge-enhancement] In the PDF/LaTeX output, images that are wider than the text are now being scaled down to text width automatically. The PDF builds now require the [adjustbox](https://ctan.org/pkg/adjustbox) LaTeX package to be available. ([#1137][github-1137])
+
+* ![Enhancement][badge-enhancement] If the TeX compilation fails for the PDF/LaTeX output, `makedocs` now throws an exception. ([#1166][github-1166])
+
+* ![Bugfix][badge-bugfix] `LaTeXWriter` now outputs valid LaTeX if an `@contents` block is nested by more than two levels, or if `@contents` or `@index` blocks do not contain any items. ([#1166][github-1166])
+
+## Version `v0.23.4`
+
+* ![Bugfix][badge-bugfix] The `include` and `eval` functions are also available in `@setup` blocks now. ([#1148][github-1148], [#1153][github-1153])
+
+## Version `v0.23.3`
+
+* ![Bugfix][badge-bugfix] Fix file permission error when `Pkg.test`ing Documenter. ([#1115][github-1115])
+
+## Version `v0.23.2`
+
+* ![Bugfix][badge-bugfix] Empty Markdown headings no longer cause Documenter to crash. ([#1081][github-1081], [#1082][github-1082])
+
+## Version `v0.23.1`
+
+* ![Bugfix][badge-bugfix] Documenter no longer throws an error if the provided `EditURL` argument is missing. ([#1076][github-1076], [#1077][github-1077])
+
+* ![Bugfix][badge-bugfix] Non-standard Markdown AST nodes no longer cause Documenter to exit with a missing method error in doctesting and HTML output. Documenter falls back to `repr()` for such nodes. ([#1073][github-1073], [#1075][github-1075])
+
+* ![Bugfix][badge-bugfix] Docstrings parsed into nested `Markdown.MD` objects are now unwrapped correctly and do not cause Documenter to crash with a missing method error anymore. The user can run into that when reusing docstrings with the `@doc @doc(foo) function bar end` pattern. ([#1075][github-1075])
+
 ## Version `v0.23.0`
 
 * Documenter v0.23 requires Julia v1.0. ([#1015][github-1015])
@@ -303,6 +391,7 @@
 [github-487]: https://github.com/JuliaDocs/Documenter.jl/issues/487
 [github-511]: https://github.com/JuliaDocs/Documenter.jl/pull/511
 [github-535]: https://github.com/JuliaDocs/Documenter.jl/issues/535
+[github-631]: https://github.com/JuliaDocs/Documenter.jl/issues/631
 [github-697]: https://github.com/JuliaDocs/Documenter.jl/pull/697
 [github-706]: https://github.com/JuliaDocs/Documenter.jl/pull/706
 [github-756]: https://github.com/JuliaDocs/Documenter.jl/issues/756
@@ -377,6 +466,7 @@
 [github-1031]: https://github.com/JuliaDocs/Documenter.jl/issues/1031
 [github-1034]: https://github.com/JuliaDocs/Documenter.jl/pull/1034
 [github-1037]: https://github.com/JuliaDocs/Documenter.jl/pull/1037
+[github-1043]: https://github.com/JuliaDocs/Documenter.jl/pull/1043
 [github-1046]: https://github.com/JuliaDocs/Documenter.jl/issues/1046
 [github-1047]: https://github.com/JuliaDocs/Documenter.jl/pull/1047
 [github-1054]: https://github.com/JuliaDocs/Documenter.jl/pull/1054
@@ -384,6 +474,40 @@
 [github-1062]: https://github.com/JuliaDocs/Documenter.jl/pull/1062
 [github-1066]: https://github.com/JuliaDocs/Documenter.jl/pull/1066
 [github-1071]: https://github.com/JuliaDocs/Documenter.jl/pull/1071
+[github-1073]: https://github.com/JuliaDocs/Documenter.jl/issues/1073
+[github-1075]: https://github.com/JuliaDocs/Documenter.jl/pull/1075
+[github-1076]: https://github.com/JuliaDocs/Documenter.jl/issues/1076
+[github-1077]: https://github.com/JuliaDocs/Documenter.jl/pull/1077
+[github-1081]: https://github.com/JuliaDocs/Documenter.jl/issues/1081
+[github-1082]: https://github.com/JuliaDocs/Documenter.jl/pull/1082
+[github-1089]: https://github.com/JuliaDocs/Documenter.jl/pull/1089
+[github-1094]: https://github.com/JuliaDocs/Documenter.jl/pull/1094
+[github-1097]: https://github.com/JuliaDocs/Documenter.jl/pull/1097
+[github-1107]: https://github.com/JuliaDocs/Documenter.jl/pull/1107
+[github-1108]: https://github.com/JuliaDocs/Documenter.jl/pull/1108
+[github-1112]: https://github.com/JuliaDocs/Documenter.jl/pull/1112
+[github-1113]: https://github.com/JuliaDocs/Documenter.jl/pull/1113
+[github-1115]: https://github.com/JuliaDocs/Documenter.jl/pull/1115
+[github-1121]: https://github.com/JuliaDocs/Documenter.jl/pull/1121
+[github-1137]: https://github.com/JuliaDocs/Documenter.jl/pull/1137
+[github-1144]: https://github.com/JuliaDocs/Documenter.jl/pull/1144
+[github-1147]: https://github.com/JuliaDocs/Documenter.jl/pull/1147
+[github-1148]: https://github.com/JuliaDocs/Documenter.jl/issues/1148
+[github-1151]: https://github.com/JuliaDocs/Documenter.jl/pull/1151
+[github-1152]: https://github.com/JuliaDocs/Documenter.jl/pull/1152
+[github-1153]: https://github.com/JuliaDocs/Documenter.jl/pull/1153
+[github-1166]: https://github.com/JuliaDocs/Documenter.jl/pull/1166
+[github-1171]: https://github.com/JuliaDocs/Documenter.jl/pull/1171
+[github-1173]: https://github.com/JuliaDocs/Documenter.jl/pull/1173
+[github-1180]: https://github.com/JuliaDocs/Documenter.jl/pull/1180
+[github-1186]: https://github.com/JuliaDocs/Documenter.jl/pull/1186
+[github-1189]: https://github.com/JuliaDocs/Documenter.jl/pull/1189
+[github-1194]: https://github.com/JuliaDocs/Documenter.jl/pull/1194
+[github-1195]: https://github.com/JuliaDocs/Documenter.jl/pull/1195
+[github-1212]: https://github.com/JuliaDocs/Documenter.jl/issues/1212
+[github-1216]: https://github.com/JuliaDocs/Documenter.jl/pull/1216
+[github-1222]: https://github.com/JuliaDocs/Documenter.jl/pull/1222
+[github-1223]: https://github.com/JuliaDocs/Documenter.jl/pull/1223
 
 [documenterlatex]: https://github.com/JuliaDocs/DocumenterLaTeX.jl
 [documentermarkdown]: https://github.com/JuliaDocs/DocumenterMarkdown.jl
diff -pruN 1.3.1+dfsg-1/debian/embedded/Documenter/docs/DocumenterShowcase.jl 1.4.0+dfsg-1/debian/embedded/Documenter/docs/DocumenterShowcase.jl
--- 1.3.1+dfsg-1/debian/embedded/Documenter/docs/DocumenterShowcase.jl	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/debian/embedded/Documenter/docs/DocumenterShowcase.jl	2020-03-30 16:16:04.000000000 +0000
@@ -0,0 +1,76 @@
+"""
+This is the [`DocumenterShowcase`](@ref), which contains
+
+* [`DocumenterShowcase.foo`](@ref)
+* [`DocumenterShowcase.bar`](@ref)
+
+!!! compat "Documenter 0.24"
+
+    This showcase page is included in Documenter version 0.24.0 and above.
+
+# Contents
+
+Docstrings can contain admonitions and other block-level nodes.
+
+!!! info
+
+    This admonition is in a docstring. It itself can contain block levels nodes such
+    as code blocks:
+
+    ```julia
+    println("Hello World")
+    ```
+
+    ... or block quotes:
+
+    > Lorem ipsum.
+
+In fact, while not recommended, you can actually have a matryoshka of admonitions:
+
+!!! danger
+    !!! warning
+        !!! tip
+            !!! note
+                Stack overflow.
+"""
+module DocumenterShowcase
+
+"""
+Docstring for `foo(::Integer)`.
+"""
+foo(::Integer) = nothing
+
+"""
+Docstring for `foo(::AbstractString)`.
+"""
+foo(::AbstractString) = nothing
+
+"""
+Docstring for `bar(::Integer)`.
+"""
+bar(::Integer) = nothing
+
+"""
+Docstring for `bar(::AbstractString)`.
+"""
+bar(::AbstractString) = nothing
+
+function hello(who)
+    println("Hello, $(who)!")
+end
+
+struct SVGCircle
+    stroke :: String
+    fill :: String
+end
+function Base.show(io, ::MIME"image/svg+xml", c::SVGCircle)
+    write(io, """
+    <svg width="50" height="50">
+      <g style="stroke-width: 3">
+        <circle cx="25" cy="25" r="24" stroke-width="2" style="stroke: #$(c.stroke); fill: #$(c.fill)" />
+      </g>
+    </svg>
+    """)
+end
+
+end # module
diff -pruN 1.3.1+dfsg-1/debian/embedded/Documenter/docs/make.jl 1.4.0+dfsg-1/debian/embedded/Documenter/docs/make.jl
--- 1.3.1+dfsg-1/debian/embedded/Documenter/docs/make.jl	2019-11-28 04:21:05.000000000 +0000
+++ 1.4.0+dfsg-1/debian/embedded/Documenter/docs/make.jl	2020-03-30 16:16:04.000000000 +0000
@@ -1,22 +1,24 @@
 using Documenter, DocumenterTools
+include("DocumenterShowcase.jl")
 
 # The DOCSARGS environment variable can be used to pass additional arguments to make.jl.
 # This is useful on CI, if you need to change the behavior of the build slightly but you
 # can not change the .travis.yml or make.jl scripts any more (e.g. for a tag build).
 if haskey(ENV, "DOCSARGS")
     for arg in split(ENV["DOCSARGS"])
-        push!(ARGS, arg)
+        (arg in ARGS) || push!(ARGS, arg)
     end
 end
 
 makedocs(
-    modules = [Documenter, DocumenterTools],
+    modules = [Documenter, DocumenterTools, DocumenterShowcase],
     format = Documenter.HTML(
         # Use clean URLs, unless built as a "local" build
         prettyurls = !("local" in ARGS),
         canonical = "https://juliadocs.github.io/Documenter.jl/stable/",
         assets = ["assets/favicon.ico"],
         analytics = "UA-136089579-2",
+        highlights = ["yaml"],
     ),
     clean = false,
     sitename = "Documenter.jl",
@@ -35,28 +37,13 @@ makedocs(
             ]),
             "man/other-formats.md",
         ],
+        "showcase.md",
         "Library" => Any[
             "Public" => "lib/public.md",
-            hide("Internals" => "lib/internals.md", Any[
-                "lib/internals/anchors.md",
-                "lib/internals/builder.md",
-                "lib/internals/cross-references.md",
-                "lib/internals/docchecks.md",
-                "lib/internals/docmeta.md",
-                "lib/internals/docsystem.md",
-                "lib/internals/doctests.md",
-                "lib/internals/documenter.md",
-                "lib/internals/documentertools.md",
-                "lib/internals/documents.md",
-                "lib/internals/dom.md",
-                "lib/internals/expanders.md",
-                "lib/internals/markdown2.md",
-                "lib/internals/mdflatten.md",
-                "lib/internals/selectors.md",
-                "lib/internals/textdiff.md",
-                "lib/internals/utilities.md",
-                "lib/internals/writers.md",
-            ])
+            "Internals" => map(
+                s -> "lib/internals/$(s)",
+                sort(readdir(joinpath(@__DIR__, "src/lib/internals")))
+            ),
         ],
         "contributing.md",
     ],
@@ -67,4 +54,5 @@ makedocs(
 deploydocs(
     repo = "github.com/JuliaDocs/Documenter.jl.git",
     target = "build",
+    push_preview = true,
 )
diff -pruN 1.3.1+dfsg-1/debian/embedded/Documenter/docs/pdf/make.jl 1.4.0+dfsg-1/debian/embedded/Documenter/docs/pdf/make.jl
--- 1.3.1+dfsg-1/debian/embedded/Documenter/docs/pdf/make.jl	2019-11-28 04:21:05.000000000 +0000
+++ 1.4.0+dfsg-1/debian/embedded/Documenter/docs/pdf/make.jl	2020-03-30 16:16:04.000000000 +0000
@@ -26,13 +26,15 @@ doc = makedocs(
             ]),
             "man/other-formats.md",
         ],
+        "showcase.md",
         "Library" => Any[
             "Public" => "lib/public.md",
-            hide("Internals" => "lib/internals.md", Any[
+            "Internals" => Any[
                 "lib/internals/anchors.md",
                 "lib/internals/builder.md",
                 "lib/internals/cross-references.md",
                 "lib/internals/docchecks.md",
+                "lib/internals/docmeta.md",
                 "lib/internals/docsystem.md",
                 "lib/internals/doctests.md",
                 "lib/internals/documenter.md",
@@ -40,15 +42,16 @@ doc = makedocs(
                 "lib/internals/documents.md",
                 "lib/internals/dom.md",
                 "lib/internals/expanders.md",
+                "lib/internals/markdown2.md",
                 "lib/internals/mdflatten.md",
                 "lib/internals/selectors.md",
                 "lib/internals/textdiff.md",
                 "lib/internals/utilities.md",
                 "lib/internals/writers.md",
-            ])
+            ],
         ],
         "contributing.md",
-    ]
+    ],
 );
 
 # hack to only deploy the actual pdf-file
diff -pruN 1.3.1+dfsg-1/debian/embedded/Documenter/docs/Project.toml 1.4.0+dfsg-1/debian/embedded/Documenter/docs/Project.toml
--- 1.3.1+dfsg-1/debian/embedded/Documenter/docs/Project.toml	2019-11-28 04:21:05.000000000 +0000
+++ 1.4.0+dfsg-1/debian/embedded/Documenter/docs/Project.toml	2020-03-30 16:16:04.000000000 +0000
@@ -1,3 +1,6 @@
 [deps]
 Documenter = "e30172f5-a6a5-5a46-863b-614d45cd2de4"
 DocumenterTools = "35a29f4d-8980-5a13-9543-d66fff28ecb8"
+
+[compat]
+DocumenterTools = "=0.1.3"
diff -pruN 1.3.1+dfsg-1/debian/embedded/Documenter/docs/src/assets/logo-dark.svg 1.4.0+dfsg-1/debian/embedded/Documenter/docs/src/assets/logo-dark.svg
--- 1.3.1+dfsg-1/debian/embedded/Documenter/docs/src/assets/logo-dark.svg	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/debian/embedded/Documenter/docs/src/assets/logo-dark.svg	2020-03-30 16:16:04.000000000 +0000
@@ -0,0 +1,77 @@
+<?xml version="1.0" encoding="UTF-8" standalone="no"?>
+<svg
+   xmlns:dc="http://purl.org/dc/elements/1.1/"
+   xmlns:cc="http://creativecommons.org/ns#"
+   xmlns:rdf="http://www.w3.org/1999/02/22-rdf-syntax-ns#"
+   xmlns:svg="http://www.w3.org/2000/svg"
+   xmlns="http://www.w3.org/2000/svg"
+   xmlns:sodipodi="http://sodipodi.sourceforge.net/DTD/sodipodi-0.dtd"
+   xmlns:inkscape="http://www.inkscape.org/namespaces/inkscape"
+   width="500pt"
+   height="500pt"
+   viewBox="0 0 500 500"
+   version="1.1"
+   id="svg15"
+   sodipodi:docname="logo-dark.svg"
+   inkscape:version="0.92.3 (2405546, 2018-03-11)">
+  <metadata
+     id="metadata21">
+    <rdf:RDF>
+      <cc:Work
+         rdf:about="">
+        <dc:format>image/svg+xml</dc:format>
+        <dc:type
+           rdf:resource="http://purl.org/dc/dcmitype/StillImage" />
+      </cc:Work>
+    </rdf:RDF>
+  </metadata>
+  <defs
+     id="defs19" />
+  <sodipodi:namedview
+     pagecolor="#ffffff"
+     bordercolor="#666666"
+     borderopacity="1"
+     objecttolerance="10"
+     gridtolerance="10"
+     guidetolerance="10"
+     inkscape:pageopacity="0"
+     inkscape:pageshadow="2"
+     inkscape:window-width="1920"
+     inkscape:window-height="1053"
+     id="namedview17"
+     showgrid="false"
+     inkscape:zoom="0.72230958"
+     inkscape:cx="-48.862721"
+     inkscape:cy="229.47087"
+     inkscape:window-x="1920"
+     inkscape:window-y="-1"
+     inkscape:window-maximized="1"
+     inkscape:current-layer="surface763305" />
+  <g
+     id="surface763305">
+    <path
+       style=" stroke:none;fill-rule:nonzero;fill:rgb(79.6%,23.5%,20%);fill-opacity:1;"
+       d="M 234.425781 352.5 C 234.425781 413.25 185.175781 462.5 124.425781 462.5 C 63.675781 462.5 14.425781 413.25 14.425781 352.5 C 14.425781 291.75 63.675781 242.5 124.425781 242.5 C 185.175781 242.5 234.425781 291.75 234.425781 352.5 "
+       id="path2" />
+    <path
+       style="fill-rule:nonzero;fill:#e2e2e2;fill-opacity:1;stroke-width:2.00024994;stroke-linecap:butt;stroke-linejoin:miter;stroke:#0f0000;stroke-opacity:1;stroke-miterlimit:10;stroke-dasharray:none"
+       d="M 130.554688 379.886719 L 130.964844 372.671875 L 131.613281 365.949219 L 132.457031 359.671875 L 133.46875 353.8125 L 134.597656 348.316406 L 135.820312 343.15625 L 138.390625 333.683594 L 140.878906 325.066406 L 143.019531 317.015625 L 143.859375 313.097656 L 144.511719 309.210938 L 144.925781 305.304688 L 145.074219 301.347656 L 144.960938 298.058594 L 144.640625 294.980469 L 144.117188 292.101562 L 143.410156 289.4375 L 142.515625 286.96875 L 141.457031 284.714844 L 140.242188 282.664062 L 138.882812 280.832031 L 137.378906 279.203125 L 135.753906 277.785156 L 134.007812 276.585938 L 132.167969 275.605469 L 130.226562 274.832031 L 128.207031 274.285156 L 126.109375 273.953125 L 123.957031 273.847656 L 121.792969 273.953125 L 119.703125 274.285156 L 117.6875 274.835938 L 115.765625 275.609375 L 113.933594 276.59375 L 112.210938 277.800781 L 110.605469 279.21875 L 109.128906 280.859375 L 107.78125 282.707031 L 106.585938 284.769531 L 105.542969 287.042969 L 104.675781 289.53125 L 103.976562 292.226562 L 103.46875 295.132812 L 103.15625 298.242188 L 103.054688 301.570312 L 103.195312 305.488281 L 103.609375 309.363281 L 104.253906 313.222656 L 105.101562 317.113281 L 107.238281 325.128906 L 109.734375 333.714844 L 112.296875 343.171875 L 113.515625 348.324219 L 114.652344 353.816406 L 115.652344 359.671875 L 116.503906 365.949219 L 117.152344 372.671875 L 117.574219 379.886719 Z M 103.054688 413.546875 L 103.136719 415.476562 L 103.390625 417.390625 L 103.8125 419.265625 L 104.398438 421.101562 L 105.148438 422.863281 L 106.0625 424.558594 L 107.140625 426.15625 L 108.386719 427.652344 L 109.78125 429.019531 L 111.34375 430.253906 L 113.058594 431.339844 L 114.933594 432.261719 L 116.957031 433 L 119.140625 433.550781 L 121.46875 433.886719 L 123.957031 434.007812 L 126.441406 433.886719 L 128.785156 433.550781 L 130.980469 433 L 133.039062 432.261719 L 134.941406 431.339844 L 136.695312 430.253906 L 138.292969 429.019531 L 139.738281 427.652344 L 141.015625 426.15625 L 142.132812 424.558594 L 143.082031 422.863281 L 143.875 421.101562 L 144.488281 419.265625 L 144.9375 417.390625 L 145.203125 415.476562 L 145.296875 413.546875 L 145.203125 411.605469 L 144.9375 409.691406 L 144.488281 407.808594 L 143.875 405.984375 L 143.082031 404.210938 L 142.132812 402.523438 L 141.015625 400.921875 L 139.738281 399.4375 L 138.292969 398.0625 L 136.695312 396.828125 L 134.941406 395.742188 L 133.039062 394.828125 L 130.980469 394.085938 L 128.785156 393.539062 L 126.441406 393.203125 L 123.957031 393.089844 L 121.46875 393.203125 L 119.140625 393.539062 L 116.957031 394.085938 L 114.933594 394.828125 L 113.058594 395.742188 L 111.34375 396.828125 L 109.78125 398.0625 L 108.386719 399.4375 L 107.140625 400.921875 L 106.0625 402.523438 L 105.148438 404.210938 L 104.398438 405.984375 L 103.8125 407.808594 L 103.390625 409.691406 L 103.136719 411.605469 Z "
+       id="path4" />
+    <path
+       style=" stroke:none;fill-rule:nonzero;fill:rgb(22%,59.6%,14.9%);fill-opacity:1;"
+       d="M 360 135 C 360 195.75 310.75 245 250 245 C 189.25 245 140 195.75 140 135 C 140 74.25 189.25 25 250 25 C 310.75 25 360 74.25 360 135 "
+       id="path6" />
+    <path
+       style=" stroke:none;fill-rule:nonzero;fill:rgb(58.4%,34.5%,69.8%);fill-opacity:1;"
+       d="M 485.574219 352.5 C 485.574219 413.25 436.324219 462.5 375.574219 462.5 C 314.824219 462.5 265.574219 413.25 265.574219 352.5 C 265.574219 291.75 314.824219 242.5 375.574219 242.5 C 436.324219 242.5 485.574219 291.75 485.574219 352.5 "
+       id="path8" />
+    <path
+       style="fill-rule:nonzero;fill:#e2e2e2;fill-opacity:1;stroke-width:2;stroke-linecap:butt;stroke-linejoin:miter;stroke:#000000;stroke-opacity:1;stroke-miterlimit:10"
+       d="M 382.195312 366.027344 L 387.449219 365.816406 L 392.492188 365.285156 L 397.296875 364.421875 L 401.855469 363.242188 L 406.136719 361.738281 L 410.140625 359.917969 L 413.839844 357.777344 L 417.226562 355.328125 L 420.269531 352.554688 L 422.96875 349.484375 L 425.292969 346.097656 L 427.238281 342.417969 L 428.773438 338.425781 L 429.894531 334.136719 L 430.578125 329.546875 L 430.816406 324.667969 L 430.570312 319.921875 L 429.84375 315.214844 L 428.636719 310.574219 L 426.96875 306.046875 L 424.832031 301.660156 L 422.246094 297.460938 L 419.210938 293.480469 L 415.742188 289.765625 L 411.832031 286.335938 L 407.5 283.25 L 402.746094 280.53125 L 397.585938 278.226562 L 392.015625 276.363281 L 386.050781 274.992188 L 379.691406 274.136719 L 372.957031 273.847656 L 368.953125 273.929688 L 365.042969 274.191406 L 361.25 274.628906 L 357.601562 275.253906 L 354.105469 276.0625 L 350.804688 277.066406 L 347.707031 278.269531 L 344.847656 279.675781 L 342.226562 281.28125 L 339.890625 283.101562 L 337.847656 285.136719 L 336.132812 287.394531 L 334.753906 289.871094 L 333.746094 292.582031 L 333.121094 295.523438 L 332.914062 298.707031 L 333.199219 302.035156 L 334.03125 305.078125 L 335.34375 307.773438 L 337.09375 310.089844 L 339.207031 311.964844 L 341.636719 313.367188 L 344.320312 314.242188 L 345.742188 314.464844 L 347.214844 314.546875 L 348.875 314.46875 L 350.414062 314.257812 L 351.832031 313.914062 L 353.144531 313.457031 L 355.46875 312.207031 L 357.460938 310.589844 L 359.175781 308.671875 L 360.691406 306.535156 L 363.382812 301.898438 L 366.066406 297.25 L 367.578125 295.109375 L 369.296875 293.199219 L 371.28125 291.574219 L 373.613281 290.332031 L 374.921875 289.867188 L 376.34375 289.53125 L 377.882812 289.320312 L 379.554688 289.25 L 382.464844 289.382812 L 385.183594 289.78125 L 387.707031 290.417969 L 390.039062 291.289062 L 392.171875 292.363281 L 394.125 293.628906 L 395.882812 295.070312 L 397.457031 296.671875 L 398.832031 298.402344 L 400.027344 300.261719 L 401.035156 302.222656 L 401.859375 304.277344 L 402.492188 306.394531 L 402.949219 308.566406 L 403.222656 310.773438 L 403.316406 313.007812 L 403.144531 316.054688 L 402.65625 318.859375 L 401.851562 321.421875 L 400.75 323.757812 L 399.347656 325.863281 L 397.671875 327.753906 L 395.722656 329.429688 L 393.523438 330.90625 L 391.066406 332.175781 L 388.375 333.257812 L 385.460938 334.15625 L 382.332031 334.878906 L 378.996094 335.421875 L 375.472656 335.808594 L 371.765625 336.03125 L 367.894531 336.109375 L 367.894531 379.886719 L 381.316406 379.886719 Z M 353.59375 413.546875 L 353.675781 415.476562 L 353.929688 417.390625 L 354.351562 419.265625 L 354.941406 421.101562 L 355.691406 422.863281 L 356.617188 424.558594 L 357.699219 426.15625 L 358.953125 427.652344 L 360.359375 429.019531 L 361.933594 430.253906 L 363.664062 431.339844 L 365.5625 432.261719 L 367.613281 433 L 369.824219 433.550781 L 372.1875 433.886719 L 374.714844 434.007812 L 377.160156 433.886719 L 379.46875 433.550781 L 381.636719 433 L 383.671875 432.261719 L 385.550781 431.339844 L 387.289062 430.253906 L 388.871094 429.019531 L 390.304688 427.652344 L 391.574219 426.15625 L 392.6875 424.558594 L 393.632812 422.863281 L 394.417969 421.101562 L 395.027344 419.265625 L 395.476562 417.390625 L 395.742188 415.476562 L 395.835938 413.546875 L 395.742188 411.605469 L 395.476562 409.691406 L 395.027344 407.808594 L 394.417969 405.984375 L 393.632812 404.210938 L 392.6875 402.523438 L 391.574219 400.921875 L 390.304688 399.4375 L 388.871094 398.0625 L 387.289062 396.828125 L 385.550781 395.742188 L 383.671875 394.828125 L 381.636719 394.085938 L 379.46875 393.539062 L 377.160156 393.203125 L 374.714844 393.089844 L 372.1875 393.203125 L 369.824219 393.539062 L 367.613281 394.085938 L 365.5625 394.828125 L 363.664062 395.742188 L 361.933594 396.828125 L 360.359375 398.0625 L 358.953125 399.4375 L 357.699219 400.921875 L 356.617188 402.523438 L 355.691406 404.210938 L 354.941406 405.984375 L 354.351562 407.808594 L 353.929688 409.691406 L 353.675781 411.605469 Z "
+       id="path10" />
+    <path
+       style="fill-rule:nonzero;fill:#e2e2e2;fill-opacity:1;stroke-width:2;stroke-linecap:butt;stroke-linejoin:miter;stroke:#000000;stroke-opacity:1;stroke-miterlimit:10"
+       d="M 317.210938 94.707031 C 319.421875 98.039062 319.917969 101.8125 318.703125 106.027344 L 295.910156 185.535156 C 294.859375 189.277344 292.746094 192.421875 289.570312 194.96875 C 286.394531 197.511719 283.007812 198.785156 279.417969 198.785156 L 202.914062 198.785156 C 198.660156 198.785156 194.558594 197.21875 190.609375 194.089844 C 186.65625 190.960938 183.910156 187.113281 182.363281 182.550781 C 181.035156 178.628906 180.980469 174.914062 182.195312 171.40625 C 182.195312 171.171875 182.277344 170.378906 182.445312 169.035156 C 182.609375 167.691406 182.722656 166.605469 182.777344 165.789062 C 182.832031 165.320312 182.746094 164.691406 182.527344 163.902344 C 182.304688 163.113281 182.222656 162.542969 182.277344 162.191406 C 182.390625 161.546875 182.609375 160.933594 182.941406 160.347656 C 183.273438 159.761719 183.730469 159.074219 184.308594 158.285156 C 184.890625 157.496094 185.34375 156.808594 185.675781 156.222656 C 186.945312 154 188.191406 151.324219 189.40625 148.191406 C 190.621094 145.0625 191.453125 142.386719 191.894531 140.164062 C 192.058594 139.578125 192.074219 138.699219 191.933594 137.53125 C 191.796875 136.359375 191.78125 135.542969 191.894531 135.074219 C 192.058594 134.429688 192.527344 133.609375 193.300781 132.617188 C 194.074219 131.621094 194.542969 130.949219 194.710938 130.597656 C 195.871094 128.492188 197.03125 125.800781 198.191406 122.523438 C 199.351562 119.246094 200.042969 116.613281 200.265625 114.625 C 200.320312 114.097656 200.25 113.164062 200.058594 111.816406 C 199.863281 110.472656 199.875 109.652344 200.097656 109.359375 C 200.320312 108.601562 200.925781 107.707031 201.921875 106.683594 C 202.914062 105.660156 203.523438 105.003906 203.746094 104.710938 C 204.796875 103.1875 205.96875 100.71875 207.269531 97.292969 C 208.566406 93.871094 209.324219 91.046875 209.546875 88.824219 C 209.601562 88.359375 209.519531 87.613281 209.296875 86.589844 C 209.078125 85.5625 209.023438 84.789062 209.132812 84.261719 C 209.242188 83.792969 209.492188 83.269531 209.878906 82.683594 C 210.265625 82.097656 210.761719 81.425781 211.371094 80.664062 C 211.976562 79.902344 212.449219 79.289062 212.777344 78.820312 C 213.222656 78.121094 213.675781 77.226562 214.144531 76.144531 C 214.617188 75.0625 215.03125 74.039062 215.390625 73.074219 C 215.75 72.109375 216.191406 71.054688 216.714844 69.914062 C 217.242188 68.773438 217.78125 67.835938 218.332031 67.105469 C 218.886719 66.375 219.617188 65.6875 220.527344 65.042969 C 221.441406 64.398438 222.433594 64.0625 223.511719 64.035156 C 224.589844 64.003906 225.902344 64.167969 227.449219 64.519531 L 227.367188 64.78125 C 229.464844 64.253906 230.875 63.992188 231.59375 63.992188 L 294.667969 63.992188 C 298.757812 63.992188 301.90625 65.628906 304.117188 68.90625 C 306.328125 72.179688 306.824219 75.984375 305.609375 80.3125 L 282.898438 159.820312 C 280.910156 166.78125 278.933594 171.273438 276.972656 173.292969 C 275.011719 175.308594 271.460938 176.320312 266.320312 176.320312 L 194.296875 176.320312 C 192.804688 176.320312 191.753906 176.757812 191.148438 177.636719 C 190.539062 178.570312 190.511719 179.828125 191.0625 181.410156 C 192.390625 185.503906 196.367188 187.550781 203 187.550781 L 279.5 187.550781 C 281.101562 187.550781 282.648438 187.097656 284.140625 186.191406 C 285.632812 185.285156 286.601562 184.070312 287.042969 182.550781 L 311.90625 95.933594 C 312.292969 94.648438 312.433594 92.980469 312.320312 90.933594 C 314.421875 91.808594 316.050781 93.066406 317.210938 94.707031 M 229.023438 94.878906 C 228.804688 95.640625 228.859375 96.300781 229.191406 96.855469 C 229.523438 97.410156 230.074219 97.6875 230.847656 97.6875 L 281.238281 97.6875 C 281.957031 97.6875 282.664062 97.410156 283.355469 96.855469 C 284.042969 96.300781 284.5 95.640625 284.722656 94.878906 L 286.460938 89.265625 C 286.683594 88.503906 286.628906 87.84375 286.296875 87.289062 C 285.964844 86.734375 285.410156 86.457031 284.636719 86.457031 L 234.246094 86.457031 C 233.527344 86.457031 232.824219 86.734375 232.132812 87.289062 C 231.441406 87.84375 230.984375 88.503906 230.765625 89.265625 Z M 222.144531 117.347656 C 221.925781 118.105469 221.980469 118.765625 222.3125 119.320312 C 222.640625 119.875 223.195312 120.15625 223.96875 120.15625 L 274.359375 120.15625 C 275.078125 120.15625 275.785156 119.875 276.472656 119.320312 C 277.164062 118.765625 277.621094 118.105469 277.84375 117.347656 L 279.582031 111.730469 C 279.804688 110.96875 279.746094 110.3125 279.417969 109.757812 C 279.085938 109.199219 278.53125 108.921875 277.757812 108.921875 L 227.367188 108.921875 C 226.648438 108.921875 225.945312 109.199219 225.253906 109.757812 C 224.5625 110.3125 224.105469 110.96875 223.886719 111.730469 Z M 222.144531 117.347656 "
+       id="path12" />
+  </g>
+</svg>
diff -pruN 1.3.1+dfsg-1/debian/embedded/Documenter/docs/src/lib/internals/documentertools.md 1.4.0+dfsg-1/debian/embedded/Documenter/docs/src/lib/internals/documentertools.md
--- 1.3.1+dfsg-1/debian/embedded/Documenter/docs/src/lib/internals/documentertools.md	2019-11-28 04:21:05.000000000 +0000
+++ 1.4.0+dfsg-1/debian/embedded/Documenter/docs/src/lib/internals/documentertools.md	2020-03-30 16:16:04.000000000 +0000
@@ -9,3 +9,13 @@ DocumenterTools.package_devpath
 ```@autodocs
 Modules = [DocumenterTools.Generator]
 ```
+
+## Themes
+
+!!! warning "Experimental API"
+
+    The theming API in DocumenterTools is very experimental and may change without notice.
+
+```@autodocs
+Modules = [DocumenterTools.Themes]
+```
diff -pruN 1.3.1+dfsg-1/debian/embedded/Documenter/docs/src/lib/internals/jsdependencies.md 1.4.0+dfsg-1/debian/embedded/Documenter/docs/src/lib/internals/jsdependencies.md
--- 1.3.1+dfsg-1/debian/embedded/Documenter/docs/src/lib/internals/jsdependencies.md	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/debian/embedded/Documenter/docs/src/lib/internals/jsdependencies.md	2020-03-30 16:16:04.000000000 +0000
@@ -0,0 +1,5 @@
+# JSDependencies
+
+```@autodocs
+Modules = [Documenter.Utilities.JSDependencies]
+```
diff -pruN 1.3.1+dfsg-1/debian/embedded/Documenter/docs/src/lib/internals/writers.md 1.4.0+dfsg-1/debian/embedded/Documenter/docs/src/lib/internals/writers.md
--- 1.3.1+dfsg-1/debian/embedded/Documenter/docs/src/lib/internals/writers.md	2019-11-28 04:21:05.000000000 +0000
+++ 1.4.0+dfsg-1/debian/embedded/Documenter/docs/src/lib/internals/writers.md	2020-03-30 16:16:04.000000000 +0000
@@ -5,6 +5,7 @@ Modules = [
     Documenter.Writers,
     Documenter.Writers.MarkdownWriter,
     Documenter.Writers.HTMLWriter,
+    Documenter.Writers.HTMLWriter.RD,
     Documenter.Writers.LaTeXWriter,
 ]
 ```
diff -pruN 1.3.1+dfsg-1/debian/embedded/Documenter/docs/src/lib/internals.md 1.4.0+dfsg-1/debian/embedded/Documenter/docs/src/lib/internals.md
--- 1.3.1+dfsg-1/debian/embedded/Documenter/docs/src/lib/internals.md	2019-11-28 04:21:05.000000000 +0000
+++ 1.4.0+dfsg-1/debian/embedded/Documenter/docs/src/lib/internals.md	1970-01-01 00:00:00.000000000 +0000
@@ -1,17 +0,0 @@
-# Internal Documentation
-
-This page lists all the documented internals of the `Documenter` module and submodules.
-
-## Contents
-
-```@contents
-Pages = [joinpath("internals", f) for f in readdir("internals")]
-```
-
-## Index
-
-A list of all internal documentation sorted by module.
-
-```@index
-Pages = [joinpath("internals", f) for f in readdir("internals")]
-```
diff -pruN 1.3.1+dfsg-1/debian/embedded/Documenter/docs/src/lib/public.md 1.4.0+dfsg-1/debian/embedded/Documenter/docs/src/lib/public.md
--- 1.3.1+dfsg-1/debian/embedded/Documenter/docs/src/lib/public.md	2019-11-28 04:21:05.000000000 +0000
+++ 1.4.0+dfsg-1/debian/embedded/Documenter/docs/src/lib/public.md	2020-03-30 16:16:04.000000000 +0000
@@ -2,7 +2,7 @@
 
 Documentation for `Documenter.jl`'s public interface.
 
-See [Internal Documentation](@ref) for internal package docs covering all submodules.
+See the Internals section of the manual for internal package docs covering all submodules.
 
 ## Contents
 
@@ -22,6 +22,7 @@ Pages = ["public.md"]
 Documenter
 makedocs
 hide
+asset
 deploydocs
 Deps
 Deps.pip
@@ -35,6 +36,5 @@ DocMeta.setdocmeta!
 
 ```@docs
 DocumenterTools.generate
-DocumenterTools.Travis.genkeys
-DocumenterTools.Travis
+DocumenterTools.genkeys
 ```
diff -pruN 1.3.1+dfsg-1/debian/embedded/Documenter/docs/src/man/examples.md 1.4.0+dfsg-1/debian/embedded/Documenter/docs/src/man/examples.md
--- 1.3.1+dfsg-1/debian/embedded/Documenter/docs/src/man/examples.md	2019-11-28 04:21:05.000000000 +0000
+++ 1.4.0+dfsg-1/debian/embedded/Documenter/docs/src/man/examples.md	2020-03-30 16:16:04.000000000 +0000
@@ -11,14 +11,14 @@ should give a good overview of what this
     Packages are listed alphabetically. If you have a package that uses Documenter then
     please open a PR that adds it to the appropriate list below; a simple way to do so
     is to navigate to
-    https://github.com/JuliaDocs/Documenter.jl/edit/master/docs/src/man/examples.md.
+    <https://github.com/JuliaDocs/Documenter.jl/edit/master/docs/src/man/examples.md>.
 
     The `make.jl` file for all listed packages will be tested to check for potential
     regressions prior to tagging new Documenter releases whenever possible.
 
 ## Registered
 
-Packages that have tagged versions available in `METADATA.jl`.
+Packages that have tagged versions available in the general Registry:
 
 - [Augmentor.jl](https://evizero.github.io/Augmentor.jl/)
 - [BanditOpt.jl](https://v-i-s-h.github.io/BanditOpt.jl/stable/)
@@ -27,6 +27,7 @@ Packages that have tagged versions avail
 - [ControlSystems.jl](http://juliacontrol.github.io/ControlSystems.jl/stable/)
 - [DiscretePredictors.jl](https://github.com/v-i-s-h/DiscretePredictors.jl)
 - [Documenter.jl](https://juliadocs.github.io/Documenter.jl/stable/)
+- [DrWatson](https://juliadynamics.github.io/DrWatson.jl/stable/)
 - [EvolvingGraphs.jl](https://etymoio.github.io/EvolvingGraphs.jl/stable/)
 - [ExtractMacro.jl](https://carlobaldassi.github.io/ExtractMacro.jl/stable/)
 - [EzXML.jl](https://bicycle1885.github.io/EzXML.jl/stable/)
@@ -55,6 +56,6 @@ Some projects or organizations maintain
 separate from specific packages.
 
 - [DifferentialEquations.jl](http://docs.juliadiffeq.org/latest/)
-- [JuliaDocs landing page](https://juliadocs.github.io/latest/)
-- [JuliaMusic](https://juliamusic.github.io/JuliaMusic_documentation.jl/latest/)
-- [Plots.jl](https://docs.juliaplots.org/latest/)
+- [JuliaDocs landing page](https://juliadocs.github.io/dev/)
+- [JuliaMusic](https://juliamusic.github.io/JuliaMusic_documentation.jl/dev/)
+- [Plots.jl](https://docs.juliaplots.org/dev/)
diff -pruN 1.3.1+dfsg-1/debian/embedded/Documenter/docs/src/man/guide.md 1.4.0+dfsg-1/debian/embedded/Documenter/docs/src/man/guide.md
--- 1.3.1+dfsg-1/debian/embedded/Documenter/docs/src/man/guide.md	2019-11-28 04:21:05.000000000 +0000
+++ 1.4.0+dfsg-1/debian/embedded/Documenter/docs/src/man/guide.md	2020-03-30 16:16:04.000000000 +0000
@@ -27,9 +27,9 @@ guide we'll be using a package called `E
 
 ```
 Example/
-    src/
-        Example.jl
-    ...
+├── src/
+│   └── Example.jl
+...
 ```
 
 Note that the `...` just represent unimportant files and folders.
@@ -39,11 +39,11 @@ It's recommended to use a folder named `
 
 ```
 Example/
-    docs/
-        ...
-    src/
-        Example.jl
-    ...
+├── docs/
+│   └── ...
+├── src/
+│   └── Example.jl
+...
 ```
 
 Inside the `docs/` folder we need to add two things. A source folder which will contain the
@@ -52,8 +52,8 @@ be used to control the build process. Th
 
 ```
 docs/
-    src/
-    make.jl
+├── src/
+└── make.jl
 ```
 
 
@@ -121,14 +121,14 @@ look like the following
 
 ```
 build/
-    assets/
-        arrow.svg
-        documenter.css
-        documenter.js
-        search.js
-    index.html
-    search/index.html
-    search_index.js
+├── assets/
+│   ├── arrow.svg
+│   ├── documenter.css
+│   ├── documenter.js
+│   └── search.js
+├── index.html
+├── search/index.html
+└── search_index.js
 ```
 
 !!! note
diff -pruN 1.3.1+dfsg-1/debian/embedded/Documenter/docs/src/man/hosting/walkthrough.md 1.4.0+dfsg-1/debian/embedded/Documenter/docs/src/man/hosting/walkthrough.md
--- 1.3.1+dfsg-1/debian/embedded/Documenter/docs/src/man/hosting/walkthrough.md	2019-11-28 04:21:05.000000000 +0000
+++ 1.4.0+dfsg-1/debian/embedded/Documenter/docs/src/man/hosting/walkthrough.md	2020-03-30 16:16:04.000000000 +0000
@@ -1,12 +1,12 @@
 # SSH Deploy Keys Walkthrough
 
-If the instructions in [SSH Deploy Keys](@ref) did not work for you (for example,
+If the instructions in [Authentication: SSH Deploy Keys](@ref) did not work for you (for example,
 `ssh-keygen` is not installed), don't worry! This walkthrough will guide you through the
 process. There are three main steps:
 
 1. [Generating an SSH Key](@ref)
 2. [Adding the Public Key to GitHub](@ref)
-3. [Adding the Private Key to Travis](@ref)
+3. [Adding the Private Key](@ref)
 
 ## Generating an SSH Key
 
@@ -30,7 +30,7 @@ And the private key usually look somethi
 
 ### If you have `ssh-keygen` installed
 
-If you have `ssh-keygen` installed, but `Travis.genkeys()` didn't work, you can generate an
+If you have `ssh-keygen` installed, but `DocumenterTools.genkeys()` didn't work, you can generate an
 SSH key as follows. First, generate a key using `ssh-keygen` and save it to the file
 `privatekey`:
 
@@ -46,8 +46,7 @@ julia> using Base64
 julia> read("privatekey", String) |> base64encode |>  println
 ```
 
-Copy and paste the output somewhere. This is your *private key* and is required for the step
-[Adding the Private Key to Travis](@ref).
+Copy and paste the output somewhere. This is your *private key* and is required for the last step.
 
 Now we need to get the public key. Run the following command:
 
@@ -89,8 +88,7 @@ Now we need to save the public key somew
 Finally, we need to save the private key somewhere.
 
 * Click the "Conversions" tab, and then click "Export OpenSSH key". Save that file
-  somewhere. That file is your *private key* and is required for the [Adding the Private Key
-  to Travis](@ref) step.
+  somewhere. That file is your *private key* and is required for the last step.
 
   ![](puttygen-export-private-key.png)
 
@@ -123,10 +121,10 @@ Now we need to fill in three pieces of i
 3. Make sure that the "Allow write access" box is checked.
 
 Once you're done, click "Add key". Congratulations! You've added the public key
-to GitHub. The next step is to add the private key to Travis.
+to GitHub. The next step is to add the private key to Travis or GitHub Secrets.
 
 
-## Adding the Private Key to Travis
+## Adding the Private Key
 
 In this section, we explain how to upload a private SSH key to Travis. By this point, you
 should have generated a private key and saved it to a file. If you haven't done this, go
@@ -135,12 +133,14 @@ read [Generating an SSH Key](@ref).
 First, we need to Base64 encode the private key. Open Julia, and run the command
 
 ```julia
+julia> using Base64
+
 julia> read("path/to/private/key", String) |> base64encode |> println
 ```
 
 Copy the resulting output.
 
-Next, go to `https://travis-ci.com/[YOUR_USER_NAME]/[YOUR_REPO_NAME]/settings`. Scroll down
+Go to `https://travis-ci.com/[YOUR_USER_NAME]/[YOUR_REPO_NAME]/settings`. Scroll down
 to the "Environment Variables" section. It should look like this:
 
 ![](travis-variables.png)
@@ -148,7 +148,7 @@ to the "Environment Variables" section.
 Now, add a new environment variable called `DOCUMENTER_KEY`, and set its value to the output
 from the Julia command above (make sure to remove the surrounding quotes).
 
-Finally, check that the "Display value in build log" is switched off and then click "Add".
+Finally, make sure that the "Display value in build log" is left switched off and then click "Add".
 Congratulations! You've added the private key to Travis.
 
 !!! warning "Security warning"
diff -pruN 1.3.1+dfsg-1/debian/embedded/Documenter/docs/src/man/hosting.md 1.4.0+dfsg-1/debian/embedded/Documenter/docs/src/man/hosting.md
--- 1.3.1+dfsg-1/debian/embedded/Documenter/docs/src/man/hosting.md	2019-11-28 04:21:05.000000000 +0000
+++ 1.4.0+dfsg-1/debian/embedded/Documenter/docs/src/man/hosting.md	2020-03-30 16:16:04.000000000 +0000
@@ -2,8 +2,9 @@
 
 After going through the [Package Guide](@ref) and [Doctests](@ref) page you will need to
 host the generated documentation somewhere for potential users to read. This guide will
-describe how to setup automatic updates for your package docs using the Travis build service
-and GitHub Pages. This is the same approach used by this package to host its own docs --
+describe how to setup automatic updates for your package docs using either the Travis CI
+build service or GitHub Actions together with and GitHub Pages for hosting the generated
+HTML files. This is the same approach used by this package to host its own docs --
 the docs you're currently reading.
 
 !!! note
@@ -17,13 +18,16 @@ the docs you're currently reading.
     [Travis](https://travis-ci.com/) accounts setup. If not then go set those up first and
     then return here.
 
+    It is possible to deploy from other systems than Travis CI or GitHub Actions,
+    see the section on [Deployment systems](@ref).
+
 
 ## Overview
 
 Once set up correctly, the following will happen each time you push new updates to your
 package repository:
 
-- Travis buildbots will start up and run your package tests in a "Test" stage.
+- Buildbots will start up and run your package tests in a "Test" stage.
 - After the Test stage completes, a single bot will run a new "Documentation" stage, which
   will build the documentation.
 - If the documentation is built successfully, the bot will attempt to push the generated
@@ -32,15 +36,52 @@ package repository:
 Note that the hosted documentation does not update when you make pull requests; you see
 updates only when you merge to `master` or push new tags.
 
-The following sections outline how to enable this for your own package.
+In the upcoming sections we describe how to configure the build service to run
+the documentation build stage. In general it is easiest to choose the same
+service as the one testing your package. If you don't explicitly select
+the service with the `deploy_config` keyword argument to `deploydocs`
+Documenter will try to automatically detect which system is running and use that.
 
+## Travis CI
 
-## SSH Deploy Keys
+To tell Travis that we want a new build stage, we can add the following to an existing `.travis.yml`
+file. Note that the snippet below will not work by itself and must be accompanied by a complete Travis file.
 
+```yaml
+jobs:
+  include:
+    - stage: "Documentation"
+      julia: 1.0
+      os: linux
+      script:
+        - julia --project=docs/ -e 'using Pkg; Pkg.develop(PackageSpec(path=pwd()));
+                                               Pkg.instantiate()'
+        - julia --project=docs/ docs/make.jl
+      after_success: skip
+```
+
+where the `julia:` and `os:` entries decide the worker from which the docs are built and
+deployed. In the example above we will thus build and deploy the documentation from a linux
+worker running Julia 1.0. For more information on how to setup a build stage, see the Travis
+manual for [Build Stages](https://docs.travis-ci.com/user/build-stages).
+
+The three lines in the `script:` section do the following:
+
+ 1. Instantiate the doc-building environment (i.e. `docs/Project.toml`, see below).
+ 2. Install your package in the doc-build environment.
+ 3. Run the docs/make.jl script, which builds and deploys the documentation.
+
+!!! note
+    If your package has a build script you should call
+    `Pkg.build("PackageName")` after the call to `Pkg.develop` to make
+    sure the package is built properly.
+
+### [Authentication: SSH Deploy Keys](@id travis-ssh)
+
+In order to push the generated documentation from Travis you need to add deploy keys.
 Deploy keys provide push access to a *single* repository, to allow secure deployment of
-generated documentation from Travis to GitHub. The SSH keys can be generated with the
-`Travis.genkeys` from the [DocumenterTools](https://github.com/JuliaDocs/DocumenterTools.jl)
-package.
+generated documentation from the builder to GitHub. The SSH keys can be generated with
+`DocumenterTools.genkeys` from the [DocumenterTools](https://github.com/JuliaDocs/DocumenterTools.jl) package.
 
 !!! note
 
@@ -59,32 +100,36 @@ pkg> add DocumenterTools
 julia> using DocumenterTools
 ```
 
-Then call the [`Travis.genkeys`](@ref) function as follows:
+Then call the [`DocumenterTools.genkeys`](@ref) function as follows:
 
 ```julia-repl
 julia> using MyPackage
-julia> Travis.genkeys(user="MyUser", repo="git@github.com:MyUser/MyPackage.jl.git")
+julia> DocumenterTools.genkeys(user="MyUser", repo="git@github.com:MyUser/MyPackage.jl.git")
 ```
 
-where `MyPackage` is the name of the package you would like to create deploy keys for and `MyUser` is your GitHub username. Note that the keyword arguments are optional and can be omitted.
+where `MyPackage` is the name of the package you would like to create deploy keys for and
+`MyUser` is your GitHub username. Note that the keyword arguments are optional and can be
+omitted.
 
-If the package is checked out in development mode with `] dev MyPackage`, you can also use `Travis.genkeys` as follows:
+If the package is checked out in development mode with `] dev MyPackage`, you can also use
+`DocumenterTools.genkeys` as follows:
 
 ```julia-repl
 julia> using MyPackage
-julia> Travis.genkeys(MyPackage)
+julia> DocumenterTools.genkeys(MyPackage)
 ```
 
-where `MyPackage` is the package you would like to create deploy keys for. The output will look similar to the text below:
+where `MyPackage` is the package you would like to create deploy keys for. The output will
+look similar to the text below:
 
 ```
-INFO: add the public key below to https://github.com/USER/REPO/settings/keys
+[ Info: add the public key below to https://github.com/USER/REPO/settings/keys
       with read/write access:
 
 [SSH PUBLIC KEY HERE]
 
-INFO: add a secure environment variable named 'DOCUMENTER_KEY' to
-      https://travis-ci.com/USER/REPO/settings with value:
+[ Info: add a secure environment variable named 'DOCUMENTER_KEY' to
+  https://travis-ci.com/USER/REPO/settings with value:
 
 [LONG BASE64 ENCODED PRIVATE KEY]
 ```
@@ -97,14 +142,15 @@ Follow the instructions that are printed
     **`Key`** field. Check **`Allow write access`** to allow Documenter to commit the
     generated documentation to the repo.
 
- 2. Next add the long private key to the Travis settings page using the provided link. Again
-    note that you should include **no whitespace** when copying the key. In the **`Environment
+ 2. Next add the long private key to the Travis settings page using the provided link.
+    Again note that you should include **no whitespace** when copying the key. In the **`Environment
     Variables`** section add a key with the name `DOCUMENTER_KEY` and the value that was printed
     out. **Do not** set the variable to be displayed in the build log. Then click **`Add`**.
 
     !!! warning "Security warning"
 
-        To reiterate: make sure that the "Display value in build log" option is **OFF** for
+        To reiterate: make sure that this key is hidden. In particular, in the Travis CI settings
+        the "Display value in build log" option should be **OFF** for
         the variable, so that it does not get printed when the tests run. This
         base64-encoded string contains the *unencrypted* private key that gives full write
         access to your repository, so it must be kept safe.  Also, make sure that you never
@@ -113,42 +159,94 @@ Follow the instructions that are printed
 
 !!! note
 
-    There are more explicit instructions for adding the keys to GitHub and Travis in the
+    There are more explicit instructions for adding the keys to Travis in the
     [SSH Deploy Keys Walkthrough](@ref) section of the manual.
 
-## `.travis.yml` Configuration
 
-To tell Travis that we want a new build stage we can add the following to the `.travis.yml`
-file:
+## GitHub Actions
+
+To run the documentation build from GitHub Actions you should add the following to your
+workflow configuration file:
 
 ```yaml
+name: Documentation
+
+on:
+  push:
+    branches:
+      - master
+    tags: '*'
+  pull_request:
+
 jobs:
-  include:
-    - stage: "Documentation"
-      julia: 1.0
-      os: linux
-      script:
-        - julia --project=docs/ -e 'using Pkg; Pkg.develop(PackageSpec(path=pwd()));
-                                               Pkg.instantiate()'
-        - julia --project=docs/ docs/make.jl
-      after_success: skip
+  build:
+    runs-on: ubuntu-latest
+    steps:
+      - uses: actions/checkout@v2
+      - uses: julia-actions/setup-julia@latest
+        with:
+          version: 1.3
+      - name: Install dependencies
+        run: julia --project=docs/ -e 'using Pkg; Pkg.develop(PackageSpec(path=pwd())); Pkg.instantiate()'
+      - name: Build and deploy
+        env:
+          GITHUB_TOKEN: ${{ secrets.GITHUB_TOKEN }} # For authentication with GitHub Actions token
+          DOCUMENTER_KEY: ${{ secrets.DOCUMENTER_KEY }} # For authentication with SSH deploy key
+        run: julia --project=docs/ docs/make.jl
+```
+
+which will install Julia, checkout the correct commit of your repository, and run the
+build of the documentation. The `julia-version:`, `julia-arch:` and `os:` entries decide
+the environment from which the docs are built and deployed. In the example above we will
+thus build and deploy the documentation from a ubuntu worker running Julia 1.2. For more
+information on how to setup a GitHub workflow see the manual for
+[Configuring a workflow](https://help.github.com/en/actions/automating-your-workflow-with-github-actions/configuring-a-workflow).
+
+The commands in the lines in the `run:` section do the same as for Travis,
+see the previous section.
+
+### Authentication: `GITHUB_TOKEN`
+
+When running from GitHub Actions it is possible to authenticate using
+[the GitHub Actions authentication token
+(`GITHUB_TOKEN`)](https://help.github.com/en/actions/automating-your-workflow-with-github-actions/authenticating-with-the-github_token). This is done by adding
+
+```yaml
+GITHUB_TOKEN: ${{ secrets.GITHUB_TOKEN }}
 ```
 
-where the `julia:` and `os:` entries decide the worker from which the docs are built and
-deployed. In the example above we will thus build and deploy the documentation from a linux
-worker running Julia 1.0. For more information on how to setup a build stage, see the Travis
-manual for [Build Stages](https://docs.travis-ci.com/user/build-stages).
+to the configuration file, as showed in the [previous section](@ref GitHub-Actions).
 
-The three lines in the `script:` section do the following:
+!!! note
+    You can only use `GITHUB_TOKEN` for authentication if the target repository
+    of the deployment is the same as the current repository. In order to push
+    elsewhere you should instead use a SSH deploy key.
+
+!!! warning "GitHub Pages and GitHub Token"
+    Currently the GitHub Page build is not triggered when the GitHub provided
+    `GITHUB_TOKEN` is used for authentication. See
+    [issue #1177](https://github.com/JuliaDocs/Documenter.jl/issues/1177)
+    for more information.
+
+### Authentication: SSH Deploy Keys
+
+It is also possible to authenticate using a SSH deploy key, just as described in
+the [SSH Deploy Keys section for Travis CI](@ref travis-ssh). You can generate the
+key in the same way, and then set the encoded key as a secret environment variable
+in your repository settings. You also need to make the key available for the doc
+building workflow by adding
 
- 1. Instantiate the doc-building environment (i.e. `docs/Project.toml`, see below).
- 2. Install your package in the doc-build environment.
- 3. Run the docs/make.jl script, which builds and deploys the documentation.
+```yaml
+DOCUMENTER_KEY: ${{ secrets.DOCUMENTER_KEY }}
+```
+
+to the configuration file, as showed in the [previous section](@ref GitHub-Actions).
+See GitHub's manual for
+[Creating and using encrypted secrets](https://help.github.com/en/actions/automating-your-workflow-with-github-actions/creating-and-using-encrypted-secrets)
+for more information.
 
-!!! note
-    If your package has a build script you should call
-    `Pkg.build("PackageName")` after the call to `Pkg.develop` to make
-    sure the package is built properly.
+
+## `docs/Project.toml`
 
 The doc-build environment `docs/Project.toml` includes Documenter and other doc-build
 dependencies your package might have. If Documenter is the only dependency, then the
@@ -156,7 +254,7 @@ dependencies your package might have. If
 
 ````@eval
 import Documenter, Markdown
-m = match(r"^version = \"(\d+.\d+.\d+)\"$"m,
+m = match(r"^version = \"(\d+.\d+.\d+)(-DEV)?\"$"m,
     read(joinpath(dirname(dirname(pathof(Documenter))), "Project.toml"), String))
 v = VersionNumber(m.captures[1])
 Markdown.parse("""
@@ -165,7 +263,7 @@ Markdown.parse("""
 Documenter = "e30172f5-a6a5-5a46-863b-614d45cd2de4"
 
 [compat]
-Documenter = "~$(v.major).$(v.minor)"
+Documenter = "$(v.major).$(v.minor)"
 ```
 """)
 ````
@@ -219,11 +317,11 @@ These are needed to avoid committing gen
 ## `gh-pages` Branch
 
 By default, Documenter pushes documentation to the `gh-pages` branch. If the branch does not
-exist it will be created automatically by [`deploydocs`](@ref). If does exist then
+exist it will be created automatically by [`deploydocs`](@ref). If it does exist then
 Documenter simply adds an additional commit with the built documentation. You should be
 aware that Documenter may overwrite existing content without warning.
 
-If you wish to create the `gh-pages` branch manually the that can be done following
+If you wish to create the `gh-pages` branch manually that can be done following
 [these instructions](https://coderwall.com/p/0n3soa/create-a-disconnected-git-branch).
 
 ## Documentation Versions
@@ -281,3 +379,22 @@ trigger these builds and neither do pull
 
 If you would like to see a more complete example of how this process is setup then take a
 look at this package's repository for some inspiration.
+
+## Deployment systems
+
+It is possible to customize Documenter to use other systems then the ones described in
+the sections above. This is done by passing a configuration
+(a [`DeployConfig`](@ref Documenter.DeployConfig)) to `deploydocs` by the `deploy_config`
+keyword argument. Documenter natively supports [`Travis`](@ref Documenter.Travis) and
+[`GitHubActions`](@ref Documenter.GitHubActions) natively, but it is easy to define
+your own by following the simple interface described below.
+
+```@docs
+Documenter.DeployConfig
+Documenter.deploy_folder
+Documenter.authentication_method
+Documenter.authenticated_repo_url
+Documenter.documenter_key
+Documenter.Travis
+Documenter.GitHubActions
+```
diff -pruN 1.3.1+dfsg-1/debian/embedded/Documenter/docs/src/man/syntax.md 1.4.0+dfsg-1/debian/embedded/Documenter/docs/src/man/syntax.md
--- 1.3.1+dfsg-1/debian/embedded/Documenter/docs/src/man/syntax.md	2019-11-28 04:21:05.000000000 +0000
+++ 1.4.0+dfsg-1/debian/embedded/Documenter/docs/src/man/syntax.md	2020-03-30 16:16:04.000000000 +0000
@@ -40,6 +40,25 @@ which will cause any unlisted docstrings
 called. If `modules` is not defined then no warnings are printed, even if a document has
 missing docstrings.
 
+Notice also that you can use `@docs` to display the documentation strings of only specific
+methods, by stating the dispatch types. For example
+````markdown
+```@docs
+f(::Type1, ::Type2)
+```
+````
+will only display the documentation string of `f` that is related to these types.
+This can be useful when your module extends a function and adds a documentation
+string to that new method.
+
+Note that when specifying signatures, it should match the method definition exactly.
+Documenter will not match methods based on dispatch rules. For example, assuming you
+have a docstring attached to `foo(::Integer) = ...`, then neither `foo(::Number)` nor
+`foo(::Int64)` will match it in an at-docs block (even though `Int64 <: Integer <: Number`).
+The only way you can splice that docstring is by listing exactly `foo(::Integer)` in
+the at-docs block.
+
+
 ## `@autodocs` block
 
 Automatically splices all docstrings from the provided modules in place of the code block.
@@ -86,7 +105,7 @@ docstrings. Note that page matching is d
 `a.jl` will be matched by *any* source file that ends in `a.jl`, i.e. `src/a.jl` or
 `src/foo/a.jl`.
 
-To filter out certain docstrings by your own criteria, you can provide function with them
+To filter out certain docstrings by your own criteria, you can provide function with the
 `Filter` keyword:
 
 ````markdown
diff -pruN 1.3.1+dfsg-1/debian/embedded/Documenter/docs/src/showcase.md 1.4.0+dfsg-1/debian/embedded/Documenter/docs/src/showcase.md
--- 1.3.1+dfsg-1/debian/embedded/Documenter/docs/src/showcase.md	2019-11-28 04:21:05.000000000 +0000
+++ 1.4.0+dfsg-1/debian/embedded/Documenter/docs/src/showcase.md	2020-03-30 16:16:04.000000000 +0000
@@ -1,4 +1,370 @@
-# Hidden showcase page
+# Showcase
+
+This page showcases the various page elements that are supported by Documenter.
+It should be read side-by-side with its source (`docs/src/showcase.md`) to see what syntax exactly is used to create the various elements.
+
+## Table of contents
+
+A table of contents can be generated with an [`@contents` block](@ref).
+The one for this page renders as
+
+```@contents
+Pages = ["showcase.md"]
+```
+
+## Basic Markdown
+
+Documenter can render all the [Markdown syntax supported by the Julia Markdown parser](https://docs.julialang.org/en/v1/stdlib/Markdown/).
+You can use all the usual markdown syntax, such as **bold text** and _italic text_ and `print("inline code")`.
+
+Code blocks are rendered as follows:
+
+```
+This is an non-highlighted code block.
+... Rendered in monospace.
+```
+
+When the language is specified for the block, e.g. by starting the block with ````` ```julia`````, the contents gets highlighted appropriately (for the language that are supported by the highlighter).
+
+```julia
+function foo(x::Integer)
+    @show x + 1
+end
+```
+
+For mathematics, both inline and display equations are available.
+Inline equations should be written as LaTeX between two backticks,
+e.g. ``` ``A x^2 + B x + C = 0`` ```.
+It will render as ``A x^2 + B x + C = 0``.
+
+The LaTeX for display equations must be wrapped in a ````` ```math ````` code block and will render like
+
+```math
+x_{1,2} = \frac{-B \pm \sqrt{B^2 - 4 A C}}{2A}
+```
+
+By default, the HTML output renders equations with [KaTeX](https://katex.org/), but [MathJax](https://www.mathjax.org/) can optionally be used as well.
+
+Finally, admonitions for notes, warnings and such:
+
+!!! note "'note' admonition"
+    Admonitions look like this. This is a `!!! note`-type admonition.
+
+    Note that admonitions themselves can contain other block-level elements too,
+    such as code blocks. E.g.
+
+    ```julia
+    f(x) = x^2
+    ```
+
+    However, you **can not** have at-blocks, docstrings, doctests etc. in an admonition.
+
+    Headings are OK though:
+    # Heading 1
+    ## Heading 2
+    ### Heading 3
+    #### Heading 4
+    ##### Heading 5
+    ###### Heading 6
+
+!!! info "'info' admonition"
+    This is a `!!! info`-type admonition. This is the same as a `!!! note`-type.
+
+!!! tip "'tip' admonition"
+    This is a `!!! tip`-type admonition.
+
+!!! warning "'warning' admonition"
+    This is a `!!! warning`-type admonition.
+
+!!! danger "'danger' admonition"
+    This is a `!!! danger`-type admonition.
+
+!!! compat "'compat' admonition"
+    This is a `!!! compat`-type admonition.
+
+!!! ukw "Unknown admonition class"
+    Admonition with an unknown admonition class. This is a `code example`.
+
+### Lists
+
+Tight lists look as follows
+
+* Lorem ipsum dolor sit amet, consectetur adipiscing elit.
+* Nulla quis venenatis justo.
+* In non _sodales_ eros.
+
+If the lists contain paragraphs or other block level elements, they look like this:
+
+* Morbi et varius nisl, eu semper orci.
+
+  Donec vel nibh sapien. Maecenas ultricies mauris sapien. Nunc et sem ac justo ultricies dignissim ac vitae sem.
+
+* Nulla molestie aliquet metus, a dapibus ligula.
+
+  Morbi pellentesque sodales sollicitudin. Fusce semper placerat suscipit. Aliquam semper tempus ex, non efficitur erat posuere in. Fusce at orci eu ex sagittis commodo.
+
+  > Fusce tempus scelerisque egestas. Pellentesque varius nulla a varius fringilla.
+
+  Fusce nec urna eu orci porta blandit.
+
+Numbered lists are also supported
+
+1. Lorem ipsum dolor sit amet, consectetur adipiscing elit.
+2. Nulla quis venenatis justo.
+3. In non _sodales_ eros.
+
+As are nested lists
+
+* Morbi et varius nisl, eu semper orci.
+
+  Donec vel nibh sapien. Maecenas ultricies mauris sapien. Nunc et sem ac justo ultricies dignissim ac vitae sem.
+
+  - Lorem ipsum dolor sit amet, consectetur adipiscing elit.
+  - Nulla quis venenatis justo.
+  - In non _sodales_ eros.
+
+* Nulla molestie aliquet metus, a dapibus ligula.
+
+  1. Lorem ipsum dolor sit amet, consectetur adipiscing elit.
+  2. Nulla quis venenatis justo.
+  3. In non _sodales_ eros.
+
+  Fusce nec urna eu orci porta blandit.
+
+Lists can also be included in other blocks that can contain block level items
+
+!!! note "Bulleted lists in admonitions"
+
+    * Lorem ipsum dolor sit amet, consectetur adipiscing elit.
+    * Nulla quis venenatis justo.
+    * In non _sodales_ eros.
+
+!!! note "Large lists in admonitions"
+
+    * Morbi et varius nisl, eu semper orci.
+
+      Donec vel nibh sapien. Maecenas ultricies mauris sapien. Nunc et sem ac justo ultricies dignissim ac vitae sem.
+
+      - Lorem ipsum dolor sit amet, consectetur adipiscing elit.
+      - Nulla quis venenatis justo.
+      - In non _sodales_ eros.
+
+    * Nulla molestie aliquet metus, a dapibus ligula.
+
+      1. Lorem ipsum dolor sit amet, consectetur adipiscing elit.
+      2. Nulla quis venenatis justo.
+      3. In non _sodales_ eros.
+
+      Fusce nec urna eu orci porta blandit.
+
+> * Morbi et varius nisl, eu semper orci.
+>
+>   Donec vel nibh sapien. Maecenas ultricies mauris sapien. Nunc et sem ac justo ultricies dignissim ac vitae sem.
+>
+>   - Lorem ipsum dolor sit amet, consectetur adipiscing elit.
+>   - Nulla quis venenatis justo.
+>   - In non _sodales_ eros.
+
+### Tables
+
+| object | implemented |      value |
+|--------|-------------|------------|
+| `A`    |      ✓      |      10.00 |
+| `BB`   |      ✓      | 1000000.00 |
+
+With explicit alignment.
+
+| object | implemented |      value |
+| :---   |    :---:    |       ---: |
+| `A`    |      ✓      |      10.00 |
+| `BB`   |      ✓      | 1000000.00 |
+
+Tables that are too wide should become scrollable.
+
+| object | implemented |      value |
+| :---   |    :---:    |       ---: |
+| `A`    |      ✓      |      10.00 |
+| `BBBBBBBBBBBBBBBBBBBB` | ✓✓✓✓✓✓✓✓✓✓✓✓✓✓✓✓✓✓✓✓✓✓✓✓✓✓✓✓✓✓✓✓✓✓✓✓✓✓✓✓✓✓✓✓ | 1000000000000000000000000000000000000000000000000000000.00 |
+
+
+### Footnotes
+
+Footnote references can be added with the `[^label]` syntax.[^1] The footnote definitions get collected at the bottom of the page.
+
+The footnote label can be an arbitrary string and even consist of block-level elements.[^Clarke61]
+
+[^1]: A footnote definition uses the `[^label]: ...` sytax in a block scope.
+
+[^Clarke61]:
+    > Any sufficiently advanced technology is indistinguishable from magic.
+    Arthur C. Clarke, _Profiles of the Future_ (1961): Clarke's Third Law.
+
+### Headings
+
+Finally, headings render as follows
+
+### Heading level 3
+#### Heading level 4
+##### Heading level 5
+###### Heading level 6
+
+To see an example of a level 1 heading see the page title and for level 2 heading, see the one just under this paragraph.
+
+!!! note "Headings in sidebars"
+    Level 1 and 2 heading show up in the sidebar, for the current page.
+
+## Docstrings
+
+The key feature of Documenter, of course, is the ability to automatically include docstrings
+from your package in the manual. The following example docstrings come from the demo
+[`DocumenterShowcase`](@ref) module, the source of which can be found in
+`docs/DocumenterShowcase.jl`.
+
+To include a docstrings into a manual page, you needs to use an [`@docs` block](@ref)
+
+````markdown
+```@docs
+DocumenterShowcase
+```
+````
+
+This will include a single docstring and it will look like this
+
+```@docs
+DocumenterShowcase
+```
+
+You can include the docstrings corresponding to different function signatures one by one.
+E.g., the [`DocumenterShowcase.foo`](@ref) function has two signatures -- `(::Integer)` and `(::AbstractString)`.
+
+````markdown
+```@docs
+DocumenterShowcase.foo(::Integer)
+```
+````
+
+yielding the following docstring
+
+```@docs
+DocumenterShowcase.foo(::Integer)
+```
+
+And now, by having `DocumenterShowcase.foo(::AbstractString)` in the `@docs` block will give the other docstring
+
+```@docs
+DocumenterShowcase.foo(::AbstractString)
+```
+
+However, if you want, you can also combine multiple docstrings into a single docstring block.
+The [`DocumenterShowcase.bar`](@ref) function has the same signatures as
+
+If we just put `DocumenterShowcase.bar` in an `@docs` block, it will combine the docstrings as follows:
+
+```@docs
+DocumenterShowcase.bar
+```
+
+If you have very many docstrings, you may also want to consider using the [`@autodocs` block](@ref) which can include a whole set of docstrings automatically based on certain filtering options
+
+### An index of docstrings
+
+The [`@index` block](@ref) can be used to generate a list of all the docstrings on a page (or even across pages) and will look as follows
+
+```@index
+Pages = ["showcase.md"]
+```
+
+## Doctesting example
+
+Often you want to write code example such as this:
+
+```jldoctest
+julia> f(x) = x^2
+f (generic function with 1 method)
+
+julia> f(3)
+9
+```
+
+If you write them as a ````` ```jldoctest ````` code block, Documenter can make sure that the doctest has not become outdated. See [Doctests](@ref) for more information.
+
+Script-style doctests are supported too:
+
+```jldoctest
+2 + 2
+# output
+4
+```
+
+## Running interactive code
+
+[`@example` block](@ref) run a code snippet and insert the output into the document.
+E.g. the following Markdown
+
+````markdown
+```@example
+2 + 3
+```
+````
+
+becomes the following code-output block pair
+
+```@example
+2 + 3
+```
+
+If the last element can be rendered as an image or `text/html` etc. (the corresponding `Base.show` method for the particular MIME type has to be defined), it will be rendered appropriately. e.g.:
+
+```@example
+using Main: DocumenterShowcase
+DocumenterShowcase.SVGCircle("000", "aaa")
+```
+
+This is handy when combined with the `Markdown` standard library
+
+```@example
+using Markdown
+Markdown.parse("""
+`Markdown.MD` objects can be constructed dynamically on the fly and still get rendered "natively".
+""")
+```
+
+If the last value in an `@example` block is a `nothing`, the standard output from the blocks' evaluation gets displayed instead
+
+```@example
+println("Hello World")
+```
+
+However, do note that if the block prints to standard output, but also has a final non-`nothing` value, the standard output just gets discarded:
+
+```@example
+println("Hello World")
+42
+```
+
+### REPL-type
+
+[`@repl` block](@ref) can be used to simulate the REPL evaluation of code blocks. For example, the following block
+
+````markdown
+```@repl
+using Statistics
+xs = collect(1:10)
+median(xs)
+sum(xs)
+```
+````
+
+It gets expanded into something that looks like as if it was evaluated in the REPL, with the `julia>` prompt prepended etc.:
+
+```@repl
+using Statistics
+xs = collect(1:10)
+median(xs)
+sum(xs)
+```
+
+## Doctest showcase
 
 Currently exists just so that there would be doctests to run in manual pages of Documenter's
 manual. This page does not show up in navigation.
diff -pruN 1.3.1+dfsg-1/debian/embedded/Documenter/Project.toml 1.4.0+dfsg-1/debian/embedded/Documenter/Project.toml
--- 1.3.1+dfsg-1/debian/embedded/Documenter/Project.toml	2019-11-28 04:21:05.000000000 +0000
+++ 1.4.0+dfsg-1/debian/embedded/Documenter/Project.toml	2020-03-30 16:16:04.000000000 +0000
@@ -1,9 +1,10 @@
 name = "Documenter"
 uuid = "e30172f5-a6a5-5a46-863b-614d45cd2de4"
-version = "0.23.0"
+version = "0.24.4"
 
 [deps]
 Base64 = "2a0f44e3-6c83-55bd-87e4-b1978d98bd5f"
+Dates = "ade2ca70-3891-5945-98fb-dc099432e06a"
 DocStringExtensions = "ffbed154-4ef7-542d-bbb7-c09d3a79fcae"
 InteractiveUtils = "b77e0a4c-d291-57a0-90e8-8db25a27a240"
 JSON = "682c06a0-de6a-54ab-a142-c8b1cf79cde6"
diff -pruN 1.3.1+dfsg-1/debian/embedded/Documenter/README.md 1.4.0+dfsg-1/debian/embedded/Documenter/README.md
--- 1.3.1+dfsg-1/debian/embedded/Documenter/README.md	2019-11-28 04:21:05.000000000 +0000
+++ 1.4.0+dfsg-1/debian/embedded/Documenter/README.md	2020-03-30 16:16:04.000000000 +0000
@@ -40,7 +40,7 @@ Usage questions can be posted on the [Ju
 
 Contributions are very welcome, as are feature requests and suggestions. Please open an [issue][issues-url] if you encounter any problems. The [contributing page][contrib-url] has a few guidelines that should be followed when opening pull requests and contributing code.
 
-[contrib-url]: https://juliadocs.github.io/Documenter.jl/latest/man/contributing/
+[contrib-url]: https://juliadocs.github.io/Documenter.jl/dev/contributing/
 [discourse-tag-url]: https://discourse.julialang.org/tags/documenter
 [gitter-url]: https://gitter.im/juliadocs/users
 
diff -pruN 1.3.1+dfsg-1/debian/embedded/Documenter/src/deployconfig.jl 1.4.0+dfsg-1/debian/embedded/Documenter/src/deployconfig.jl
--- 1.3.1+dfsg-1/debian/embedded/Documenter/src/deployconfig.jl	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/debian/embedded/Documenter/src/deployconfig.jl	2020-03-30 16:16:04.000000000 +0000
@@ -0,0 +1,402 @@
+import JSON
+
+"""
+    DeployConfig
+
+Abstract type which new deployment configs should be subtypes of.
+"""
+abstract type DeployConfig end
+
+"""
+    Documenter.documenter_key(cfg::DeployConfig)
+
+Return the Base64-encoded SSH private key for the repository.
+Defaults to reading the `DOCUMENTER_KEY` environment variable.
+
+This method must be supported by configs that push with SSH, see
+[`Documenter.authentication_method`](@ref).
+"""
+function documenter_key(::DeployConfig)
+    return ENV["DOCUMENTER_KEY"]
+end
+
+"""
+    Documenter.deploy_folder(cfg::DeployConfig; repo, devbranch, push_preview, devurl, kwargs...)
+
+Return the folder where the documentation should be deployed to, or `nothing`
+if the current build should not deploy.
+This function is called with the `repo`, `devbranch`, `push_preview` and `devurl`
+arguments from [`deploydocs`](@ref).
+
+!!! note
+    Implementations of this functions should accept trailing `kwargs...` for
+    compatibility with future Documenter releases which may pass additional
+    keyword arguments.
+"""
+function deploy_folder(cfg::DeployConfig; kwargs...)
+    @warn "Documenter.deploy_folder(::$(typeof(cfg)); kwargs...) not implemented. Skipping deployment."
+    return nothing
+end
+function deploy_folder(::Nothing; kwargs...)
+    @warn "Documenter could not auto-detect the building environment Skipping deployment."
+    return nothing
+end
+
+@enum AuthenticationMethod SSH HTTPS
+
+"""
+    Documenter.authentication_method(::DeployConfig)
+
+Return enum instance `SSH` or `HTTPS` depending on push method to be used.
+
+Configs returning `SSH` should support [`Documenter.documenter_key`](@ref).
+Configs returning `HTTPS` should support [`Documenter.authenticated_repo_url`](@ref).
+"""
+authentication_method(::DeployConfig) = SSH
+
+"""
+    Documenter.authenticated_repo_url(cfg::DeployConfig)
+
+Return an authenticated URL to the upstream repository.
+
+This method must be supported by configs that push with HTTPS, see
+[`Documenter.authentication_method`](@ref).
+"""
+function authenticated_repo_url end
+
+post_status(cfg::Union{DeployConfig,Nothing}; kwargs...) = nothing
+post_status(; kwargs...) = post_status(auto_detect_deploy_system(); kwargs...)
+
+marker(x) = x ? "✔" : "✘"
+
+#############
+# Travis CI #
+#############
+
+"""
+    Travis <: DeployConfig
+
+Default implementation of `DeployConfig`.
+
+The following environment variables influences the build
+when using the `Travis` configuration:
+
+ - `DOCUMENTER_KEY`: must contain the Base64-encoded SSH private key for the repository.
+   This variable should be set in the Travis settings for the repository. Make sure this
+   variable is marked **NOT** to be displayed in the build log.
+
+ - `TRAVIS_PULL_REQUEST`: must be set to `false`.
+   This avoids deployment on pull request builds.
+
+ - `TRAVIS_REPO_SLUG`: must match the value of the `repo` keyword to [`deploydocs`](@ref).
+
+ - `TRAVIS_EVENT_TYPE`: may not be set to `cron`. This avoids re-deployment of existing
+   docs on builds that were triggered by a Travis cron job.
+
+ - `TRAVIS_BRANCH`: unless `TRAVIS_TAG` is non-empty, this must have the same value as
+   the `devbranch` keyword to [`deploydocs`](@ref). This makes sure that only the
+   development branch (commonly, the `master` branch) will deploy the "dev" documentation
+   (deployed into a directory specified by the `devurl` keyword to [`deploydocs`](@ref)).
+
+ - `TRAVIS_TAG`: if set, a tagged version deployment is performed instead; the value
+   must be a valid version number (i.e. match `Base.VERSION_REGEX`). The documentation for
+   a package version tag gets deployed to a directory named after the version number in
+   `TRAVIS_TAG` instead.
+
+The `TRAVIS_*` variables are set automatically on Travis. More information on how Travis
+sets the `TRAVIS_*` variables can be found in the
+[Travis documentation](https://docs.travis-ci.com/user/environment-variables/#default-environment-variables).
+"""
+struct Travis <: DeployConfig
+    travis_branch::String
+    travis_pull_request::String
+    travis_repo_slug::String
+    travis_tag::String
+    travis_event_type::String
+end
+function Travis()
+    travis_branch       = get(ENV, "TRAVIS_BRANCH",        "")
+    travis_pull_request = get(ENV, "TRAVIS_PULL_REQUEST",  "")
+    travis_repo_slug    = get(ENV, "TRAVIS_REPO_SLUG",     "")
+    travis_tag          = get(ENV, "TRAVIS_TAG",           "")
+    travis_event_type   = get(ENV, "TRAVIS_EVENT_TYPE",    "")
+    return Travis(travis_branch, travis_pull_request,
+        travis_repo_slug, travis_tag, travis_event_type)
+end
+
+# Check criteria for deployment
+function deploy_folder(cfg::Travis; repo, devbranch, push_preview, devurl, kwargs...)
+    io = IOBuffer()
+    all_ok = true
+    ## Determine build type; release, devbranch or preview
+    if cfg.travis_pull_request != "false"
+        build_type = :preview
+    elseif !isempty(cfg.travis_tag)
+        build_type = :release
+    else
+        build_type = :devbranch
+    end
+    println(io, "Deployment criteria for deploying $(build_type) build from Travis:")
+    ## The deploydocs' repo should match TRAVIS_REPO_SLUG
+    repo_ok = occursin(cfg.travis_repo_slug, repo)
+    all_ok &= repo_ok
+    println(io, "- $(marker(repo_ok)) ENV[\"TRAVIS_REPO_SLUG\"]=\"$(cfg.travis_repo_slug)\" occurs in repo=\"$(repo)\"")
+    if build_type === :release
+        ## Do not deploy for PRs
+        pr_ok = cfg.travis_pull_request == "false"
+        println(io, "- $(marker(pr_ok)) ENV[\"TRAVIS_PULL_REQUEST\"]=\"$(cfg.travis_pull_request)\" is \"false\"")
+        all_ok &= pr_ok
+        ## If a tag exist it should be a valid VersionNumber
+        tag_ok = occursin(Base.VERSION_REGEX, cfg.travis_tag)
+        all_ok &= tag_ok
+        println(io, "- $(marker(tag_ok)) ENV[\"TRAVIS_TAG\"] contains a valid VersionNumber")
+        ## Deploy to folder according to the tag
+        subfolder = cfg.travis_tag
+    elseif build_type === :devbranch
+        ## Do not deploy for PRs
+        pr_ok = cfg.travis_pull_request == "false"
+        println(io, "- $(marker(pr_ok)) ENV[\"TRAVIS_PULL_REQUEST\"]=\"$(cfg.travis_pull_request)\" is \"false\"")
+        all_ok &= pr_ok
+        ## deploydocs' devbranch should match TRAVIS_BRANCH
+        branch_ok = !isempty(cfg.travis_tag) || cfg.travis_branch == devbranch
+        all_ok &= branch_ok
+        println(io, "- $(marker(branch_ok)) ENV[\"TRAVIS_BRANCH\"] matches devbranch=\"$(devbranch)\"")
+        ## Deploy to deploydocs devurl kwarg
+        subfolder = devurl
+    else # build_type === :preview
+        pr_number = tryparse(Int, cfg.travis_pull_request)
+        pr_ok = pr_number !== nothing
+        all_ok &= pr_ok
+        println(io, "- $(marker(pr_ok)) ENV[\"TRAVIS_PULL_REQUEST\"]=\"$(cfg.travis_pull_request)\" is a number")
+        btype_ok = push_preview
+        all_ok &= btype_ok
+        println(io, "- $(marker(btype_ok)) `push_preview` keyword argument to deploydocs is `true`")
+        ## deploy to previews/PR
+        subfolder = "previews/PR$(something(pr_number, 0))"
+    end
+    ## DOCUMENTER_KEY should exist (just check here and extract the value later)
+    key_ok = haskey(ENV, "DOCUMENTER_KEY")
+    all_ok &= key_ok
+    println(io, "- $(marker(key_ok)) ENV[\"DOCUMENTER_KEY\"] exists")
+    ## Cron jobs should not deploy
+    type_ok = cfg.travis_event_type != "cron"
+    all_ok &= type_ok
+    println(io, "- $(marker(type_ok)) ENV[\"TRAVIS_EVENT_TYPE\"]=\"$(cfg.travis_event_type)\" is not \"cron\"")
+    print(io, "Deploying: $(marker(all_ok))")
+    @info String(take!(io))
+    return all_ok ? subfolder : nothing
+end
+
+
+##################
+# GitHub Actions #
+##################
+
+"""
+    GitHubActions <: DeployConfig
+
+Implementation of `DeployConfig` for deploying from GitHub Actions.
+
+The following environment variables influences the build
+when using the `GitHubActions` configuration:
+
+ - `GITHUB_EVENT_NAME`: must be set to `push`.
+   This avoids deployment on pull request builds.
+
+ - `GITHUB_REPOSITORY`: must match the value of the `repo` keyword to [`deploydocs`](@ref).
+
+ - `GITHUB_REF`: must match the `devbranch` keyword to [`deploydocs`](@ref), alternatively
+   correspond to a git tag.
+
+ - `GITHUB_TOKEN` or `DOCUMENTER_KEY`: used for authentication with GitHub,
+   see the manual section for [GitHub Actions](@ref) for more information.
+
+The `GITHUB_*` variables are set automatically on GitHub Actions, see the
+[documentation](https://help.github.com/en/actions/automating-your-workflow-with-github-actions/using-environment-variables#default-environment-variables).
+"""
+struct GitHubActions <: DeployConfig
+    github_repository::String
+    github_event_name::String
+    github_ref::String
+end
+function GitHubActions()
+    github_repository = get(ENV, "GITHUB_REPOSITORY", "") # "JuliaDocs/Documenter.jl"
+    github_event_name = get(ENV, "GITHUB_EVENT_NAME", "") # "push", "pull_request" or "cron" (?)
+    github_ref        = get(ENV, "GITHUB_REF",        "") # "refs/heads/$(branchname)" for branch, "refs/tags/$(tagname)" for tags
+    return GitHubActions(github_repository, github_event_name, github_ref)
+end
+
+# Check criteria for deployment
+function deploy_folder(cfg::GitHubActions; repo, devbranch, push_preview, devurl, kwargs...)
+    io = IOBuffer()
+    all_ok = true
+    ## Determine build type
+    if cfg.github_event_name == "pull_request"
+        build_type = :preview
+    elseif occursin(r"^refs\/tags\/(.*)$", cfg.github_ref)
+        build_type = :release
+    else
+        build_type = :devbranch
+    end
+    println(io, "Deployment criteria for deploying $(build_type) build from GitHub Actions:")
+    ## The deploydocs' repo should match GITHUB_REPOSITORY
+    repo_ok = occursin(cfg.github_repository, repo)
+    all_ok &= repo_ok
+    println(io, "- $(marker(repo_ok)) ENV[\"GITHUB_REPOSITORY\"]=\"$(cfg.github_repository)\" occurs in repo=\"$(repo)\"")
+    if build_type === :release
+        ## Do not deploy for PRs
+        event_ok = cfg.github_event_name == "push"
+        all_ok &= event_ok
+        println(io, "- $(marker(event_ok)) ENV[\"GITHUB_EVENT_NAME\"]=\"$(cfg.github_event_name)\" is \"push\"")
+        ## If a tag exist it should be a valid VersionNumber
+        m = match(r"^refs\/tags\/(.*)$", cfg.github_ref)
+        tag_ok = m === nothing ? false : occursin(Base.VERSION_REGEX, String(m.captures[1]))
+        all_ok &= tag_ok
+        println(io, "- $(marker(tag_ok)) ENV[\"GITHUB_REF\"]=\"$(cfg.github_ref)\" contains a valid VersionNumber")
+        ## Deploy to folder according to the tag
+        subfolder = m === nothing ? nothing : String(m.captures[1])
+    elseif build_type === :devbranch
+        ## Do not deploy for PRs
+        event_ok = cfg.github_event_name == "push"
+        all_ok &= event_ok
+        println(io, "- $(marker(event_ok)) ENV[\"GITHUB_EVENT_NAME\"]=\"$(cfg.github_event_name)\" is \"push\"")
+        ## deploydocs' devbranch should match the current branch
+        m = match(r"^refs\/heads\/(.*)$", cfg.github_ref)
+        branch_ok = m === nothing ? false : String(m.captures[1]) == devbranch
+        all_ok &= branch_ok
+        println(io, "- $(marker(branch_ok)) ENV[\"GITHUB_REF\"] matches devbranch=\"$(devbranch)\"")
+        ## Deploy to deploydocs devurl kwarg
+        subfolder = devurl
+    else # build_type === :preview
+        m = match(r"refs\/pull\/(\d+)\/merge", cfg.github_ref)
+        pr_number = tryparse(Int, m === nothing ? "" : m.captures[1])
+        pr_ok = pr_number !== nothing
+        all_ok &= pr_ok
+        println(io, "- $(marker(pr_ok)) ENV[\"GITHUB_REF\"] corresponds to a PR number")
+        btype_ok = push_preview
+        all_ok &= btype_ok
+        println(io, "- $(marker(btype_ok)) `push_preview` keyword argument to deploydocs is `true`")
+        ## deploydocs to previews/PR
+        subfolder = "previews/PR$(something(pr_number, 0))"
+    end
+    ## GITHUB_ACTOR should exist (just check here and extract the value later)
+    actor_ok = haskey(ENV, "GITHUB_ACTOR")
+    all_ok &= actor_ok
+    println(io, "- $(marker(actor_ok)) ENV[\"GITHUB_ACTOR\"] exists")
+    ## GITHUB_TOKEN or DOCUMENTER_KEY should exist (just check here and extract the value later)
+    token_ok = haskey(ENV, "GITHUB_TOKEN")
+    key_ok = haskey(ENV, "DOCUMENTER_KEY")
+    auth_ok = token_ok | key_ok
+    all_ok &= auth_ok
+    if key_ok
+        println(io, "- $(marker(key_ok)) ENV[\"DOCUMENTER_KEY\"] exists exists")
+    elseif token_ok
+        println(io, "- $(marker(token_ok)) ENV[\"GITHUB_TOKEN\"] exists exists")
+    else
+        println(io, "- $(marker(auth_ok)) ENV[\"DOCUMENTER_KEY\"] or ENV[\"GITHUB_TOKEN\"]  exists")
+    end
+    print(io, "Deploying: $(marker(all_ok))")
+    @info String(take!(io))
+    return all_ok ? subfolder : nothing
+end
+
+function authentication_method(::GitHubActions)
+    if haskey(ENV, "DOCUMENTER_KEY")
+        return SSH
+    else
+        @warn "Currently the GitHub Pages build is not triggered when " *
+              "using `GITHUB_TOKEN` for authentication. See issue #1177 " *
+              "(https://github.com/JuliaDocs/Documenter.jl/issues/1177) " *
+              "for more information."
+        return HTTPS
+    end
+end
+function authenticated_repo_url(cfg::GitHubActions)
+    return "https://$(ENV["GITHUB_ACTOR"]):$(ENV["GITHUB_TOKEN"])@github.com/$(cfg.github_repository).git"
+end
+
+
+
+function post_status(::GitHubActions; type, repo::String, subfolder=nothing, kwargs...)
+    try # make this non-fatal and silent
+        # If we got this far it usually means everything is in
+        # order so no need to check everything again.
+        # In particular this is only called after we have
+        # determined to deploy.
+        sha = nothing
+        if get(ENV, "GITHUB_EVENT_NAME", nothing) == "pull_request"
+            event_path = get(ENV, "GITHUB_EVENT_PATH", nothing)
+            event_path === nothing && return
+            event = JSON.parsefile(event_path)
+            if haskey(event, "pull_request") &&
+               haskey(event["pull_request"], "head") &&
+               haskey(event["pull_request"]["head"], "sha")
+               sha = event["pull_request"]["head"]["sha"]
+            end
+        elseif get(ENV, "GITHUB_EVENT_NAME", nothing) == "push"
+            sha = get(ENV, "GITHUB_SHA", nothing)
+        end
+        sha === nothing && return
+        return post_github_status(type, repo, sha, subfolder)
+    catch
+        @debug "Failed to post status"
+    end
+end
+
+function post_github_status(type::S, deploydocs_repo::S, sha::S, subfolder=nothing) where S <: String
+    try
+        Sys.which("curl") === nothing && return
+        ## Extract owner and repository name
+        m = match(r"^github.com\/(.+?)\/(.+?\.jl)(.git)?$", deploydocs_repo)
+        m === nothing && return
+        owner = String(m.captures[1])
+        repo = String(m.captures[2])
+
+        ## Need an access token for this
+        auth = get(ENV, "GITHUB_TOKEN", nothing)
+        auth === nothing && return
+        # construct the curl call
+        cmd = `curl -sX POST`
+        push!(cmd.exec, "-H", "Authorization: token $(auth)")
+        push!(cmd.exec, "-H", "User-Agent: Documenter.jl")
+        push!(cmd.exec, "-H", "Content-Type: application/json")
+        json = Dict{String,Any}("context" => "documenter/deploy", "state"=>type)
+        if type == "pending"
+            json["description"] = "Documentation build in progress"
+        elseif type == "success"
+            json["description"] = "Documentation build succeeded"
+            if subfolder !== nothing
+                json["target_url"] = "https://$(owner).github.io/$(repo)/$(subfolder)/"
+            end
+        elseif type == "error"
+            json["description"] = "Documentation build errored"
+        elseif type == "failure"
+            json["description"] = "Documentation build failed"
+        else
+            error("unsupported type: $type")
+        end
+        push!(cmd.exec, "-d", sprint(JSON.print, json))
+        push!(cmd.exec, "https://api.github.com/repos/$(owner)/$(repo)/statuses/$(sha)")
+        # Run the command (silently)
+        io = IOBuffer()
+        res = run(pipeline(cmd; stdout=io, stderr=devnull))
+        @debug "Response of curl POST request" response=String(take!(io))
+    catch
+        @debug "Failed to post status"
+    end
+    return nothing
+end
+
+
+##################
+# Auto-detection #
+##################
+function auto_detect_deploy_system()
+    if haskey(ENV, "TRAVIS_REPO_SLUG")
+        return Travis()
+    elseif haskey(ENV, "GITHUB_REPOSITORY")
+        return GitHubActions()
+    else
+        return nothing
+    end
+end
diff -pruN 1.3.1+dfsg-1/debian/embedded/Documenter/src/DocTests.jl 1.4.0+dfsg-1/debian/embedded/Documenter/src/DocTests.jl
--- 1.3.1+dfsg-1/debian/embedded/Documenter/src/DocTests.jl	2019-11-28 04:21:06.000000000 +0000
+++ 1.4.0+dfsg-1/debian/embedded/Documenter/src/DocTests.jl	2020-03-30 16:16:04.000000000 +0000
@@ -70,10 +70,18 @@ function doctest(docstr::Docs.DocStr, mo
     # Note: parsedocs / formatdoc in Base is weird. It double-wraps the docstring Markdown
     # in a Markdown.MD object..
     @assert isa(md, Markdown.MD) # relying on Julia internals here
-    if length(md.content) == 1 && isa(first(md.content), Markdown.MD)
+    while length(md.content) == 1 && isa(first(md.content), Markdown.MD)
         md = first(md.content)
     end
-    md2ast = Markdown2.convert(Markdown2.MD, md)
+    md2ast = try
+        Markdown2.convert(Markdown2.MD, md)
+    catch err
+        @error """
+            Markdown2 conversion error for a docstring in $(mod).
+            This is a bug — please report this on the Documenter issue tracker
+            """ docstr.data
+        rethrow(err)
+    end
     ctx = DocTestContext(docstr.data[:path], doc)
     merge!(ctx.meta, DocMeta.getdocmeta(mod))
     ctx.meta[:CurrentFile] = get(docstr.data, :path, nothing)
diff -pruN 1.3.1+dfsg-1/debian/embedded/Documenter/src/Documenter.jl 1.4.0+dfsg-1/debian/embedded/Documenter/src/Documenter.jl
--- 1.3.1+dfsg-1/debian/embedded/Documenter/src/Documenter.jl	2019-11-28 04:21:06.000000000 +0000
+++ 1.4.0+dfsg-1/debian/embedded/Documenter/src/Documenter.jl	2020-03-30 16:16:04.000000000 +0000
@@ -50,12 +50,12 @@ include("Writers/Writers.jl")
 include("Deps.jl")
 
 import .Utilities: Selectors
-import .Writers.HTMLWriter: HTML
-
+import .Writers.HTMLWriter: HTML, asset
+import .Writers.HTMLWriter.RD: KaTeX, MathJax
 
 # User Interface.
 # ---------------
-export Deps, makedocs, deploydocs, hide, doctest, DocMeta
+export Deps, makedocs, deploydocs, hide, doctest, DocMeta, KaTeX, MathJax, asset
 
 """
     makedocs(
@@ -186,9 +186,9 @@ when a minor version changes (i.e. excep
 **`checkdocs`** instructs [`makedocs`](@ref) to check whether all names within the modules
 defined in the `modules` keyword that have a docstring attached have the docstring also
 listed in the manual (e.g. there's a `@docs` blocks with that docstring). Possible values
-are `:all` (check all names) and `:exports` (check only exported names). The default value
-is `:none`, in which case no checks are performed. If `strict` is also enabled then the
-build will fail if any missing docstrings are encountered.
+are `:all` (check all names; the default), `:exports` (check only exported names) and
+`:none` (no checks are performed). If `strict` is also enabled then the build will fail if
+any missing docstrings are encountered.
 
 **`linkcheck`** -- if set to `true` [`makedocs`](@ref) uses `curl` to check the status codes
 of external-pointing links, to make sure that they are up-to-date. The links and their
@@ -231,89 +231,7 @@ See the [Other Output Formats](@ref) for
 A guide detailing how to document a package using Documenter's [`makedocs`](@ref) is provided
 in the [setup guide in the manual](@ref Package-Guide).
 """
-function makedocs(components...; debug = false, format = HTML(),
-                  html_prettyurls::Union{Bool, Nothing} = nothing, # deprecated
-                  html_disable_git::Union{Bool, Nothing} = nothing, # deprecated
-                  html_edit_branch::Union{String, Nothing} = nothing, # deprecated
-                  html_canonical::Union{String, Nothing} = nothing, # deprecated
-                  assets::Union{Vector{<:AbstractString}, Nothing} = nothing, # deprecated
-                  analytics::Union{<:AbstractString, Nothing} = nothing, # deprecated
-                  kwargs...)
-    # html_ keywords deprecation
-    html_keywords = Dict()
-    function html_warn(kw)
-        replace_with = startswith(kw, "html_") ? kw[6:end] : kw
-        @warn """
-        The `$kw` keyword argument should now be specified in the
-        `Documenter.HTML()` format specifier. To fix this warning replace
-        ```
-        $kw = ...
-        ```
-        with
-        ```
-        format = Documenter.HTML($(replace_with) = ...)
-        ```
-        """
-    end
-    if html_prettyurls !== nothing
-        html_warn("html_prettyurls")
-        html_keywords[:prettyurls] = html_prettyurls
-    end
-    if html_disable_git !== nothing
-        html_warn("html_disable_git")
-        html_keywords[:disable_git] = html_disable_git
-    end
-    if html_edit_branch !== nothing
-        html_warn("html_edit_branch")
-        html_keywords[:edit_branch] = html_edit_branch
-    end
-    if html_canonical !== nothing
-        html_warn("html_canonical")
-        html_keywords[:canonical] = html_canonical
-    end
-    if assets !== nothing
-        html_warn("assets")
-        html_keywords[:assets] = assets
-    end
-    if analytics !== nothing
-        html_warn("analytics")
-        html_keywords[:analytics] = analytics
-    end
-
-    # deprecation of format as Symbols
-    function fmt(f)
-        if f === :html
-            Base.depwarn("`format = :html` is deprecated, use `format = Documenter.HTML()` instead.", :makedocs)
-            return Writers.HTMLWriter.HTML(; html_keywords...)
-        elseif f === :latex
-            Base.depwarn("`format = :latex` is deprecated, use `format = LaTeX()` from " *
-                "the DocumenterLaTeX package instead.", :makedocs)
-            return Writers.LaTeXWriter.LaTeX()
-        elseif f === :markdown
-            Base.depwarn("`format = :markdown` is deprecated, use `format = Markdown()` " *
-                "from the DocumenterMarkdown package instead.", :makedocs)
-            return Writers.MarkdownWriter.Markdown()
-        end
-    end
-    if isa(format, AbstractVector{<:Symbol})
-        format = fmt.(format)
-    elseif isa(format, Symbol)
-        format = fmt(format)
-    end
-    # overwrite some stuff in HTML() if outer html_ kwargs have been set
-    # seems ok since the depwarns will still be there.
-    overwrite(x) = x
-    function overwrite(html::HTML)
-        d = Dict(x => getfield(html, x) for x in fieldnames(HTML))
-        d = merge!(d, html_keywords)
-        return HTML(; d...)
-    end
-    if isa(format, HTML)
-        format = overwrite(format)
-    elseif format isa AbstractVector
-        format = overwrite.(format)
-    end
-
+function makedocs(components...; debug = false, format = HTML(), kwargs...)
     document = Documents.Document(components; format=format, kwargs...)
     cd(document.user.root) do
         Selectors.dispatch(Builder.DocumentPipeline, document)
@@ -371,6 +289,8 @@ makedocs(
 hide(root::Pair, children) = (true, root.first, root.second, map(hide, children))
 hide(root::AbstractString, children) = (true, nothing, root, map(hide, children))
 
+include("deployconfig.jl")
+
 """
     deploydocs(
         root   = "<current-directory>",
@@ -415,6 +335,11 @@ repo = "github.com/JuliaDocs/Documenter.
 
 # Optional keyword arguments
 
+**`deploy_config`** determines configuration for the deployment.
+If this is not specified Documenter will try to autodetect from the
+currently running environment. See the manual section about
+[Deployment systems](@ref).
+
 **`root`** has the same purpose as the `root` keyword for [`makedocs`](@ref).
 
 **`target`** is the directory, relative to `root`, where generated content that should be
@@ -462,42 +387,8 @@ the generated html. The following entrie
    The second argument can be `"v^"`, to point to the maximum version docs
    (as in e.g. `"stable" => "v^"`).
 
-# Environment variables
-
-[`deploydocs`](@ref)'s behavior is influenced by the following environment variables, many
-of which are specific to the [Travis CI platform](https://travis-ci.com/).
-
- - **`DOCUMENTER_KEY`**: must contain the Base64-encoded SSH private key for the repository.
-
- - **`TRAVIS_PULL_REQUEST`**: must be set to `false`.
-
-   This avoids deployment on pull request builds. Note that there is no way to _safely_
-   enable builds on pull requests, since that would expose the SSH private key
-   (`DOCUMENTER_KEY`), giving anyone opening a pull request full write access to the repository.
-
- - **`TRAVIS_REPO_SLUG`**: must match the value of the `repo` keyword.
-
- - **`TRAVIS_EVENT_TYPE`**: may not be set to `cron`.
-
-   This avoids the re-deployment of existing docs on builds that were triggered by a Travis
-   cron job.
-
- - **`TRAVIS_BRANCH`**: unless `TRAVIS_TAG` is non-empty, this must have the same value as the
-   `devbranch` keyword.
-
-   This makes sure that only the development branch (commonly, the `master` branch) will deploy
-   the "dev" documentation (deployed into a directory specified by the `devurl` keyword).
-
- - **`TRAVIS_TAG`**: if set, a tagged version deployment is performed instead; the value must be
-   a valid version number (i.e. match `Base.VERSION_REGEX`).
-
-   The documentation for a package version tag gets deployed to a directory named after the
-   version number in `TRAVIS_TAG` instead.
-
-The `TRAVIS_*` variables are set automatically on Travis, but could be set manually to
-appropriate values as well to run [`deploydocs`](@ref) locally or on other CI platforms.
-More information on how Travis sets the `TRAVIS_*` variables can be found in the
-[Travis documentation](https://docs.travis-ci.com/user/environment-variables/#default-environment-variables).
+**`push_preview`** a boolean that specifies if preview documentation should be
+deployed from pull requests or not.
 
 # See Also
 
@@ -512,10 +403,6 @@ function deploydocs(;
 
         repo   = error("no 'repo' keyword provided."),
         branch = "gh-pages",
-        latest::Union{String,Nothing} = nothing, # deprecated
-
-        osname::Union{String,Nothing} = nothing, # deprecated
-        julia::Union{String,Nothing} = nothing, # deprecated
 
         deps   = nothing,
         make   = nothing,
@@ -524,81 +411,12 @@ function deploydocs(;
         devurl = "dev",
         versions = ["stable" => "v^", "v#.#", devurl => devurl],
         forcepush::Bool = false,
+        deploy_config = auto_detect_deploy_system(),
+        push_preview::Bool = false,
     )
-    # deprecation of latest kwarg (renamed to devbranch)
-    if latest !== nothing
-        Base.depwarn("The `latest` keyword argument has been renamed to `devbranch`.", :deploydocs)
-        devbranch = latest
-        @info "setting `devbranch` to `$(devbranch)`."
-    end
-    # deprecation/removal of `julia` and `osname` kwargs
-    if julia !== nothing
-        Base.depwarn("the `julia` keyword argument to `Documenter.deploydocs` is " *
-            "removed. Use Travis Build Stages for determining from where to deploy instead. " *
-            "See the section about Hosting in the Documenter manual for more details.", :deploydocs)
-        @info "skipping docs deployment."
-        return
-    end
-    if osname !== nothing
-        Base.depwarn("the `osname` keyword argument to `Documenter.deploydocs` is " *
-            "removed. Use Travis Build Stages for determining from where to deploy instead. " *
-            "See the section about Hosting in the Documenter manual for more details.", :deploydocs)
-        @info "skipping docs deployment."
-        return
-    end
-
-    # Get environment variables.
-    documenter_key      = get(ENV, "DOCUMENTER_KEY",       "")
-    travis_branch       = get(ENV, "TRAVIS_BRANCH",        "")
-    travis_pull_request = get(ENV, "TRAVIS_PULL_REQUEST",  "")
-    travis_repo_slug    = get(ENV, "TRAVIS_REPO_SLUG",     "")
-    travis_tag          = get(ENV, "TRAVIS_TAG",           "")
-    travis_event_type   = get(ENV, "TRAVIS_EVENT_TYPE",    "")
-
-
-    # Other variables.
-    sha = cd(root) do
-        # We'll make sure we run the git commands in the source directory (root), in case
-        # the working directory has been changed (e.g. if the makedocs' build argument is
-        # outside root).
-        try
-            readchomp(`git rev-parse --short HEAD`)
-        catch
-            # git rev-parse will throw an error and return code 128 if it is not being
-            # run in a git repository, which will make run/readchomp throw an exception.
-            # We'll assume that if readchomp fails it is due to this and set the sha
-            # variable accordingly.
-            "(not-git-repo)"
-        end
-    end
-
-    # Check criteria for deployment
-    ## The deploydocs' repo should match TRAVIS_REPO_SLUG
-    repo_ok = occursin(travis_repo_slug, repo)
-    ## Do not deploy for PRs
-    pr_ok = travis_pull_request == "false"
-    ## If a tag exist it should be a valid VersionNumber
-    tag_ok = isempty(travis_tag) || occursin(Base.VERSION_REGEX, travis_tag)
-    ## If no tag exists deploydocs' devbranch should match TRAVIS_BRANCH
-    branch_ok = !isempty(travis_tag) || travis_branch == devbranch
-    ## DOCUMENTER_KEY should exist
-    key_ok = !isempty(documenter_key)
-    ## Cron jobs should not deploy
-    type_ok = travis_event_type != "cron"
-    should_deploy = repo_ok && pr_ok && tag_ok && branch_ok && key_ok && type_ok
-
-    marker(x) = x ? "✔" : "✘"
-    @info """Deployment criteria:
-    - $(marker(repo_ok)) ENV["TRAVIS_REPO_SLUG"]="$(travis_repo_slug)" occurs in repo="$(repo)"
-    - $(marker(pr_ok)) ENV["TRAVIS_PULL_REQUEST"]="$(travis_pull_request)" is "false"
-    - $(marker(tag_ok)) ENV["TRAVIS_TAG"]="$(travis_tag)" is (i) empty or (ii) a valid VersionNumber
-    - $(marker(branch_ok)) ENV["TRAVIS_BRANCH"]="$(travis_branch)" matches devbranch="$(devbranch)" (if tag is empty)
-    - $(marker(key_ok)) ENV["DOCUMENTER_KEY"] exists
-    - $(marker(type_ok)) ENV["TRAVIS_EVENT_TYPE"]="$(travis_event_type)" is not "cron"
-    Deploying: $(marker(should_deploy))
-    """
 
-    if should_deploy
+    subfolder = deploy_folder(deploy_config; repo=repo, devbranch=devbranch, push_preview=push_preview, devurl=devurl)
+    if subfolder !== nothing
         # Add local bin path if needed.
         Deps.updatepath!()
         # Install dependencies when applicable.
@@ -608,6 +426,20 @@ function deploydocs(;
         end
         # Change to the root directory and try to deploy the docs.
         cd(root) do
+            # Find the commit sha.
+            # We'll make sure we run the git commands in the source directory (root), in case
+            # the working directory has been changed (e.g. if the makedocs' build argument is
+            # outside root).
+            sha = try
+                readchomp(`git rev-parse --short HEAD`)
+            catch
+                # git rev-parse will throw an error and return code 128 if it is not being
+                # run in a git repository, which will make run/readchomp throw an exception.
+                # We'll assume that if readchomp fails it is due to this and set the sha
+                # variable accordingly.
+                "(not-git-repo)"
+            end
+
             @debug "setting up target directory."
             isdir(target) || mkpath(target)
             # Run extra build steps defined in `make` if required.
@@ -620,8 +452,8 @@ function deploydocs(;
                 git_push(
                     root, temp, repo;
                     branch=branch, dirname=dirname, target=target,
-                    tag=travis_tag, key=documenter_key, sha=sha,
-                    devurl = devurl, versions = versions, forcepush = forcepush,
+                    sha=sha, deploy_config=deploy_config, subfolder=subfolder,
+                    devurl=devurl, versions=versions, forcepush=forcepush,
                 )
             end
         end
@@ -631,139 +463,155 @@ end
 """
     git_push(
         root, tmp, repo;
-        branch="gh-pages", dirname="", target="site", tag="", key="", sha="", devurl="dev"
+        branch="gh-pages", dirname="", target="site", sha="", devurl="dev",
+        deploy_config, folder,
     )
 
 Handles pushing changes to the remote documentation branch.
-When `tag` is empty the docs are deployed to the `devurl` directory,
-and when building docs for a tag they are deployed to a `vX.Y.Z` directory.
+The documentation are placed in the folder specified by `subfolder`.
 """
 function git_push(
         root, temp, repo;
-        branch="gh-pages", dirname="", target="site", tag="", key="", sha="", devurl="dev",
-        versions, forcepush=false,
+        branch="gh-pages", dirname="", target="site", sha="", devurl="dev",
+        versions, forcepush=false, deploy_config, subfolder,
     )
     dirname = isempty(dirname) ? temp : joinpath(temp, dirname)
     isdir(dirname) || mkpath(dirname)
 
     target_dir = abspath(target)
 
-    # Extract host from repo as everything up to first ':' or '/' character
-    host = match(r"(.*?)[:\/]", repo)[1]
-
-    # The upstream URL to which we push new content and the ssh decryption commands.
-    upstream = "git@$(replace(repo, "$host/" => "$host:"))"
-
-    keyfile = abspath(joinpath(root, ".documenter"))
-    try
-        write(keyfile, String(base64decode(key)))
-    catch e
-        @error """
-        Documenter failed to decode the DOCUMENTER_KEY environment variable.
-        Make sure that the environment variable is properly set up as a Base64-encoded string
-        of the SSH private key. You may need to re-generate the keys with DocumenterTools.
-        """
-        rethrow(e)
-    end
-    chmod(keyfile, 0o600)
+    # Generate a closure with common commands for ssh and https
+    function git_commands(sshconfig=nothing)
+        # Setup git.
+        run(`git init`)
+        run(`git config user.name "zeptodoctor"`)
+        run(`git config user.email "44736852+zeptodoctor@users.noreply.github.com"`)
+        if sshconfig !== nothing
+            run(`git config core.sshCommand "ssh -F $(sshconfig)"`)
+        end
 
-    try
-        # Use a custom SSH config file to avoid overwriting the default user config.
-        withfile(joinpath(homedir(), ".ssh", "config"),
-            """
-            Host $host
-                StrictHostKeyChecking no
-                HostName $host
-                IdentityFile "$keyfile"
-                BatchMode yes
+        # Fetch from remote and checkout the branch.
+        run(`git remote add upstream $upstream`)
+        try
+            run(`git fetch upstream`)
+        catch e
+            @error """
+            Git failed to fetch $upstream
+            This can be caused by a DOCUMENTER_KEY variable that is not correctly set up.
+            Make sure that the environment variable is properly set up as a Base64-encoded string
+            of the SSH private key. You may need to re-generate the keys with DocumenterTools.
             """
-        ) do
-            cd(temp) do
-                # Setup git.
-                run(`git init`)
-                run(`git config user.name "zeptodoctor"`)
-                run(`git config user.email "44736852+zeptodoctor@users.noreply.github.com"`)
-
-                # Fetch from remote and checkout the branch.
-                run(`git remote add upstream $upstream`)
-                try
-                    run(`git fetch upstream`)
-                catch e
-                    @error """
-                    Git failed to fetch $upstream
-                    This can be caused by a DOCUMENTER_KEY variable that is not correctly set up.
-                    Make sure that the environment variable is properly set up as a Base64-encoded string
-                    of the SSH private key. You may need to re-generate the keys with DocumenterTools.
-                    """
-                    rethrow(e)
-                end
+            rethrow(e)
+        end
 
-                try
-                    run(`git checkout -b $branch upstream/$branch`)
-                catch e
-                    @debug "checking out $branch failed with error: $e"
-                    @debug "creating a new local $branch branch."
-                    run(`git checkout --orphan $branch`)
-                    run(`git commit --allow-empty -m "Initial empty commit for docs"`)
-                end
+        try
+            run(`git checkout -b $branch upstream/$branch`)
+        catch e
+            @debug "checking out $branch failed with error: $e"
+            @debug "creating a new local $branch branch."
+            run(`git checkout --orphan $branch`)
+            run(`git commit --allow-empty -m "Initial empty commit for docs"`)
+        end
 
-                # Copy docs to `devurl`, or `stable`, `<release>`, and `<version>` directories.
-                if isempty(tag)
-                    devurl_dir = joinpath(dirname, devurl)
-                    gitrm_copy(target_dir, devurl_dir)
-                    Writers.HTMLWriter.generate_siteinfo_file(devurl_dir, devurl)
-                    # symlink "latest" to devurl to preserve links (remove in some future release)
-                    if devurl != "latest"
-                        rm(joinpath(dirname, "latest"); recursive = true, force = true)
-                        @warn(string("creating symlink from `latest` to `$(devurl)` for backwards ",
-                            "compatibility with old links. In future Documenter versions this symlink ",
-                            "will not be created. Please update any links that point to `latest`."))
-                        cd(dirname) do; rm_and_add_symlink(devurl, "latest"); end
-                    end
+        # Copy docs to `subfolder` directory.
+        deploy_dir = joinpath(dirname, subfolder)
+        gitrm_copy(target_dir, deploy_dir)
+        Writers.HTMLWriter.generate_siteinfo_file(deploy_dir, subfolder)
+
+        # Expand the users `versions` vector
+        entries, symlinks = Writers.HTMLWriter.expand_versions(dirname, versions)
+
+        # Create the versions.js file containing a list of `entries`.
+        # This must always happen after the folder copying.
+        Writers.HTMLWriter.generate_version_file(joinpath(dirname, "versions.js"), entries)
+
+        # generate the symlinks, make sure we don't overwrite devurl
+        cd(dirname) do
+            for kv in symlinks
+                i = findfirst(x -> x.first == devurl, symlinks)
+                if i === nothing
+                    rm_and_add_symlink(kv.second, kv.first)
                 else
-                    tagged_dir = joinpath(dirname, tag)
-                    gitrm_copy(target_dir, tagged_dir)
-                    Writers.HTMLWriter.generate_siteinfo_file(tagged_dir, tag)
+                    throw(ArgumentError(string("link `$(kv)` cannot overwrite ",
+                        "`devurl = $(devurl)` with the same name.")))
                 end
+            end
+        end
 
-                # Expand the users `versions` vector
-                entries, symlinks = Writers.HTMLWriter.expand_versions(dirname, versions)
+        # Add, commit, and push the docs to the remote.
+        run(`git add -A .`)
+        if !success(`git diff --cached --exit-code`)
+            if forcepush
+                run(`git commit --amend --date=now -m "build based on $sha"`)
+                run(`git push -fq upstream HEAD:$branch`)
+            else
+                run(`git commit -m "build based on $sha"`)
+                run(`git push -q upstream HEAD:$branch`)
+            end
+        else
+            @debug "new docs identical to the old -- not committing nor pushing."
+        end
+    end
 
-                # Create the versions.js file containing a list of `entries`.
-                # This must always happen after the folder copying.
-                Writers.HTMLWriter.generate_version_file(joinpath(dirname, "versions.js"), entries)
-
-                # generate the symlinks, make sure we don't overwrite devurl
-                cd(dirname) do
-                    for kv in symlinks
-                        i = findfirst(x -> x.first == devurl, symlinks)
-                        if i === nothing
-                            rm_and_add_symlink(kv.second, kv.first)
-                        else
-                            throw(ArgumentError(string("link `$(kv)` cannot overwrite ",
-                                "`devurl = $(devurl)` with the same name.")))
-                        end
-                    end
-                end
+    if authentication_method(deploy_config) === SSH
+        # Extract host from repo as everything up to first ':' or '/' character
+        host = match(r"(.*?)[:\/]", repo)[1]
 
-                # Add, commit, and push the docs to the remote.
-                run(`git add -A .`)
-                if !success(`git diff --cached --exit-code`)
-                    if forcepush
-                        run(`git commit --amend --date=now -m "build based on $sha"`)
-                        run(`git push -fq upstream HEAD:$branch`)
-                    else
-                        run(`git commit -m "build based on $sha"`)
-                        run(`git push -q upstream HEAD:$branch`)
-                    end
-                else
-                    @debug "new docs identical to the old -- not committing nor pushing."
+        # The upstream URL to which we push new content and the ssh decryption commands.
+        upstream = "git@$(replace(repo, "$host/" => "$host:"))"
+
+        keyfile = abspath(joinpath(root, ".documenter"))
+        try
+            write(keyfile, base64decode(documenter_key(deploy_config)))
+        catch e
+            @error """
+            Documenter failed to decode the DOCUMENTER_KEY environment variable.
+            Make sure that the environment variable is properly set up as a Base64-encoded string
+            of the SSH private key. You may need to re-generate the keys with DocumenterTools.
+            """
+            rm(keyfile; force=true)
+            rethrow(e)
+        end
+        chmod(keyfile, 0o600)
+
+        try
+            mktemp() do sshconfig, io
+                print(io,
+                """
+                Host $host
+                    StrictHostKeyChecking no
+                    User git
+                    HostName $host
+                    IdentityFile "$keyfile"
+                    IdentitiesOnly yes
+                    BatchMode yes
+                """)
+                close(io)
+                chmod(sshconfig, 0o600)
+                # git config core.sshCommand requires git 2.10.0, but
+                # GIT_SSH_COMMAND works from 2.3.0 so define both.
+                withenv("GIT_SSH_COMMAND" => "ssh -F $(sshconfig)") do
+                    cd(() -> git_commands(sshconfig), temp)
                 end
             end
+            post_status(deploy_config; repo=repo, type="success", subfolder=subfolder)
+        catch e
+            @error "Failed to push:" exception=(e, catch_backtrace())
+            post_status(deploy_config; repo=repo, type="error")
+        finally
+            # Remove the unencrypted private key.
+            isfile(keyfile) && rm(keyfile)
+        end
+    else # authentication_method(deploy_config) === HTTPS
+        # The upstream URL to which we push new content authenticated with token
+        upstream = authenticated_repo_url(deploy_config)
+        try
+            cd(git_commands, temp)
+            post_status(deploy_config; repo=repo, type="success", subfolder=subfolder)
+        catch e
+            @error "Failed to push:" exception=(e, catch_backtrace())
+            post_status(deploy_config; repo=repo, type="error")
         end
-    finally
-        # Remove the unencrypted private key.
-        isfile(keyfile) && rm(keyfile)
     end
 end
 
@@ -788,38 +636,12 @@ first, `git add -A` will not detect case
 function gitrm_copy(src, dst)
     # --ignore-unmatch so that we wouldn't get errors if dst does not exist
     run(`git rm -rf --ignore-unmatch $(dst)`)
+    # git rm also removed parent directories
+    # if they are empty so need to mkpath after
+    mkpath(dst)
     cp(src, dst; force=true)
 end
 
-function withfile(func, file::AbstractString, contents::AbstractString)
-    dir = dirname(file)
-    hasdir = isdir(dir)
-    hasdir || mkpath(dir)
-
-    hasfile = isfile(file)
-    original = hasfile ? read(file, String) : ""
-    open(file, "w") do stream
-        print(stream, contents)
-        flush(stream) # Make sure file is written before continuing.
-    end
-    try
-        func()
-    finally
-        if hasfile
-            open(file, "w") do stream
-                print(stream, original)
-            end
-        else
-            rm(file)
-        end
-
-        if !hasdir
-            # dir should be empty now as the only file inside was deleted
-            rm(dir, recursive=true)
-        end
-    end
-end
-
 function getenv(regex::Regex)
     for (key, value) in ENV
         occursin(regex, key) && return value
@@ -908,8 +730,7 @@ function doctest(
             )
             true
         catch err
-            @error "Doctesting failed"
-            showerror(stdout, err, catch_backtrace())
+            @error "Doctesting failed" exception=(err, catch_backtrace())
             false
         finally
             rm(dir; recursive=true)
diff -pruN 1.3.1+dfsg-1/debian/embedded/Documenter/src/Documents.jl 1.4.0+dfsg-1/debian/embedded/Documenter/src/Documents.jl
--- 1.3.1+dfsg-1/debian/embedded/Documenter/src/Documents.jl	2019-11-28 04:21:06.000000000 +0000
+++ 1.4.0+dfsg-1/debian/embedded/Documenter/src/Documents.jl	2020-03-30 16:16:04.000000000 +0000
@@ -58,9 +58,12 @@ function Page(source::AbstractString, bu
     mdpage = Markdown.parse(read(source, String))
     md2ast = try
         Markdown2.convert(Markdown2.MD, mdpage)
-    catch e
-        @error "Markdown2.convert failed to convert $(source)"
-        rethrow(e)
+    catch err
+        @error """
+            Markdown2 conversion error on $(source).
+            This is a bug — please report this on the Documenter issue tracker
+            """
+        rethrow(err)
     end
     Page(source, build, workdir, mdpage.content, IdDict{Any,Any}(), Globals(), md2ast)
 end
diff -pruN 1.3.1+dfsg-1/debian/embedded/Documenter/src/Expanders.jl 1.4.0+dfsg-1/debian/embedded/Documenter/src/Expanders.jl
--- 1.3.1+dfsg-1/debian/embedded/Documenter/src/Expanders.jl	2019-11-28 04:21:06.000000000 +0000
+++ 1.4.0+dfsg-1/debian/embedded/Documenter/src/Expanders.jl	2020-03-30 16:16:04.000000000 +0000
@@ -641,7 +641,7 @@ function Selectors.runner(::Type{SetupBl
     # The sandboxed module -- either a new one or a cached one from this page.
     name = matched[1]
     sym  = isempty(name) ? gensym("ex-") : Symbol("ex-", name)
-    mod  = get!(page.globals.meta, sym, Module(sym))::Module
+    mod  = get!(() -> get_new_sandbox(sym), page.globals.meta, sym)
 
     # Evaluate whole @setup block at once instead of piecewise
     page.mapping[x] =
diff -pruN 1.3.1+dfsg-1/debian/embedded/Documenter/src/Utilities/JSDependencies.jl 1.4.0+dfsg-1/debian/embedded/Documenter/src/Utilities/JSDependencies.jl
--- 1.3.1+dfsg-1/debian/embedded/Documenter/src/Utilities/JSDependencies.jl	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/debian/embedded/Documenter/src/Utilities/JSDependencies.jl	2020-03-30 16:16:04.000000000 +0000
@@ -0,0 +1,339 @@
+"""
+Provides an API to programmatically construct a [RequireJS](https://requirejs.org/) script.
+"""
+module JSDependencies
+using JSON
+
+"""
+    struct RemoteLibrary
+
+Declares a remote JS dependency that should be declared in the RequireJS configuration shim.
+
+# Fields
+
+* `name`: a unique name for the dependency, used to refer to it in other dependencies and
+  snippets
+* `url`: full remote URL from where the dependency can be loaded from
+* `deps`: a list of the library's dependencies (becomes the `deps` configuration in the
+  RequireJS shim)
+* `exports`: sets the `exports` config in the resulting RequireJS shim
+
+# Constructors
+
+```julia
+RemoteLibrary(name::AbstractString, url::AbstractString; deps=String[], exports=nothing)
+```
+"""
+struct RemoteLibrary
+    name :: String
+    url :: String
+    # The following become part of the shim
+    deps :: Vector{String}
+    exports :: Union{Nothing, String}
+
+    function RemoteLibrary(name::AbstractString, url::AbstractString; deps=String[], exports=nothing)
+        new(name, url, deps, exports)
+    end
+end
+
+"""
+    struct Snippet
+
+Declares a JS code snipped that should be loaded with RequireJS. This gets wrapped in
+`require([deps...], function(args...) {script...})` in the output.
+
+# Fields
+
+* `deps`: names of the [`RemoteLibrary`](@ref) dependencies of the snippet
+* `args`: the arguments of the callback function, corresponding to the library objects
+  of the dependencies, in the order of `deps`
+* `js`: the JS code of the function that gets used as the function body of the callback
+
+# Constructors
+
+```julia
+Snippet(deps::AbstractVector, args::AbstractVector, js::AbstractString)
+```
+"""
+struct Snippet
+    deps :: Vector{String}
+    args :: Vector{String}
+    js :: String
+
+    function Snippet(deps::AbstractVector, args::AbstractVector, js::AbstractString)
+        new(deps, args, js)
+    end
+end
+
+"""
+    struct RequireJS
+
+Declares a single RequireJS configuration/app file.
+
+# Fields
+
+* `libraries`: a dictionary of [`RemoteLibrary`](@ref) declarations (keys are the library
+  names)
+* `snippets`: a list of JS snippets ([`Snippet`](@ref))
+
+# Constructors
+
+```julia
+RequireJS(libraries::AbstractVector{RemoteLibrary}, snippets::AbstractVector{Snippet} = Snippet[])
+```
+
+# API
+
+* The `push!` function can be used to add additional libraries and snippets.
+*
+"""
+struct RequireJS
+    libraries :: Dict{String, RemoteLibrary}
+    snippets :: Vector{Snippet}
+
+    function RequireJS(libraries::AbstractVector, snippets::AbstractVector = Snippet[])
+        all(x -> isa(x, RemoteLibrary), libraries) || throw(ArgumentError("Bad element types for `libraries`: $(typeof.(libraries))"))
+        all(x -> isa(x, Snippet), snippets) || throw(ArgumentError("Bad element types for `snippets`: $(typeof.(snippets))"))
+        r = new(Dict(), [])
+        for library in libraries
+            push!(r, library)
+        end
+        for snippet in snippets
+            push!(r, snippet)
+        end
+        return r
+    end
+end
+
+function Base.push!(r::RequireJS, lib::RemoteLibrary)
+    if lib.name in keys(r.libraries)
+        error("Library already added.")
+    end
+    r.libraries[lib.name] = lib
+end
+
+Base.push!(r::RequireJS, s::Snippet) = push!(r.snippets, s)
+
+"""
+    verify(r::RequireJS; verbose=false) -> Bool
+
+Checks that none of the dependencies are missing (returns `false` if some are). If `verbose`
+is set to `true`, it will also log an error with the missing dependency.
+"""
+function verify(r::RequireJS; verbose=false)
+    isvalid = true
+    for (name, lib) in r.libraries
+        for dep in lib.deps
+            if !(dep in keys(r.libraries))
+                verbose && @error("$(dep) of $(name) missing from libraries")
+                isvalid = false
+            end
+        end
+    end
+    for s in r.snippets
+        for dep in s.deps
+            if !(dep in keys(r.libraries))
+                verbose && @error("$(dep) missing from libraries")
+                isvalid = false
+            end
+        end
+    end
+    return isvalid
+end
+
+"""
+    writejs(io::IO, r::RequireJS)
+    writejs(filename::AbstractString, r::RequireJS)
+
+Writes out the [`RequireJS`](@ref) object as a valid JS that can be loaded with a `<script>`
+tag, either into a stream or a file. It will contain all the configuration and snippets.
+"""
+function writejs end
+
+function writejs(filename::AbstractString, r::RequireJS)
+    open(filename, "w") do io
+        writejs(io, r)
+    end
+end
+
+function writejs(io::IO, r::RequireJS)
+    write(io, """
+    // Generated by Documenter.jl
+    requirejs.config({
+      paths: {
+    """)
+    for (name, lib) in r.libraries
+        url = endswith(lib.url, ".js") ? replace(lib.url, r"\.js$" => "") : lib.url
+        write(io, """
+            '$(jsescape(lib.name))': '$(jsescape(url))',
+        """)
+    end
+    write(io, "  }")
+
+    shim = shimdict(r)
+    isempty(shim) ? write(io, '\n') : write(io, ",\n  shim: ", json_jsescape(shim, 2))
+    write(io, "});\n")
+
+    for s in r.snippets
+        args = join(s.args, ", ") # Note: not string literals => no escaping
+        deps = join(("\'$(jsescape(d))\'" for d in s.deps), ", ")
+        write(io, """
+        $("/"^80)
+        require([$(deps)], function($(args)) {
+        $(s.js)
+        })
+        """)
+    end
+end
+
+function shimdict(r::RequireJS)
+    shim = Dict{String,Any}()
+    for (name, lib) in r.libraries
+        @assert name == lib.name
+        libshim = shimdict(lib)
+        if libshim !== nothing
+            shim[name] = libshim
+        end
+    end
+    return shim
+end
+
+function shimdict(lib::RemoteLibrary)
+    isempty(lib.deps) && (lib.exports === nothing) && return nothing
+    shim = Dict{Symbol,Any}()
+    if !isempty(lib.deps)
+        shim[:deps] = lib.deps
+    end
+    if lib.exports !== nothing
+        shim[:exports] = lib.exports
+    end
+    return shim
+end
+
+"""
+    parse_snippet(filename::AbstractString) -> Snippet
+    parse_snippet(io::IO) -> Snippet
+
+Parses a JS snippet file into a [`Snippet`](@ref) object.
+
+# Format
+
+The first few lines are parsed to get the dependencies and argument variable names of the
+snippet. They need to match `^//\\s*([a-z]+):` (i.e. start with `//`, optional whitespace, a
+lowercase identifier, and a colon). Once the parser hits a line that does not match that
+pattern, it will assume that it and all the following lines are the actual script.
+
+Only lowercase letters are allowed in the identifiers. Currently only `libraries` and
+`arguments` are actually parsed and lines with other syntactically valid identifiers are
+ignored. For `libraries` and `arguments`, the value (after the colon) must be a comma
+separated list.
+
+A valid snippet file would look like the following. Note that the list of arguments can be
+shorter than the list of dependencies.
+
+```js
+// libraries: jquery, highlight, highlight-julia, highlight-julia-repl
+// arguments: \$, hljs
+
+// Initialize the highlight.js highlighter
+\$(document).ready(function() {
+  hljs.initHighlighting();
+})
+```
+"""
+function parse_snippet end
+
+parse_snippet(filename::AbstractString; kwargs...) = open(filename, "r") do io
+    parse_snippet(io; kwargs...)
+end
+
+function parse_snippet(io::IO)
+    libraries = String[]
+    arguments = String[]
+    lineno = 1
+    while true
+        pos = position(io)
+        line = readline(io)
+        m = match(r"^//\s*([a-z]+):(.*)$", line)
+        if m === nothing
+            seek(io, pos) # undo the last readline() call
+            break
+        end
+        if m[1] == "libraries"
+            libraries = strip.(split(m[2], ","))
+            if any(s -> match(r"^[a-z-_]+$", s) === nothing, libraries)
+                error("Unable to parse a library declaration '$(line)' on line $(lineno)")
+            end
+        elseif m[1] == "arguments"
+            arguments = strip.(split(m[2], ","))
+        end
+        lineno += 1
+    end
+    snippet = String(read(io))
+    Snippet(libraries, arguments, snippet)
+end
+
+"""
+Replaces some of the characters in the string with escape sequences so that the strings
+would be valid JS string literals, as per the
+[ECMAScript® 2017 standard](https://www.ecma-international.org/ecma-262/8.0/index.html#sec-literals-string-literals).
+Note that it always escapes both potential `"` and `'` closing quotes.
+"""
+function jsescape(s)
+    b = IOBuffer()
+    # From the ECMAScript® 2017 standard:
+    #
+    # > All code points may appear literally in a string literal except for the closing
+    # > quote code points, U+005C (REVERSE SOLIDUS), U+000D (CARRIAGE RETURN), U+2028 (LINE
+    # > SEPARATOR), U+2029 (PARAGRAPH SEPARATOR), and U+000A (LINE FEED).
+    #
+    # https://www.ecma-international.org/ecma-262/8.0/index.html#sec-literals-string-literals
+    #
+    # Note: in ECMAScript® 2019 (10th edition), U+2028 and U+2029 do not actually need to be
+    # escaped anymore:
+    #
+    # > Updated syntax includes /--/ allowing U+2028 (LINE SEPARATOR) and U+2029 (PARAGRAPH
+    # > SEPARATOR) in string literals to align with JSON.
+    #
+    # https://www.ecma-international.org/ecma-262/10.0/index.html#sec-intro
+    #
+    # But we'll  keep these escapes around for now, as not all JS parsers may be compatible
+    # with the latest standard yet.
+    for c in s
+        if c === '\u000a'     # LINE FEED,       i.e. \n
+            write(b, "\\n")
+        elseif c === '\u000d' # CARRIAGE RETURN, i.e. \r
+            write(b, "\\r")
+        elseif c === '\u005c' # REVERSE SOLIDUS, i.e. \
+            write(b, "\\\\")
+        elseif c === '\u0022' # QUOTATION MARK,  i.e. "
+            write(b, "\\\"")
+        elseif c === '\u0027' # APOSTROPHE,      i.e. '
+            write(b, "\\'")
+        elseif c === '\u2028' # LINE SEPARATOR
+            write(b, "\\u2028")
+        elseif c === '\u2029' # PARAGRAPH SEPARATOR
+            write(b, "\\u2029")
+        else
+            write(b, c)
+        end
+    end
+    String(take!(b))
+end
+
+"""
+    json_jsescape(args...)
+
+Call `JSON.json(args...)` to generate a `String` of JSON, but then also escape two Unicode
+characters to get valid JS (since [JSON is not a JS subset](http://timelessrepo.com/json-isnt-a-javascript-subset)).
+
+!!! note
+    Technically, starting with ECMAScript® 2019 (10th edition), this is no longer necessary.
+    The JS standard was changed in a way that all valid JSON is also valid JS.
+"""
+function json_jsescape(args...)
+    escapes = ('\u2028' => "\\u2028", '\u2029' => "\\u2029")
+    reduce(replace, escapes, init=JSON.json(args...))
+end
+
+end
diff -pruN 1.3.1+dfsg-1/debian/embedded/Documenter/src/Utilities/Markdown2.jl 1.4.0+dfsg-1/debian/embedded/Documenter/src/Utilities/Markdown2.jl
--- 1.3.1+dfsg-1/debian/embedded/Documenter/src/Utilities/Markdown2.jl	2019-11-28 04:21:06.000000000 +0000
+++ 1.4.0+dfsg-1/debian/embedded/Documenter/src/Utilities/Markdown2.jl	2020-03-30 16:16:04.000000000 +0000
@@ -217,7 +217,12 @@ end
 
 _convert_block(xs::Vector) = MarkdownBlockNode[_convert_block(x) for x in xs]
 _convert_block(b::Markdown.HorizontalRule) = ThematicBreak()
-_convert_block(b::Markdown.Header{N}) where N = Heading(N, _convert_inline(b.text))
+function _convert_block(b::Markdown.Header{N}) where N
+    text = _convert_inline(b.text)
+    # Empty headings have just an empty String as text
+    nodes = isa(text, AbstractVector) ? text : MarkdownInlineNode[text]
+    Heading(N, nodes)
+end
 _convert_block(b::Markdown.Code) = CodeBlock(b.language, b.code)
 _convert_block(b::Markdown.Paragraph) = Paragraph(_convert_inline(b.content))
 _convert_block(b::Markdown.BlockQuote) = BlockQuote(_convert_block(b.content))
@@ -240,6 +245,11 @@ function _convert_block(b::Markdown.Tabl
 end
 _convert_block(b::Markdown.Admonition) = Admonition(b.category, b.title, _convert_block(b.content))
 
+# Fallback
+function _convert_block(x)
+    @debug "Strange inline Markdown node (typeof(x) = $(typeof(x))), falling back to repr()" x
+    Paragraph([Text(repr(x))])
+end
 
 _convert_inline(xs::Vector) = MarkdownInlineNode[_convert_inline(x) for x in xs]
 _convert_inline(s::String) = Text(s)
@@ -266,6 +276,12 @@ function _convert_inline(s::Markdown.Foo
     FootnoteReference(s.id)
 end
 
+# Fallback
+function _convert_inline(x)
+    @debug "Strange inline Markdown node (typeof(x) = $(typeof(x))), falling back to repr()" x
+    Text(repr(x))
+end
+
 
 # walk() function
 # ===============
diff -pruN 1.3.1+dfsg-1/debian/embedded/Documenter/src/Utilities/Utilities.jl 1.4.0+dfsg-1/debian/embedded/Documenter/src/Utilities/Utilities.jl
--- 1.3.1+dfsg-1/debian/embedded/Documenter/src/Utilities/Utilities.jl	2019-11-28 04:21:06.000000000 +0000
+++ 1.4.0+dfsg-1/debian/embedded/Documenter/src/Utilities/Utilities.jl	2020-03-30 16:16:04.000000000 +0000
@@ -363,7 +363,12 @@ function repo_commit(file)
 end
 
 function url(repo, file; commit=nothing)
-    file = realpath(abspath(file))
+    file = abspath(file)
+    if !isfile(file)
+        @warn "couldn't find file \"$file\" when generating URL"
+        return nothing
+    end
+    file = realpath(file)
     remote = getremote(dirname(file))
     isempty(repo) && (repo = "https://github.com/$remote/blob/{commit}{path}")
     path = relpath_from_repo_root(file)
@@ -658,10 +663,33 @@ function display_dict(x)
     return out
 end
 
+"""
+    struct Default{T}
+
+Internal wrapper type that is meant to be used in situations where it is necessary to
+distinguish whether the user explicitly passed the same value as the default value to a
+keyword argument, or whether the keyword argument was not passed at all.
+
+```julia
+function foo(; kwarg = Default("default value"))
+    if isa(kwarg, Default)
+        # User did not explicitly pass a value for kwarg
+    else kwarg === "default value"
+        # User passed "default value" explicitly
+    end
+end
+```
+"""
+struct Default{T}
+    value :: T
+end
+Base.getindex(default::Default) = default.value
+
 include("DOM.jl")
 include("MDFlatten.jl")
 include("TextDiff.jl")
 include("Selectors.jl")
 include("Markdown2.jl")
+include("JSDependencies.jl")
 
 end
diff -pruN 1.3.1+dfsg-1/debian/embedded/Documenter/src/Writers/HTMLWriter.jl 1.4.0+dfsg-1/debian/embedded/Documenter/src/Writers/HTMLWriter.jl
--- 1.3.1+dfsg-1/debian/embedded/Documenter/src/Writers/HTMLWriter.jl	2019-11-28 04:21:06.000000000 +0000
+++ 1.4.0+dfsg-1/debian/embedded/Documenter/src/Writers/HTMLWriter.jl	2020-03-30 16:16:04.000000000 +0000
@@ -7,7 +7,7 @@ A module for rendering `Document` object
 [`Documenter.makedocs`](@ref): `authors`, `pages`, `sitename`, `version`.
 The behavior of [`HTMLWriter`](@ref) can be further customized by setting the `format`
 keyword of [`Documenter.makedocs`](@ref) to a [`HTML`](@ref), which accepts the following
-keyword arguments: `analytics`, `assets`, `canonical`, `disable_git`, `edit_branch` and
+keyword arguments: `analytics`, `assets`, `canonical`, `disable_git`, `edit_link` and
 `prettyurls`.
 
 **`sitename`** is the site's title displayed in the title bar and at the top of the
@@ -40,6 +40,7 @@ then it is intended as the page title. T
 """
 module HTMLWriter
 
+using Dates: Dates, @dateformat_str, now
 import Markdown
 import JSON
 
@@ -52,11 +53,169 @@ import ...Documenter:
     Utilities,
     Writers
 
+using ...Utilities: Default
+using ...Utilities.JSDependencies: JSDependencies, json_jsescape
 import ...Utilities.DOM: DOM, Tag, @tags
 using ...Utilities.MDFlatten
 
 export HTML
 
+"List of Documenter native themes."
+const THEMES = ["documenter-light", "documenter-dark"]
+"The root directory of the HTML assets."
+const ASSETS = normpath(joinpath(@__DIR__, "..", "..", "assets", "html"))
+"The directory where all the Sass/SCSS files needed for theme building are."
+const ASSETS_SASS = joinpath(ASSETS, "scss")
+"Directory for the compiled CSS files of the themes."
+const ASSETS_THEMES = joinpath(ASSETS, "themes")
+
+struct HTMLAsset
+    class :: Symbol
+    uri :: String
+    islocal :: Bool
+
+    function HTMLAsset(class::Symbol, uri::String, islocal::Bool)
+        if !islocal && match(r"^https?://", uri) === nothing
+            error("Remote asset URL must start with http:// or https://")
+        end
+        class in [:ico, :css, :js] || error("Unrecognised asset class $class for `$(uri)`")
+        new(class, uri, islocal)
+    end
+end
+
+"""
+    asset(uri)
+
+Can be used to pass non-local web assets to [`HTML`](@ref), where `uri` should be an absolute
+HTTP or HTTPS URL.
+
+It accepts the following keyword arguments:
+
+**`class`** can be used to override the asset class, which determines how exactly the asset
+gets included in the HTML page. This is necessary if the class can not be determined
+automatically (default).
+
+Should be one of: `:js`, `:css` or `:ico`. They become a `<script>`,
+`<link rel="stylesheet" type="text/css">` and `<link rel="icon" type="image/x-icon">`
+elements in `<head>`, respectively.
+
+**`islocal`** can be used to declare the asset to be local. The `uri` should then be a path
+relative to the documentation source directory (conventionally `src/`). This can be useful
+when it is necessary to override the asset class of a local asset.
+
+# Usage
+
+```julia
+Documenter.HTML(assets = [
+    # Standard local asset
+    "assets/extra_styles.css",
+    # Standard remote asset (extension used to determine that class = :js)
+    asset("https://example.com/jslibrary.js"),
+    # Setting asset class manually, since it can't be determined manually
+    asset("https://example.com/fonts", class = :css),
+    # Same as above, but for a local asset
+    asset("asset/foo.script", class=:js, islocal=true),
+])
+```
+"""
+function asset(uri; class = nothing, islocal=false)
+    if class === nothing
+        class = assetclass(uri)
+        (class === nothing) && error("""
+        Unable to determine asset class for: $(uri)
+        It can be set explicitly with the `class` keyword argument.
+        """)
+    end
+    HTMLAsset(class, uri, islocal)
+end
+
+function assetclass(uri)
+    # TODO: support actual proper URIs
+    ext = splitext(uri)[end]
+    ext == ".ico" ? :ico :
+    ext == ".css" ? :css :
+    ext == ".js"  ? :js  : :unknown
+end
+
+abstract type MathEngine end
+
+"""
+    KaTeX(config::Dict = <default>, override = false)
+
+An instance of the `KaTeX` type can be passed to [`HTML`](@ref) via the `mathengine` keyword
+to specify that the [KaTeX rendering engine](https://katex.org/) should be used in the HTML
+output to render mathematical expressions.
+
+A dictionary can be passed via the `config` argument to configure KaTeX. It becomes the
+[options argument of `renderMathInElement`](https://katex.org/docs/autorender.html#api). By
+default, Documenter only sets a custom `delimiters` option.
+
+By default, the user-provided dictionary gets _merged_ with the default dictionary (i.e. the
+resulting configuration dictionary will contain the values from both dictionaries, but e.g.
+setting your own `delimiters` value will override the default). This can be overridden by
+setting `override` to `true`, in which case the default values are ignored and only the
+user-provided dictionary is used.
+"""
+struct KaTeX <: MathEngine
+    config :: Dict{Symbol,Any}
+    function KaTeX(config::Union{Dict,Nothing} = nothing, override=false)
+        default = Dict(
+            :delimiters => [
+                Dict(:left => raw"$",   :right => raw"$",   display => false),
+                Dict(:left => raw"$$",  :right => raw"$$",  display => true),
+                Dict(:left => raw"\[", :right => raw"\]", display => true),
+            ]
+        )
+        new((config === nothing) ? default : override ? config : merge(default, config))
+    end
+end
+
+"""
+    MathJax(config::Dict = <default>, override = false)
+
+An instance of the `MathJax` type can be passed to [`HTML`](@ref) via the `mathengine`
+keyword to specify that the [MathJax rendering engine](https://www.mathjax.org/) should be
+used in the HTML output to render mathematical expressions.
+
+A dictionary can be passed via the `config` argument to configure MathJax. It gets passed to
+the [`MathJax.Hub.Config`](https://docs.mathjax.org/en/latest/options/) function. By
+default, Documenter set custom configuration for `tex2jax`, `config`, `jax`, `extensions`
+and `Tex`.
+
+By default, the user-provided dictionary gets _merged_ with the default dictionary (i.e. the
+resulting configuration dictionary will contain the values from both dictionaries, but e.g.
+setting your own `tex2jax` value will override the default). This can be overridden by
+setting `override` to `true`, in which case the default values are ignored and only the
+user-provided dictionary is used.
+"""
+struct MathJax <: MathEngine
+    config :: Dict{Symbol,Any}
+    function MathJax(config::Union{Dict,Nothing} = nothing, override=false)
+        default = Dict(
+           :tex2jax => Dict(
+               "inlineMath" => [["\$","\$"], ["\\(","\\)"]],
+               "processEscapes" => true
+           ),
+           :config => ["MMLorHTML.js"],
+           :jax => [
+               "input/TeX",
+               "output/HTML-CSS",
+               "output/NativeMML"
+           ],
+           :extensions => [
+               "MathMenu.js",
+               "MathZoom.js",
+               "TeX/AMSmath.js",
+               "TeX/AMSsymbols.js",
+               "TeX/autobold.js",
+               "TeX/autoload-all.js"
+           ],
+           :TeX => Dict(:equationNumbers => Dict(:autoNumber => "AMS"))
+        )
+        new((config === nothing) ? default : override ? config : merge(default, config))
+    end
+end
+
 """
     HTML(kwargs...)
 
@@ -87,8 +246,11 @@ an error and exit if any of the Git comm
 gather information about the current commit hash and file paths, necessary for constructing
 the links to the remote repository.
 
-**`edit_branch`** specifies which branch, tag or commit the "Edit on GitHub" links
-point to. It defaults to `master`. If it set to `nothing`, the current commit will be used.
+**`edit_link`** can be used to specify which branch, tag or commit (when passed a `String`)
+in the remote repository the "Edit on ..." links point to. If a special `Symbol` value
+`:commit` is passed, the current commit will be used instead. If set to `nothing`, the
+link edit link will be hidden altogether. Default value is `"master"`, making the edit link
+point to the master branch.
 
 **`canonical`** specifies the canonical URL for your documentation. We recommend
 you set this to the base url of your stable documentation, e.g. `https://juliadocs.github.io/Documenter.jl/stable`.
@@ -101,6 +263,26 @@ Default is `nothing`, in which case no c
 **`assets`** can be used to include additional assets (JS, CSS, ICO etc. files). See below
 for more information.
 
+**`sidebar_sitename`** determines whether the site name is shown in the sidebar or not.
+Setting it to `false` can be useful when the logo already contains the name of the package.
+Defaults to `true`.
+
+**`highlights`** can be used to add highlighting for additional languages. By default,
+Documenter already highlights all the ["Common" highlight.js](https://highlightjs.org/download/)
+languages and Julia (`julia`, `julia-repl`). Additional languages must be specified by"
+their filenames as they appear on [CDNJS](https://cdnjs.com/libraries/highlight.js) for the
+highlight.js version Documenter is using. E.g. to include highlighting for YAML and LLVM IR,
+you would set `highlights = ["llvm", "yaml"]`. Note that no verification is done whether the
+provided language names are sane.
+
+**`mathengine`** specifies which LaTeX rendering engine will be used to render the math
+blocks. The options are either [KaTeX](https://katex.org/) (default) or
+[MathJax](https://www.mathjax.org/), enabled by passing an instance of [`KaTeX`](@ref) or
+[`MathJax`](@ref) objects, respectively. The rendering engine can further be customized by
+passing options to the [`KaTeX`](@ref) or [`MathJax`](@ref) constructors.
+
+**`lang`** can be used to specify the language tag of each HTML page. Default is `"en"`.
+
 # Default and custom assets
 
 Documenter copies all files under the source directory (e.g. `/docs/src/`) over
@@ -117,39 +299,173 @@ the subdirectories of `assets/` are not
 
 For the **logo**, Documenter checks for the existence of `assets/logo.{svg,png,webp,gif,jpg,jpeg}`,
 in this order. The first one it finds gets displayed at the top of the navigation sidebar.
+It will also check for `assets/logo-dark.{svg,png,webp,gif,jpg,jpeg}` and use that for dark
+themes.
+
+Additional JS, ICO, and CSS assets can be included in the generated pages by passing them as
+a list with the `assets` keyword. Each asset will be included in the `<head>` of every page
+in the order in which they are given. The type of the asset (i.e. whether it is going to be
+included with a `<script>` or a `<link>` tag) is determined by the file's extension --
+either `.js`, `.ico`[^1], or `.css` (unless overridden with [`asset`](@ref)).
+
+Simple strings are assumed to be local assets and that each correspond to a file relative to
+the documentation source directory (conventionally `src/`). Non-local assets, identified by
+their absolute URLs, can be included with the [`asset`](@ref) function.
 
-Additional JS, ICO, and CSS assets can be included in the generated pages using the
-`assets` keyword for `makedocs`. `assets` must be a `Vector{String}` and will include
-each listed asset in the `<head>` of every page in the order in which they are listed.
-The type of the asset (i.e. whether it is going to be included with a `<script>` or a
-`<link>` tag) is determined by the file's extension -- either `.js`, `.ico`, or `.css`.
-Adding an ICO asset is primarilly useful for setting a custom `favicon`.
+[^1]: Adding an ICO asset is primarily useful for setting a custom `favicon`.
 """
 struct HTML <: Documenter.Writer
-    prettyurls  :: Bool
-    disable_git :: Bool
-    edit_branch :: Union{String, Nothing}
-    canonical   :: Union{String, Nothing}
-    assets      :: Vector{String}
-    analytics   :: String
+    prettyurls    :: Bool
+    disable_git   :: Bool
+    edit_link     :: Union{String, Symbol, Nothing}
+    canonical     :: Union{String, Nothing}
+    assets        :: Vector{HTMLAsset}
+    analytics     :: String
+    collapselevel :: Int
+    sidebar_sitename :: Bool
+    highlights    :: Vector{String}
+    mathengine    :: Union{MathEngine,Nothing}
+    lang          :: String
 
     function HTML(;
-        prettyurls::Bool = true,
-        disable_git::Bool = false,
-        edit_branch::Union{String, Nothing} = "master",
-        canonical::Union{String, Nothing} = nothing,
-        assets::Vector{String} = String[],
-        analytics::String = "")
-        new(prettyurls, disable_git, edit_branch, canonical, assets, analytics)
+            prettyurls    :: Bool = true,
+            disable_git   :: Bool = false,
+            edit_link     :: Union{String, Symbol, Nothing, Default} = Default("master"),
+            canonical     :: Union{String, Nothing} = nothing,
+            assets        :: Vector = String[],
+            analytics     :: String = "",
+            collapselevel :: Integer = 2,
+            sidebar_sitename :: Bool = true,
+            highlights :: Vector{String} = String[],
+            mathengine :: Union{MathEngine,Nothing} = KaTeX(),
+            # deprecated keywords
+            edit_branch   :: Union{String, Nothing, Default} = Default(nothing),
+            lang          :: String = "en",
+        )
+        collapselevel >= 1 || throw(ArgumentError("collapselevel must be >= 1"))
+        assets = map(assets) do asset
+            isa(asset, HTMLAsset) && return asset
+            isa(asset, AbstractString) && return HTMLAsset(assetclass(asset), asset, true)
+            error("Invalid value in assets: $(asset) [$(typeof(asset))]")
+        end
+        # Handle edit_branch deprecation
+        if !isa(edit_branch, Default)
+            isa(edit_link, Default) || error("Can't specify edit_branch (deprecated) and edit_link simultaneously")
+            @warn """
+            The edit_branch keyword is deprecated -- use edit_link instead.
+            Note: `edit_branch = nothing` must be changed to `edit_link = :commit`.
+            """
+            edit_link = (edit_branch === nothing) ? :commit : edit_branch
+        end
+        if isa(edit_link, Symbol) && (edit_link !== :commit)
+            throw(ArgumentError("Invalid symbol (:$edit_link) passed to edit_link."))
+        end
+        isa(edit_link, Default) && (edit_link = edit_link[])
+        new(prettyurls, disable_git, edit_link, canonical, assets, analytics,
+            collapselevel, sidebar_sitename, highlights, mathengine, lang)
     end
 end
 
-const requirejs_cdn = "file:///usr/share/javascript/requirejs/require.min.js"
-const normalize_css = "file:///usr/share/javascript/normalize.css/normalize.min.css"
-const google_fonts = "file:///usr/share/doc/julia-doc/fontface.css"
-const fontawesome_css = "file:///usr/share/fonts-font-awesome/css/font-awesome.min.css"
-const highlightjs_css = "file:///usr/share/javascript/highlight.js/styles/default.css"
+"Provides a namespace for remote dependencies."
+module RD
+    using JSON
+    using ....Utilities.JSDependencies: RemoteLibrary, Snippet, RequireJS, jsescape, json_jsescape
+    using ..HTMLWriter: KaTeX, MathJax
+
+    const requirejs_cdn = "https://cdnjs.cloudflare.com/ajax/libs/require.js/2.3.6/require.min.js"
+    const google_fonts = "https://fonts.googleapis.com/css?family=Lato|Roboto+Mono"
+    const fontawesome_version = "5.11.2"
+    const fontawesome_css = [
+        "https://cdnjs.cloudflare.com/ajax/libs/font-awesome/$(fontawesome_version)/css/fontawesome.min.css",
+        "https://cdnjs.cloudflare.com/ajax/libs/font-awesome/$(fontawesome_version)/css/solid.min.css",
+        "https://cdnjs.cloudflare.com/ajax/libs/font-awesome/$(fontawesome_version)/css/brands.min.css",
+    ]
 
+    const jquery = RemoteLibrary("jquery", "https://cdnjs.cloudflare.com/ajax/libs/jquery/3.4.1/jquery.min.js")
+    const jqueryui = RemoteLibrary("jqueryui", "https://cdnjs.cloudflare.com/ajax/libs/jqueryui/1.12.1/jquery-ui.min.js")
+    const lunr = RemoteLibrary("lunr", "https://cdnjs.cloudflare.com/ajax/libs/lunr.js/2.3.6/lunr.min.js")
+    const lodash = RemoteLibrary("lodash", "https://cdnjs.cloudflare.com/ajax/libs/lodash.js/4.17.15/lodash.min.js")
+
+    # headroom
+    const headroom_version = "0.10.3"
+    const headroom = RemoteLibrary("headroom", "https://cdnjs.cloudflare.com/ajax/libs/headroom/$(headroom_version)/headroom.min.js")
+    const headroom_jquery = RemoteLibrary(
+        "headroom-jquery",
+        "https://cdnjs.cloudflare.com/ajax/libs/headroom/$(headroom_version)/jQuery.headroom.min.js",
+        deps = ["jquery", "headroom"],
+    )
+
+    # highlight.js
+    "Add the highlight.js dependencies and snippet to a [`RequireJS`](@ref) declaration."
+    function highlightjs!(r::RequireJS, languages = String[])
+        # NOTE: the CSS themes for hightlightjs are compiled into the Documenter CSS
+        # When updating this dependency, it is also necessary to update the the CSS
+        # files the CSS files in assets/html/scss/highlightjs
+        hljs_version = "9.15.10"
+        push!(r, RemoteLibrary(
+            "highlight",
+            "https://cdnjs.cloudflare.com/ajax/libs/highlight.js/$(hljs_version)/highlight.min.js"
+        ))
+        prepend!(languages, ["julia", "julia-repl"])
+        for language in languages
+            language = jsescape(language)
+            push!(r, RemoteLibrary(
+                "highlight-$(language)",
+                "https://cdnjs.cloudflare.com/ajax/libs/highlight.js/$(hljs_version)/languages/$(language).min.js",
+                deps = ["highlight"]
+            ))
+        end
+        push!(r, Snippet(
+            vcat(["jquery", "highlight"], ["highlight-$(jsescape(language))" for language in languages]),
+            ["\$", "hljs"],
+            raw"""
+            $(document).ready(function() {
+                hljs.initHighlighting();
+            })
+            """
+        ))
+    end
+
+    # MathJax & KaTeX
+    const katex_version = "0.11.1"
+    const katex_css = "https://cdnjs.cloudflare.com/ajax/libs/KaTeX/$(katex_version)/katex.min.css"
+    function mathengine!(r::RequireJS, engine::KaTeX)
+        push!(r, RemoteLibrary(
+            "katex",
+            "https://cdnjs.cloudflare.com/ajax/libs/KaTeX/$(katex_version)/katex.min.js"
+        ))
+        push!(r, RemoteLibrary(
+            "katex-auto-render",
+            "https://cdnjs.cloudflare.com/ajax/libs/KaTeX/$(katex_version)/contrib/auto-render.min.js",
+            deps = ["katex"],
+        ))
+        push!(r, Snippet(
+            ["jquery", "katex", "katex-auto-render"],
+            ["\$", "katex", "renderMathInElement"],
+            """
+            \$(document).ready(function() {
+              renderMathInElement(
+                document.body,
+                $(json_jsescape(engine.config, 2))
+              );
+            })
+            """
+        ))
+    end
+    function mathengine!(r::RequireJS, engine::MathJax)
+        push!(r, RemoteLibrary(
+            "mathjax",
+            "https://cdnjs.cloudflare.com/ajax/libs/mathjax/2.7.6/MathJax.js?config=TeX-AMS_HTML",
+            exports = "MathJax"
+        ))
+        push!(r, Snippet(["mathjax"], ["MathJax"],
+            """
+            MathJax.Hub.Config($(json_jsescape(engine.config, 2)));
+            """
+        ))
+    end
+    mathengine(::RequireJS, ::Nothing) = nothing
+end
 
 struct SearchRecord
     src :: String
@@ -168,17 +484,17 @@ other recursive functions.
 mutable struct HTMLContext
     doc :: Documents.Document
     settings :: HTML
-    logo :: String
     scripts :: Vector{String}
     documenter_js :: String
+    themeswap_js :: String
     search_js :: String
     search_index :: Vector{SearchRecord}
     search_index_js :: String
     search_navnode :: Documents.NavNode
-    local_assets :: Vector{String}
+    footnotes :: Vector{Markdown.Footnote}
 end
 
-HTMLContext(doc, settings=HTML()) = HTMLContext(doc, settings, "", [], "", "", [], "", Documents.NavNode("search", "Search", nothing), [])
+HTMLContext(doc, settings=HTML()) = HTMLContext(doc, settings, [], "", "", "", [], "", Documents.NavNode("search", "Search", nothing), [])
 
 function SearchRecord(ctx::HTMLContext, navnode; loc="", title=nothing, category="page", text="")
     page_title = mdflatten(pagetitle(ctx, navnode))
@@ -234,22 +550,41 @@ function render(doc::Documents.Document,
 
     ctx = HTMLContext(doc, settings)
     ctx.search_index_js = "search_index.js"
+    ctx.themeswap_js = copy_asset("themeswap.js", doc)
 
-    copy_asset("arrow.svg", doc)
-
-    for logoext in ["svg", "png", "webp", "gif", "jpg", "jpeg"]
-        logo = joinpath("assets", "logo.$(logoext)")
-        if isfile(joinpath(doc.user.build, logo))
-            ctx.logo = logo
-            break
+    # Generate documenter.js file with all the JS dependencies
+    ctx.documenter_js = "assets/documenter.js"
+    if isfile(joinpath(doc.user.source, "assets", "documenter.js"))
+        @warn "not creating 'documenter.js', provided by the user."
+    else
+        r = JSDependencies.RequireJS([
+            RD.jquery, RD.jqueryui, RD.headroom, RD.headroom_jquery,
+        ])
+        RD.mathengine!(r, settings.mathengine)
+        RD.highlightjs!(r, settings.highlights)
+        for filename in readdir(joinpath(ASSETS, "js"))
+            path = joinpath(ASSETS, "js", filename)
+            endswith(filename, ".js") && isfile(path) || continue
+            push!(r, JSDependencies.parse_snippet(path))
         end
+        JSDependencies.verify(r; verbose=true) || error("RequireJS declaration is invalid")
+        JSDependencies.writejs(joinpath(doc.user.build, "assets", "documenter.js"), r)
     end
 
-    ctx.documenter_js = copy_asset("documenter.js", doc)
-    ctx.search_js = copy_asset("search.js", doc)
+    # Generate search.js file with all the JS dependencies
+    ctx.search_js = "assets/search.js"
+    if isfile(joinpath(doc.user.source, "assets", "search.js"))
+        @warn "not creating 'search.js', provided by the user."
+    else
+        r = JSDependencies.RequireJS([RD.jquery, RD.lunr, RD.lodash])
+        push!(r, JSDependencies.parse_snippet(joinpath(ASSETS, "search.js")))
+        JSDependencies.verify(r; verbose=true) || error("RequireJS declaration is invalid")
+        JSDependencies.writejs(joinpath(doc.user.build, "assets", "search.js"), r)
+    end
 
-    push!(ctx.local_assets, copy_asset("documenter.css", doc))
-    append!(ctx.local_assets, settings.assets)
+    for theme in THEMES
+        copy_asset("themes/$(theme).css", doc)
+    end
 
     for page in keys(doc.blueprint.pages)
         idx = findfirst(nn -> nn.page == page, doc.internal.navlist)
@@ -262,12 +597,8 @@ function render(doc::Documents.Document,
 
     open(joinpath(doc.user.build, ctx.search_index_js), "w") do io
         println(io, "var documenterSearchIndex = {\"docs\":")
-        # convert Vector{SearchRecord} to a JSON string, and escape two Unicode
-        # characters since JSON is not a JS subset, and we want JS here
-        # ref http://timelessrepo.com/json-isnt-a-javascript-subset
-        escapes = ('\u2028' => "\\u2028", '\u2029' => "\\u2029")
-        js = reduce(replace, escapes, init=JSON.json(ctx.search_index))
-        println(io, js, "\n}")
+        # convert Vector{SearchRecord} to a JSON string + do additional JS escaping
+        println(io, json_jsescape(ctx.search_index), "\n}")
     end
 end
 
@@ -282,7 +613,7 @@ function copy_asset(file, doc)
     isfile(src) || error("Asset '$file' not found at $(abspath(src))")
 
     # Since user's alternative assets are already copied over in a previous build
-    # step and they should override documenter's original assets, we only actually
+    # step and they should override Documenter's original assets, we only actually
     # perform the copy if <source>/assets/<file> does not exist. Note that checking
     # the existence of <build>/assets/<file> is not sufficient since the <build>
     # directory might be dirty from a previous build.
@@ -301,28 +632,107 @@ end
 # Page
 # ------------------------------------------------------------------------------
 
+## Standard page
 """
 Constructs and writes the page referred to by the `navnode` to `.build`.
 """
 function render_page(ctx, navnode)
-    @tags html body
-
+    @tags html div body
     page = getpage(ctx, navnode)
-
     head = render_head(ctx, navnode)
-    navmenu = render_navmenu(ctx, navnode)
+    sidebar = render_sidebar(ctx, navnode)
+    navbar = render_navbar(ctx, navnode, true)
     article = render_article(ctx, navnode)
+    footer = render_footer(ctx, navnode)
+    htmldoc = render_html(ctx, navnode, head, sidebar, navbar, article, footer)
+    open_output(ctx, navnode) do io
+        print(io, htmldoc)
+    end
+end
+
+## Search page
+function render_search(ctx)
+    @tags article body h1 header hr html li nav p span ul script
+
+    src = get_url(ctx, ctx.search_navnode)
+
+    head = render_head(ctx, ctx.search_navnode)
+    sidebar = render_sidebar(ctx, ctx.search_navnode)
+    navbar = render_navbar(ctx, ctx.search_navnode, false)
+    article = article(
+        p["#documenter-search-info"]("Loading search..."),
+        ul["#documenter-search-results"]
+    )
+    footer = render_footer(ctx, ctx.search_navnode)
+    scripts = [
+        script[:src => relhref(src, ctx.search_index_js)],
+        script[:src => relhref(src, ctx.search_js)],
+    ]
+    htmldoc = render_html(ctx, ctx.search_navnode, head, sidebar, navbar, article, footer, scripts)
+    open_output(ctx, ctx.search_navnode) do io
+        print(io, htmldoc)
+    end
+end
+
+## Rendering HTML elements
+# ------------------------------------------------------------------------------
 
-    htmldoc = DOM.HTMLDocument(
-        html[:lang=>"en"](
+"""
+Renders the main `<html>` tag.
+"""
+function render_html(ctx, navnode, head, sidebar, navbar, article, footer, scripts::Vector{DOM.Node}=DOM.Node[])
+    @tags html body div
+    DOM.HTMLDocument(
+        html[:lang=>ctx.settings.lang](
             head,
-            body(navmenu, article)
+            body(
+                div["#documenter"](
+                    sidebar,
+                    div[".docs-main"](navbar, article, footer),
+                    render_settings(ctx),
+                ),
+            ),
+            scripts...
         )
     )
+end
 
-    open_output(ctx, navnode) do io
-        print(io, htmldoc)
-    end
+"""
+Renders the modal settings dialog.
+"""
+function render_settings(ctx)
+    @tags div header section footer p button hr span select option label a
+
+    theme_selector = p(
+        label[".label"]("Theme"),
+        div[".select"](
+            select["#documenter-themepicker"](option[:value=>theme](theme) for theme in THEMES)
+        )
+    )
+
+    now_full, now_short = Dates.format(now(), dateformat"E d U Y HH:MM"), Dates.format(now(), dateformat"E d U Y")
+    buildinfo = p(
+        "This document was generated with ",
+        a[:href => "https://github.com/JuliaDocs/Documenter.jl"]("Documenter.jl"),
+        " on ",
+        span[".colophon-date", :title => now_full](now_short),
+        ". ",
+        "Using Julia version $(Base.VERSION)."
+    )
+
+    div["#documenter-settings.modal"](
+        div[".modal-background"],
+        div[".modal-card"](
+            header[".modal-card-head"](
+                p[".modal-card-title"]("Settings"),
+                button[".delete"]()
+            ),
+            section[".modal-card-body"](
+                theme_selector, hr(), buildinfo
+            ),
+            footer[".modal-card-foot"]()
+        )
+    )
 end
 
 function render_head(ctx, navnode)
@@ -331,10 +741,9 @@ function render_head(ctx, navnode)
 
     page_title = "$(mdflatten(pagetitle(ctx, navnode))) · $(ctx.doc.user.sitename)"
     css_links = [
-        normalize_css,
-        google_fonts,
-        fontawesome_css,
-        highlightjs_css,
+        RD.google_fonts,
+        RD.fontawesome_css...,
+        RD.katex_css,
     ]
     head(
         meta[:charset=>"UTF-8"],
@@ -352,7 +761,7 @@ function render_head(ctx, navnode)
 
         script("documenterBaseURL=\"$(relhref(src, "."))\""),
         script[
-            :src => requirejs_cdn,
+            :src => RD.requirejs_cdn,
             Symbol("data-main") => relhref(src, ctx.documenter_js)
         ],
 
@@ -360,20 +769,32 @@ function render_head(ctx, navnode)
         script[:src => relhref(src, "../versions.js")],
 
         # Custom user-provided assets.
-        asset_links(src, ctx.local_assets)
+        asset_links(src, ctx.settings.assets),
+        # Themes. Note: we reverse the make sure that the default theme (first in the array)
+        # comes as the last <link> tag.
+        map(Iterators.reverse(enumerate(THEMES))) do (i, theme)
+            e = link[".docs-theme-link",
+                :rel => "stylesheet", :type => "text/css",
+                :href => relhref(src, "assets/themes/$(theme).css"),
+                Symbol("data-theme-name") => theme,
+            ]
+            (i == 1) && push!(e.attributes, Symbol("data-theme-primary") => "")
+            return e
+        end,
+        script[:src => relhref(src, ctx.themeswap_js)],
     )
 end
 
-function asset_links(src::AbstractString, assets::Vector)
+function asset_links(src::AbstractString, assets::Vector{HTMLAsset})
     @tags link script
     links = DOM.Node[]
-    for each in assets
-        ext = splitext(each)[end]
-        url = relhref(src, each)
+    for asset in assets
+        class = asset.class
+        url = asset.islocal ? relhref(src, asset.uri) : asset.uri
         node =
-            ext == ".ico" ? link[:href  => url, :rel => "icon", :type => "image/x-icon"] :
-            ext == ".css" ? link[:href  => url, :rel => "stylesheet", :type => "text/css"] :
-            ext == ".js"  ? script[:src => url] : continue # Skip non-js/css files.
+            class == :ico ? link[:href  => url, :rel => "icon", :type => "image/x-icon"] :
+            class == :css ? link[:href  => url, :rel => "stylesheet", :type => "text/css"] :
+            class == :js  ? script[:src => url] : continue # Skip non-js/css files.
         push!(links, node)
     end
     return links
@@ -388,7 +809,7 @@ analytics_script(tracking_id::AbstractSt
         })(window,document,'script','https://www.google-analytics.com/analytics.js','ga');
 
         ga('create', '$(tracking_id)', 'auto');
-        ga('send', 'pageview');
+        ga('send', 'pageview', {'page': location.pathname + location.search + location.hash});
         """
     )
 
@@ -403,89 +824,87 @@ function canonical_link_element(canonica
    end
 end
 
-## Search page
-# ------------
-
-function render_search(ctx)
-    @tags article body h1 header hr html li nav p span ul script
-
-    src = get_url(ctx, ctx.search_navnode)
-
-    head = render_head(ctx, ctx.search_navnode)
-    navmenu = render_navmenu(ctx, ctx.search_navnode)
-    article = article(
-        header(
-            nav(ul(li("Search"))),
-            hr(),
-            render_topbar(ctx, ctx.search_navnode),
-        ),
-        h1("Search"),
-        p["#search-info"]("Number of results: ", span["#search-results-number"]("loading...")),
-        ul["#search-results"]
-    )
-
-    htmldoc = DOM.HTMLDocument(
-        html[:lang=>"en"](
-            head,
-            body(navmenu, article),
-            script[:src => relhref(src, ctx.search_index_js)],
-            script[:src => relhref(src, ctx.search_js)],
-        )
-    )
-    open_output(ctx, ctx.search_navnode) do io
-        print(io, htmldoc)
-    end
-end
-
 # Navigation menu
 # ------------------------------------------------------------------------------
 
-function render_navmenu(ctx, navnode)
-    @tags a form h1 img input nav div select option
+struct NavMenuContext
+    htmlctx :: HTMLContext
+    current :: Documents.NavNode
+    idstack :: Vector{Int}
+end
+NavMenuContext(ctx::HTMLContext, current::Documents.NavNode) = NavMenuContext(ctx, current, [])
 
+function render_sidebar(ctx, navnode)
+    @tags a form img input nav div select option span
     src = get_url(ctx, navnode)
+    navmenu = nav[".docs-sidebar"]
 
-    navmenu = nav[".toc"]
-    if !isempty(ctx.logo)
-        push!(navmenu.nodes,
-            # the logo will point to the first page in the navigation menu
-            a[:href => navhref(ctx, first(ctx.doc.internal.navlist), navnode)](
-                img[
-                    ".logo",
-                    :src => relhref(src, ctx.logo),
-                    :alt => "$(ctx.doc.user.sitename) logo"
-                ]
-            )
-        )
-    end
-    push!(navmenu.nodes, h1(ctx.doc.user.sitename))
-    let version_selector = select["#version-selector", :onChange => "window.location.href=this.value"]()
-        if isempty(ctx.doc.user.version)
-            push!(version_selector.attributes, :style => "visibility: hidden")
+    # Logo
+    logo = find_image_asset(ctx, "logo")
+    logo_dark = find_image_asset(ctx, "logo-dark")
+    if logo !== nothing
+        # the logo will point to the first page in the navigation menu
+        href = navhref(ctx, first(ctx.doc.internal.navlist), navnode)
+        alt = isempty(ctx.doc.user.sitename) ? "Logo" : "$(ctx.doc.user.sitename) logo"
+        logo_element = a[".docs-logo", :href => href]
+        if logo_dark === nothing
+            push!(logo_element.nodes, img[:src => relhref(src, logo), :alt => alt])
         else
-            push!(version_selector.nodes,
-                option[
-                    :value => "#",
-                    :selected => "selected",
-                ](ctx.doc.user.version)
-            )
+            push!(logo_element.nodes, img[".docs-light-only", :src => relhref(src, logo), :alt => alt])
+            push!(logo_element.nodes, img[".docs-dark-only", :src => relhref(src, logo_dark), :alt => alt])
         end
-        push!(navmenu.nodes, version_selector)
+        push!(navmenu.nodes, logo_element)
     end
+    # Sitename
+    if ctx.settings.sidebar_sitename
+        push!(navmenu.nodes, div[".docs-package-name"](
+            span[".docs-autofit"](ctx.doc.user.sitename)
+        ))
+    end
+
+    # Search box
     push!(navmenu.nodes,
-        form[".search#search-form", :action => navhref(ctx, ctx.search_navnode, navnode)](
+        form[".docs-search", :action => navhref(ctx, ctx.search_navnode, navnode)](
             input[
-                "#search-query",
+                "#documenter-search-query.docs-search-query",
                 :name => "q",
                 :type => "text",
                 :placeholder => "Search docs",
             ],
         )
     )
-    push!(navmenu.nodes, navitem(ctx, navnode))
+
+    # The menu itself
+    menu = navitem(NavMenuContext(ctx, navnode, ))
+    push!(menu.attributes, :class => "docs-menu")
+    push!(navmenu.nodes, menu)
+
+    # Version selector
+    let
+        vs_class = ".docs-version-selector.field.has-addons"
+        vs_label = span[".docs-label.button.is-static.is-size-7"]("Version")
+        vs_label = div[".control"](vs_label)
+        vs_select = select["#documenter-version-selector"]
+        if !isempty(ctx.doc.user.version)
+            vs_class = "$(vs_class).visible"
+            opt = option[:value => "#", :selected => "selected", ](ctx.doc.user.version)
+            vs_select = vs_select(opt)
+        end
+        vs_select = div[".select.is-fullwidth.is-size-7"](vs_select)
+        vs_select = div[".docs-selector.control.is-expanded"](vs_select)
+        push!(navmenu.nodes, div[vs_class](vs_label, vs_select))
+    end
     navmenu
 end
 
+function find_image_asset(ctx, name)
+    for ext in ["svg", "png", "webp", "gif", "jpg", "jpeg"]
+        filename = joinpath("assets", "$(name).$(ext)")
+        isfile(joinpath(ctx.doc.user.build, filename)) && return filename
+    end
+    return nothing
+end
+
 """
 [`navitem`](@ref) returns the lists and list items of the navigation menu.
 It gets called recursively to construct the whole tree.
@@ -493,31 +912,45 @@ It gets called recursively to construct
 It always returns a [`DOM.Node`](@ref). If there's nothing to display (e.g. the node is set
 to be invisible), it returns an empty text node (`DOM.Node("")`).
 """
-navitem(ctx, current) = navitem(ctx, current, ctx.doc.internal.navtree)
-function navitem(ctx, current, nns::Vector)
-    nodes = map(nn -> navitem(ctx, current, nn), nns)
-    filter!(node -> node.name !== DOM.TEXT, nodes)
-    isempty(nodes) ? DOM.Node("") : DOM.Tag(:ul)(nodes)
-end
-function navitem(ctx, current, nn::Documents.NavNode)
-    @tags ul li span a
-
+navitem(nctx) = navitem(nctx, nctx.htmlctx.doc.internal.navtree)
+function navitem(nctx, nns::Vector)
+    push!(nctx.idstack, 0)
+    nodes = map(nns) do nn
+        nctx.idstack[end] = nctx.idstack[end] + 1
+        navitem(nctx, nn)
+    end
+    pop!(nctx.idstack)
+    filter!(node -> node.name !== DOM.TEXT, nodes) # FIXME: why?
+    ulclass = (length(nctx.idstack) >= nctx.htmlctx.settings.collapselevel) ? ".collapsed" : ""
+    isempty(nodes) ? DOM.Node("") : DOM.Tag(:ul)[ulclass](nodes)
+end
+function navitem(nctx, nn::Documents.NavNode)
+    @tags ul li span a input label i
+    ctx, current = nctx.htmlctx, nctx.current
     # We'll do the children first, primarily to determine if this node has any that are
     # visible. If it does not and it itself is not visible (including current), then
     # we'll hide this one as well, returning an empty string Node.
-    children = navitem(ctx, current, nn.children)
+    children = navitem(nctx, nn.children)
     if nn !== current && !nn.visible && children.name === DOM.TEXT
         return DOM.Node("")
     end
 
     # construct this item
     title = mdconvert(pagetitle(ctx, nn); droplinks=true)
-    link = if nn.page === nothing
-        span[".toctext"](title)
+    currentclass = (nn === current) ? ".is-active" : ""
+    item = if length(nctx.idstack) >= ctx.settings.collapselevel && children.name !== DOM.TEXT
+        menuid = "menuitem-$(join(nctx.idstack, '-'))"
+        input_attr = ["#$(menuid).collapse-toggle", :type => "checkbox"]
+        nn in Documents.navpath(nctx.current) && push!(input_attr, :checked)
+        li[currentclass](
+            input[input_attr...],
+            label[".tocitem", :for => menuid](span[".docs-label"](title), i[".docs-chevron"]),
+        )
+    elseif nn.page === nothing
+        li[currentclass](span[".tocitem"](title))
     else
-        a[".toctext", :href => navhref(ctx, nn, current)](title)
+        li[currentclass](a[".tocitem", :href => navhref(ctx, nn, current)](title))
     end
-    item = (nn === current) ? li[".current"](link) : li(link)
 
     # add the subsections (2nd level headings) from the page
     if (nn === current) && current.page !== nothing
@@ -525,9 +958,10 @@ function navitem(ctx, current, nn::Docum
         internal_links = map(subs) do s
             istoplevel, anchor, text = s
             _li = istoplevel ? li[".toplevel"] : li[]
-            _li(a[".toctext", :href => anchor](mdconvert(text; droplinks=true)))
+            _li(a[".tocitem", :href => anchor](span(mdconvert(text; droplinks=true))))
         end
-        push!(item.nodes, ul[".internal"](internal_links))
+        # Only create the ul.internal tag if there actually are in-page headers
+        length(internal_links) > 0 && push!(item.nodes, ul[".internal"](internal_links))
     end
 
     # add the visible subsections, if any, as a single list
@@ -536,79 +970,128 @@ function navitem(ctx, current, nn::Docum
     item
 end
 
+function render_navbar(ctx, navnode, edit_page_link::Bool)
+    @tags div header nav ul li a span
 
-# Article (page contents)
-# ------------------------------------------------------------------------------
-
-function render_article(ctx, navnode)
-    @tags article header footer nav ul li hr span a
-
-    header_links = map(Documents.navpath(navnode)) do nn
+    # The breadcrumb (navigation links on top)
+    navpath = Documents.navpath(navnode)
+    header_links = map(navpath) do nn
         title = mdconvert(pagetitle(ctx, nn); droplinks=true)
-        nn.page === nothing ? li(title) : li(a[:href => navhref(ctx, nn, navnode)](title))
+        nn.page === nothing ? li(a[".is-disabled"](title)) : li(a[:href => navhref(ctx, nn, navnode)](title))
     end
+    header_links[end] = header_links[end][".is-active"]
+    breadcrumb = nav[".breadcrumb"](
+        ul[".is-hidden-mobile"](header_links),
+        ul[".is-hidden-tablet"](header_links[end]) # when on mobile, we only show the page title, basically
+    )
 
-    topnav = nav(ul(header_links))
+    # The "Edit on GitHub" links and the hamburger to open the sidebar (on mobile) float right
+    navbar_right = div[".docs-right"]
 
     # Set the logo and name for the "Edit on.." button.
-    host_type = Utilities.repo_host_from_url(ctx.doc.user.repo)
-    if host_type == Utilities.RepoGitlab
-        host = "GitLab"
-        logo = "\uf296"
-    elseif host_type == Utilities.RepoGithub
-        host = "GitHub"
-        logo = "\uf09b"
-    elseif host_type == Utilities.RepoBitbucket
-        host = "BitBucket"
-        logo = "\uf171"
-    else
-        host = ""
-        logo = "\uf15c"
-    end
-    hoststring = isempty(host) ? " source" : " on $(host)"
+    if edit_page_link && (ctx.settings.edit_link !== nothing) && !ctx.settings.disable_git
+        host_type = Utilities.repo_host_from_url(ctx.doc.user.repo)
+        if host_type == Utilities.RepoGitlab
+            host = "GitLab"
+            logo = "\uf296"
+        elseif host_type == Utilities.RepoGithub
+            host = "GitHub"
+            logo = "\uf09b"
+        elseif host_type == Utilities.RepoBitbucket
+            host = "BitBucket"
+            logo = "\uf171"
+        else
+            host = ""
+            logo = "\uf15c"
+        end
+        hoststring = isempty(host) ? " source" : " on $(host)"
 
-    if !ctx.settings.disable_git
         pageurl = get(getpage(ctx, navnode).globals.meta, :EditURL, getpage(ctx, navnode).source)
-        if Utilities.isabsurl(pageurl)
-            url = pageurl
+        edit_branch = isa(ctx.settings.edit_link, String) ? ctx.settings.edit_link : nothing
+        url = if Utilities.isabsurl(pageurl)
+            pageurl
         else
             if !(pageurl == getpage(ctx, navnode).source)
                 # need to set users path relative the page itself
                 pageurl = joinpath(first(splitdir(getpage(ctx, navnode).source)), pageurl)
             end
-            url = Utilities.url(ctx.doc.user.repo, pageurl, commit=ctx.settings.edit_branch)
+            Utilities.url(ctx.doc.user.repo, pageurl, commit=edit_branch)
         end
         if url !== nothing
-            edit_verb = (ctx.settings.edit_branch === nothing) ? "View" : "Edit"
-            push!(topnav.nodes, a[".edit-page", :href => url](span[".fa"](logo), " $(edit_verb)$hoststring"))
+            edit_verb = (edit_branch === nothing) ? "View" : "Edit"
+            title = "$(edit_verb)$hoststring"
+            push!(navbar_right.nodes,
+                a[".docs-edit-link", :href => url, :title => title](
+                    span[".docs-icon.fab"](logo),
+                    span[".docs-label.is-hidden-touch"](title)
+                )
+            )
         end
     end
-    art_header = header(topnav, hr(), render_topbar(ctx, navnode))
 
-    # build the footer with nav links
-    art_footer = footer(hr())
+    # Settings cog
+    push!(navbar_right.nodes, a[
+        "#documenter-settings-button.docs-settings-button.fas.fa-cog",
+        :href => "#", :title => "Settings",
+    ])
+
+    # Hamburger on mobile
+    push!(navbar_right.nodes, a[
+        "#documenter-sidebar-button.docs-sidebar-button.fa.fa-bars.is-hidden-desktop",
+        :href => "#"
+    ])
+
+    # Construct the main <header> node that should be the first element in div.docs-main
+    header[".docs-navbar"](breadcrumb, navbar_right)
+end
+
+function render_footer(ctx, navnode)
+    @tags a div nav
+    # Navigation links (previous/next page), if there are any
+    navlinks = DOM.Node[]
     if navnode.prev !== nothing
-        direction = span[".direction"]("Previous")
-        title = span[".title"](mdconvert(pagetitle(ctx, navnode.prev); droplinks=true))
-        link = a[".previous", :href => navhref(ctx, navnode.prev, navnode)](direction, title)
-        push!(art_footer.nodes, link)
+        title = mdconvert(pagetitle(ctx, navnode.prev); droplinks=true)
+        link = a[".docs-footer-prevpage", :href => navhref(ctx, navnode.prev, navnode)]("« ", title)
+        push!(navlinks, link)
     end
-
     if navnode.next !== nothing
-        direction = span[".direction"]("Next")
-        title = span[".title"](mdconvert(pagetitle(ctx, navnode.next); droplinks=true))
-        link = a[".next", :href => navhref(ctx, navnode.next, navnode)](direction, title)
-        push!(art_footer.nodes, link)
+        title = mdconvert(pagetitle(ctx, navnode.next); droplinks=true)
+        link = a[".docs-footer-nextpage", :href => navhref(ctx, navnode.next, navnode)](title, " »")
+        push!(navlinks, link)
     end
-
-    pagenodes = domify(ctx, navnode)
-    article["#docs"](art_header, pagenodes, art_footer)
+    return isempty(navlinks) ? "" : nav[".docs-footer"](navlinks)
 end
 
-function render_topbar(ctx, navnode)
-    @tags a div span
-    page_title = string(mdflatten(pagetitle(ctx, navnode)))
-    return div["#topbar"](span(page_title), a[".fa .fa-bars", :href => "#"])
+# Article (page contents)
+# ------------------------------------------------------------------------------
+
+function render_article(ctx, navnode)
+    @tags article section ul li hr span a div p
+
+    # Build the page itself (and collect any footnotes)
+    empty!(ctx.footnotes)
+    art_body = article["#documenter-page.content"](domify(ctx, navnode))
+    # Footnotes, if there are any
+    if !isempty(ctx.footnotes)
+        fnotes = map(ctx.footnotes) do f
+            fid = "footnote-$(f.id)"
+            citerefid = "citeref-$(f.id)"
+            if length(f.text) == 1 && first(f.text) isa Markdown.Paragraph
+                li["#$(fid).footnote"](
+                    a[".tag.is-link", :href => "#$(citerefid)"](f.id),
+                    mdconvert(f.text[1].content),
+                )
+            else
+                li["#$(fid).footnote"](
+                    a[".tag.is-link", :href => "#$(citerefid)"](f.id),
+                    # passing an empty MD() as `parent` to give it block context
+                    mdconvert(f.text, Markdown.MD()),
+                )
+            end
+        end
+        push!(art_body.nodes, section[".footnotes.is-size-7"](ul(fnotes)))
+    end
+    return art_body
 end
 
 # expand the versions argument from the user
@@ -730,7 +1213,7 @@ end
 
 function domify(ctx, navnode, node)
     fixlinks!(ctx, navnode, node)
-    mdconvert(node, Markdown.MD())
+    mdconvert(node, Markdown.MD(); footnotes=ctx.footnotes)
 end
 
 function domify(ctx, navnode, anchor::Anchors.Anchor)
@@ -739,11 +1222,12 @@ function domify(ctx, navnode, anchor::An
     if isa(anchor.object, Markdown.Header)
         h = anchor.object
         fixlinks!(ctx, navnode, h)
-        DOM.Tag(Symbol("h$(Utilities.header_level(h))"))(
-            a[".nav-anchor", :id => aid, :href => "#$aid"](mdconvert(h.text, h))
+        DOM.Tag(Symbol("h$(Utilities.header_level(h))"))[:id => aid](
+            a[".docs-heading-anchor", :href => "#$aid"](mdconvert(h.text, h)),
+            a[".docs-heading-anchor-permalink", :href => "#$aid", :title => "Permalink"]
         )
     else
-        a[".nav-anchor", :id => aid, :href => "#$aid"](domify(ctx, navnode, anchor.object))
+        a[:id => aid, :href => "#$aid"](domify(ctx, navnode, anchor.object))
     end
 end
 
@@ -807,7 +1291,7 @@ function domify(ctx, navnode, docs::Docu
 end
 
 function domify(ctx, navnode, node::Documents.DocsNode)
-    @tags a code div section span
+    @tags a code article header span
 
     # push to search index
     rec = SearchRecord(ctx, navnode;
@@ -818,39 +1302,38 @@ function domify(ctx, navnode, node::Docu
 
     push!(ctx.search_index, rec)
 
-    section[".docstring"](
-        div[".docstring-header"](
+    article[".docstring"](
+        header(
             a[".docstring-binding", :id=>node.anchor.id, :href=>"#$(node.anchor.id)"](code("$(node.object.binding)")),
             " — ", # &mdash;
-            span[".docstring-category"]("$(Utilities.doccat(node.object))"),
-            "."
+            span[".docstring-category"]("$(Utilities.doccat(node.object))")
         ),
         domify_doc(ctx, navnode, node.docstr)
     )
 end
 
 function domify_doc(ctx, navnode, md::Markdown.MD)
-    @tags a
+    @tags a section footer div
     if haskey(md.meta, :results)
         # The `:results` field contains a vector of `Docs.DocStr` objects associated with
         # each markdown object. The `DocStr` contains data such as file and line info that
         # we need for generating correct source links.
         map(zip(md.content, md.meta[:results])) do md
             markdown, result = md
-            ret = Any[domify(ctx, navnode, Writers.MarkdownWriter.dropheaders(markdown))]
+            ret = section(div(domify(ctx, navnode, Writers.MarkdownWriter.dropheaders(markdown))))
             # When a source link is available then print the link.
             if !ctx.settings.disable_git
                 url = Utilities.url(ctx.doc.internal.remote, ctx.doc.user.repo, result)
                 if url !== nothing
-                    push!(ret, a[".source-link", :target=>"_blank", :href=>url]("source"))
+                    push!(ret.nodes, a[".docs-sourcelink", :target=>"_blank", :href=>url]("source"))
                 end
             end
-            ret
+            return ret
         end
     else
         # Docstrings with no `:results` metadata won't contain source locations so we don't
         # try to print them out. Just print the basic docstring.
-        domify(ctx, navnode, Writers.MarkdownWriter.dropheaders(md))
+        section(domify(ctx, navnode, Writers.MarkdownWriter.dropheaders(md)))
     end
 end
 
@@ -996,9 +1479,12 @@ end
 # mdconvert
 # ------------------------------------------------------------------------------
 
-const md_block_nodes = [Markdown.MD, Markdown.BlockQuote]
-push!(md_block_nodes, Markdown.List)
-push!(md_block_nodes, Markdown.Admonition)
+const md_block_nodes = [
+    Markdown.MD,
+    Markdown.BlockQuote,
+    Markdown.List,
+    Markdown.Admonition,
+]
 
 """
 [`MDBlockContext`](@ref) is a union of all the Markdown nodes whose children should
@@ -1017,7 +1503,7 @@ mdconvert(text::AbstractString, parent;
 
 mdconvert(vec::Vector, parent; kwargs...) = [mdconvert(x, parent; kwargs...) for x in vec]
 
-mdconvert(md::Markdown.MD, parent; kwargs...) = Tag(:div)(mdconvert(md.content, md; kwargs...))
+mdconvert(md::Markdown.MD, parent; kwargs...) = mdconvert(md.content, md; kwargs...)
 
 mdconvert(b::Markdown.BlockQuote, parent; kwargs...) = Tag(:blockquote)(mdconvert(b.content, b; kwargs...))
 
@@ -1094,20 +1580,30 @@ end
 
 mdconvert(expr::Union{Expr,Symbol}, parent; kwargs...) = string(expr)
 
-mdconvert(f::Markdown.Footnote, parent; kwargs...) = footnote(f.id, f.text, parent; kwargs...)
-footnote(id, text::Nothing, parent; kwargs...) = Tag(:a)[:href => "#footnote-$(id)"]("[$id]")
-function footnote(id, text, parent; kwargs...)
-    Tag(:div)[".footnote#footnote-$(id)"](
-        Tag(:a)[:href => "#footnote-$(id)"](Tag(:strong)("[$id]")),
-        mdconvert(text, parent; kwargs...),
-    )
+function mdconvert(f::Markdown.Footnote, parent; footnotes = nothing, kwargs...)
+    @tags sup a
+    if f.text === nothing # => Footnote link
+        return sup[".footnote-reference"](a["#citeref-$(f.id)", :href => "#footnote-$(f.id)"]("[$(f.id)]"))
+    elseif footnotes !== nothing # Footnote definition
+        push!(footnotes, f)
+    else # => Footnote definition, but nowhere to put it
+        @error "Bad footnote definition."
+    end
+    return []
 end
 
 function mdconvert(a::Markdown.Admonition, parent; kwargs...)
-    @tags div
-    div[".admonition.$(a.category)"](
-        div[".admonition-title"](a.title),
-        div[".admonition-text"](mdconvert(a.content, a; kwargs...))
+    @tags header div
+    colorclass =
+        (a.category == "danger")  ? "is-danger"  :
+        (a.category == "warning") ? "is-warning" :
+        (a.category == "note")    ? "is-info"    :
+        (a.category == "info")    ? "is-info"    :
+        (a.category == "tip")     ? "is-success" :
+        (a.category == "compat")  ? "is-compat"  : ""
+    div[".admonition.$(colorclass)"](
+        header[".admonition-header"](a.title),
+        div[".admonition-body"](mdconvert(a.content, a; kwargs...))
     )
 end
 
@@ -1141,6 +1637,12 @@ function mdconvert(d::Dict{MIME,Any}, pa
     return mdconvert(out, parent; kwargs...)
 end
 
+# Fallback
+function mdconvert(x, parent; kwargs...)
+    @debug "Strange inline Markdown node (typeof(x) = $(typeof(x))), falling back to repr()" x
+    repr(x)
+end
+
 # fixlinks!
 # ------------------------------------------------------------------------------
 
@@ -1171,7 +1673,7 @@ function fixlinks!(ctx, navnode, link::M
         # provided files or generated by code examples)
         path = relhref(get_url(ctx, navnode), path)
     else
-        @warn "invalid local link: unresolved path in $(Utilities.locrepr(navnode.page))" link = link.url
+        @warn "invalid local link: unresolved path in $(Utilities.locrepr(navnode.page))" link.text link.url
     end
 
     # Replace any backslashes in links, if building the docs on Windows
diff -pruN 1.3.1+dfsg-1/debian/embedded/Documenter/src/Writers/LaTeXWriter.jl 1.4.0+dfsg-1/debian/embedded/Documenter/src/Writers/LaTeXWriter.jl
--- 1.3.1+dfsg-1/debian/embedded/Documenter/src/Writers/LaTeXWriter.jl	2019-11-28 04:21:06.000000000 +0000
+++ 1.4.0+dfsg-1/debian/embedded/Documenter/src/Writers/LaTeXWriter.jl	2020-03-30 16:16:04.000000000 +0000
@@ -84,9 +84,18 @@ const DOCUMENT_STRUCTURE = (
     "subparagraph",
 )
 
+# https://github.com/JuliaLang/julia/pull/32851
+function mktempdir(args...; kwargs...)
+    if VERSION < v"1.3.0-alpha.112"
+        return Base.mktempdir(args...; kwargs...)
+    else
+        return Base.mktempdir(args...; cleanup=false, kwargs...)
+    end
+end
+
 function render(doc::Documents.Document, settings::LaTeX=LaTeX())
     @info "LaTeXWriter: rendering PDF."
-    mktempdir() do path
+    Base.mktempdir() do path
         cp(joinpath(doc.user.root, doc.user.build), joinpath(path, "build"))
         cd(joinpath(path, "build")) do
             name = doc.user.sitename
@@ -125,16 +134,24 @@ function render(doc::Documents.Document,
             end
             cp(STYLE, "documenter.sty")
 
-            # compile .tex and copy over the .pdf file if compile_tex return true
+            # compile .tex
             status = compile_tex(doc, settings, texfile)
-            status && cp(pdffile, joinpath(doc.user.root, doc.user.build, pdffile); force = true)
 
             # Debug: if DOCUMENTER_LATEX_DEBUG environment variable is set, copy the LaTeX
             # source files over to a directory under doc.user.root.
             if haskey(ENV, "DOCUMENTER_LATEX_DEBUG")
-                sources = cp(pwd(), mktempdir(doc.user.root), force=true)
+                dst = isempty(ENV["DOCUMENTER_LATEX_DEBUG"]) ? mktempdir(doc.user.root) :
+                    joinpath(doc.user.root, ENV["DOCUMENTER_LATEX_DEBUG"])
+                sources = cp(pwd(), dst, force=true)
                 @info "LaTeX sources copied for debugging to $(sources)"
             end
+
+            # If the build was successful, copy of the PDF to the .build directory
+            if status
+                cp(pdffile, joinpath(doc.user.root, doc.user.build, pdffile); force = true)
+            else
+                error("Compiling the .tex file failed. See logs for more information.")
+            end
         end
     end
 end
@@ -288,6 +305,10 @@ end
 ## Index, Contents, and Eval Nodes.
 
 function latex(io::IO, index::Documents.IndexNode, page, doc)
+    # Having an empty itemize block in LaTeX throws an error, so we bail early
+    # in that situation:
+    isempty(index.elements) && (_println(io); return)
+
     _println(io, "\\begin{itemize}")
     for (object, _, page, mod, cat) in index.elements
         id = string(hash(string(Utilities.slugify(object))))
@@ -301,22 +322,39 @@ function latex(io::IO, index::Documents.
 end
 
 function latex(io::IO, contents::Documents.ContentsNode, page, doc)
+    # Having an empty itemize block in LaTeX throws an error, so we bail early
+    # in that situation:
+    isempty(contents.elements) && (_println(io); return)
+
     depth = 1
-    needs_end = false
     _println(io, "\\begin{itemize}")
     for (count, path, anchor) in contents.elements
         header = anchor.object
         level = Utilities.header_level(header)
         id = string(hash(string(anchor.id, "-", anchor.nth)))
-        level < depth && (_println(io, "\\end{itemize}"); needs_end = false)
-        level > depth && (_println(io, "\\begin{itemize}"); needs_end = true)
+        # If we're changing depth, we need to make sure we always print the
+        # correct number of \begin{itemize} and \end{itemize} statements.
+        if level > depth
+            for k in 1:(level - depth)
+                # if we jump by more than one level deeper we need to put empty
+                # \items in -- otherwise LaTeX will complain
+                (k >= 2) && _println(io, "\\item ~")
+                _println(io, "\\begin{itemize}")
+                depth += 1
+            end
+        elseif level < depth
+            for _ in 1:(depth - level)
+                _println(io, "\\end{itemize}")
+                depth -= 1
+            end
+        end
+        # Print the corresponding \item statement
         _print(io, "\\item \\hyperlink{", id, "}{")
         latexinline(io, header.text)
         _println(io, "}")
-        depth = level
     end
-    needs_end && _println(io, "\\end{itemize}")
-    _println(io, "\\end{itemize}")
+    # print any remaining missing \end{itemize} statements
+    for _ = 1:depth; _println(io, "\\end{itemize}"); end
     _println(io)
 end
 
@@ -336,7 +374,7 @@ function latex(io::IO, d::Dict{MIME,Any}
         _println(io, """
         \\begin{figure}[H]
         \\centering
-        \\includegraphics{$(filename)}
+        \\includegraphics[max width=\\linewidth]{$(filename)}
         \\end{figure}
         """)
     elseif haskey(d, MIME"image/jpeg"())
@@ -344,7 +382,7 @@ function latex(io::IO, d::Dict{MIME,Any}
         _println(io, """
         \\begin{figure}[H]
         \\centering
-        \\includegraphics{$(filename)}
+        \\includegraphics[max width=\\linewidth]{$(filename)}
         \\end{figure}
         """)
     elseif haskey(d, MIME"text/latex"())
@@ -558,7 +596,7 @@ function latexinline(io::IO, md::Markdow
             normpath(joinpath(dirname(io.filename), md.url))
         end
         url = replace(url, "\\" => "/") # use / on Windows too.
-        wrapinline(io, "includegraphics") do
+        wrapinline(io, "includegraphics[max width=\\linewidth]") do
             _print(io, url)
         end
         _println(io)
diff -pruN 1.3.1+dfsg-1/debian/embedded/Documenter/test/deployconfig.jl 1.4.0+dfsg-1/debian/embedded/Documenter/test/deployconfig.jl
--- 1.3.1+dfsg-1/debian/embedded/Documenter/test/deployconfig.jl	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/debian/embedded/Documenter/test/deployconfig.jl	2020-03-30 16:16:04.000000000 +0000
@@ -0,0 +1,230 @@
+using Logging
+
+@testset "Travis CI deploy configuration" begin; with_logger(NullLogger()) do
+    # Regular tag build
+    withenv("TRAVIS_CI" => "true",
+            "TRAVIS_PULL_REQUEST" => "false",
+            "TRAVIS_REPO_SLUG" => "JuliaDocs/Documenter.jl",
+            "TRAVIS_BRANCH" => "master",
+            "TRAVIS_TAG" => "v1.2.3",
+            "TRAVIS_EVENT_TYPE" => nothing,
+            "DOCUMENTER_KEY" => "SGVsbG8sIHdvcmxkLg==",
+        ) do
+        cfg = Documenter.Travis()
+        @test Documenter.deploy_folder(cfg; repo="github.com/JuliaDocs/Documenter.jl.git",
+                  devbranch="master", devurl="dev", push_preview=true) == "v1.2.3"
+        @test Documenter.documenter_key(cfg) === "SGVsbG8sIHdvcmxkLg=="
+        @test Documenter.authentication_method(cfg) === Documenter.SSH
+    end
+    # Broken tag build
+    withenv("TRAVIS_CI" => "true",
+            "TRAVIS_PULL_REQUEST" => "false",
+            "TRAVIS_REPO_SLUG" => "JuliaDocs/Documenter.jl",
+            "TRAVIS_BRANCH" => "master",
+            "TRAVIS_TAG" => "not-a-version",
+            "TRAVIS_EVENT_TYPE" => nothing,
+            "DOCUMENTER_KEY" => "SGVsbG8sIHdvcmxkLg==",
+        ) do
+        cfg = Documenter.Travis()
+        @test Documenter.deploy_folder(cfg; repo="github.com/JuliaDocs/Documenter.jl.git",
+                  devbranch="master", devurl="dev", push_preview=true) === nothing
+    end
+    # Regular/broken devbranch build
+    withenv("TRAVIS_CI" => "true",
+            "TRAVIS_PULL_REQUEST" => "false",
+            "TRAVIS_REPO_SLUG" => "JuliaDocs/Documenter.jl",
+            "TRAVIS_BRANCH" => "master",
+            "TRAVIS_TAG" => nothing,
+            "TRAVIS_EVENT_TYPE" => nothing,
+            "DOCUMENTER_KEY" => "SGVsbG8sIHdvcmxkLg==",
+        ) do
+        cfg = Documenter.Travis()
+        @test Documenter.deploy_folder(cfg; repo="github.com/JuliaDocs/Documenter.jl.git",
+                  devbranch="master", devurl="hello-world", push_preview=true) == "hello-world"
+        @test Documenter.deploy_folder(cfg; repo="github.com/JuliaDocs/Documenter.jl.git",
+                  devbranch="not-master", devurl="hello-world", push_preview=true) === nothing
+        @test Documenter.documenter_key(cfg) === "SGVsbG8sIHdvcmxkLg=="
+    end
+    # Regular pull request build
+    withenv("TRAVIS_CI" => "true",
+            "TRAVIS_PULL_REQUEST" => "42",
+            "TRAVIS_REPO_SLUG" => "JuliaDocs/Documenter.jl",
+            "TRAVIS_BRANCH" => "something",
+            "TRAVIS_TAG" => nothing,
+            "TRAVIS_EVENT_TYPE" => nothing,
+            "DOCUMENTER_KEY" => "SGVsbG8sIHdvcmxkLg==",
+        ) do
+        cfg = Documenter.Travis()
+        @test Documenter.deploy_folder(cfg; repo="github.com/JuliaDocs/Documenter.jl.git",
+                  devbranch="master", devurl="hello-world", push_preview=true) == "previews/PR42"
+        @test Documenter.deploy_folder(cfg; repo="github.com/JuliaDocs/Documenter.jl.git",
+                  devbranch="master", devurl="hello-world", push_preview=false) === nothing
+        @test Documenter.documenter_key(cfg) === "SGVsbG8sIHdvcmxkLg=="
+    end
+    # Missing/broken environment variables
+    withenv("TRAVIS_CI" => "true",
+            "TRAVIS_PULL_REQUEST" => "false",
+            "TRAVIS_REPO_SLUG" => "JuliaDocs/Documenter.jl",
+            "TRAVIS_BRANCH" => "master",
+            "TRAVIS_TAG" => "v1.2.3",
+            "TRAVIS_EVENT_TYPE" => nothing,
+            "DOCUMENTER_KEY" => nothing,
+        ) do
+        cfg = Documenter.Travis()
+        @test Documenter.deploy_folder(cfg; repo="github.com/JuliaDocs/Documenter.jl.git",
+                  devbranch="master", devurl="hello-world", push_preview=false) === nothing
+    end
+end end
+
+@testset "GitHub Actions deploy configuration" begin; with_logger(NullLogger()) do
+    # Regular tag build with GITHUB_TOKEN
+    withenv("GITHUB_EVENT_NAME" => "push",
+            "GITHUB_REPOSITORY" => "JuliaDocs/Documenter.jl",
+            "GITHUB_REF" => "refs/tags/v1.2.3",
+            "GITHUB_ACTOR" => "github-actions",
+            "GITHUB_TOKEN" => "SGVsbG8sIHdvcmxkLg==",
+            "DOCUMENTER_KEY" => nothing,
+        ) do
+        cfg = Documenter.GitHubActions()
+        @test Documenter.deploy_folder(cfg; repo="github.com/JuliaDocs/Documenter.jl.git",
+                  devbranch="master", devurl="dev", push_preview=true) == "v1.2.3"
+        @test Documenter.authentication_method(cfg) === Documenter.HTTPS
+        @test Documenter.authenticated_repo_url(cfg) === "https://github-actions:SGVsbG8sIHdvcmxkLg==@github.com/JuliaDocs/Documenter.jl.git"
+    end
+    # Regular tag build with SSH deploy key (SSH key prioritized)
+    withenv("GITHUB_EVENT_NAME" => "push",
+            "GITHUB_REPOSITORY" => "JuliaDocs/Documenter.jl",
+            "GITHUB_REF" => "refs/tags/v1.2.3",
+            "GITHUB_ACTOR" => "github-actions",
+            "GITHUB_TOKEN" => "SGVsbG8sIHdvcmxkLg==",
+            "DOCUMENTER_KEY" => "SGVsbG8sIHdvcmxkLg==",
+        ) do
+        cfg = Documenter.GitHubActions()
+        @test Documenter.deploy_folder(cfg; repo="github.com/JuliaDocs/Documenter.jl.git",
+                  devbranch="master", devurl="dev", push_preview=true) == "v1.2.3"
+        @test Documenter.authentication_method(cfg) === Documenter.SSH
+        @test Documenter.documenter_key(cfg) === "SGVsbG8sIHdvcmxkLg=="
+    end
+    # Broken tag build
+    withenv("GITHUB_EVENT_NAME" => "push",
+            "GITHUB_REPOSITORY" => "JuliaDocs/Documenter.jl",
+            "GITHUB_REF" => "refs/tags/not-a-version",
+            "GITHUB_ACTOR" => "github-actions",
+            "GITHUB_TOKEN" => "SGVsbG8sIHdvcmxkLg==",
+            "DOCUMENTER_KEY" => nothing,
+        ) do
+        cfg = Documenter.GitHubActions()
+        @test Documenter.deploy_folder(cfg; repo="github.com/JuliaDocs/Documenter.jl.git",
+                  devbranch="master", devurl="dev", push_preview=true) === nothing
+    end
+    # Regular devbranch build with GITHUB_TOKEN
+    withenv("GITHUB_EVENT_NAME" => "push",
+            "GITHUB_REPOSITORY" => "JuliaDocs/Documenter.jl",
+            "GITHUB_REF" => "refs/heads/master",
+            "GITHUB_ACTOR" => "github-actions",
+            "GITHUB_TOKEN" => "SGVsbG8sIHdvcmxkLg==",
+            "DOCUMENTER_KEY" => nothing,
+        ) do
+        cfg = Documenter.GitHubActions()
+        @test Documenter.deploy_folder(cfg; repo="github.com/JuliaDocs/Documenter.jl.git",
+                  devbranch="master", devurl="hello-world", push_preview=true) == "hello-world"
+        @test Documenter.deploy_folder(cfg; repo="github.com/JuliaDocs/Documenter.jl.git",
+                  devbranch="not-master", devurl="hello-world", push_preview=true) === nothing
+        @test Documenter.authentication_method(cfg) === Documenter.HTTPS
+        @test Documenter.authenticated_repo_url(cfg) === "https://github-actions:SGVsbG8sIHdvcmxkLg==@github.com/JuliaDocs/Documenter.jl.git"
+    end
+    # Regular devbranch build with SSH deploy key (SSH key prioritized)
+    withenv("GITHUB_EVENT_NAME" => "push",
+            "GITHUB_REPOSITORY" => "JuliaDocs/Documenter.jl",
+            "GITHUB_REF" => "refs/heads/master",
+            "GITHUB_ACTOR" => "github-actions",
+            "GITHUB_TOKEN" => "SGVsbG8sIHdvcmxkLg==",
+            "DOCUMENTER_KEY" => "SGVsbG8sIHdvcmxkLg==",
+        ) do
+        cfg = Documenter.GitHubActions()
+        @test Documenter.deploy_folder(cfg; repo="github.com/JuliaDocs/Documenter.jl.git",
+                  devbranch="master", devurl="hello-world", push_preview=true) == "hello-world"
+        @test Documenter.deploy_folder(cfg; repo="github.com/JuliaDocs/Documenter.jl.git",
+                  devbranch="not-master", devurl="hello-world", push_preview=true) === nothing
+        @test Documenter.authentication_method(cfg) === Documenter.SSH
+        @test Documenter.documenter_key(cfg) === "SGVsbG8sIHdvcmxkLg=="
+    end
+    # Regular pull request build with GITHUB_TOKEN
+    withenv("GITHUB_EVENT_NAME" => "pull_request",
+            "GITHUB_REPOSITORY" => "JuliaDocs/Documenter.jl",
+            "GITHUB_REF" => "refs/pull/42/merge",
+            "GITHUB_ACTOR" => "github-actions",
+            "GITHUB_TOKEN" => "SGVsbG8sIHdvcmxkLg==",
+            "DOCUMENTER_KEY" => nothing,
+        ) do
+        cfg = Documenter.GitHubActions()
+        @test Documenter.deploy_folder(cfg; repo="github.com/JuliaDocs/Documenter.jl.git",
+                  devbranch="master", devurl="hello-world", push_preview=true) == "previews/PR42"
+        @test Documenter.deploy_folder(cfg; repo="github.com/JuliaDocs/Documenter.jl.git",
+                  devbranch="not-master", devurl="hello-world", push_preview=false) === nothing
+        @test Documenter.authentication_method(cfg) === Documenter.HTTPS
+        @test Documenter.authenticated_repo_url(cfg) === "https://github-actions:SGVsbG8sIHdvcmxkLg==@github.com/JuliaDocs/Documenter.jl.git"
+    end
+    # Regular pull request build with SSH deploy key (SSH key prioritized)
+    withenv("GITHUB_EVENT_NAME" => "pull_request",
+            "GITHUB_REPOSITORY" => "JuliaDocs/Documenter.jl",
+            "GITHUB_REF" => "refs/pull/42/merge",
+            "GITHUB_ACTOR" => "github-actions",
+            "GITHUB_TOKEN" => "SGVsbG8sIHdvcmxkLg==",
+            "DOCUMENTER_KEY" => "SGVsbG8sIHdvcmxkLg==",
+        ) do
+        cfg = Documenter.GitHubActions()
+        @test Documenter.deploy_folder(cfg; repo="github.com/JuliaDocs/Documenter.jl.git",
+                  devbranch="master", devurl="hello-world", push_preview=true) == "previews/PR42"
+        @test Documenter.deploy_folder(cfg; repo="github.com/JuliaDocs/Documenter.jl.git",
+                  devbranch="not-master", devurl="hello-world", push_preview=false) === nothing
+        @test Documenter.authentication_method(cfg) === Documenter.SSH
+        @test Documenter.documenter_key(cfg) === "SGVsbG8sIHdvcmxkLg=="
+    end
+    # Missing environment variables
+    withenv("GITHUB_EVENT_NAME" => "push",
+            "GITHUB_REPOSITORY" => "JuliaDocs/Documenter.jl",
+            "GITHUB_REF" => "refs/tags/v1.2.3",
+            "GITHUB_ACTOR" => "github-actions",
+            "GITHUB_TOKEN" => nothing,
+            "DOCUMENTER_KEY" => nothing,
+        ) do
+        cfg = Documenter.GitHubActions()
+        @test Documenter.deploy_folder(cfg; repo="github.com/JuliaDocs/Documenter.jl.git",
+                  devbranch="master", devurl="hello-world", push_preview=true) === nothing
+    end
+end end
+
+struct CustomConfig <: Documenter.DeployConfig end
+Documenter.deploy_folder(::CustomConfig; kwargs...) = "v1.2.3"
+struct BrokenConfig <: Documenter.DeployConfig end
+
+@testset "Custom configuration" begin; with_logger(NullLogger()) do
+        cfg = CustomConfig()
+        @test Documenter.deploy_folder(cfg; repo="github.com/JuliaDocs/Documenter.jl.git",
+                  devbranch="master", devurl="dev", push_preview=true) == "v1.2.3"
+        cfg = BrokenConfig()
+        @test (@test_logs (:warn, r"Documenter\.deploy_folder\(::BrokenConfig; kwargs\.\.\.\) not implemented") Documenter.deploy_folder(cfg)) === nothing
+        @test (@test_logs (:warn, r"Documenter could not auto-detect") Documenter.deploy_folder(nothing)) === nothing
+end end
+
+@testset "Autodetection of deploy system" begin
+    withenv("TRAVIS_REPO_SLUG" => "JuliaDocs/Documenter.jl",
+            "GITHUB_REPOSITORY" => nothing,
+        ) do
+        cfg = Documenter.auto_detect_deploy_system()
+        @test cfg isa Documenter.Travis
+    end
+    withenv("TRAVIS_REPO_SLUG" => nothing,
+            "GITHUB_REPOSITORY" => "JuliaDocs/Documenter.jl",
+        ) do
+        cfg = Documenter.auto_detect_deploy_system()
+        @test cfg isa Documenter.GitHubActions
+    end
+    withenv("TRAVIS_REPO_SLUG" => nothing,
+            "GITHUB_REPOSITORY" => nothing,
+        ) do
+        cfg = Documenter.auto_detect_deploy_system()
+        @test cfg === nothing
+    end
+end
diff -pruN 1.3.1+dfsg-1/debian/embedded/Documenter/test/doctests/doctestapi.jl 1.4.0+dfsg-1/debian/embedded/Documenter/test/doctests/doctestapi.jl
--- 1.3.1+dfsg-1/debian/embedded/Documenter/test/doctests/doctestapi.jl	2019-11-28 04:21:06.000000000 +0000
+++ 1.4.0+dfsg-1/debian/embedded/Documenter/test/doctests/doctestapi.jl	2020-03-30 16:16:04.000000000 +0000
@@ -17,7 +17,14 @@ function run_doctest(f, args...; kwargs.
         # Running inside a Task to make sure that the parent testsets do not interfere.
         t = Task(() -> doctest(args...; kwargs...))
         schedule(t)
-        fetch(t) # if an exception happens, it gets propagated
+        # if an exception happens, it gets propagated
+        try
+            fetch(t)
+        catch e
+            # Note: in Julia 1.3 fetch no longer throws the exception direction, but instead
+            # wraps it in a TaskFailedException (https://github.com/JuliaLang/julia/pull/32814).
+            rethrow(t.exception)
+        end
     end
 
     @debug """run_doctest($args;, $kwargs) -> $(success ? "success" : "fail")
@@ -140,6 +147,15 @@ ERROR: syntax: invalid numeric constant
 """
 module ScriptParseErrorFail end
 
+module PR1075
+    "x \$(42) y"
+    function qux end
+    "..."
+    function foo end
+    @doc @doc(foo) function bar end
+    @doc @doc(bar) function baz end
+end
+
 @testset "Documenter.doctest" begin
     # DocTest1
     run_doctest(nothing, [DocTest1]) do result, success, backtrace, output
@@ -205,6 +221,12 @@ module ScriptParseErrorFail end
         @test !success
         @test result isa TestSetException
     end
+
+    # PR 1075
+    run_doctest(nothing, [PR1075]) do result, success, backtrace, output
+        @test success
+        @test result isa Test.DefaultTestSet
+    end
 end
 
 end # module
diff -pruN 1.3.1+dfsg-1/debian/embedded/Documenter/test/doctests/fix/tests.jl 1.4.0+dfsg-1/debian/embedded/Documenter/test/doctests/fix/tests.jl
--- 1.3.1+dfsg-1/debian/embedded/Documenter/test/doctests/fix/tests.jl	2019-11-28 04:21:06.000000000 +0000
+++ 1.4.0+dfsg-1/debian/embedded/Documenter/test/doctests/fix/tests.jl	2020-03-30 16:16:04.000000000 +0000
@@ -9,8 +9,11 @@ function test_doctest_fix(dir)
     srcdir = mktempdir(dir)
     builddir = mktempdir(dir)
     @debug "Testing doctest = :fix" srcdir builddir
-    cp(joinpath(@__DIR__, "broken.md"), joinpath(srcdir, "index.md"))
-    cp(joinpath(@__DIR__, "broken.jl"), joinpath(srcdir, "src.jl"))
+
+    # Pkg.add changes permission of files to read-only,
+    # so instead of copying them we read + write.
+    write(joinpath(srcdir, "index.md"), read(joinpath(@__DIR__, "broken.md")))
+    write(joinpath(srcdir, "src.jl"), read(joinpath(@__DIR__, "broken.jl")))
 
     # fix up
     include(joinpath(srcdir, "src.jl")); @eval import .Foo
diff -pruN 1.3.1+dfsg-1/debian/embedded/Documenter/test/examples/make.jl 1.4.0+dfsg-1/debian/embedded/Documenter/test/examples/make.jl
--- 1.3.1+dfsg-1/debian/embedded/Documenter/test/examples/make.jl	2019-11-28 04:21:06.000000000 +0000
+++ 1.4.0+dfsg-1/debian/embedded/Documenter/test/examples/make.jl	2020-03-30 16:16:04.000000000 +0000
@@ -9,6 +9,18 @@ isdefined(@__MODULE__, :examples_root) &
 # The `Mod` and `AutoDocs` modules are assumed to exists in the Main module.
 (@__MODULE__) === Main || error("$(@__FILE__) must be included into Main.")
 
+# DOCUMENTER_TEST_EXAMPLES environment variable can be used to control which
+# builds actually run. E.g. to only build the HTML deployment example build, you
+# could call the make.jl file as follows:
+#
+#     DOCUMENTER_TEST_EXAMPLES=html julia --project test/examples/make.jl
+#
+EXAMPLE_BUILDS = if haskey(ENV, "DOCUMENTER_TEST_EXAMPLES")
+    split(ENV["DOCUMENTER_TEST_EXAMPLES"])
+else
+    ["markdown", "html", "html-local"]
+end
+
 # Modules `Mod` and `AutoDocs`
 module Mod
     """
@@ -96,35 +108,47 @@ module AutoDocs
     end
 end
 
+# Helper functions
+function withassets(f, assets...)
+    src(asset) = joinpath(@__DIR__, asset)
+    dst(asset) = joinpath(@__DIR__, "src/assets/$(basename(asset))")
+    for asset in assets
+        isfile(src(asset)) || error("$(asset) is missing")
+    end
+    for asset in assets
+        cp(src(asset), dst(asset))
+    end
+    rv, exception = try
+        f(), nothing
+    catch e
+        nothing, e
+    end
+    for asset in assets
+        rm(dst(asset))
+    end
+    return (exception === nothing) ? rv : throw(exception)
+end
+
 # Build example docs
 using Documenter, DocumenterMarkdown
+isdefined(@__MODULE__, :TestUtilities) || (include("../TestUtilities.jl"); using .TestUtilities)
 
-const examples_root = @__DIR__
-const builds_directory = joinpath(examples_root, "builds")
+examples_root = @__DIR__
+builds_directory = joinpath(examples_root, "builds")
 ispath(builds_directory) && rm(builds_directory, recursive=true)
 
 expandfirst = ["expandorder/AA.md"]
-
-@info("Building mock package docs: MarkdownWriter")
-examples_markdown_doc = makedocs(
-    format = Markdown(),
-    debug = true,
-    root  = examples_root,
-    build = "builds/markdown",
-    doctest = false,
-    expandfirst = expandfirst,
-)
-
-
 htmlbuild_pages = Any[
     "**Home**" => "index.md",
     "Manual" => [
         "man/tutorial.md",
+        "man/style.md",
     ],
     hide("hidden.md"),
     "Library" => [
         "lib/functions.md",
         "lib/autodocs.md",
+        "lib/editurl.md",
     ],
     hide("Hidden Pages" => "hidden/index.md", Any[
         "Page X" => "hidden/x.md",
@@ -137,68 +161,163 @@ htmlbuild_pages = Any[
         "expandorder/AA.md",
     ],
     "unicode.md",
+    "latex.md",
 ]
 
-@info("Building mock package docs: HTMLWriter / local build")
-examples_html_local_doc = makedocs(
-    debug = true,
-    root  = examples_root,
-    build = "builds/html-local",
-    doctestfilters = [r"Ptr{0x[0-9]+}"],
-    sitename = "Documenter example",
-    pages = htmlbuild_pages,
-    expandfirst = expandfirst,
-
-    linkcheck = true,
-    linkcheck_ignore = [r"(x|y).md", "z.md", r":func:.*"],
-    format = Documenter.HTML(
-        assets = ["assets/custom.css"],
-        prettyurls = false,
-        edit_branch = nothing,
-    ),
-)
-
 # Build with pretty URLs and canonical links and a PNG logo
-@info("Building mock package docs: HTMLWriter / deployment build")
-
-function withassets(f, assets...)
-    src(asset) = joinpath(@__DIR__, asset)
-    dst(asset) = joinpath(@__DIR__, "src/assets/$(basename(asset))")
-    for asset in assets
-        isfile(src(asset)) || error("$(asset) is missing")
-    end
-    for asset in assets
-        cp(src(asset), dst(asset))
-    end
-    rv = try
-        f()
-    catch exception
-        @warn "f() threw an exception" exception
-        nothing
-    end
-    for asset in assets
-        rm(dst(asset))
+examples_html_doc = if "html" in EXAMPLE_BUILDS
+    @info("Building mock package docs: HTMLWriter / deployment build")
+    @quietly withassets("images/logo.png", "images/logo.jpg", "images/logo.gif") do
+        makedocs(
+            debug = true,
+            root  = examples_root,
+            build = "builds/html",
+            doctestfilters = [r"Ptr{0x[0-9]+}"],
+            sitename = "Documenter example",
+            pages = htmlbuild_pages,
+            expandfirst = expandfirst,
+            doctest = false,
+            format = Documenter.HTML(
+                assets = [
+                    "assets/favicon.ico",
+                    "assets/custom.css",
+                    asset("https://example.com/resource.js"),
+                    asset("http://example.com/fonts?param=foo", class=:css),
+                    asset("https://fonts.googleapis.com/css?family=Nanum+Brush+Script&display=swap", class=:css),
+                ],
+                prettyurls = true,
+                canonical = "https://example.com/stable",
+                mathengine = MathJax(Dict(:TeX => Dict(
+                    :equationNumbers => Dict(:autoNumber => "AMS"),
+                    :Macros => Dict(
+                        :ket => ["|#1\\rangle", 1],
+                        :bra => ["\\langle#1|", 1],
+                    ),
+                ))),
+                highlights = ["erlang", "erlang-repl"],
+            )
+        )
     end
-    return rv
+else
+    @info "Skipping build: HTML/deploy" EXAMPLE_BUILDS get(ENV, "DOCUMENTER_TEST_EXAMPLES", nothing)
+    nothing
 end
 
-examples_html_deploy_doc = withassets("images/logo.png", "images/logo.jpg", "images/logo.gif") do
-    makedocs(
+# HTML: local build with pretty URLs off
+examples_html_local_doc = if "html-local" in EXAMPLE_BUILDS
+    @info("Building mock package docs: HTMLWriter / local build")
+    @quietly makedocs(
         debug = true,
         root  = examples_root,
-        build = "builds/html-deploy",
+        build = "builds/html-local",
         doctestfilters = [r"Ptr{0x[0-9]+}"],
         sitename = "Documenter example",
         pages = htmlbuild_pages,
         expandfirst = expandfirst,
-        doctest = false,
+
+        linkcheck = true,
+        linkcheck_ignore = [r"(x|y).md", "z.md", r":func:.*"],
         format = Documenter.HTML(
-            assets = [
-                "assets/favicon.ico",
-                "assets/custom.css"
+            assets = ["assets/custom.css"],
+            prettyurls = false,
+            edit_branch = nothing,
+        ),
+    )
+else
+    @info "Skipping build: HTML/local" EXAMPLE_BUILDS get(ENV, "DOCUMENTER_TEST_EXAMPLES", nothing)
+    nothing
+end
+
+# Markdown
+examples_markdown_doc = if "markdown" in EXAMPLE_BUILDS
+    @info("Building mock package docs: MarkdownWriter")
+    @quietly makedocs(
+        format = Markdown(),
+        debug = true,
+        root  = examples_root,
+        build = "builds/markdown",
+        doctest = false,
+        expandfirst = expandfirst,
+    )
+else
+    @info "Skipping build: Markdown" EXAMPLE_BUILDS get(ENV, "DOCUMENTER_TEST_EXAMPLES", nothing)
+    nothing
+end
+
+# PDF/LaTeX
+examples_latex_simple_doc = if "latex_simple" in EXAMPLE_BUILDS
+    @info("Building mock package docs: LaTeXWriter/simple")
+    @quietly makedocs(
+        format = Documenter.Writers.LaTeXWriter.LaTeX(platform = "docker"),
+        sitename = "Documenter LaTeX Simple",
+        root  = examples_root,
+        build = "builds/latex_simple",
+        source = "src.latex_simple",
+        pages = ["Main section" => ["index.md"]],
+        doctest = false,
+        debug = true,
+    )
+else
+    @info "Skipping build: LaTeXWriter/simple" EXAMPLE_BUILDS get(ENV, "DOCUMENTER_TEST_EXAMPLES", nothing)
+    nothing
+end
+
+examples_latex_doc = if "latex" in EXAMPLE_BUILDS
+    @info("Building mock package docs: LaTeXWriter/latex")
+    @quietly makedocs(
+        format = Documenter.Writers.LaTeXWriter.LaTeX(platform = "docker"),
+        sitename = "Documenter LaTeX",
+        root  = examples_root,
+        build = "builds/latex",
+        pages = htmlbuild_pages = Any[
+            "General" => [
+                "index.md",
+                "latex.md",
+                "unicode.md",
+                hide("hidden.md"),
             ],
-            prettyurls = true,
-            canonical = "https://example.com/stable",
-        )
+            # SVG images nor code blocks in footnotes are allowed in LaTeX
+            # "Manual" => [
+            #     "man/tutorial.md",
+            #     "man/style.md",
+            # ],
+            hide("Hidden Pages" => "hidden/index.md", Any[
+                "Page X" => "hidden/x.md",
+                "hidden/y.md",
+                "hidden/z.md",
+            ]),
+            "Library" => [
+                "lib/functions.md",
+                "lib/autodocs.md",
+                "lib/editurl.md",
+            ],
+            "Expandorder" => [
+                "expandorder/00.md",
+                "expandorder/01.md",
+                "expandorder/AA.md",
+            ],
+        ],
+        doctest = false,
+        debug = true,
+    )
+else
+    @info "Skipping build: LaTeXWriter/latex" EXAMPLE_BUILDS get(ENV, "DOCUMENTER_TEST_EXAMPLES", nothing)
+    nothing
+end
+
+examples_latex_simple_nondocker_doc = if "latex_simple_nondocker" in EXAMPLE_BUILDS
+    @info("Building mock package docs: LaTeXWriter/latex_simple_nondocker")
+    @quietly makedocs(
+        format = Documenter.Writers.LaTeXWriter.LaTeX(),
+        sitename = "Documenter LaTeX Simple Non-Docker",
+        root  = examples_root,
+        build = "builds/latex_simple_nondocker",
+        source = "src.latex_simple",
+        pages = ["Main section" => ["index.md"]],
+        doctest = false,
+        debug = true,
     )
+else
+    @info "Skipping build: LaTeXWriter/latex_simple_nondocker" EXAMPLE_BUILDS get(ENV, "DOCUMENTER_TEST_EXAMPLES", nothing)
+    nothing
 end
diff -pruN 1.3.1+dfsg-1/debian/embedded/Documenter/test/examples/src/index.md 1.4.0+dfsg-1/debian/embedded/Documenter/test/examples/src/index.md
--- 1.3.1+dfsg-1/debian/embedded/Documenter/test/examples/src/index.md	2019-11-28 04:21:06.000000000 +0000
+++ 1.4.0+dfsg-1/debian/embedded/Documenter/test/examples/src/index.md	2020-03-30 16:16:04.000000000 +0000
@@ -402,6 +402,19 @@ julia> ans
 "world"
 ```
 
+## Issue #1148
+
+```@setup setup-include-test
+write("issue1148.jl", "x = 1148")
+r = include("issue1148.jl")
+rm("issue1148.jl")
+```
+
+```@repl setup-include-test
+x
+@assert x == 1148
+```
+
 # Issue513
 
 ```jldoctest named
@@ -479,3 +492,6 @@ MarkdownOnly("""
 **bold** output from MarkdownOnly
 """)
 ```
+
+# Empty heading
+##
diff -pruN 1.3.1+dfsg-1/debian/embedded/Documenter/test/examples/src/latex.md 1.4.0+dfsg-1/debian/embedded/Documenter/test/examples/src/latex.md
--- 1.3.1+dfsg-1/debian/embedded/Documenter/test/examples/src/latex.md	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/debian/embedded/Documenter/test/examples/src/latex.md	2020-03-30 16:16:04.000000000 +0000
@@ -0,0 +1,22 @@
+# LaTeX MWEs
+
+## `ContentsNode` level jumps
+
+```@contents
+Pages = ["latex.md"]
+Depth = 9000
+```
+
+#### Level 4
+## Level 2 again
+### Level 3
+
+## Empty `ContentsNode` and `IndexNode`
+
+```@contents
+Pages = ["does-not-exist.md"]
+```
+
+```@index
+Pages = ["does-not-exist.md"]
+```
diff -pruN 1.3.1+dfsg-1/debian/embedded/Documenter/test/examples/src/lib/editurl.md 1.4.0+dfsg-1/debian/embedded/Documenter/test/examples/src/lib/editurl.md
--- 1.3.1+dfsg-1/debian/embedded/Documenter/test/examples/src/lib/editurl.md	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/debian/embedded/Documenter/test/examples/src/lib/editurl.md	2020-03-30 16:16:04.000000000 +0000
@@ -0,0 +1,5 @@
+# Rubbish EditURL
+
+```@meta
+EditURL = "/foo/bar/baz/I/Should/Not/Exist"
+```
diff -pruN 1.3.1+dfsg-1/debian/embedded/Documenter/test/examples/src/man/style.md 1.4.0+dfsg-1/debian/embedded/Documenter/test/examples/src/man/style.md
--- 1.3.1+dfsg-1/debian/embedded/Documenter/test/examples/src/man/style.md	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/debian/embedded/Documenter/test/examples/src/man/style.md	2020-03-30 16:16:04.000000000 +0000
@@ -0,0 +1,64 @@
+# Style demos
+
+## Styling of lists
+
+* Lorem ipsum dolor sit amet, consectetur adipiscing elit.
+* Nulla quis venenatis justo.
+* In non _sodales_ eros.
+
+In an admonition it looks like this:
+
+!!! note "Bulleted lists in admonitions"
+
+    * Lorem ipsum dolor sit amet, consectetur adipiscing elit.
+    * Nulla quis venenatis justo.
+    * In non _sodales_ eros.
+
+    Second list
+
+    * Lorem ipsum dolor sit amet, consectetur adipiscing elit.
+    * Nulla quis venenatis justo.
+    * In non _sodales_ eros.
+
+But otherwise
+
+* Lorem ipsum dolor sit amet, consectetur adipiscing elit.
+* Nulla quis venenatis justo.
+* In non _sodales_ eros.
+
+In block quotes
+
+> * Lorem ipsum dolor sit amet, consectetur adipiscing elit.
+> * Nulla quis venenatis justo.
+> * In non _sodales_ eros.
+>
+> Second list
+>
+> * Lorem ipsum dolor sit amet, consectetur adipiscing elit.
+> * Nulla quis venenatis justo.
+> * In non _sodales_ eros.
+
+!!! note
+    1. asd
+    2. asdf
+
+## Links and code spans
+
+Lorem [ipsum](#) dolor sit [`amet`](#), consectetur adipiscing `elit`.
+
+## Code blocks
+
+```julia
+foo = "Example of string $(interpolation)."
+```
+
+## Footnote rendering
+
+This sentence has a footnote.[^5]
+
+[^5]: An example of how you can benchmark a log density with gradient `∇P`, obtained as described below:
+    ```julia
+    using BenchmarkTools, LogDensityProblems
+    x = randn(LogDensityProblems.dimension(∇P))
+    @benchmark LogDensityProblems.logdensity_and_gradient($∇P, $x)
+    ```
diff -pruN 1.3.1+dfsg-1/debian/embedded/Documenter/test/examples/src/man/tutorial.md 1.4.0+dfsg-1/debian/embedded/Documenter/test/examples/src/man/tutorial.md
--- 1.3.1+dfsg-1/debian/embedded/Documenter/test/examples/src/man/tutorial.md	2019-11-28 04:21:06.000000000 +0000
+++ 1.4.0+dfsg-1/debian/embedded/Documenter/test/examples/src/man/tutorial.md	2020-03-30 16:16:04.000000000 +0000
@@ -350,3 +350,38 @@ With explicit alignment.
 | :---   |    :---:    |       ---: |
 | `A`    |      ✓      |      10.00 |
 | `BB`   |      ✓      | 1000000.00 |
+
+## Customizing assets
+
+The following example only works on the deploy build where
+
+```julia
+mathengine = Documenter.MathJax(Dict(:TeX => Dict(
+    :equationNumbers => Dict(:autoNumber => "AMS"),
+    :Macros => Dict(
+        :ket => ["|#1\\rangle", 1],
+        :bra => ["\\langle#1|", 1],
+    ),
+)))
+```
+
+```math
+\bra{x}\ket{y}
+```
+
+The following at-raw block only renders correctly on the deploy build, where
+
+```julia
+assets = [
+  asset("https://fonts.googleapis.com/css?family=Nanum+Brush+Script&display=swap", class=:css),
+  ...
+]
+```
+
+```@raw html
+<div style="font-family: 'Nanum Brush Script'; text-align: center; font-size: xx-large;">
+Hello World!
+<br />
+Written in <a href="https://fonts.google.com/specimen/Nanum+Brush+Script">Nanum Brush Script.</a>
+</div>
+```
diff -pruN 1.3.1+dfsg-1/debian/embedded/Documenter/test/examples/src.latex_simple/index.md 1.4.0+dfsg-1/debian/embedded/Documenter/test/examples/src.latex_simple/index.md
--- 1.3.1+dfsg-1/debian/embedded/Documenter/test/examples/src.latex_simple/index.md	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/debian/embedded/Documenter/test/examples/src.latex_simple/index.md	2020-03-30 16:16:04.000000000 +0000
@@ -0,0 +1,4 @@
+# Simple LaTeX build
+
+This build only contains a single paragraph of text to make sure that a
+near-empty LaTeX builds passes.
diff -pruN 1.3.1+dfsg-1/debian/embedded/Documenter/test/examples/tests.jl 1.4.0+dfsg-1/debian/embedded/Documenter/test/examples/tests.jl
--- 1.3.1+dfsg-1/debian/embedded/Documenter/test/examples/tests.jl	2019-11-28 04:21:06.000000000 +0000
+++ 1.4.0+dfsg-1/debian/embedded/Documenter/test/examples/tests.jl	2020-03-30 16:16:04.000000000 +0000
@@ -1,5 +1,10 @@
 using Test
 
+# DOCUMENTER_TEST_EXAMPLES can be used to control which builds are performed in
+# make.jl. But for the tests we need to make sure that all the relevant builds
+# ran.
+haskey(ENV, "DOCUMENTER_TEST_EXAMPLES") && error("DOCUMENTER_TEST_EXAMPLES env. variable is set")
+
 # When the file is run separately we need to include make.jl which actually builds
 # the docs and defines a few modules that are referred to in the docs. The make.jl
 # has to be expected in the context of the Main module.
@@ -13,6 +18,56 @@ elseif (@__MODULE__) !== Main && !isdefi
 end
 
 @testset "Examples" begin
+    @testset "HTML: deploy" begin
+        doc = Main.examples_html_doc
+
+        @test isa(doc, Documenter.Documents.Document)
+
+        let build_dir = joinpath(examples_root, "builds", "html")
+            @test joinpath(build_dir, "index.html") |> isfile
+            @test joinpath(build_dir, "omitted", "index.html") |> isfile
+            @test joinpath(build_dir, "hidden", "index.html") |> isfile
+            @test joinpath(build_dir, "lib", "autodocs", "index.html") |> isfile
+
+            # Test existence of some HTML elements
+            indexhtml = String(read(joinpath(build_dir, "index.html")))
+            #@test occursin("", indexhtml)
+
+            # Assets
+            @test joinpath(build_dir, "assets", "documenter.js") |> isfile
+
+            # This build includes erlang and erlang-repl highlighting
+            documenterjs = String(read(joinpath(build_dir, "assets", "documenter.js")))
+            @test occursin("languages/julia.min", documenterjs)
+            @test occursin("languages/julia-repl.min", documenterjs)
+            @test occursin("languages/erlang-repl.min", documenterjs)
+            @test occursin("languages/erlang.min", documenterjs)
+        end
+    end
+
+    @testset "HTML: local" begin
+        doc = Main.examples_html_local_doc
+
+        @test isa(doc, Documenter.Documents.Document)
+
+        let build_dir = joinpath(examples_root, "builds", "html-local")
+
+            index_html = read(joinpath(build_dir, "index.html"), String)
+            @test occursin("<strong>bold</strong> output from MarkdownOnly", index_html)
+
+            @test isfile(joinpath(build_dir, "index.html"))
+            @test isfile(joinpath(build_dir, "omitted.html"))
+            @test isfile(joinpath(build_dir, "hidden.html"))
+            @test isfile(joinpath(build_dir, "lib", "autodocs.html"))
+
+            # Assets
+            @test joinpath(build_dir, "assets", "documenter.js") |> isfile
+            documenterjs = String(read(joinpath(build_dir, "assets", "documenter.js")))
+            @test occursin("languages/julia.min", documenterjs)
+            @test occursin("languages/julia-repl.min", documenterjs)
+        end
+    end
+
     @testset "Markdown" begin
         doc = Main.examples_markdown_doc
 
@@ -50,7 +105,7 @@ end
 
         @test realpath(doc.internal.assets) == realpath(joinpath(dirname(@__FILE__), "..", "..", "assets"))
 
-        @test length(doc.blueprint.pages) == 15
+        @test length(doc.blueprint.pages) == 18
 
         let headers = doc.internal.headers
             @test Documenter.Anchors.exists(headers, "Documentation")
@@ -74,38 +129,4 @@ end
 
         @test length(doc.internal.objects) == 41
     end
-
-    @testset "HTML: local" begin
-        doc = Main.examples_html_local_doc
-
-        @test isa(doc, Documenter.Documents.Document)
-
-        # TODO: test the HTML build
-
-        let build_dir = joinpath(examples_root, "builds", "html-local")
-
-            index_html = read(joinpath(build_dir, "index.html"), String)
-            @test occursin("<strong>bold</strong> output from MarkdownOnly", index_html)
-
-            @test isfile(joinpath(build_dir, "index.html"))
-            @test isfile(joinpath(build_dir, "omitted.html"))
-            @test isfile(joinpath(build_dir, "hidden.html"))
-            @test isfile(joinpath(build_dir, "lib", "autodocs.html"))
-        end
-    end
-
-    @testset "HTML: deploy" begin
-        doc = Main.examples_html_deploy_doc
-
-        @test isa(doc, Documenter.Documents.Document)
-
-        # TODO: test the HTML build with pretty URLs
-
-        let build_dir = joinpath(examples_root, "builds", "html-deploy")
-            @test joinpath(build_dir, "index.html") |> isfile
-            @test joinpath(build_dir, "omitted", "index.html") |> isfile
-            @test joinpath(build_dir, "hidden", "index.html") |> isfile
-            @test joinpath(build_dir, "lib", "autodocs", "index.html") |> isfile
-        end
-    end
 end
diff -pruN 1.3.1+dfsg-1/debian/embedded/Documenter/test/examples/tests_latex.jl 1.4.0+dfsg-1/debian/embedded/Documenter/test/examples/tests_latex.jl
--- 1.3.1+dfsg-1/debian/embedded/Documenter/test/examples/tests_latex.jl	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/debian/embedded/Documenter/test/examples/tests_latex.jl	2020-03-30 16:16:04.000000000 +0000
@@ -0,0 +1,35 @@
+using Test
+
+# DOCUMENTER_TEST_EXAMPLES can be used to control which builds are performed in
+# make.jl, and we need to set it to the relevant LaTeX builds.
+ENV["DOCUMENTER_TEST_EXAMPLES"] = "latex latex_simple"
+
+# When the file is run separately we need to include make.jl which actually builds
+# the docs and defines a few modules that are referred to in the docs. The make.jl
+# has to be expected in the context of the Main module.
+if (@__MODULE__) === Main && !@isdefined examples_root
+    include("make.jl")
+elseif (@__MODULE__) !== Main && isdefined(Main, :examples_root)
+    using Documenter
+    const examples_root = Main.examples_root
+elseif (@__MODULE__) !== Main && !isdefined(Main, :examples_root)
+    error("examples/make.jl has not been loaded into Main.")
+end
+
+@testset "Examples/LaTeX" begin
+    @testset "PDF/LaTeX: simple" begin
+        doc = Main.examples_latex_simple_doc
+        @test isa(doc, Documenter.Documents.Document)
+        let build_dir = joinpath(examples_root, "builds", "latex_simple")
+            @test joinpath(build_dir, "DocumenterLaTeXSimple.pdf") |> isfile
+        end
+    end
+
+    @testset "PDF/LaTeX" begin
+        doc = Main.examples_latex_doc
+        @test isa(doc, Documenter.Documents.Document)
+        let build_dir = joinpath(examples_root, "builds", "latex")
+            @test joinpath(build_dir, "DocumenterLaTeX.pdf") |> isfile
+        end
+    end
+end
diff -pruN 1.3.1+dfsg-1/debian/embedded/Documenter/test/expanders.jl 1.4.0+dfsg-1/debian/embedded/Documenter/test/expanders.jl
--- 1.3.1+dfsg-1/debian/embedded/Documenter/test/expanders.jl	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/debian/embedded/Documenter/test/expanders.jl	2020-03-30 16:16:04.000000000 +0000
@@ -0,0 +1,30 @@
+# Docstring signature syntax highlighting tests.
+module HighlightSig
+    using Test
+    import Markdown
+    import Documenter.Expanders: highlightsig!
+
+    @testset "highlightsig!" begin
+        s = """
+                foo(bar::Baz)
+            ---
+                foo(bar::Baz)
+            """
+        original = Markdown.parse(s)
+        md = Markdown.parse(s)
+        highlightsig!(md)
+        @test isempty(original.content[1].language)
+        @test md.content[1].language == "julia"
+        @test original.content[end].language == md.content[end].language
+
+        s = """
+            ```lang
+             foo(bar::Baz)
+            ```
+            """
+        original = Markdown.parse(s)
+        md = Markdown.parse(s)
+        highlightsig!(md)
+        @test original == md
+    end
+end
diff -pruN 1.3.1+dfsg-1/debian/embedded/Documenter/test/formats/markdown.jl 1.4.0+dfsg-1/debian/embedded/Documenter/test/formats/markdown.jl
--- 1.3.1+dfsg-1/debian/embedded/Documenter/test/formats/markdown.jl	2019-11-28 04:21:06.000000000 +0000
+++ 1.4.0+dfsg-1/debian/embedded/Documenter/test/formats/markdown.jl	2020-03-30 16:16:04.000000000 +0000
@@ -3,14 +3,14 @@ module MarkdownFormatTests
 using Test
 using Random
 
-using Documenter
+using Documenter, DocumenterMarkdown
 
 # Documenter package docs
 @info("Building Documenter's docs with Markdown.")
 const Documenter_root = normpath(joinpath(@__DIR__, "..", "..", "docs"))
 build_dir_relpath = relpath(joinpath(@__DIR__, "builds/markdown"), Documenter_root)
 doc = makedocs(
-    format = :markdown,
+    format = Markdown(),
     debug   = true,
     root    = Documenter_root,
     modules = Documenter,
diff -pruN 1.3.1+dfsg-1/debian/embedded/Documenter/test/htmlwriter.jl 1.4.0+dfsg-1/debian/embedded/Documenter/test/htmlwriter.jl
--- 1.3.1+dfsg-1/debian/embedded/Documenter/test/htmlwriter.jl	2019-11-28 04:21:06.000000000 +0000
+++ 1.4.0+dfsg-1/debian/embedded/Documenter/test/htmlwriter.jl	2020-03-30 16:16:04.000000000 +0000
@@ -1,9 +1,9 @@
 module HTMLWriterTests
 
 using Test
-
-import JSON
-import Documenter.Writers.HTMLWriter: generate_version_file, expand_versions
+using Documenter
+using Documenter: DocSystem
+using Documenter.Writers.HTMLWriter: HTMLWriter, generate_version_file, expand_versions
 
 function verify_version_file(versionfile, entries)
     @test isfile(versionfile)
@@ -17,6 +17,87 @@ function verify_version_file(versionfile
 end
 
 @testset "HTMLWriter" begin
+    @test isdir(HTMLWriter.ASSETS)
+    @test isdir(HTMLWriter.ASSETS_SASS)
+    @test isdir(HTMLWriter.ASSETS_THEMES)
+
+    for theme in HTMLWriter.THEMES
+        @test isfile(joinpath(HTMLWriter.ASSETS_SASS, "$(theme).scss"))
+        @test isfile(joinpath(HTMLWriter.ASSETS_THEMES, "$(theme).css"))
+    end
+
+    # asset handling
+    let asset = asset("https://example.com/foo.js")
+        @test asset.uri == "https://example.com/foo.js"
+        @test asset.class == :js
+        @test asset.islocal === false
+    end
+    let asset = asset("http://example.com/foo.js", class=:ico)
+        @test asset.uri == "http://example.com/foo.js"
+        @test asset.class == :ico
+        @test asset.islocal === false
+    end
+    let asset = asset("foo/bar.css", islocal=true)
+        @test asset.uri == "foo/bar.css"
+        @test asset.class == :css
+        @test asset.islocal === true
+    end
+    @test_throws Exception asset("ftp://example.com/foo.js")
+    @test_throws Exception asset("example.com/foo.js")
+    @test_throws Exception asset("foo.js")
+    @test_throws Exception asset("https://example.com/foo.js?q=1")
+    @test_throws Exception asset("https://example.com/foo.js", class=:error)
+
+    # HTML format object
+    @test Documenter.HTML() isa Documenter.HTML
+    @test_throws ArgumentError Documenter.HTML(collapselevel=-200)
+    @test_throws Exception Documenter.HTML(assets=["foo.js", 10])
+
+    # MathEngine
+    let katex = KaTeX()
+        @test length(katex.config) == 1
+        @test haskey(katex.config, :delimiters)
+    end
+    let katex = KaTeX(Dict(:foo => 1))
+        @test length(katex.config) == 2
+        @test haskey(katex.config, :delimiters)
+        @test haskey(katex.config, :foo)
+    end
+    let katex = KaTeX(Dict(:delimiters => 1, :foo => 2))
+        @test length(katex.config) == 2
+        @test haskey(katex.config, :delimiters)
+        @test katex.config[:delimiters] == 1
+        @test haskey(katex.config, :foo)
+    end
+
+    let mathjax = MathJax()
+        @test length(mathjax.config) == 5
+        @test haskey(mathjax.config, :tex2jax)
+        @test haskey(mathjax.config, :config)
+        @test haskey(mathjax.config, :jax)
+        @test haskey(mathjax.config, :extensions)
+        @test haskey(mathjax.config, :TeX)
+    end
+    let mathjax = MathJax(Dict(:foo => 1))
+        @test length(mathjax.config) == 6
+        @test haskey(mathjax.config, :tex2jax)
+        @test haskey(mathjax.config, :config)
+        @test haskey(mathjax.config, :jax)
+        @test haskey(mathjax.config, :extensions)
+        @test haskey(mathjax.config, :TeX)
+        @test haskey(mathjax.config, :foo)
+    end
+    let mathjax = MathJax(Dict(:tex2jax => 1, :foo => 2))
+        @test length(mathjax.config) == 6
+        @test haskey(mathjax.config, :tex2jax)
+        @test haskey(mathjax.config, :config)
+        @test haskey(mathjax.config, :jax)
+        @test haskey(mathjax.config, :extensions)
+        @test haskey(mathjax.config, :TeX)
+        @test haskey(mathjax.config, :foo)
+        @test mathjax.config[:tex2jax] == 1
+    end
+
     mktempdir() do tmpdir
         versionfile = joinpath(tmpdir, "versions.js")
         versions = ["stable", "dev",
@@ -70,6 +151,17 @@ end
         versions = ["stable" => "v^", "dev" => "stable"]
         @test_throws ArgumentError expand_versions(tmpdir, versions)
     end
-end
 
+    # Exhaustive Conversion from Markdown to Nodes.
+    @testset "MD2Node" begin
+        for mod in Base.Docs.modules
+            for (binding, multidoc) in DocSystem.getmeta(mod)
+                for (typesig, docstr) in multidoc.docs
+                    md = Documenter.DocSystem.parsedoc(docstr)
+                    @test string(HTMLWriter.mdconvert(md; footnotes=[])) isa String
+                end
+            end
+        end
+    end
+end
 end
diff -pruN 1.3.1+dfsg-1/debian/embedded/Documenter/test/manual.jl 1.4.0+dfsg-1/debian/embedded/Documenter/test/manual.jl
--- 1.3.1+dfsg-1/debian/embedded/Documenter/test/manual.jl	2019-11-28 04:21:06.000000000 +0000
+++ 1.4.0+dfsg-1/debian/embedded/Documenter/test/manual.jl	2020-03-30 16:16:04.000000000 +0000
@@ -17,7 +17,13 @@ using Test
     ```
     """)
     @test isfile(tmpfile)
-    @test_throws TestSetException fetch(schedule(Task(() -> doctest(Documenter))))
+    # Note: in Julia 1.3 fetch no longer throws the exception direction, but instead
+    # wraps it in a TaskFailedException (https://github.com/JuliaLang/julia/pull/32814).
+    if isdefined(Base, :TaskFailedException)
+        @test_throws TaskFailedException fetch(schedule(Task(() -> doctest(Documenter))))
+    else
+        @test_throws TestSetException fetch(schedule(Task(() -> doctest(Documenter))))
+    end
     println("^^^ Expected error output.")
     rm(tmpfile)
     @test !isfile(tmpfile)
diff -pruN 1.3.1+dfsg-1/debian/embedded/Documenter/test/markdown2.jl 1.4.0+dfsg-1/debian/embedded/Documenter/test/markdown2.jl
--- 1.3.1+dfsg-1/debian/embedded/Documenter/test/markdown2.jl	2019-11-28 04:21:06.000000000 +0000
+++ 1.4.0+dfsg-1/debian/embedded/Documenter/test/markdown2.jl	2020-03-30 16:16:04.000000000 +0000
@@ -177,6 +177,42 @@ import Documenter.Utilities: Markdown2
 
         @test isa(md2.nodes[1], Markdown2.Table)
     end
+
+    # Issue 1073
+    let md = Markdown.parse(raw"""
+        $$
+        f
+        $$
+        """),
+        md2 = convert(Markdown2.MD, md)
+        @test isa(md2, Markdown2.MD)
+    end
+    let md = Markdown.parse(raw"""
+        X $(42) Y
+        """),
+        md2 = convert(Markdown2.MD, md)
+
+        @test isa(md2, Markdown2.MD)
+        @test length(md2) == 1
+        @test isa(md2.nodes[1], Markdown2.Paragraph)
+        let p = md2.nodes[1]
+            @test length(p.nodes) == 3
+            @test p.nodes[2] == Markdown2.Text("42")
+        end
+    end
+
+    # Issue 1081
+    let md = Markdown.parse(raw"""
+        #
+        """),
+        md2 = convert(Markdown2.MD, md)
+        @test isa(md2, Markdown2.MD)
+        @test length(md2) === 1
+        @test isa(md2.nodes[1], Markdown2.Heading)
+        @test length(md2.nodes[1].nodes) === 1
+        @test isa(md2.nodes[1].nodes[1], Markdown2.Text)
+        @test md2.nodes[1].nodes[1].text == ""
+    end
 end
 
 end # module
diff -pruN 1.3.1+dfsg-1/debian/embedded/Documenter/test/runtests.jl 1.4.0+dfsg-1/debian/embedded/Documenter/test/runtests.jl
--- 1.3.1+dfsg-1/debian/embedded/Documenter/test/runtests.jl	2019-11-28 04:21:06.000000000 +0000
+++ 1.4.0+dfsg-1/debian/embedded/Documenter/test/runtests.jl	2020-03-30 16:16:04.000000000 +0000
@@ -1,21 +1,26 @@
 using Test
+import Documenter
+include("TestUtilities.jl"); using .TestUtilities
 
-# Build the example docs
-include("examples/make.jl")
-
-# Test missing docs
-include("missingdocs/make.jl")
-
-# Primary @testset
+@testset "Documenter" begin
+    # Test TestUtilities
+    TestUtilities.test()
 
-# Error reporting.
-println("="^50)
-@info("The following errors are expected output.")
-include(joinpath("errors", "make.jl"))
-@info("END of expected error output.")
-println("="^50)
+    # Build the example docs
+    @info "Building example/make.jl"
+    include("examples/make.jl")
+
+    # Test missing docs
+    @info "Building missingdocs/make.jl"
+    @quietly include("missingdocs/make.jl")
+
+    # Error reporting.
+    println("="^50)
+    @info("The following errors are expected output.")
+    include("errors/make.jl")
+    @info("END of expected error output.")
+    println("="^50)
 
-@testset "Documenter" begin
     # Unit tests for module internals.
     include("utilities.jl")
     include("markdown2.jl")
@@ -41,9 +46,15 @@ println("="^50)
     # MDFlatten tests.
     include("mdflatten.jl")
 
+    # Expanders
+    include("expanders.jl")
+
     # HTMLWriter
     include("htmlwriter.jl")
 
+    # Deployment configurations
+    include("deployconfig.jl")
+
     # Mock package docs.
     include("examples/tests.jl")
 
@@ -58,55 +69,7 @@ println("="^50)
 
     # Passing a writer positionally (https://github.com/JuliaDocs/Documenter.jl/issues/1046)
     @test_throws ArgumentError makedocs(sitename="", HTML())
-end
-
-# Additional tests
 
-## `Markdown.MD` to `DOM.Node` conversion tests.
-module MarkdownToNode
-    import Documenter.DocSystem
-    import Documenter.Writers.HTMLWriter: mdconvert
-
-    # Exhaustive Conversion from Markdown to Nodes.
-    for mod in Base.Docs.modules
-        for (binding, multidoc) in DocSystem.getmeta(mod)
-            for (typesig, docstr) in multidoc.docs
-                md = DocSystem.parsedoc(docstr)
-                string(mdconvert(md))
-            end
-        end
-    end
+    # Running doctest() on our own manual
+    include("manual.jl")
 end
-
-# Docstring signature syntax highlighting tests.
-module HighlightSig
-    using Test
-    import Markdown
-    import Documenter.Expanders: highlightsig!
-
-    @testset "highlightsig!" begin
-        s = """
-                foo(bar::Baz)
-            ---
-                foo(bar::Baz)
-            """
-        original = Markdown.parse(s)
-        md = Markdown.parse(s)
-        highlightsig!(md)
-        @test isempty(original.content[1].language)
-        @test md.content[1].language == "julia"
-        @test original.content[end].language == md.content[end].language
-
-        s = """
-            ```lang
-             foo(bar::Baz)
-            ```
-            """
-        original = Markdown.parse(s)
-        md = Markdown.parse(s)
-        highlightsig!(md)
-        @test original == md
-    end
-end
-
-include("manual.jl")
diff -pruN 1.3.1+dfsg-1/debian/embedded/Documenter/test/TestUtilities.jl 1.4.0+dfsg-1/debian/embedded/Documenter/test/TestUtilities.jl
--- 1.3.1+dfsg-1/debian/embedded/Documenter/test/TestUtilities.jl	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/debian/embedded/Documenter/test/TestUtilities.jl	2020-03-30 16:16:04.000000000 +0000
@@ -0,0 +1,93 @@
+module TestUtilities
+using Test
+using Documenter.Utilities: withoutput
+
+export @quietly
+
+const QUIETLY_LOG = joinpath(@__DIR__, "quietly.log")
+
+__init__() = isfile(QUIETLY_LOG) && rm(QUIETLY_LOG)
+
+struct QuietlyException <: Exception
+    exception
+    backtrace
+end
+
+function Base.showerror(io::IO, e::QuietlyException)
+    println(io, "@quietly hit an exception ($(typeof(e.exception))):")
+    showerror(io, e.exception, e.backtrace)
+end
+
+function _quietly(f, expr, source)
+    result, success, backtrace, output = withoutput(f)
+    haskey(ENV, "DOCUMENTER_TEST_QUIETLY") && open(QUIETLY_LOG; write=true, append=true) do io
+        println(io, "@quietly: success = $(success) / $(sizeof(output)) bytes of output captured")
+        println(io, "@quietly: $(source.file):$(source.line)")
+        println(io, "@quietly: typeof(result) = ", typeof(result))
+        println(io, "@quietly: STDOUT")
+        println(io, output)
+        println(io, "@quietly: end of STDOUT")
+        if success
+            println(io, "@quietly: result =")
+            println(io, result)
+        else
+            println(io, "@quietly: result (error) =")
+            showerror(io, result, backtrace)
+        end
+    end
+    if success
+        printstyled("@quietly: success, $(sizeof(output)) bytes of output hidden\n"; color=:magenta)
+        return result
+    else
+        @error """
+        An error was thrown in @quietly, $(sizeof(output)) bytes of output captured
+        $(typeof(result)) at $(source.file):$(source.line) in expression:
+        $(expr)
+        $(sizeof(output)) bytes of output captured
+        """
+        if !isempty(output)
+            printstyled("$("="^21) @quietly: output from the expression $("="^21)\n"; color=:magenta)
+            print(output)
+            last(output) != "\n" && println()
+            printstyled("$("="^27) @quietly: end of output $("="^28)\n"; color=:magenta)
+        end
+        throw(QuietlyException(result, backtrace))
+    end
+end
+macro quietly(expr)
+    orig_expr = Expr(:inert, expr)
+    source = QuoteNode(__source__)
+    quote
+        _quietly($orig_expr, $source) do
+            $(esc(expr))
+        end
+    end
+end
+
+"Runs the tests for TestUtilities"
+function test()
+    @testset "TestUtilities" begin
+        # Various tests use Utilities.withoutput to capture output. So we'll first make sure
+        # that it is working properly.
+        @testset "withoutput" begin
+            let (result, success, backtrace, output) = withoutput() do
+                    println("test stdout")
+                end
+                @test success
+                @test result === nothing
+                @test output == "test stdout\n"
+            end
+            let (result, success, backtrace, output) = withoutput(() -> 42)
+                @test success
+                @test result === 42
+                @test output == ""
+            end
+            let (result, success, backtrace, output) = withoutput(() -> error("test error"))
+                @test !success
+                @test result isa ErrorException
+                @test output == ""
+            end
+        end
+    end
+end
+end
diff -pruN 1.3.1+dfsg-1/debian/embedded/Documenter/test/themes/Project.toml 1.4.0+dfsg-1/debian/embedded/Documenter/test/themes/Project.toml
--- 1.3.1+dfsg-1/debian/embedded/Documenter/test/themes/Project.toml	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/debian/embedded/Documenter/test/themes/Project.toml	2020-03-30 16:16:04.000000000 +0000
@@ -0,0 +1,6 @@
+[deps]
+Documenter = "e30172f5-a6a5-5a46-863b-614d45cd2de4"
+DocumenterTools = "35a29f4d-8980-5a13-9543-d66fff28ecb8"
+
+[compat]
+DocumenterTools = "=0.1.3"
diff -pruN 1.3.1+dfsg-1/debian/embedded/Documenter/test/themes/themes.jl 1.4.0+dfsg-1/debian/embedded/Documenter/test/themes/themes.jl
--- 1.3.1+dfsg-1/debian/embedded/Documenter/test/themes/themes.jl	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/debian/embedded/Documenter/test/themes/themes.jl	2020-03-30 16:16:04.000000000 +0000
@@ -0,0 +1,30 @@
+# This file checks that the compiled CSS files for the HTML themes are up to date.
+#
+# This does not run as part of the standard test suite, since the CSS produced by libsass
+# is likely not deterministic across libsass versions.
+#
+# However, we can still run these tests as part of the CI, and ignore the results as needed.
+using Test
+using Documenter.Writers: HTMLWriter
+using DocumenterTools: Themes
+
+@testset "HTML themes" begin
+    @test isdir(HTMLWriter.ASSETS)
+    @test isdir(HTMLWriter.ASSETS_SASS)
+    @test isdir(HTMLWriter.ASSETS_THEMES)
+
+    for theme in HTMLWriter.THEMES
+        @test isfile(joinpath(HTMLWriter.ASSETS_SASS, "$(theme).scss"))
+        @test isfile(joinpath(HTMLWriter.ASSETS_THEMES, "$(theme).css"))
+    end
+
+    mktempdir() do tmpdir
+        for theme in HTMLWriter.THEMES
+            dst = joinpath(tmpdir, "$(theme).css")
+            Themes.compile_native_theme(theme; dst=dst)
+            css_compiled = read(dst)
+            css_repo = read(joinpath(HTMLWriter.ASSETS_THEMES, "$(theme).css"))
+            @test css_compiled == css_repo
+        end
+    end
+end
diff -pruN 1.3.1+dfsg-1/debian/embedded/Documenter/test/utilities.jl 1.4.0+dfsg-1/debian/embedded/Documenter/test/utilities.jl
--- 1.3.1+dfsg-1/debian/embedded/Documenter/test/utilities.jl	2019-11-28 04:21:06.000000000 +0000
+++ 1.4.0+dfsg-1/debian/embedded/Documenter/test/utilities.jl	2020-03-30 16:16:04.000000000 +0000
@@ -311,6 +311,121 @@ end
         @test_throws ArgumentError mdparse("x\n\ny", mode=:span)
         @info ".. end of expected error output."
     end
+
+    @testset "JSDependencies" begin
+        using Documenter.Utilities.JSDependencies:
+            RemoteLibrary, Snippet, RequireJS, verify, writejs, parse_snippet
+        libraries = [
+            RemoteLibrary("foo", "example.com/foo"),
+            RemoteLibrary("bar", "example.com/bar"; deps = ["foo"]),
+        ]
+        snippet = Snippet(["foo", "bar"], ["Foo"], "f(x)")
+        let r = RequireJS(libraries)
+            push!(r, snippet)
+            @test verify(r)
+            output = let io = IOBuffer()
+                writejs(io, r)
+                String(take!(io))
+            end
+            # The expected output should look something like this:
+            #
+            #   // Generated by Documenter.jl
+            #   requirejs.config({
+            #     paths: {
+            #       'bar': 'example.com/bar',
+            #       'foo': 'example.com/foo',
+            #     },
+            #     shim: {
+            #     "bar": {
+            #       "deps": [
+            #         "foo"
+            #       ]
+            #     }
+            #   }
+            #   });
+            #   ////////////////////////////////////////////////////////////////////////////////
+            #   require(['foo', 'bar'], function(Foo) {
+            #   f(x)
+            #   })
+            #
+            # But the output is not entirely deterministic, so we can't do just a string
+            # comparison. Hence, we'll just do a few simple `occursin` tests, to make sure
+            # that the most important things are at least present.
+            @test occursin("'foo'", output)
+            @test occursin("'bar'", output)
+            @test occursin("example.com/foo", output)
+            @test occursin("example.com/bar", output)
+            @test occursin("f(x)", output)
+            @test occursin(r"requirejs\.config\({[\S\s]+}\)", output)
+            @test occursin(r"require\([\S\s]+\)", output)
+        end
+        # Error conditions: missing dependency
+        let r = RequireJS([
+                RemoteLibrary("foo", "example.com/foo"),
+                RemoteLibrary("bar", "example.com/bar"; deps = ["foo", "baz"]),
+            ])
+            @test !verify(r)
+            push!(r, RemoteLibrary("baz", "example.com/baz"))
+            @test verify(r)
+            push!(r, Snippet(["foo", "qux"], ["Foo"], "f(x)"))
+            @test !verify(r)
+            push!(r, RemoteLibrary("qux", "example.com/qux"))
+            @test verify(r)
+        end
+
+        let io = IOBuffer(raw"""
+            // libraries: foo, bar
+            // arguments: $
+            script
+            """)
+            snippet = parse_snippet(io)
+            @test snippet.deps == ["foo", "bar"]
+            @test snippet.args == ["\$"]
+            @test snippet.js == "script\n"
+        end
+
+        # jsescape
+        @testset "jsescape" begin
+            using Documenter.Utilities.JSDependencies: jsescape
+            @test jsescape("abc123") == "abc123"
+            @test jsescape("▶αβγ") == "▶αβγ"
+            @test jsescape("") == ""
+
+            @test jsescape("a\nb") == "a\\nb"
+            @test jsescape("\r\n") == "\\r\\n"
+            @test jsescape("\\") == "\\\\"
+
+            @test jsescape("\"'") == "\\\"\\'"
+
+            # Ref: #639
+            @test jsescape("\u2028") == "\\u2028"
+            @test jsescape("\u2029") == "\\u2029"
+            @test jsescape("policy to  delete.") == "policy to\\u2028 delete."
+        end
+
+        @testset "json_jsescape" begin
+            using Documenter.Utilities.JSDependencies: json_jsescape
+            @test json_jsescape(["abc"]) == raw"[\"abc\"]"
+            @test json_jsescape(["\\"]) == raw"[\"\\\\\"]"
+            @test json_jsescape(["x\u2028y"]) == raw"[\"x\u2028y\"]"
+        end
+
+        # Proper escaping of generated JS
+        let r = RequireJS([
+                RemoteLibrary("fo\'o", "example.com\n/foo"),
+            ])
+            @test verify(r)
+            push!(r, Snippet(["fo\'o"], ["Foo"], "f(x)"))
+            output = let io = IOBuffer()
+                writejs(io, r)
+                String(take!(io))
+            end
+            @test occursin("'fo\\'o'", output)
+            @test occursin("example.com\\n/foo", output)
+            @test !occursin("'fo'o'", output)
+            @test !occursin("example.com\n/foo", output)
+        end
+    end
 end
 
 end
diff -pruN 1.3.1+dfsg-1/debian/embedded/Documenter/.travis.yml 1.4.0+dfsg-1/debian/embedded/Documenter/.travis.yml
--- 1.3.1+dfsg-1/debian/embedded/Documenter/.travis.yml	2019-11-28 04:21:05.000000000 +0000
+++ 1.4.0+dfsg-1/debian/embedded/Documenter/.travis.yml	2020-03-30 16:16:04.000000000 +0000
@@ -6,13 +6,23 @@ os:
 
 julia:
   - 1.0
-  - 1.1
+  - 1.3
   - nightly
+matrix:
+  allow_failures:
+  - julia: nightly
+
+branches:
+  only:
+    - master
+    - /^release-.*$/
+    - /^v\d+\.\d+(\.\d+)?(-\S*)?$/
 
 notifications:
   email: false
 
 after_success:
+  - if [ -f test/quietly.log ]; then cat test/quietly.log; fi
   - if [[ $TRAVIS_JULIA_VERSION = 1.1 ]] && [[ $TRAVIS_OS_NAME = linux ]]; then
       julia --project=coverage/ -e 'using Pkg; Pkg.instantiate();
           using Coverage; Codecov.submit(Codecov.process_folder())';
@@ -20,9 +30,16 @@ after_success:
 
 jobs:
   include:
+    - stage: "Additional tests"
+      script:
+        - julia --project=test/themes -e 'using Pkg; Pkg.instantiate(); Pkg.develop(PackageSpec(path=pwd()))'
+        - julia --project=test/themes test/themes/themes.jl
+      name: "Themes"
+    - script:
+      - julia --project=test/examples -e 'using Pkg; Pkg.instantiate(); Pkg.develop(PackageSpec(path=pwd())); Pkg.add("DocumenterMarkdown")'
+      - julia --project=test/examples test/examples/tests_latex.jl
+      name: "PDF/LaTeX backend"
     - stage: "Documentation"
-      julia: 1.0
-      os: linux
       script:
         - julia --project=docs/ -e 'using Pkg; Pkg.develop(PackageSpec(path=pwd())); Pkg.instantiate()'
         - julia --project=docs/ docs/make.jl
Binary files 1.3.1+dfsg-1/debian/embedded/f71e2c5a119b9c850f9b357fc8c56068f5b51cc0 and 1.4.0+dfsg-1/debian/embedded/f71e2c5a119b9c850f9b357fc8c56068f5b51cc0 differ
diff -pruN 1.3.1+dfsg-1/debian/embedded/update-jl.sh 1.4.0+dfsg-1/debian/embedded/update-jl.sh
--- 1.3.1+dfsg-1/debian/embedded/update-jl.sh	2019-12-31 04:27:59.000000000 +0000
+++ 1.4.0+dfsg-1/debian/embedded/update-jl.sh	2020-04-02 06:58:02.000000000 +0000
@@ -1,7 +1,10 @@
 #!/bin/sh -e
 
 PKG_JL_BASE=https://api.github.com/repos/JuliaLang/Pkg.jl/tarball/
-PKG_JL_HASH=f71e2c5a119b9c850f9b357fc8c56068f5b51cc0
+PKG_JL_HASH=9419c70af69153cd5c4276bff90fbb135e0aa3f1
+
+STA_JL_BASE=https://api.github.com/repos/JuliaLang/Statistics.jl/tarball/
+STA_JL_HASH=a2203d3b67f7413701be5de251622cb85c9cc69d
 
 LIBUV_BASE=https://api.github.com/repos/JuliaLang/libuv/tarball/
 LIBUV_HASH=35b1504507a7a4168caae3d78db54d1121b121e1
@@ -13,6 +16,10 @@ if ! test -r $PKG_JL_HASH; then
 	wget -c ${PKG_JL_BASE}${PKG_JL_HASH}
 fi
 
+if ! test -r $STA_JL_HASH; then
+	wget -c ${STA_JL_BASE}${STA_JL_HASH}
+fi
+
 if ! test -r libuv-$LIBUV_HASH.tar.gz; then
 	wget -c ${LIBUV_BASE}${LIBUV_HASH} -O libuv-${LIBUV_HASH}.tar.gz
 fi
@@ -32,7 +39,7 @@ foobar () {
 	fi
 }
 
-Documenter=https://github.com/JuliaDocs/Documenter.jl/archive/v0.23.0.tar.gz
+Documenter=https://github.com/JuliaDocs/Documenter.jl/archive/v0.24.4.tar.gz
 foobar Documenter $Documenter
 
 JSON=https://github.com/JuliaIO/JSON.jl/archive/v0.21.0.tar.gz
diff -pruN 1.3.1+dfsg-1/debian/julia-common.lintian-overrides 1.4.0+dfsg-1/debian/julia-common.lintian-overrides
--- 1.3.1+dfsg-1/debian/julia-common.lintian-overrides	2019-11-28 04:21:06.000000000 +0000
+++ 1.4.0+dfsg-1/debian/julia-common.lintian-overrides	2020-04-16 12:23:06.000000000 +0000
@@ -1,4 +1,2 @@
 # Docs are deliberately put there.
 julia-common: package-contains-documentation-outside-usr-share-doc usr/share/julia/stdlib/*
-# This is false-positive
-julia-common: wrong-path-for-interpreter
diff -pruN 1.3.1+dfsg-1/debian/libjulia1.lintian-overrides 1.4.0+dfsg-1/debian/libjulia1.lintian-overrides
--- 1.3.1+dfsg-1/debian/libjulia1.lintian-overrides	2019-11-28 08:23:09.000000000 +0000
+++ 1.4.0+dfsg-1/debian/libjulia1.lintian-overrides	2020-04-16 12:23:34.000000000 +0000
@@ -1,7 +1,5 @@
 # Deliberately keeping debug info https://github.com/JuliaLang/julia/issues/23115#issuecomment-320715030
 libjulia1: unstripped-binary-or-object usr/lib/*/julia/sys.so
-# Deliberately keeping debug info https://github.com/JuliaLang/julia/issues/23115#issuecomment-320715030
-libjulia1: unstripped-binary-or-object usr/lib/*/libjulia.so.*
 
 libjulia1: shared-lib-without-dependency-information usr/lib/*/julia/libsuitesparse_wrapper.so
 
diff -pruN 1.3.1+dfsg-1/debian/libjulia1.symbols 1.4.0+dfsg-1/debian/libjulia1.symbols
--- 1.3.1+dfsg-1/debian/libjulia1.symbols	2019-11-29 05:15:51.000000000 +0000
+++ 1.4.0+dfsg-1/debian/libjulia1.symbols	2020-04-16 12:26:12.000000000 +0000
@@ -1,4 +1,5 @@
 libjulia.so.1 libjulia1 #MINVER#
+* Build-Depends-Package: libjulia-dev
  LLVMExtraAddAllocOptPass@Base 1.2.0~rc2
  LLVMExtraAddBarrierNoopPass@Base 1.2.0~rc2
  LLVMExtraAddCombineMulAddPass@Base 1.2.0~rc2
@@ -14,7 +15,6 @@ libjulia.so.1 libjulia1 #MINVER#
  LLVMExtraAddPass@Base 0.7.0~beta2
  LLVMExtraAddPropagateJuliaAddrspaces@Base 1.2.0~rc2
  LLVMExtraAddTargetLibraryInfoByTiple@Base 0.7.0~beta2
- LLVMExtraCreateBasicBlockPass@Base 0.7.0~beta2
  LLVMExtraCreateFunctionPass@Base 0.7.0~beta2
  LLVMExtraCreateModulePass@Base 0.7.0~beta2
  LLVMExtraGetDebugMDVersion@Base 0.7.0~beta2
@@ -142,7 +142,6 @@ libjulia.so.1 libjulia1 #MINVER#
  jl_array_rank@Base 0.6.3
  jl_array_size@Base 0.6.3
  jl_array_sizehint@Base 0.6.3
- jl_array_store_unboxed@Base 0.7.0~beta2
  jl_array_symbol_type@Base 0.6.3
  jl_array_to_string@Base 0.6.3
  jl_array_type@Base 0.6.3
@@ -292,12 +291,14 @@ libjulia.so.1 libjulia1 #MINVER#
  jl_exit@Base 0.6.3
  jl_exit_on_sigint@Base 0.6.3
  jl_expand@Base 0.6.3
+ jl_expand_and_resolve@Base 1.4.0
  jl_expand_stmt@Base 0.7.0~beta2
  jl_expand_stmt_with_loc@Base 1.2.0~rc2
  jl_expand_with_loc@Base 1.2.0~rc2
  jl_expr_type@Base 0.6.3
  jl_extern_c@Base 0.6.3
  jl_f__apply@Base 0.6.3
+ jl_f__apply_iterate@Base 1.4.0
  jl_f__apply_latest@Base 0.6.3
  jl_f__apply_pure@Base 0.6.3
  jl_f__expr@Base 0.6.3
@@ -396,8 +397,10 @@ libjulia.so.1 libjulia1 #MINVER#
  jl_gc_enable_finalizers@Base 0.6.3
  jl_gc_external_obj_hdr_size@Base 1.1.0+dfsg
  jl_gc_find_taggedvalue_pool@Base 0.6.3
+ jl_gc_get_total_bytes@Base 1.4.0
  jl_gc_internal_obj_base_ptr@Base 1.1.0+dfsg
  jl_gc_is_enabled@Base 0.6.3
+ jl_gc_live_bytes@Base 1.4.0
  jl_gc_managed_malloc@Base 0.6.3
  jl_gc_managed_realloc@Base 0.6.3
  jl_gc_mark_queue_obj@Base 1.1.0+dfsg
@@ -407,6 +410,7 @@ libjulia.so.1 libjulia1 #MINVER#
  jl_gc_new_weakref_th@Base 0.6.3
  jl_gc_num@Base 0.6.3
  jl_gc_pool_alloc@Base 0.6.3
+ jl_gc_queue_multiroot@Base 1.4.0
  jl_gc_queue_root@Base 0.6.3
  jl_gc_safe_enter@Base 0.6.3
  jl_gc_safe_leave@Base 0.6.3
@@ -418,7 +422,6 @@ libjulia.so.1 libjulia1 #MINVER#
  jl_gc_set_cb_pre_gc@Base 1.1.0+dfsg
  jl_gc_set_cb_root_scanner@Base 1.1.0+dfsg
  jl_gc_set_cb_task_scanner@Base 1.1.0+dfsg
- jl_gc_total_bytes@Base 0.6.3
  jl_gc_total_hrtime@Base 0.6.3
  jl_gc_unsafe_enter@Base 0.6.3
  jl_gc_unsafe_leave@Base 0.6.3
@@ -439,7 +442,6 @@ libjulia.so.1 libjulia1 #MINVER#
  jl_get_cpu_name@Base 0.6.3
  jl_get_current_task@Base 0.6.3
  jl_get_default_sysimg_path@Base 0.6.3
- jl_get_dobj_data@Base 0.6.3
  jl_get_excstack@Base 1.1.0+dfsg
  jl_get_fenv_consts@Base 0.6.3
  jl_get_field@Base 0.6.3
@@ -463,7 +465,6 @@ libjulia.so.1 libjulia1 #MINVER#
  jl_get_nth_field_noalloc@Base 0.7.0~beta2
  jl_get_ptls_states@Base 0.6.3
  jl_get_root_symbol@Base 0.6.3
- jl_get_section_start@Base 0.6.3
  jl_get_size@Base 0.6.3
  jl_get_spec_lambda@Base 0.6.3
  jl_get_task_tid@Base 1.2.0~rc2
@@ -520,12 +521,10 @@ libjulia.so.1 libjulia1 #MINVER#
  jl_is_char_signed@Base 0.6.3
  jl_is_const@Base 0.6.3
  jl_is_debugbuild@Base 0.6.3
- jl_is_enter_interpreter_frame@Base 0.7.0~beta2
  jl_is_identifier@Base 0.7.0~beta2
  jl_is_imported@Base 0.6.3
  jl_is_in_pure_context@Base 0.6.3
  jl_is_initialized@Base 0.6.3
- jl_is_interpreter_frame@Base 0.7.0~beta2
  jl_is_memdebug@Base 0.6.3
  jl_is_not_broken_subtype@Base 0.7.0~beta2
  jl_is_operator@Base 0.6.3
@@ -682,7 +681,6 @@ libjulia.so.1 libjulia1 #MINVER#
  jl_rettype_inferred@Base 1.2.0~rc2
  jl_rint_llvm@Base 0.6.3
  jl_rint_llvm_withtype@Base 0.6.3
- jl_run_once@Base 0.6.3
  jl_running_on_valgrind@Base 0.6.3
  jl_safe_printf@Base 0.6.3
  jl_save_incremental@Base 0.6.3
@@ -733,6 +731,8 @@ libjulia.so.1 libjulia1 #MINVER#
  jl_specializations_get_linfo@Base 0.6.3
  jl_specializations_lookup@Base 0.6.3
  jl_sqrt_llvm@Base 0.6.3
+ jl_sqrt_llvm_fast@Base 1.4.0
+ jl_sqrt_llvm_fast_withtype@Base 1.4.0
  jl_sqrt_llvm_withtype@Base 0.6.3
  jl_srem_int@Base 0.6.3
  jl_ssavalue_type@Base 0.6.3
@@ -757,6 +757,7 @@ libjulia.so.1 libjulia1 #MINVER#
  jl_stdin_stream@Base 0.6.3
  jl_stdout_obj@Base 0.6.3
  jl_stdout_stream@Base 0.6.3
+ jl_stored_inline@Base 1.4.0
  jl_string_ptr@Base 0.6.3
  jl_string_to_array@Base 0.6.3
  jl_string_type@Base 0.6.3
@@ -877,6 +878,7 @@ libjulia.so.1 libjulia1 #MINVER#
  jl_uv_connect_handle@Base 0.6.3
  jl_uv_disassociate_julia_struct@Base 0.6.3
  jl_uv_file_handle@Base 0.6.3
+ jl_uv_flush@Base 1.4.0
  jl_uv_fs_t_path@Base 1.2.0~rc2
  jl_uv_fs_t_ptr@Base 0.6.3
  jl_uv_handle@Base 0.6.3
diff -pruN 1.3.1+dfsg-1/debian/patches/do-not-download-llvm.patch 1.4.0+dfsg-1/debian/patches/do-not-download-llvm.patch
--- 1.3.1+dfsg-1/debian/patches/do-not-download-llvm.patch	2019-11-28 04:21:24.000000000 +0000
+++ 1.4.0+dfsg-1/debian/patches/do-not-download-llvm.patch	2020-03-30 16:16:05.000000000 +0000
@@ -1,11 +1,20 @@
 --- a/deps/llvm.mk
 +++ b/deps/llvm.mk
-@@ -171,7 +171,7 @@
- LLVM_CMAKE += -DLLVM_TOOL_LLDB_BUILD=OFF
- endif
- 
+@@ -185,13 +185,16 @@
+ ifeq ($(shell [ x"$(LLVM_VER)" = x"8.0.1" ]; echo $$?),0)
+ LLVM_SRC_URL := https://github.com/llvm/llvm-project/releases/download/llvmorg-$(LLVM_VER)
+ else
 -LLVM_SRC_URL := http://releases.llvm.org/$(LLVM_VER)
 +LLVM_SRC_URL := file://$(shell pwd)/../debian/embedded/$(LLVM_VER)
+ endif
+ else
+ LLVM_VER_SPLIT := $(subst rc, ,$(LLVM_VER))
+ LLVM_SRC_URL := https://prereleases.llvm.org/$(word 1,$(LLVM_VER_SPLIT))/rc$(word 2,$(LLVM_VER_SPLIT))
+ endif
  
++
++
++
  ifneq ($(LLVM_CLANG_TAR),)
  $(LLVM_CLANG_TAR): | $(SRCCACHE)
+ 	$(JLDOWNLOAD) $@ $(LLVM_SRC_URL)/$(notdir $@)
diff -pruN 1.3.1+dfsg-1/debian/patches/do-not-download-pkgjl.patch 1.4.0+dfsg-1/debian/patches/do-not-download-pkgjl.patch
--- 1.3.1+dfsg-1/debian/patches/do-not-download-pkgjl.patch	2019-11-28 04:21:06.000000000 +0000
+++ 1.4.0+dfsg-1/debian/patches/do-not-download-pkgjl.patch	2020-03-30 16:16:05.000000000 +0000
@@ -3,13 +3,12 @@ Forward: no need
 Author: Mo Zhou
 --- a/stdlib/Makefile
 +++ b/stdlib/Makefile
-@@ -20,7 +20,8 @@
-           SharedArrays Sockets SparseArrays Statistics SuiteSparse Test Unicode UUIDs
- STDLIBS_EXT = Pkg
+@@ -20,7 +20,7 @@
+           SharedArrays Sockets SparseArrays SuiteSparse Test Unicode UUIDs
+ STDLIBS_EXT = Pkg Statistics
  PKG_GIT_URL := git://github.com/JuliaLang/Pkg.jl.git
 -PKG_TAR_URL = https://api.github.com/repos/JuliaLang/Pkg.jl/tarball/$1
 +PKG_TAR_URL = file://$(CURDIR)/../debian/embedded/$1
-+
- 
- $(foreach module, $(STDLIBS_EXT), $(eval $(call stdlib-external,$(module),$(shell echo $(module) | tr a-z A-Z))))
+ STATISTICS_GIT_URL := git://github.com/JuliaLang/Statistics.jl.git
+ STATISTICS_TAR_URL = https://api.github.com/repos/JuliaLang/Statistics.jl/tarball/$1
  
diff -pruN 1.3.1+dfsg-1/debian/patches/do-not-download-statisticsjl.patch 1.4.0+dfsg-1/debian/patches/do-not-download-statisticsjl.patch
--- 1.3.1+dfsg-1/debian/patches/do-not-download-statisticsjl.patch	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/debian/patches/do-not-download-statisticsjl.patch	2020-04-02 06:58:02.000000000 +0000
@@ -0,0 +1,11 @@
+--- a/stdlib/Makefile
++++ b/stdlib/Makefile
+@@ -22,7 +22,7 @@
+ PKG_GIT_URL := git://github.com/JuliaLang/Pkg.jl.git
+ PKG_TAR_URL = file://$(CURDIR)/../debian/embedded/$1
+ STATISTICS_GIT_URL := git://github.com/JuliaLang/Statistics.jl.git
+-STATISTICS_TAR_URL = https://api.github.com/repos/JuliaLang/Statistics.jl/tarball/$1
++STATISTICS_TAR_URL = file://$(CURDIR)/../debian/embedded/$1
+ 
+ $(foreach module, $(STDLIBS_EXT), $(eval $(call stdlib-external,$(module),$(shell echo $(module) | tr a-z A-Z))))
+ 
diff -pruN 1.3.1+dfsg-1/debian/patches/mask-failing-tests.patch 1.4.0+dfsg-1/debian/patches/mask-failing-tests.patch
--- 1.3.1+dfsg-1/debian/patches/mask-failing-tests.patch	2019-11-28 04:21:22.000000000 +0000
+++ 1.4.0+dfsg-1/debian/patches/mask-failing-tests.patch	2020-03-30 16:16:05.000000000 +0000
@@ -1,6 +1,6 @@
 --- a/test/offsetarray.jl
 +++ b/test/offsetarray.jl
-@@ -474,8 +474,8 @@
+@@ -502,8 +502,8 @@
  
  @test rotl90(A) == OffsetArray(rotl90(parent(A)), A.offsets[[2,1]])
  @test rotr90(A) == OffsetArray(rotr90(parent(A)), A.offsets[[2,1]])
diff -pruN 1.3.1+dfsg-1/debian/patches/mask-tests-1.2.0.patch 1.4.0+dfsg-1/debian/patches/mask-tests-1.2.0.patch
--- 1.3.1+dfsg-1/debian/patches/mask-tests-1.2.0.patch	2019-11-28 04:21:26.000000000 +0000
+++ 1.4.0+dfsg-1/debian/patches/mask-tests-1.2.0.patch	2020-03-30 16:16:05.000000000 +0000
@@ -1,6 +1,6 @@
 --- a/test/file.jl
 +++ b/test/file.jl
-@@ -428,8 +428,9 @@
+@@ -460,8 +460,9 @@
          @test stat(file).gid == 0
          @test stat(file).uid == 0
      else
diff -pruN 1.3.1+dfsg-1/debian/patches/openblas037.patch 1.4.0+dfsg-1/debian/patches/openblas037.patch
--- 1.3.1+dfsg-1/debian/patches/openblas037.patch	2019-11-28 04:21:24.000000000 +0000
+++ 1.4.0+dfsg-1/debian/patches/openblas037.patch	2020-03-30 16:16:05.000000000 +0000
@@ -17,4 +17,4 @@ Description: we use openblas 0.3.7 becau
 -		patch -p1 -f < $(SRCDIR)/patches/openblas-skylakexdgemm.patch
  	echo 1 > $@
  
- $(BUILDDIR)/$(OPENBLAS_SRC_DIR)/build-configured: $(BUILDDIR)/$(OPENBLAS_SRC_DIR)/openblas-skylakexdgemm.patch-applied
+ $(BUILDDIR)/$(OPENBLAS_SRC_DIR)/openblas-winexit.patch-applied: $(BUILDDIR)/$(OPENBLAS_SRC_DIR)/source-extracted
diff -pruN 1.3.1+dfsg-1/debian/patches/openblas-skip-patch.patch 1.4.0+dfsg-1/debian/patches/openblas-skip-patch.patch
--- 1.3.1+dfsg-1/debian/patches/openblas-skip-patch.patch	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/debian/patches/openblas-skip-patch.patch	2020-04-02 06:58:02.000000000 +0000
@@ -0,0 +1,13 @@
+--- a/deps/blas.mk
++++ b/deps/blas.mk
+@@ -98,8 +98,8 @@
+ 	echo 1 > $@
+ 
+ $(BUILDDIR)/$(OPENBLAS_SRC_DIR)/openblas-winexit.patch-applied: $(BUILDDIR)/$(OPENBLAS_SRC_DIR)/source-extracted
+-	cd $(BUILDDIR)/$(OPENBLAS_SRC_DIR) && \
+-		patch -p1 -f < $(SRCDIR)/patches/openblas-winexit.patch
++	#cd $(BUILDDIR)/$(OPENBLAS_SRC_DIR) && \
++	#	patch -p1 -f < $(SRCDIR)/patches/openblas-winexit.patch
+ 	echo 1 > $@
+ 
+ $(BUILDDIR)/$(OPENBLAS_SRC_DIR)/build-configured: $(BUILDDIR)/$(OPENBLAS_SRC_DIR)/openblas-skylakexdgemm.patch-applied $(BUILDDIR)/$(OPENBLAS_SRC_DIR)/openblas-winexit.patch-applied
diff -pruN 1.3.1+dfsg-1/debian/patches/require-sse2-on-i386.patch 1.4.0+dfsg-1/debian/patches/require-sse2-on-i386.patch
--- 1.3.1+dfsg-1/debian/patches/require-sse2-on-i386.patch	2019-11-28 04:21:22.000000000 +0000
+++ 1.4.0+dfsg-1/debian/patches/require-sse2-on-i386.patch	2020-03-30 16:16:05.000000000 +0000
@@ -22,7 +22,7 @@ This patch header follows DEP-3: http://
  #include <string>
  #include <sstream>
  #include <fstream>
-@@ -7629,6 +7632,15 @@
+@@ -7765,6 +7768,15 @@
  
  extern "C" void *jl_init_llvm(void)
  {
diff -pruN 1.3.1+dfsg-1/debian/patches/series 1.4.0+dfsg-1/debian/patches/series
--- 1.3.1+dfsg-1/debian/patches/series	2019-11-28 04:21:06.000000000 +0000
+++ 1.4.0+dfsg-1/debian/patches/series	2020-04-02 06:58:02.000000000 +0000
@@ -7,6 +7,7 @@ no-debug-version.patch
 do-not-download-libuv.patch
 do-not-download-libwhich.patch
 do-not-download-pkgjl.patch
+do-not-download-statisticsjl.patch
 do-not-download-llvm.patch
 do-not-download-openblas.patch
 openblas037.patch
@@ -28,3 +29,4 @@ test-skip-dns-ubuntu.patch
 
 mask-tests-1.2.0.patch
 arm64-openblas.patch
+openblas-skip-patch.patch
diff -pruN 1.3.1+dfsg-1/debian/patches/support-noopt.patch 1.4.0+dfsg-1/debian/patches/support-noopt.patch
--- 1.3.1+dfsg-1/debian/patches/support-noopt.patch	2019-11-28 04:21:22.000000000 +0000
+++ 1.4.0+dfsg-1/debian/patches/support-noopt.patch	2020-03-30 16:16:05.000000000 +0000
@@ -33,12 +33,12 @@ This patch header follows DEP-3: http://
  
 --- a/src/Makefile
 +++ b/src/Makefile
-@@ -150,7 +150,7 @@
- $(BUILDDIR)/%.dbg.obj: $(SRCDIR)/%.c $(HEADERS) | $(BUILDDIR)
- 	@$(call PRINT_CC, $(CC) $(JCPPFLAGS) $(JCFLAGS) $(DEBUGFLAGS) -c $< -o $@)
- $(BUILDDIR)/%.o: $(SRCDIR)/%.cpp $(SRCDIR)/llvm-version.h $(HEADERS) $(LLVM_CONFIG_ABSOLUTE) | $(BUILDDIR)
--	@$(call PRINT_CC, $(CXX) $(shell $(LLVM_CONFIG_HOST) --cxxflags) $(JCPPFLAGS) $(JCXXFLAGS) $(SHIPFLAGS) $(CXX_DISABLE_ASSERTION) -c $< -o $@)
-+	@$(call PRINT_CC, $(CXX) $(shell $(LLVM_CONFIG_HOST) --cxxflags | sed 's/^/ /;s/$$/ /;s/\s-O.\s/ /') $(JCPPFLAGS) $(JCXXFLAGS) $(SHIPFLAGS) $(CXX_DISABLE_ASSERTION) -c $< -o $@)
- $(BUILDDIR)/%.dbg.obj: $(SRCDIR)/%.cpp $(SRCDIR)/llvm-version.h $(HEADERS) $(LLVM_CONFIG_ABSOLUTE) | $(BUILDDIR)
- 	@$(call PRINT_CC, $(CXX) $(shell $(LLVM_CONFIG_HOST) --cxxflags) $(JCPPFLAGS) $(JCXXFLAGS) $(DEBUGFLAGS) -c $< -o $@)
+@@ -95,7 +95,7 @@
+ PUBLIC_HEADER_TARGETS := $(addprefix $(build_includedir)/julia/,$(notdir $(PUBLIC_HEADERS)) $(UV_HEADERS))
  
+ LLVM_LDFLAGS := $(shell $(LLVM_CONFIG_HOST) --ldflags)
+-LLVM_CXXFLAGS := $(shell $(LLVM_CONFIG_HOST) --cxxflags)
++LLVM_CXXFLAGS := $(shell $(LLVM_CONFIG_HOST) --cxxflags | sed 's/^/ /;s/$$/ /;s/\s-O.\s/ /')
+ 
+ ifeq ($(JULIACODEGEN),LLVM)
+ ifneq ($(USE_SYSTEM_LLVM),0)
diff -pruN 1.3.1+dfsg-1/debian/patches/test-skip-dns-ubuntu.patch 1.4.0+dfsg-1/debian/patches/test-skip-dns-ubuntu.patch
--- 1.3.1+dfsg-1/debian/patches/test-skip-dns-ubuntu.patch	2019-11-28 04:21:25.000000000 +0000
+++ 1.4.0+dfsg-1/debian/patches/test-skip-dns-ubuntu.patch	2020-03-30 16:16:05.000000000 +0000
@@ -4,7 +4,7 @@ Last-Update: 2018-10-01
 
 --- a/stdlib/Sockets/test/runtests.jl
 +++ b/stdlib/Sockets/test/runtests.jl
-@@ -163,25 +163,25 @@
+@@ -183,25 +183,25 @@
  end
  
  @testset "getnameinfo on some unroutable IP addresses (RFC 5737)" begin
diff -pruN 1.3.1+dfsg-1/debian/shlibdeps.mk 1.4.0+dfsg-1/debian/shlibdeps.mk
--- 1.3.1+dfsg-1/debian/shlibdeps.mk	2019-11-28 04:21:06.000000000 +0000
+++ 1.4.0+dfsg-1/debian/shlibdeps.mk	2020-04-08 15:46:26.000000000 +0000
@@ -86,7 +86,10 @@ SHLIBDEPS += -lutf8proc
 endif
 
 # Append other libraries
-SHLIBDEPS += -lquadmath -lgcc_s -lgfortran
+ifneq (,$(filter $(DEB_HOST_ARCH),amd64 ia64 i386 x32 hurd-i386 kfreebsd-i386 kfreebsd-amd64 ppc64el))
+SHLIBDEPS += -lquadmath
+endif
+SHLIBDEPS += -lgcc_s -lgfortran
 
 # The dummy executable is linked with --no-as-needed to prevent
 # the linker from potentially disregarding the given libraries
diff -pruN 1.3.1+dfsg-1/debian/source/include-binaries 1.4.0+dfsg-1/debian/source/include-binaries
--- 1.3.1+dfsg-1/debian/source/include-binaries	2019-12-31 04:28:43.000000000 +0000
+++ 1.4.0+dfsg-1/debian/source/include-binaries	2020-04-16 12:21:29.000000000 +0000
@@ -1,21 +1,4 @@
-debian/embedded/libuv-ed3700c849289ed01fe04273a7bf865340b2bd7e.tar.gz
 debian/embedded/libwhich-81e9723c0273d78493dc8c8ed570f68d9ce7e89e.tar.gz
-debian/embedded/1609a05aee5d5960670738d8d834d91235bd6b1e
-debian/embedded/Documenter.jl-0.20.0/docs/src/man/hosting/puttygen-generated.png
-debian/embedded/Documenter.jl-0.20.0/docs/src/man/hosting/puttygen-export-private-key.png
-debian/embedded/Documenter.jl-0.20.0/docs/src/man/hosting/puttygen.png
-debian/embedded/Documenter.jl-0.20.0/docs/src/man/hosting/travis-variables.png
-debian/embedded/Documenter.jl-0.20.0/docs/src/man/hosting/github-add-deploy-key.png
-debian/embedded/Documenter.jl-0.20.0/docs/src/assets/favicon.ico
-debian/embedded/Documenter.jl-0.20.0/docs/src/assets/logo.png
-debian/embedded/Documenter.jl-0.20.0/test/examples/src/assets/favicon.ico
-debian/embedded/Documenter.jl-0.20.0/test/examples/images/logo.jpg
-debian/embedded/Documenter.jl-0.20.0/test/examples/images/logo.webp
-debian/embedded/Documenter.jl-0.20.0/test/examples/images/logo.gif
-debian/embedded/Documenter.jl-0.20.0/test/examples/images/logo.png
-debian/embedded/DocStringExtensions.jl-0.5.0/docs/src/assets/logo.png
-debian/embedded/libuv-2348256acf5759a544e5ca7935f638d2bc091d60.tar.gz
-debian/embedded/40cbbe224d4a491503279dfc5b9aefe15412f007
 debian/embedded/Documenter/test/examples/images/logo.gif
 debian/embedded/Documenter/test/examples/images/logo.jpg
 debian/embedded/Documenter/test/examples/images/logo.webp
@@ -28,12 +11,9 @@ debian/embedded/Documenter/docs/src/man/
 debian/embedded/Documenter/docs/src/man/hosting/puttygen.png
 debian/embedded/Documenter/docs/src/assets/favicon.ico
 debian/embedded/DocStringExtensions/docs/src/assets/favicon.ico
-debian/embedded/394e7c5d55d3722f5b2ab660ca0a694ea0041974
 debian/embedded/SuiteSparse-5.4.0.tar.gz
-debian/embedded/openblas-eebc18928715775c9ed254684edee16e4efe0342.tar.gz
-debian/embedded/eebc18928715775c9ed254684edee16e4efe0342
 debian/embedded/6a79b36d1bf73584a513139806d226f9189d621e
 debian/embedded/openblas-6a79b36d1bf73584a513139806d226f9189d621e.tar.gz
 debian/embedded/libuv-35b1504507a7a4168caae3d78db54d1121b121e1.tar.gz
-debian/embedded/5de608c7b1837a24ed84eaaa14dde017986cb460
-debian/embedded/f71e2c5a119b9c850f9b357fc8c56068f5b51cc0
+debian/embedded/9419c70af69153cd5c4276bff90fbb135e0aa3f1
+debian/embedded/a2203d3b67f7413701be5de251622cb85c9cc69d
diff -pruN 1.3.1+dfsg-1/deps/blas.mk 1.4.0+dfsg-1/deps/blas.mk
--- 1.3.1+dfsg-1/deps/blas.mk	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/blas.mk	2020-03-21 16:36:32.000000000 +0000
@@ -99,7 +99,12 @@ $(BUILDDIR)/$(OPENBLAS_SRC_DIR)/openblas
 		patch -p1 -f < $(SRCDIR)/patches/openblas-skylakexdgemm.patch
 	echo 1 > $@
 
-$(BUILDDIR)/$(OPENBLAS_SRC_DIR)/build-configured: $(BUILDDIR)/$(OPENBLAS_SRC_DIR)/openblas-skylakexdgemm.patch-applied
+$(BUILDDIR)/$(OPENBLAS_SRC_DIR)/openblas-winexit.patch-applied: $(BUILDDIR)/$(OPENBLAS_SRC_DIR)/source-extracted
+	cd $(BUILDDIR)/$(OPENBLAS_SRC_DIR) && \
+		patch -p1 -f < $(SRCDIR)/patches/openblas-winexit.patch
+	echo 1 > $@
+
+$(BUILDDIR)/$(OPENBLAS_SRC_DIR)/build-configured: $(BUILDDIR)/$(OPENBLAS_SRC_DIR)/openblas-skylakexdgemm.patch-applied $(BUILDDIR)/$(OPENBLAS_SRC_DIR)/openblas-winexit.patch-applied
 	echo 1 > $@
 
 $(BUILDDIR)/$(OPENBLAS_SRC_DIR)/build-compiled: $(BUILDDIR)/$(OPENBLAS_SRC_DIR)/build-configured
@@ -204,7 +209,7 @@ check-lapack: $(BUILDDIR)/lapack-$(LAPAC
 else # USE_BINARYBUILDER_OPENBLAS
 
 
-OPENBLAS_BB_URL_BASE := https://github.com/JuliaPackaging/Yggdrasil/releases/download/OpenBLAS-v$(OPENBLAS_VER)-$(OPENBLAS_BB_REL)
+OPENBLAS_BB_URL_BASE := https://github.com/JuliaBinaryWrappers/OpenBLAS_jll.jl/releases/download/OpenBLAS-v$(OPENBLAS_VER)+$(OPENBLAS_BB_REL)
 OPENBLAS_BB_NAME := OpenBLAS.v$(OPENBLAS_VER)
 
 $(eval $(call bb-install,openblas,OPENBLAS,true))
diff -pruN 1.3.1+dfsg-1/deps/checksums/cacert-2019-10-16.pem/md5 1.4.0+dfsg-1/deps/checksums/cacert-2019-10-16.pem/md5
--- 1.3.1+dfsg-1/deps/checksums/cacert-2019-10-16.pem/md5	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/cacert-2019-10-16.pem/md5	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-5805059ab9e4646e4803ce1e007eb8ba
diff -pruN 1.3.1+dfsg-1/deps/checksums/cacert-2019-10-16.pem/sha512 1.4.0+dfsg-1/deps/checksums/cacert-2019-10-16.pem/sha512
--- 1.3.1+dfsg-1/deps/checksums/cacert-2019-10-16.pem/sha512	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/cacert-2019-10-16.pem/sha512	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-49778472e46ce3b86b3930f4df5731ac86daf4d8602d418af1c89dc35df5f98c4557aa6c6eb280558c61139ead4b96cbb457a259f72640452f28a2fecd4ccb89
diff -pruN 1.3.1+dfsg-1/deps/checksums/cacert-2020-01-01.pem/md5 1.4.0+dfsg-1/deps/checksums/cacert-2020-01-01.pem/md5
--- 1.3.1+dfsg-1/deps/checksums/cacert-2020-01-01.pem/md5	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/cacert-2020-01-01.pem/md5	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+c726ae88fd600aa26df1d30f42b51fec
diff -pruN 1.3.1+dfsg-1/deps/checksums/cacert-2020-01-01.pem/sha512 1.4.0+dfsg-1/deps/checksums/cacert-2020-01-01.pem/sha512
--- 1.3.1+dfsg-1/deps/checksums/cacert-2020-01-01.pem/sha512	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/cacert-2020-01-01.pem/sha512	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+cc129ae1a4377a43a74b0854b6eccb2b315cdfce018142d1dd5524fb64c8945cde067cb18f366351fa7d6af3f9f36cf21bc1f626f987f9e4627878472ea59cde
diff -pruN 1.3.1+dfsg-1/deps/checksums/curl-7.66.0.tar.bz2/md5 1.4.0+dfsg-1/deps/checksums/curl-7.66.0.tar.bz2/md5
--- 1.3.1+dfsg-1/deps/checksums/curl-7.66.0.tar.bz2/md5	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/curl-7.66.0.tar.bz2/md5	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+c238aa394e3aa47ca4fcb0491774149f
diff -pruN 1.3.1+dfsg-1/deps/checksums/curl-7.66.0.tar.bz2/sha512 1.4.0+dfsg-1/deps/checksums/curl-7.66.0.tar.bz2/sha512
--- 1.3.1+dfsg-1/deps/checksums/curl-7.66.0.tar.bz2/sha512	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/curl-7.66.0.tar.bz2/sha512	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+dd4bebd7f1ede8843dc7416b7d172c361f7e5170a963a40cc8187e7cfdfc4c99849cc2885252dd0a8ac35cf1af4133eb21cce05044c8b116a8ed1597ead67323
diff -pruN 1.3.1+dfsg-1/deps/checksums/GMP.v6.1.2-3.aarch64-linux-gnu.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/GMP.v6.1.2-3.aarch64-linux-gnu.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/GMP.v6.1.2-3.aarch64-linux-gnu.tar.gz/md5	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/GMP.v6.1.2-3.aarch64-linux-gnu.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-ed06ab3d41f85e837cd605bc3fad476b
diff -pruN 1.3.1+dfsg-1/deps/checksums/GMP.v6.1.2-3.aarch64-linux-gnu.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/GMP.v6.1.2-3.aarch64-linux-gnu.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/GMP.v6.1.2-3.aarch64-linux-gnu.tar.gz/sha512	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/GMP.v6.1.2-3.aarch64-linux-gnu.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-8b04b36670d77e4a4f281c7587b3d878449ec8b7a07cd86f41a4e594f8428b4587659be0ecef59ff065bc9c6ba607bf03158a082b4ce2cb4c0c9e74411295106
diff -pruN 1.3.1+dfsg-1/deps/checksums/GMP.v6.1.2-3.aarch64-linux-musl.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/GMP.v6.1.2-3.aarch64-linux-musl.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/GMP.v6.1.2-3.aarch64-linux-musl.tar.gz/md5	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/GMP.v6.1.2-3.aarch64-linux-musl.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-5041b7635c6f1fc50b66f67075cda4c3
diff -pruN 1.3.1+dfsg-1/deps/checksums/GMP.v6.1.2-3.aarch64-linux-musl.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/GMP.v6.1.2-3.aarch64-linux-musl.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/GMP.v6.1.2-3.aarch64-linux-musl.tar.gz/sha512	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/GMP.v6.1.2-3.aarch64-linux-musl.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-f90edfec0792379c35129ca5b38d987455522da64ef2dd6ff624c8c271f04868f3f816b8c23f07b705af025119708005990e93bc3018952aa5c38b4365e01a5a
diff -pruN 1.3.1+dfsg-1/deps/checksums/GMP.v6.1.2-3.arm-linux-gnueabihf.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/GMP.v6.1.2-3.arm-linux-gnueabihf.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/GMP.v6.1.2-3.arm-linux-gnueabihf.tar.gz/md5	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/GMP.v6.1.2-3.arm-linux-gnueabihf.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-9da15965b743ecdd869ac374ed7dee72
diff -pruN 1.3.1+dfsg-1/deps/checksums/GMP.v6.1.2-3.arm-linux-gnueabihf.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/GMP.v6.1.2-3.arm-linux-gnueabihf.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/GMP.v6.1.2-3.arm-linux-gnueabihf.tar.gz/sha512	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/GMP.v6.1.2-3.arm-linux-gnueabihf.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-1a2915d7e5e0a624f2053c16df3daba567f45e1fca0e19ab81535856e36b83978ead98cd72e6212fb6bc293b409f5674cb8ea8b3369a35b825a2ac3aac57494a
diff -pruN 1.3.1+dfsg-1/deps/checksums/GMP.v6.1.2-3.arm-linux-musleabihf.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/GMP.v6.1.2-3.arm-linux-musleabihf.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/GMP.v6.1.2-3.arm-linux-musleabihf.tar.gz/md5	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/GMP.v6.1.2-3.arm-linux-musleabihf.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-e073ec5a73eaad5a70660fd75a41781d
diff -pruN 1.3.1+dfsg-1/deps/checksums/GMP.v6.1.2-3.arm-linux-musleabihf.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/GMP.v6.1.2-3.arm-linux-musleabihf.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/GMP.v6.1.2-3.arm-linux-musleabihf.tar.gz/sha512	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/GMP.v6.1.2-3.arm-linux-musleabihf.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-2d0e5b9bf07ffc048306d76f6bb27f1897ec4f6480597fa27ab647f742285f3e5ae5fbc495d9abde63f2b3439dbb41ccf7b0ca395106ee7adb3233d3e43d44b8
diff -pruN 1.3.1+dfsg-1/deps/checksums/GMP.v6.1.2-3.i686-linux-gnu.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/GMP.v6.1.2-3.i686-linux-gnu.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/GMP.v6.1.2-3.i686-linux-gnu.tar.gz/md5	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/GMP.v6.1.2-3.i686-linux-gnu.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-d8908bead56aa3db1dec41c18782e532
diff -pruN 1.3.1+dfsg-1/deps/checksums/GMP.v6.1.2-3.i686-linux-gnu.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/GMP.v6.1.2-3.i686-linux-gnu.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/GMP.v6.1.2-3.i686-linux-gnu.tar.gz/sha512	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/GMP.v6.1.2-3.i686-linux-gnu.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-89da4c61528e51e5bc7293b824cd57fd10fad93757227a5f5a52a1e347f353b91bdcdbcc8591cc0d01c0952d37c03339a107856505cf2a17d25f35328453388c
diff -pruN 1.3.1+dfsg-1/deps/checksums/GMP.v6.1.2-3.i686-linux-musl.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/GMP.v6.1.2-3.i686-linux-musl.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/GMP.v6.1.2-3.i686-linux-musl.tar.gz/md5	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/GMP.v6.1.2-3.i686-linux-musl.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-31564e45dd5fdafe816d29e09402ba79
diff -pruN 1.3.1+dfsg-1/deps/checksums/GMP.v6.1.2-3.i686-linux-musl.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/GMP.v6.1.2-3.i686-linux-musl.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/GMP.v6.1.2-3.i686-linux-musl.tar.gz/sha512	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/GMP.v6.1.2-3.i686-linux-musl.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-a43b13ba05812a9dd9225aca5db39615baebad3ef1510458d3f441519c3253774ed46497f4d65730a24e021440bae19342e4f7e56ed0e956c10e77cf61016040
diff -pruN 1.3.1+dfsg-1/deps/checksums/GMP.v6.1.2-3.i686-w64-mingw32.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/GMP.v6.1.2-3.i686-w64-mingw32.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/GMP.v6.1.2-3.i686-w64-mingw32.tar.gz/md5	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/GMP.v6.1.2-3.i686-w64-mingw32.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-cc730eddb20303e8131dc4b551a48500
diff -pruN 1.3.1+dfsg-1/deps/checksums/GMP.v6.1.2-3.i686-w64-mingw32.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/GMP.v6.1.2-3.i686-w64-mingw32.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/GMP.v6.1.2-3.i686-w64-mingw32.tar.gz/sha512	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/GMP.v6.1.2-3.i686-w64-mingw32.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-e080478a9c40572eac4baec78c0295c5f4b3ca683a3a66fb4dd24a76fc9be92d2de7f0e9409b6e281babc6a1ba3f543d3f0ab7e6b12f67957d43931c74076bf1
diff -pruN 1.3.1+dfsg-1/deps/checksums/GMP.v6.1.2-3.powerpc64le-linux-gnu.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/GMP.v6.1.2-3.powerpc64le-linux-gnu.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/GMP.v6.1.2-3.powerpc64le-linux-gnu.tar.gz/md5	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/GMP.v6.1.2-3.powerpc64le-linux-gnu.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-aeb0300673be0b235737eee73ac8ab4a
diff -pruN 1.3.1+dfsg-1/deps/checksums/GMP.v6.1.2-3.powerpc64le-linux-gnu.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/GMP.v6.1.2-3.powerpc64le-linux-gnu.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/GMP.v6.1.2-3.powerpc64le-linux-gnu.tar.gz/sha512	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/GMP.v6.1.2-3.powerpc64le-linux-gnu.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-85b1504811515525a4d03f5068760138c0c11f66b47b140eac5009f2a18fd413ea8bbd1a9a02253a7ba14bede26317f46f9daf689d36915a6eb7a0a2bb029d44
diff -pruN 1.3.1+dfsg-1/deps/checksums/GMP.v6.1.2-3.x86_64-apple-darwin14.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/GMP.v6.1.2-3.x86_64-apple-darwin14.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/GMP.v6.1.2-3.x86_64-apple-darwin14.tar.gz/md5	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/GMP.v6.1.2-3.x86_64-apple-darwin14.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-d574efeb8dae18a80ebd1ce3e6d4ecc3
diff -pruN 1.3.1+dfsg-1/deps/checksums/GMP.v6.1.2-3.x86_64-apple-darwin14.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/GMP.v6.1.2-3.x86_64-apple-darwin14.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/GMP.v6.1.2-3.x86_64-apple-darwin14.tar.gz/sha512	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/GMP.v6.1.2-3.x86_64-apple-darwin14.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-80e7c6eff9cba0dc871f320d0c570523d6fd53a9bcb3022fa6b75b4ef509872c9d4414fb4d37f9e4138cf2266621aac9bbd4da0a7deeb1ed014be8c37cbc2adb
diff -pruN 1.3.1+dfsg-1/deps/checksums/GMP.v6.1.2-3.x86_64-linux-gnu.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/GMP.v6.1.2-3.x86_64-linux-gnu.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/GMP.v6.1.2-3.x86_64-linux-gnu.tar.gz/md5	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/GMP.v6.1.2-3.x86_64-linux-gnu.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-8b6da6984c1113f21ebbaf8cd5820418
diff -pruN 1.3.1+dfsg-1/deps/checksums/GMP.v6.1.2-3.x86_64-linux-gnu.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/GMP.v6.1.2-3.x86_64-linux-gnu.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/GMP.v6.1.2-3.x86_64-linux-gnu.tar.gz/sha512	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/GMP.v6.1.2-3.x86_64-linux-gnu.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-bcdcbd20b950cc8ca94c2df66b85f3633ca997cfeaf042dfc6093607a2cd16f109b9263c1a83cd1c3e259a8c278cf7ef1cf47805ad762f4e49939cc5f132d75f
diff -pruN 1.3.1+dfsg-1/deps/checksums/GMP.v6.1.2-3.x86_64-linux-musl.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/GMP.v6.1.2-3.x86_64-linux-musl.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/GMP.v6.1.2-3.x86_64-linux-musl.tar.gz/md5	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/GMP.v6.1.2-3.x86_64-linux-musl.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-34894a2ce504f62a02bf05190d5e67c5
diff -pruN 1.3.1+dfsg-1/deps/checksums/GMP.v6.1.2-3.x86_64-linux-musl.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/GMP.v6.1.2-3.x86_64-linux-musl.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/GMP.v6.1.2-3.x86_64-linux-musl.tar.gz/sha512	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/GMP.v6.1.2-3.x86_64-linux-musl.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-df4e5467ecbe8d4b340c8c63a691d5de8edaa8b6cf047bc702a5ae32e1868199bb16661d54a97c205488d6fb0238e0c75984723f23e114b11b2bece022fbb0fe
diff -pruN 1.3.1+dfsg-1/deps/checksums/GMP.v6.1.2-3.x86_64-unknown-freebsd11.1.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/GMP.v6.1.2-3.x86_64-unknown-freebsd11.1.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/GMP.v6.1.2-3.x86_64-unknown-freebsd11.1.tar.gz/md5	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/GMP.v6.1.2-3.x86_64-unknown-freebsd11.1.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-c553733282390fde94c66b38e1a78a15
diff -pruN 1.3.1+dfsg-1/deps/checksums/GMP.v6.1.2-3.x86_64-unknown-freebsd11.1.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/GMP.v6.1.2-3.x86_64-unknown-freebsd11.1.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/GMP.v6.1.2-3.x86_64-unknown-freebsd11.1.tar.gz/sha512	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/GMP.v6.1.2-3.x86_64-unknown-freebsd11.1.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-45647d628299e0cf22bac66afd457d83fdcc8eabef13b3e5c3f2b1b0ae193c4c86cd56921556a0ecacbf6bb9256c24daccf894dbd16929ef6f4387c615f67019
diff -pruN 1.3.1+dfsg-1/deps/checksums/GMP.v6.1.2-3.x86_64-w64-mingw32.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/GMP.v6.1.2-3.x86_64-w64-mingw32.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/GMP.v6.1.2-3.x86_64-w64-mingw32.tar.gz/md5	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/GMP.v6.1.2-3.x86_64-w64-mingw32.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-44ded1fc674258c516768e3036f2ba6b
diff -pruN 1.3.1+dfsg-1/deps/checksums/GMP.v6.1.2-3.x86_64-w64-mingw32.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/GMP.v6.1.2-3.x86_64-w64-mingw32.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/GMP.v6.1.2-3.x86_64-w64-mingw32.tar.gz/sha512	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/GMP.v6.1.2-3.x86_64-w64-mingw32.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-f87d6c4cd0c9e1011d516d88b7f72f38ef29e3342c2c44dc638c24f17d975d5f6ddfac363f1114d2cb476999de7b7675f33998e7ae82e875d9e4c1a1accf23f9
diff -pruN 1.3.1+dfsg-1/deps/checksums/GMP.v6.1.2-4.aarch64-linux-gnu.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/GMP.v6.1.2-4.aarch64-linux-gnu.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/GMP.v6.1.2-4.aarch64-linux-gnu.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/GMP.v6.1.2-4.aarch64-linux-gnu.tar.gz/md5	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+fb8136c2a92d37edcd0ba4ae22352b5c
diff -pruN 1.3.1+dfsg-1/deps/checksums/GMP.v6.1.2-4.aarch64-linux-gnu.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/GMP.v6.1.2-4.aarch64-linux-gnu.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/GMP.v6.1.2-4.aarch64-linux-gnu.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/GMP.v6.1.2-4.aarch64-linux-gnu.tar.gz/sha512	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+9622464c9054371ee1621efe87801259b900e80457aa5cf39d4323e51dec56b7b3527c6fcf9ae74058f2b4db8034a204f71b9a28c02b3975239064261db5c361
diff -pruN 1.3.1+dfsg-1/deps/checksums/GMP.v6.1.2-4.aarch64-linux-musl.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/GMP.v6.1.2-4.aarch64-linux-musl.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/GMP.v6.1.2-4.aarch64-linux-musl.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/GMP.v6.1.2-4.aarch64-linux-musl.tar.gz/md5	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+f7d1f68ba15b3a5e9996cb349d4d5c58
diff -pruN 1.3.1+dfsg-1/deps/checksums/GMP.v6.1.2-4.aarch64-linux-musl.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/GMP.v6.1.2-4.aarch64-linux-musl.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/GMP.v6.1.2-4.aarch64-linux-musl.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/GMP.v6.1.2-4.aarch64-linux-musl.tar.gz/sha512	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+921723c1e71cc80e1dd9f35f4142ca16be030ab1bd7a3c78c73a63be2d0ed80a342e28376bbc074d7203c97bec6e593b386f41ab25fbf22b8942d9d6818edbea
diff -pruN 1.3.1+dfsg-1/deps/checksums/GMP.v6.1.2-4.arm-linux-gnueabihf.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/GMP.v6.1.2-4.arm-linux-gnueabihf.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/GMP.v6.1.2-4.arm-linux-gnueabihf.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/GMP.v6.1.2-4.arm-linux-gnueabihf.tar.gz/md5	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+b7210d1ffa5e517ef0bada8669303fab
diff -pruN 1.3.1+dfsg-1/deps/checksums/GMP.v6.1.2-4.arm-linux-gnueabihf.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/GMP.v6.1.2-4.arm-linux-gnueabihf.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/GMP.v6.1.2-4.arm-linux-gnueabihf.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/GMP.v6.1.2-4.arm-linux-gnueabihf.tar.gz/sha512	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+77be741f35248a4c4fda80d5efb3b7b1b4ca3fd4f0fed9e305794b89bbb88c7baf5d1d57747bb8e0047377bf1ccbb00cba1a61df17d1c58df6a9901ca42eb593
diff -pruN 1.3.1+dfsg-1/deps/checksums/GMP.v6.1.2-4.arm-linux-musleabihf.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/GMP.v6.1.2-4.arm-linux-musleabihf.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/GMP.v6.1.2-4.arm-linux-musleabihf.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/GMP.v6.1.2-4.arm-linux-musleabihf.tar.gz/md5	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+cbd71c0e90e4c92381c79045d9310752
diff -pruN 1.3.1+dfsg-1/deps/checksums/GMP.v6.1.2-4.arm-linux-musleabihf.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/GMP.v6.1.2-4.arm-linux-musleabihf.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/GMP.v6.1.2-4.arm-linux-musleabihf.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/GMP.v6.1.2-4.arm-linux-musleabihf.tar.gz/sha512	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+1a8a622746ad1bc7c6576476d7217e383c72771a8b2b3a3c74e5e9d3b0daec1920f85f556339c95857c16ebeb5d5c79669c900cb4b30f68969b9b57146f53b4c
diff -pruN 1.3.1+dfsg-1/deps/checksums/GMP.v6.1.2-4.i686-linux-gnu.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/GMP.v6.1.2-4.i686-linux-gnu.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/GMP.v6.1.2-4.i686-linux-gnu.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/GMP.v6.1.2-4.i686-linux-gnu.tar.gz/md5	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+96228c26a324e616715ff5116129efbf
diff -pruN 1.3.1+dfsg-1/deps/checksums/GMP.v6.1.2-4.i686-linux-gnu.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/GMP.v6.1.2-4.i686-linux-gnu.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/GMP.v6.1.2-4.i686-linux-gnu.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/GMP.v6.1.2-4.i686-linux-gnu.tar.gz/sha512	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+dda1eed06658ee175868c80dac0dcc4848a2b179fa6226e5899de13492205e6d509180c65d533a132b46fdbcbcaa49a85df627a637336f5b14291ea747350d84
diff -pruN 1.3.1+dfsg-1/deps/checksums/GMP.v6.1.2-4.i686-linux-musl.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/GMP.v6.1.2-4.i686-linux-musl.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/GMP.v6.1.2-4.i686-linux-musl.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/GMP.v6.1.2-4.i686-linux-musl.tar.gz/md5	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+bcb20e336ed586893a2bd1664bd4af96
diff -pruN 1.3.1+dfsg-1/deps/checksums/GMP.v6.1.2-4.i686-linux-musl.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/GMP.v6.1.2-4.i686-linux-musl.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/GMP.v6.1.2-4.i686-linux-musl.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/GMP.v6.1.2-4.i686-linux-musl.tar.gz/sha512	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+e0cfabe7d2b331c3cc693ca50311319737785a087fc84b15f1862c6a60d036dfffed6f4e9a865d0b83fc374cba3b625face165505fd45de78f674bdafb34fbd2
diff -pruN 1.3.1+dfsg-1/deps/checksums/GMP.v6.1.2-4.i686-w64-mingw32.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/GMP.v6.1.2-4.i686-w64-mingw32.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/GMP.v6.1.2-4.i686-w64-mingw32.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/GMP.v6.1.2-4.i686-w64-mingw32.tar.gz/md5	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+df89ac295cf9a17e16357e433fd917a9
diff -pruN 1.3.1+dfsg-1/deps/checksums/GMP.v6.1.2-4.i686-w64-mingw32.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/GMP.v6.1.2-4.i686-w64-mingw32.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/GMP.v6.1.2-4.i686-w64-mingw32.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/GMP.v6.1.2-4.i686-w64-mingw32.tar.gz/sha512	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+856cbaf79376e470ec5be0913a37f4ff06827bb6d06fceb462007375bd8d2b430ff8de938d7f3807a6612ba20d57cddfbb7fa52c94d828d62c678f75c1f5cb31
diff -pruN 1.3.1+dfsg-1/deps/checksums/GMP.v6.1.2-4.powerpc64le-linux-gnu.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/GMP.v6.1.2-4.powerpc64le-linux-gnu.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/GMP.v6.1.2-4.powerpc64le-linux-gnu.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/GMP.v6.1.2-4.powerpc64le-linux-gnu.tar.gz/md5	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+5b232584c835a70ff5d43cfc57ec3438
diff -pruN 1.3.1+dfsg-1/deps/checksums/GMP.v6.1.2-4.powerpc64le-linux-gnu.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/GMP.v6.1.2-4.powerpc64le-linux-gnu.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/GMP.v6.1.2-4.powerpc64le-linux-gnu.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/GMP.v6.1.2-4.powerpc64le-linux-gnu.tar.gz/sha512	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+9ce5e5686bfcb14ca1ae7589cba6beec49215ffa2fe9b179c6afd5300d9da7b5c31133888a29cba923e4d399322b018ffb19d5a2bc096c1577a9e7bc7b8b33de
diff -pruN 1.3.1+dfsg-1/deps/checksums/GMP.v6.1.2-4.x86_64-apple-darwin14.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/GMP.v6.1.2-4.x86_64-apple-darwin14.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/GMP.v6.1.2-4.x86_64-apple-darwin14.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/GMP.v6.1.2-4.x86_64-apple-darwin14.tar.gz/md5	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+a0d321bba6e59a449c92088fa693c969
diff -pruN 1.3.1+dfsg-1/deps/checksums/GMP.v6.1.2-4.x86_64-apple-darwin14.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/GMP.v6.1.2-4.x86_64-apple-darwin14.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/GMP.v6.1.2-4.x86_64-apple-darwin14.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/GMP.v6.1.2-4.x86_64-apple-darwin14.tar.gz/sha512	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+2b9ae682eecf5b5513bf7bc06872bd2bb79ac0d09d1a032217e8727854429e57bb415c5e6a6a04fd7da94cbcb45e3ad8a8578e7b9cf3ba1949db82dd8a9eb6ff
diff -pruN 1.3.1+dfsg-1/deps/checksums/GMP.v6.1.2-4.x86_64-linux-gnu.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/GMP.v6.1.2-4.x86_64-linux-gnu.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/GMP.v6.1.2-4.x86_64-linux-gnu.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/GMP.v6.1.2-4.x86_64-linux-gnu.tar.gz/md5	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+a6fabb3bc108b0eef63c5543d1f13b7d
diff -pruN 1.3.1+dfsg-1/deps/checksums/GMP.v6.1.2-4.x86_64-linux-gnu.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/GMP.v6.1.2-4.x86_64-linux-gnu.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/GMP.v6.1.2-4.x86_64-linux-gnu.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/GMP.v6.1.2-4.x86_64-linux-gnu.tar.gz/sha512	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+cf1fd3a1072f4a5ed3f71db9bf6cab2fa54fab8ae55fcc7bb2d6496e106a6a9a1844f9d8b8d7fdacfcd51e811e168fb99605ebbe1e87e61f978449ad6a280e24
diff -pruN 1.3.1+dfsg-1/deps/checksums/GMP.v6.1.2-4.x86_64-linux-musl.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/GMP.v6.1.2-4.x86_64-linux-musl.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/GMP.v6.1.2-4.x86_64-linux-musl.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/GMP.v6.1.2-4.x86_64-linux-musl.tar.gz/md5	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+ba1b090802d2636f460ee71253825a4c
diff -pruN 1.3.1+dfsg-1/deps/checksums/GMP.v6.1.2-4.x86_64-linux-musl.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/GMP.v6.1.2-4.x86_64-linux-musl.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/GMP.v6.1.2-4.x86_64-linux-musl.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/GMP.v6.1.2-4.x86_64-linux-musl.tar.gz/sha512	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+6320d81bc7d27848606aa7063cf29e1c088f22272db28600a27238a0f933c6695b917ecb54670c93473dbdb7141c7ee33e65b8d717edd0f400966d5a03d5bd86
diff -pruN 1.3.1+dfsg-1/deps/checksums/GMP.v6.1.2-4.x86_64-unknown-freebsd11.1.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/GMP.v6.1.2-4.x86_64-unknown-freebsd11.1.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/GMP.v6.1.2-4.x86_64-unknown-freebsd11.1.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/GMP.v6.1.2-4.x86_64-unknown-freebsd11.1.tar.gz/md5	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+deb35cf6f3aa221c814a9cb9b77a99d9
diff -pruN 1.3.1+dfsg-1/deps/checksums/GMP.v6.1.2-4.x86_64-unknown-freebsd11.1.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/GMP.v6.1.2-4.x86_64-unknown-freebsd11.1.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/GMP.v6.1.2-4.x86_64-unknown-freebsd11.1.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/GMP.v6.1.2-4.x86_64-unknown-freebsd11.1.tar.gz/sha512	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+d80954af671b6c24d8f0988c8cca8e89499dbb7206c8d0cd5c655688df9cc3a6b2e6ca8dbafb86ffaa42707be3e6da44e82c04d8173f7543514dae8dab4d5162
diff -pruN 1.3.1+dfsg-1/deps/checksums/GMP.v6.1.2-4.x86_64-w64-mingw32.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/GMP.v6.1.2-4.x86_64-w64-mingw32.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/GMP.v6.1.2-4.x86_64-w64-mingw32.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/GMP.v6.1.2-4.x86_64-w64-mingw32.tar.gz/md5	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+51fb1b1a43cec0ec216c61d17cd637cd
diff -pruN 1.3.1+dfsg-1/deps/checksums/GMP.v6.1.2-4.x86_64-w64-mingw32.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/GMP.v6.1.2-4.x86_64-w64-mingw32.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/GMP.v6.1.2-4.x86_64-w64-mingw32.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/GMP.v6.1.2-4.x86_64-w64-mingw32.tar.gz/sha512	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+9a702da6de85f3a81262858a2299222664417d424d89b1704eca702661f77e27cd07b7fca8fbd77c58521ef9caa83287c05956fbe97d9047272a4cb6912fc80d
diff -pruN 1.3.1+dfsg-1/deps/checksums/LibCURL.v7.61.0-1.aarch64-linux-gnu.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/LibCURL.v7.61.0-1.aarch64-linux-gnu.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/LibCURL.v7.61.0-1.aarch64-linux-gnu.tar.gz/md5	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/LibCURL.v7.61.0-1.aarch64-linux-gnu.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-a679e1c2bcd5b2bcb6e0f7b6398644a3
diff -pruN 1.3.1+dfsg-1/deps/checksums/LibCURL.v7.61.0-1.aarch64-linux-gnu.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/LibCURL.v7.61.0-1.aarch64-linux-gnu.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/LibCURL.v7.61.0-1.aarch64-linux-gnu.tar.gz/sha512	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/LibCURL.v7.61.0-1.aarch64-linux-gnu.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-4fa6f0e27d99fb9149ae6d133066226660ec53fb8cef2b21e66a98cccd9f5f7a8ca236ac0bc191aa994a47fb9d185f86001b73d3266bd996d1f3f4d620e1e46d
diff -pruN 1.3.1+dfsg-1/deps/checksums/LibCURL.v7.61.0-1.aarch64-linux-musl.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/LibCURL.v7.61.0-1.aarch64-linux-musl.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/LibCURL.v7.61.0-1.aarch64-linux-musl.tar.gz/md5	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/LibCURL.v7.61.0-1.aarch64-linux-musl.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-e2df01b8890ba6a793dbf62531f3ae32
diff -pruN 1.3.1+dfsg-1/deps/checksums/LibCURL.v7.61.0-1.aarch64-linux-musl.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/LibCURL.v7.61.0-1.aarch64-linux-musl.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/LibCURL.v7.61.0-1.aarch64-linux-musl.tar.gz/sha512	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/LibCURL.v7.61.0-1.aarch64-linux-musl.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-4105964b14fb0ce99b1f573e51fe3973554bf4cf064b5371bd9e3cb3595b4462ee18f4009c29930706cef882428a3386323dc8f661417ab7da1a830702aecc61
diff -pruN 1.3.1+dfsg-1/deps/checksums/LibCURL.v7.61.0-1.arm-linux-gnueabihf.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/LibCURL.v7.61.0-1.arm-linux-gnueabihf.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/LibCURL.v7.61.0-1.arm-linux-gnueabihf.tar.gz/md5	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/LibCURL.v7.61.0-1.arm-linux-gnueabihf.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-d1e6c73aa6290037945bd2aea209b0d1
diff -pruN 1.3.1+dfsg-1/deps/checksums/LibCURL.v7.61.0-1.arm-linux-gnueabihf.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/LibCURL.v7.61.0-1.arm-linux-gnueabihf.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/LibCURL.v7.61.0-1.arm-linux-gnueabihf.tar.gz/sha512	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/LibCURL.v7.61.0-1.arm-linux-gnueabihf.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-edefce343de35f111aaa293e28d9482a99ada565d4c0a262063302b6eb1086bd412c31798e3fd9c4b4811aeb0a49979a29afe2a6a853484c4bd18a929d72b382
diff -pruN 1.3.1+dfsg-1/deps/checksums/LibCURL.v7.61.0-1.arm-linux-musleabihf.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/LibCURL.v7.61.0-1.arm-linux-musleabihf.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/LibCURL.v7.61.0-1.arm-linux-musleabihf.tar.gz/md5	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/LibCURL.v7.61.0-1.arm-linux-musleabihf.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-92f8d286ca7c0fdadf48f8f14fa5464d
diff -pruN 1.3.1+dfsg-1/deps/checksums/LibCURL.v7.61.0-1.arm-linux-musleabihf.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/LibCURL.v7.61.0-1.arm-linux-musleabihf.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/LibCURL.v7.61.0-1.arm-linux-musleabihf.tar.gz/sha512	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/LibCURL.v7.61.0-1.arm-linux-musleabihf.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-0cd2610eb19bde172640fe485c63f9f8eec804988c314ae59d835d207a5b54dd20d7ff9af38ab383531671a03502239f561ff013affdd311aa6b1b04a138282a
diff -pruN 1.3.1+dfsg-1/deps/checksums/LibCURL.v7.61.0-1.i686-linux-gnu.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/LibCURL.v7.61.0-1.i686-linux-gnu.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/LibCURL.v7.61.0-1.i686-linux-gnu.tar.gz/md5	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/LibCURL.v7.61.0-1.i686-linux-gnu.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-e1d1655a61aafa128babc105624483ad
diff -pruN 1.3.1+dfsg-1/deps/checksums/LibCURL.v7.61.0-1.i686-linux-gnu.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/LibCURL.v7.61.0-1.i686-linux-gnu.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/LibCURL.v7.61.0-1.i686-linux-gnu.tar.gz/sha512	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/LibCURL.v7.61.0-1.i686-linux-gnu.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-a7c719fbc38bccc1e9a548c48839f3296fb17389924bee27d89aeb61bc462875237df534bc60bbe7571e8cc0494771f0c5ff0f421e24fe7d360be0fe74bccde7
diff -pruN 1.3.1+dfsg-1/deps/checksums/LibCURL.v7.61.0-1.i686-linux-musl.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/LibCURL.v7.61.0-1.i686-linux-musl.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/LibCURL.v7.61.0-1.i686-linux-musl.tar.gz/md5	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/LibCURL.v7.61.0-1.i686-linux-musl.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-d0f4b89ae107d3e9e3cf429a467c8b5a
diff -pruN 1.3.1+dfsg-1/deps/checksums/LibCURL.v7.61.0-1.i686-linux-musl.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/LibCURL.v7.61.0-1.i686-linux-musl.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/LibCURL.v7.61.0-1.i686-linux-musl.tar.gz/sha512	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/LibCURL.v7.61.0-1.i686-linux-musl.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-80031156ebf65ddcaa2bf48db893e0b6f35cd34d27ed91ed3c74e432a41e4f52a640a0d4ea7ffc92f1ce647b3b67056fe927c49fc60bb07e0c3fd4ea2cfc2b21
diff -pruN 1.3.1+dfsg-1/deps/checksums/LibCURL.v7.61.0-1.i686-w64-mingw32.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/LibCURL.v7.61.0-1.i686-w64-mingw32.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/LibCURL.v7.61.0-1.i686-w64-mingw32.tar.gz/md5	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/LibCURL.v7.61.0-1.i686-w64-mingw32.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-feeff120fa186c3bc59db3e91173e6c6
diff -pruN 1.3.1+dfsg-1/deps/checksums/LibCURL.v7.61.0-1.i686-w64-mingw32.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/LibCURL.v7.61.0-1.i686-w64-mingw32.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/LibCURL.v7.61.0-1.i686-w64-mingw32.tar.gz/sha512	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/LibCURL.v7.61.0-1.i686-w64-mingw32.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-6260f42f1480ee47163fa5dc54697cea88511fc81c5abc4086ae32380e645a1f0ac53c70f2d958ee5aed9945442595aaf9f3a980ec3625b2ef57a4495a650be2
diff -pruN 1.3.1+dfsg-1/deps/checksums/LibCURL.v7.61.0-1.powerpc64le-linux-gnu.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/LibCURL.v7.61.0-1.powerpc64le-linux-gnu.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/LibCURL.v7.61.0-1.powerpc64le-linux-gnu.tar.gz/md5	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/LibCURL.v7.61.0-1.powerpc64le-linux-gnu.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-522e59c003b3618f36b7621f42c03f22
diff -pruN 1.3.1+dfsg-1/deps/checksums/LibCURL.v7.61.0-1.powerpc64le-linux-gnu.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/LibCURL.v7.61.0-1.powerpc64le-linux-gnu.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/LibCURL.v7.61.0-1.powerpc64le-linux-gnu.tar.gz/sha512	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/LibCURL.v7.61.0-1.powerpc64le-linux-gnu.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-85955ea8a45eb2dd5efc110f939e80de1c56e1f5c3f89c695f306e03f9e5a1b206a1ee1634e41002c54894ca8b925e387f1a0f7692b72fa1a68fb09e65caf58d
diff -pruN 1.3.1+dfsg-1/deps/checksums/LibCURL.v7.61.0-1.x86_64-apple-darwin14.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/LibCURL.v7.61.0-1.x86_64-apple-darwin14.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/LibCURL.v7.61.0-1.x86_64-apple-darwin14.tar.gz/md5	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/LibCURL.v7.61.0-1.x86_64-apple-darwin14.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-f64f5357c95c71774748d25b589ffc3f
diff -pruN 1.3.1+dfsg-1/deps/checksums/LibCURL.v7.61.0-1.x86_64-apple-darwin14.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/LibCURL.v7.61.0-1.x86_64-apple-darwin14.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/LibCURL.v7.61.0-1.x86_64-apple-darwin14.tar.gz/sha512	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/LibCURL.v7.61.0-1.x86_64-apple-darwin14.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-928663098cc31d29415bf169ce6e0599190b5bc6f4f5cb0afb9dd5e27a1b755b5895b133692386d72af20587deacabf8992b773e623ef30a2b7c9a01f40661a6
diff -pruN 1.3.1+dfsg-1/deps/checksums/LibCURL.v7.61.0-1.x86_64-linux-gnu.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/LibCURL.v7.61.0-1.x86_64-linux-gnu.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/LibCURL.v7.61.0-1.x86_64-linux-gnu.tar.gz/md5	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/LibCURL.v7.61.0-1.x86_64-linux-gnu.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-29f7832336bdad46574fe7a7b79ba053
diff -pruN 1.3.1+dfsg-1/deps/checksums/LibCURL.v7.61.0-1.x86_64-linux-gnu.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/LibCURL.v7.61.0-1.x86_64-linux-gnu.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/LibCURL.v7.61.0-1.x86_64-linux-gnu.tar.gz/sha512	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/LibCURL.v7.61.0-1.x86_64-linux-gnu.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-4e58147b7db1c274158fd04442873293fe353c4eacee79963f09cd3f955f39260e70b96abf93f5a4bc2198397c6c6e5c3e9e64555ac28c86d5a09e9837cf90cb
diff -pruN 1.3.1+dfsg-1/deps/checksums/LibCURL.v7.61.0-1.x86_64-linux-musl.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/LibCURL.v7.61.0-1.x86_64-linux-musl.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/LibCURL.v7.61.0-1.x86_64-linux-musl.tar.gz/md5	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/LibCURL.v7.61.0-1.x86_64-linux-musl.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-3769a289fa301c2c62b3735d8c136c98
diff -pruN 1.3.1+dfsg-1/deps/checksums/LibCURL.v7.61.0-1.x86_64-linux-musl.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/LibCURL.v7.61.0-1.x86_64-linux-musl.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/LibCURL.v7.61.0-1.x86_64-linux-musl.tar.gz/sha512	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/LibCURL.v7.61.0-1.x86_64-linux-musl.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-16f6d5c8f7bda5c1374c4aabe9d8a6e80b2557cf43881cdee72e4b64753eb1732cebfcfee108d7572e244b4696e2ccb972d27deec64e29eddf300f547e899f35
diff -pruN 1.3.1+dfsg-1/deps/checksums/LibCURL.v7.61.0-1.x86_64-unknown-freebsd11.1.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/LibCURL.v7.61.0-1.x86_64-unknown-freebsd11.1.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/LibCURL.v7.61.0-1.x86_64-unknown-freebsd11.1.tar.gz/md5	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/LibCURL.v7.61.0-1.x86_64-unknown-freebsd11.1.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-b07a8a49e8286d223acffe13c304deda
diff -pruN 1.3.1+dfsg-1/deps/checksums/LibCURL.v7.61.0-1.x86_64-unknown-freebsd11.1.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/LibCURL.v7.61.0-1.x86_64-unknown-freebsd11.1.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/LibCURL.v7.61.0-1.x86_64-unknown-freebsd11.1.tar.gz/sha512	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/LibCURL.v7.61.0-1.x86_64-unknown-freebsd11.1.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-2d6b221b0c2da6aad25914285e300b38c738dbcd9f9f8ef4c140ad8a9facf48a26769ffabbd2cd2f1dc4e466dd95dd7a116e4fa6f7ddecdf4d19ef283b6d67fc
diff -pruN 1.3.1+dfsg-1/deps/checksums/LibCURL.v7.61.0-1.x86_64-w64-mingw32.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/LibCURL.v7.61.0-1.x86_64-w64-mingw32.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/LibCURL.v7.61.0-1.x86_64-w64-mingw32.tar.gz/md5	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/LibCURL.v7.61.0-1.x86_64-w64-mingw32.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-064cc210e65632f94b9171f190fa3e79
diff -pruN 1.3.1+dfsg-1/deps/checksums/LibCURL.v7.61.0-1.x86_64-w64-mingw32.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/LibCURL.v7.61.0-1.x86_64-w64-mingw32.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/LibCURL.v7.61.0-1.x86_64-w64-mingw32.tar.gz/sha512	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/LibCURL.v7.61.0-1.x86_64-w64-mingw32.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-a51974e5fcc80adc09276f858ac4adf62c46f4b43e42e69b0b8f45f9ee0b696019649c2a65e74abe732c7f7dd0ac1843abf8fa68cabcd9bf1c7cdfac22700f81
diff -pruN 1.3.1+dfsg-1/deps/checksums/LibCURL.v7.66.0-1.aarch64-linux-gnu.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/LibCURL.v7.66.0-1.aarch64-linux-gnu.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/LibCURL.v7.66.0-1.aarch64-linux-gnu.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/LibCURL.v7.66.0-1.aarch64-linux-gnu.tar.gz/md5	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+a9b50e20ccb840657b88ef5964f5b50d
diff -pruN 1.3.1+dfsg-1/deps/checksums/LibCURL.v7.66.0-1.aarch64-linux-gnu.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/LibCURL.v7.66.0-1.aarch64-linux-gnu.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/LibCURL.v7.66.0-1.aarch64-linux-gnu.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/LibCURL.v7.66.0-1.aarch64-linux-gnu.tar.gz/sha512	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+1bea6285dbbcb69f1be36ccd25898f6bc0635e07a1ae8c6731b6967ab5c897774e2455324d34decf84682937ac4affd439c0801acdebcfc5bf2bf3545da06072
diff -pruN 1.3.1+dfsg-1/deps/checksums/LibCURL.v7.66.0-1.aarch64-linux-musl.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/LibCURL.v7.66.0-1.aarch64-linux-musl.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/LibCURL.v7.66.0-1.aarch64-linux-musl.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/LibCURL.v7.66.0-1.aarch64-linux-musl.tar.gz/md5	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+eb113968d9770ca43cdcca8a40f25be8
diff -pruN 1.3.1+dfsg-1/deps/checksums/LibCURL.v7.66.0-1.aarch64-linux-musl.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/LibCURL.v7.66.0-1.aarch64-linux-musl.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/LibCURL.v7.66.0-1.aarch64-linux-musl.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/LibCURL.v7.66.0-1.aarch64-linux-musl.tar.gz/sha512	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+6f96c6d982741aa6d84493bbc43495662943cf1158c2158b78f12085e3395e31fe958e742ea42de85fe69b63afb40ff255836cbdfa1aa39a57372d6cda0dbb1f
diff -pruN 1.3.1+dfsg-1/deps/checksums/LibCURL.v7.66.0-1.arm-linux-gnueabihf.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/LibCURL.v7.66.0-1.arm-linux-gnueabihf.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/LibCURL.v7.66.0-1.arm-linux-gnueabihf.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/LibCURL.v7.66.0-1.arm-linux-gnueabihf.tar.gz/md5	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+f5a22f9885d44483940775cbce28fefb
diff -pruN 1.3.1+dfsg-1/deps/checksums/LibCURL.v7.66.0-1.arm-linux-gnueabihf.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/LibCURL.v7.66.0-1.arm-linux-gnueabihf.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/LibCURL.v7.66.0-1.arm-linux-gnueabihf.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/LibCURL.v7.66.0-1.arm-linux-gnueabihf.tar.gz/sha512	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+207bfab6aa91ffc89be3d8a8cf2d473c3b07dd2561a94a82e77887ba108ca2b7192d2531de23b1b9e3ae3d63e2f1c97add625eafdab9dcffe62f742f88d4ab66
diff -pruN 1.3.1+dfsg-1/deps/checksums/LibCURL.v7.66.0-1.arm-linux-musleabihf.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/LibCURL.v7.66.0-1.arm-linux-musleabihf.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/LibCURL.v7.66.0-1.arm-linux-musleabihf.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/LibCURL.v7.66.0-1.arm-linux-musleabihf.tar.gz/md5	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+8376478c61653188cdcee7b7f3bd7f56
diff -pruN 1.3.1+dfsg-1/deps/checksums/LibCURL.v7.66.0-1.arm-linux-musleabihf.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/LibCURL.v7.66.0-1.arm-linux-musleabihf.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/LibCURL.v7.66.0-1.arm-linux-musleabihf.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/LibCURL.v7.66.0-1.arm-linux-musleabihf.tar.gz/sha512	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+e8c174714d825a87e9d062161b4752cf1daefd7672ba98268c416e38195df6ed70d97c8cf60ebec495a158873d9c9b1c20d878bc91cc677f03189a9de7d2f6d7
diff -pruN 1.3.1+dfsg-1/deps/checksums/LibCURL.v7.66.0-1.i686-linux-gnu.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/LibCURL.v7.66.0-1.i686-linux-gnu.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/LibCURL.v7.66.0-1.i686-linux-gnu.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/LibCURL.v7.66.0-1.i686-linux-gnu.tar.gz/md5	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+0561371e7f5af0329174a5664cc502bc
diff -pruN 1.3.1+dfsg-1/deps/checksums/LibCURL.v7.66.0-1.i686-linux-gnu.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/LibCURL.v7.66.0-1.i686-linux-gnu.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/LibCURL.v7.66.0-1.i686-linux-gnu.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/LibCURL.v7.66.0-1.i686-linux-gnu.tar.gz/sha512	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+065204141e83ceb31747932c8be28af738040f1fb814ec47506f78ca76ef83543319964ab9d2695cb7e7346eadff94a4882f7cb6d8f48054ac8e1481c2075308
diff -pruN 1.3.1+dfsg-1/deps/checksums/LibCURL.v7.66.0-1.i686-linux-musl.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/LibCURL.v7.66.0-1.i686-linux-musl.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/LibCURL.v7.66.0-1.i686-linux-musl.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/LibCURL.v7.66.0-1.i686-linux-musl.tar.gz/md5	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+bab1dabc470c8056b21568409eda36c6
diff -pruN 1.3.1+dfsg-1/deps/checksums/LibCURL.v7.66.0-1.i686-linux-musl.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/LibCURL.v7.66.0-1.i686-linux-musl.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/LibCURL.v7.66.0-1.i686-linux-musl.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/LibCURL.v7.66.0-1.i686-linux-musl.tar.gz/sha512	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+674d73397864df94bc519f9b538bb1c8d15f719c3f15ae037c347ce5c97b16a374cfd86ece572f2e9d56b90ffd00119ea9923c46792b038cb892965615f3f54c
diff -pruN 1.3.1+dfsg-1/deps/checksums/LibCURL.v7.66.0-1.i686-w64-mingw32.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/LibCURL.v7.66.0-1.i686-w64-mingw32.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/LibCURL.v7.66.0-1.i686-w64-mingw32.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/LibCURL.v7.66.0-1.i686-w64-mingw32.tar.gz/md5	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+e43d122f5646d7e25bf50efd6e08009a
diff -pruN 1.3.1+dfsg-1/deps/checksums/LibCURL.v7.66.0-1.i686-w64-mingw32.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/LibCURL.v7.66.0-1.i686-w64-mingw32.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/LibCURL.v7.66.0-1.i686-w64-mingw32.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/LibCURL.v7.66.0-1.i686-w64-mingw32.tar.gz/sha512	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+ba36dbeda881db12f0f852a4f610e1bd5ec78168b462278f1f199455261e2acdc56909352dfe6cff81d09e8e8f3fecb19bf008c98e19084ecfd972dce08bab0a
diff -pruN 1.3.1+dfsg-1/deps/checksums/LibCURL.v7.66.0-1.powerpc64le-linux-gnu.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/LibCURL.v7.66.0-1.powerpc64le-linux-gnu.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/LibCURL.v7.66.0-1.powerpc64le-linux-gnu.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/LibCURL.v7.66.0-1.powerpc64le-linux-gnu.tar.gz/md5	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+43eb69d7b7511c5847e5ba20113852f9
diff -pruN 1.3.1+dfsg-1/deps/checksums/LibCURL.v7.66.0-1.powerpc64le-linux-gnu.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/LibCURL.v7.66.0-1.powerpc64le-linux-gnu.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/LibCURL.v7.66.0-1.powerpc64le-linux-gnu.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/LibCURL.v7.66.0-1.powerpc64le-linux-gnu.tar.gz/sha512	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+63817f3d8f7aca038945c9e18cc272456ddfde8682823c8160674d4f26899d8a34c1d6c14e956bf59eb48d13db3ccd7e00d5d4aa27a7960be203d4915e388782
diff -pruN 1.3.1+dfsg-1/deps/checksums/LibCURL.v7.66.0-1.x86_64-apple-darwin14.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/LibCURL.v7.66.0-1.x86_64-apple-darwin14.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/LibCURL.v7.66.0-1.x86_64-apple-darwin14.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/LibCURL.v7.66.0-1.x86_64-apple-darwin14.tar.gz/md5	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+5fcfbb7debf246db712b2370d641aec8
diff -pruN 1.3.1+dfsg-1/deps/checksums/LibCURL.v7.66.0-1.x86_64-apple-darwin14.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/LibCURL.v7.66.0-1.x86_64-apple-darwin14.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/LibCURL.v7.66.0-1.x86_64-apple-darwin14.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/LibCURL.v7.66.0-1.x86_64-apple-darwin14.tar.gz/sha512	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+c501171baa8570a69117ca32aa8bbae18e7a2a1e7f5bde15ffec2c5080d02f9e1cfbbe40e5104ef5a5d044e64f51e4917f80534a1aedad2ac3a3173d6edbfa7c
diff -pruN 1.3.1+dfsg-1/deps/checksums/LibCURL.v7.66.0-1.x86_64-linux-gnu.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/LibCURL.v7.66.0-1.x86_64-linux-gnu.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/LibCURL.v7.66.0-1.x86_64-linux-gnu.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/LibCURL.v7.66.0-1.x86_64-linux-gnu.tar.gz/md5	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+f9917fb981e190dca659288b42a44b72
diff -pruN 1.3.1+dfsg-1/deps/checksums/LibCURL.v7.66.0-1.x86_64-linux-gnu.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/LibCURL.v7.66.0-1.x86_64-linux-gnu.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/LibCURL.v7.66.0-1.x86_64-linux-gnu.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/LibCURL.v7.66.0-1.x86_64-linux-gnu.tar.gz/sha512	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+1b34ea6bdd756e1dcf01944eb625990a3076a407d3b7f5ad4db9e5b7c11375cacd16afff9913b3467d95c302ef7acf39600e25b0527b06578f237388285e5b48
diff -pruN 1.3.1+dfsg-1/deps/checksums/LibCURL.v7.66.0-1.x86_64-linux-musl.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/LibCURL.v7.66.0-1.x86_64-linux-musl.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/LibCURL.v7.66.0-1.x86_64-linux-musl.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/LibCURL.v7.66.0-1.x86_64-linux-musl.tar.gz/md5	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+b8980cb7c553d615e99b4b605767689c
diff -pruN 1.3.1+dfsg-1/deps/checksums/LibCURL.v7.66.0-1.x86_64-linux-musl.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/LibCURL.v7.66.0-1.x86_64-linux-musl.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/LibCURL.v7.66.0-1.x86_64-linux-musl.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/LibCURL.v7.66.0-1.x86_64-linux-musl.tar.gz/sha512	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+27feec073996c7c3ae43c3d9009041b1eb835814e07a7182450bd8b9615f8162b929e795c5d03d39a56aa472316db6d2c0574391de273e538ead0811817970bf
diff -pruN 1.3.1+dfsg-1/deps/checksums/LibCURL.v7.66.0-1.x86_64-unknown-freebsd11.1.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/LibCURL.v7.66.0-1.x86_64-unknown-freebsd11.1.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/LibCURL.v7.66.0-1.x86_64-unknown-freebsd11.1.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/LibCURL.v7.66.0-1.x86_64-unknown-freebsd11.1.tar.gz/md5	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+4d329868c7dc53302870d08b79bdc39f
diff -pruN 1.3.1+dfsg-1/deps/checksums/LibCURL.v7.66.0-1.x86_64-unknown-freebsd11.1.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/LibCURL.v7.66.0-1.x86_64-unknown-freebsd11.1.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/LibCURL.v7.66.0-1.x86_64-unknown-freebsd11.1.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/LibCURL.v7.66.0-1.x86_64-unknown-freebsd11.1.tar.gz/sha512	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+c8ea193706857d45f55f2360d6fe653fe2b13b1aa4b2012f85bdc001bcfe2881577dd2d2c6ed3ef52cae9fde0a6d4ed1dea392724ceada91182684a28ab2ddec
diff -pruN 1.3.1+dfsg-1/deps/checksums/LibCURL.v7.66.0-1.x86_64-w64-mingw32.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/LibCURL.v7.66.0-1.x86_64-w64-mingw32.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/LibCURL.v7.66.0-1.x86_64-w64-mingw32.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/LibCURL.v7.66.0-1.x86_64-w64-mingw32.tar.gz/md5	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+45d61e34397103dc0368841fd5a8566d
diff -pruN 1.3.1+dfsg-1/deps/checksums/LibCURL.v7.66.0-1.x86_64-w64-mingw32.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/LibCURL.v7.66.0-1.x86_64-w64-mingw32.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/LibCURL.v7.66.0-1.x86_64-w64-mingw32.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/LibCURL.v7.66.0-1.x86_64-w64-mingw32.tar.gz/sha512	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+88931ff63fca4864721072fc7094f3a25e0b487159c94f73761a51acbb5439f2cfca733d47c5aa59f02c7ff84b2b7f8c959d19f16b0662044158a12b1a78730e
diff -pruN 1.3.1+dfsg-1/deps/checksums/LibGit2.v0.28.2-0.aarch64-linux-gnu.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/LibGit2.v0.28.2-0.aarch64-linux-gnu.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/LibGit2.v0.28.2-0.aarch64-linux-gnu.tar.gz/md5	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/LibGit2.v0.28.2-0.aarch64-linux-gnu.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-69e6f91fc215b7a04a2fc33c8d815b02
diff -pruN 1.3.1+dfsg-1/deps/checksums/LibGit2.v0.28.2-0.aarch64-linux-gnu.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/LibGit2.v0.28.2-0.aarch64-linux-gnu.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/LibGit2.v0.28.2-0.aarch64-linux-gnu.tar.gz/sha512	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/LibGit2.v0.28.2-0.aarch64-linux-gnu.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-0294187cc3aa536d91e30d6074f9d5be11968b0df48d95bcdd39eadad4622520ab8dd1dda525afb1fc10297a3a5b7d3c326d2e6139adcdf7471c50d118bbc984
diff -pruN 1.3.1+dfsg-1/deps/checksums/LibGit2.v0.28.2-0.aarch64-linux-musl.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/LibGit2.v0.28.2-0.aarch64-linux-musl.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/LibGit2.v0.28.2-0.aarch64-linux-musl.tar.gz/md5	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/LibGit2.v0.28.2-0.aarch64-linux-musl.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-0d0a0b92a78a98f79bb4d28270cacaf2
diff -pruN 1.3.1+dfsg-1/deps/checksums/LibGit2.v0.28.2-0.aarch64-linux-musl.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/LibGit2.v0.28.2-0.aarch64-linux-musl.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/LibGit2.v0.28.2-0.aarch64-linux-musl.tar.gz/sha512	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/LibGit2.v0.28.2-0.aarch64-linux-musl.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-8e0dd3cf4298df12bcc477f72b1c8e10aefe4ec8966211cc256a6fd677993508258ebcdbdc4b52843fa5f3fcd02650c93f1b4f1cd91357eabe715caa381797c3
diff -pruN 1.3.1+dfsg-1/deps/checksums/LibGit2.v0.28.2-0.arm-linux-gnueabihf.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/LibGit2.v0.28.2-0.arm-linux-gnueabihf.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/LibGit2.v0.28.2-0.arm-linux-gnueabihf.tar.gz/md5	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/LibGit2.v0.28.2-0.arm-linux-gnueabihf.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-959fe4c2139aecdba5a7c54914a48c9a
diff -pruN 1.3.1+dfsg-1/deps/checksums/LibGit2.v0.28.2-0.arm-linux-gnueabihf.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/LibGit2.v0.28.2-0.arm-linux-gnueabihf.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/LibGit2.v0.28.2-0.arm-linux-gnueabihf.tar.gz/sha512	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/LibGit2.v0.28.2-0.arm-linux-gnueabihf.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-7607ad7b7825179dfd213092268e455c80a5d12ecb6a5b348dd64ff33410a3f3f00380784df083c251bce648f453687cfe05c3a1bbe208c301f2fee0be01961b
diff -pruN 1.3.1+dfsg-1/deps/checksums/LibGit2.v0.28.2-0.arm-linux-musleabihf.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/LibGit2.v0.28.2-0.arm-linux-musleabihf.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/LibGit2.v0.28.2-0.arm-linux-musleabihf.tar.gz/md5	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/LibGit2.v0.28.2-0.arm-linux-musleabihf.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-e2b501234f162681c0d13984ed3b2ee6
diff -pruN 1.3.1+dfsg-1/deps/checksums/LibGit2.v0.28.2-0.arm-linux-musleabihf.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/LibGit2.v0.28.2-0.arm-linux-musleabihf.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/LibGit2.v0.28.2-0.arm-linux-musleabihf.tar.gz/sha512	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/LibGit2.v0.28.2-0.arm-linux-musleabihf.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-766ac41027dfdb3ac126648f3ccfdda5c05b38de59afdc8cbb4eecff52538926ede5969fce13cd069263dc7e1a85b4d5ed9a4d03059d3203d6616e230653bdb4
diff -pruN 1.3.1+dfsg-1/deps/checksums/LibGit2.v0.28.2-0.i686-linux-gnu.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/LibGit2.v0.28.2-0.i686-linux-gnu.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/LibGit2.v0.28.2-0.i686-linux-gnu.tar.gz/md5	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/LibGit2.v0.28.2-0.i686-linux-gnu.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-be29004b070454211f78ee056ea3e7a0
diff -pruN 1.3.1+dfsg-1/deps/checksums/LibGit2.v0.28.2-0.i686-linux-gnu.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/LibGit2.v0.28.2-0.i686-linux-gnu.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/LibGit2.v0.28.2-0.i686-linux-gnu.tar.gz/sha512	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/LibGit2.v0.28.2-0.i686-linux-gnu.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-81efc0d456d7c3527691916259582eaea7e3084b43d271f207f3444c67fe8db7bb1a0d848ee49d3ba4731a4ef91123ed65ad0b7f9c2fc6d91262b25a69beec81
diff -pruN 1.3.1+dfsg-1/deps/checksums/LibGit2.v0.28.2-0.i686-linux-musl.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/LibGit2.v0.28.2-0.i686-linux-musl.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/LibGit2.v0.28.2-0.i686-linux-musl.tar.gz/md5	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/LibGit2.v0.28.2-0.i686-linux-musl.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-16a48be4d8077f5bff75b4420182c5aa
diff -pruN 1.3.1+dfsg-1/deps/checksums/LibGit2.v0.28.2-0.i686-linux-musl.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/LibGit2.v0.28.2-0.i686-linux-musl.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/LibGit2.v0.28.2-0.i686-linux-musl.tar.gz/sha512	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/LibGit2.v0.28.2-0.i686-linux-musl.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-5e9a50afb191ed8a0d007277062c6527c9c246c82969efa6b58ae18967a9ef67d89755331e5c0411c8efb6a9e5321039477dcad22f983a4a7f72c4cb4144a7e5
diff -pruN 1.3.1+dfsg-1/deps/checksums/LibGit2.v0.28.2-0.i686-w64-mingw32.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/LibGit2.v0.28.2-0.i686-w64-mingw32.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/LibGit2.v0.28.2-0.i686-w64-mingw32.tar.gz/md5	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/LibGit2.v0.28.2-0.i686-w64-mingw32.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-2f9032cf6489e9beebd62b0a7515aa3d
diff -pruN 1.3.1+dfsg-1/deps/checksums/LibGit2.v0.28.2-0.i686-w64-mingw32.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/LibGit2.v0.28.2-0.i686-w64-mingw32.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/LibGit2.v0.28.2-0.i686-w64-mingw32.tar.gz/sha512	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/LibGit2.v0.28.2-0.i686-w64-mingw32.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-9ab9819fcaaabfb5284ab167ece066e144bdc198d61e7d458aad03ebc0a84875a29bf42ed71a87c07e4e6b6c2f3e364f0d27d4b79c8aa0075a2912338dd11f23
diff -pruN 1.3.1+dfsg-1/deps/checksums/LibGit2.v0.28.2-0.powerpc64le-linux-gnu.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/LibGit2.v0.28.2-0.powerpc64le-linux-gnu.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/LibGit2.v0.28.2-0.powerpc64le-linux-gnu.tar.gz/md5	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/LibGit2.v0.28.2-0.powerpc64le-linux-gnu.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-8b38e077ee7c0fefab9d6fbafae4b9fd
diff -pruN 1.3.1+dfsg-1/deps/checksums/LibGit2.v0.28.2-0.powerpc64le-linux-gnu.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/LibGit2.v0.28.2-0.powerpc64le-linux-gnu.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/LibGit2.v0.28.2-0.powerpc64le-linux-gnu.tar.gz/sha512	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/LibGit2.v0.28.2-0.powerpc64le-linux-gnu.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-a40ebae0bffbc72429e8f3211bf5fd6689fbbf207e3cff46c5ca3b368b3c3e3dce646695adf79b25a2bcc507512b8b0ae222c40e1b92dd231b1ddc13be617f62
diff -pruN 1.3.1+dfsg-1/deps/checksums/LibGit2.v0.28.2-0.x86_64-apple-darwin14.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/LibGit2.v0.28.2-0.x86_64-apple-darwin14.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/LibGit2.v0.28.2-0.x86_64-apple-darwin14.tar.gz/md5	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/LibGit2.v0.28.2-0.x86_64-apple-darwin14.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-b7e43e56116621e39e14992da40b5072
diff -pruN 1.3.1+dfsg-1/deps/checksums/LibGit2.v0.28.2-0.x86_64-apple-darwin14.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/LibGit2.v0.28.2-0.x86_64-apple-darwin14.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/LibGit2.v0.28.2-0.x86_64-apple-darwin14.tar.gz/sha512	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/LibGit2.v0.28.2-0.x86_64-apple-darwin14.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-1561b498755622ed4a1c9e857b5f684b52a43954cee06b9cbb04dcce65e60a87a54d2d694d7fd67422ee1e436c99e481899a6c3a171db66cbf5409098e7aa724
diff -pruN 1.3.1+dfsg-1/deps/checksums/LibGit2.v0.28.2-0.x86_64-linux-gnu.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/LibGit2.v0.28.2-0.x86_64-linux-gnu.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/LibGit2.v0.28.2-0.x86_64-linux-gnu.tar.gz/md5	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/LibGit2.v0.28.2-0.x86_64-linux-gnu.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-174eb178c914cd35e3cd86e434e483c3
diff -pruN 1.3.1+dfsg-1/deps/checksums/LibGit2.v0.28.2-0.x86_64-linux-gnu.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/LibGit2.v0.28.2-0.x86_64-linux-gnu.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/LibGit2.v0.28.2-0.x86_64-linux-gnu.tar.gz/sha512	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/LibGit2.v0.28.2-0.x86_64-linux-gnu.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-eb3d81ab6bef4abaa95ef57d9f6137834a663ed9484c85e2d3a687f2ec31fd018bb94371e3317ef8422df5738edeb85d3fd0a768d0a5676c1bd243d751e9cafc
diff -pruN 1.3.1+dfsg-1/deps/checksums/LibGit2.v0.28.2-0.x86_64-linux-musl.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/LibGit2.v0.28.2-0.x86_64-linux-musl.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/LibGit2.v0.28.2-0.x86_64-linux-musl.tar.gz/md5	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/LibGit2.v0.28.2-0.x86_64-linux-musl.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-6eae54904dc532cb896e6b8353771ba0
diff -pruN 1.3.1+dfsg-1/deps/checksums/LibGit2.v0.28.2-0.x86_64-linux-musl.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/LibGit2.v0.28.2-0.x86_64-linux-musl.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/LibGit2.v0.28.2-0.x86_64-linux-musl.tar.gz/sha512	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/LibGit2.v0.28.2-0.x86_64-linux-musl.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-52c850177a1d12ae4afdb8ba0c7b990d85e28e49cddc766b506bcb2b331eea96d1434def121e923b4a19c0c163bd8938b8b0158c0d635da46e10ad4416cb3eef
diff -pruN 1.3.1+dfsg-1/deps/checksums/LibGit2.v0.28.2-0.x86_64-unknown-freebsd11.1.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/LibGit2.v0.28.2-0.x86_64-unknown-freebsd11.1.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/LibGit2.v0.28.2-0.x86_64-unknown-freebsd11.1.tar.gz/md5	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/LibGit2.v0.28.2-0.x86_64-unknown-freebsd11.1.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-dcc9e512ea89ceca7e8909107fc26ebe
diff -pruN 1.3.1+dfsg-1/deps/checksums/LibGit2.v0.28.2-0.x86_64-unknown-freebsd11.1.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/LibGit2.v0.28.2-0.x86_64-unknown-freebsd11.1.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/LibGit2.v0.28.2-0.x86_64-unknown-freebsd11.1.tar.gz/sha512	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/LibGit2.v0.28.2-0.x86_64-unknown-freebsd11.1.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-f38b6dedec618891757735e849df98930bb0aa53bfb6c8f2cdca4d83fcf747aac520330e83aee8e89463772dadb2c7b9e1e07816d3901b9699e55052ede50763
diff -pruN 1.3.1+dfsg-1/deps/checksums/LibGit2.v0.28.2-0.x86_64-w64-mingw32.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/LibGit2.v0.28.2-0.x86_64-w64-mingw32.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/LibGit2.v0.28.2-0.x86_64-w64-mingw32.tar.gz/md5	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/LibGit2.v0.28.2-0.x86_64-w64-mingw32.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-adeef31a88dec49266b5e2ae1bf74ff6
diff -pruN 1.3.1+dfsg-1/deps/checksums/LibGit2.v0.28.2-0.x86_64-w64-mingw32.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/LibGit2.v0.28.2-0.x86_64-w64-mingw32.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/LibGit2.v0.28.2-0.x86_64-w64-mingw32.tar.gz/sha512	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/LibGit2.v0.28.2-0.x86_64-w64-mingw32.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-4173ae2455ba2e651b0a98c5fd5e2019a0af76387f715c64e08130579eb8ce587c426af9862f096597dc6d23d76cd12232870ad4598049c313e45b2cb796ca97
diff -pruN 1.3.1+dfsg-1/deps/checksums/LibGit2.v0.28.2-1.aarch64-linux-gnu.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/LibGit2.v0.28.2-1.aarch64-linux-gnu.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/LibGit2.v0.28.2-1.aarch64-linux-gnu.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/LibGit2.v0.28.2-1.aarch64-linux-gnu.tar.gz/md5	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+d1bf78dc08e2aa5a8b96bf6daa294387
diff -pruN 1.3.1+dfsg-1/deps/checksums/LibGit2.v0.28.2-1.aarch64-linux-gnu.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/LibGit2.v0.28.2-1.aarch64-linux-gnu.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/LibGit2.v0.28.2-1.aarch64-linux-gnu.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/LibGit2.v0.28.2-1.aarch64-linux-gnu.tar.gz/sha512	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+b432a73d5078093cc3a3d622746a160cdad5b11f0434df7e61479adeb0e1bf6cb56d6d5aa0fd534f4b236ef779012677379bf2e7d913811344223f1b29dc3b82
diff -pruN 1.3.1+dfsg-1/deps/checksums/LibGit2.v0.28.2-1.aarch64-linux-musl.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/LibGit2.v0.28.2-1.aarch64-linux-musl.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/LibGit2.v0.28.2-1.aarch64-linux-musl.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/LibGit2.v0.28.2-1.aarch64-linux-musl.tar.gz/md5	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+43e4409595b449208eced5c58be28eae
diff -pruN 1.3.1+dfsg-1/deps/checksums/LibGit2.v0.28.2-1.aarch64-linux-musl.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/LibGit2.v0.28.2-1.aarch64-linux-musl.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/LibGit2.v0.28.2-1.aarch64-linux-musl.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/LibGit2.v0.28.2-1.aarch64-linux-musl.tar.gz/sha512	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+6f5adba125e8be8e66317e18a2c36a9fa8f3d1f6647e0a9bb03957879a2f023717c7432651b3d33319b72c70e7b78eee0960c140308c6dad66ae6669a2d99922
diff -pruN 1.3.1+dfsg-1/deps/checksums/LibGit2.v0.28.2-1.arm-linux-gnueabihf.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/LibGit2.v0.28.2-1.arm-linux-gnueabihf.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/LibGit2.v0.28.2-1.arm-linux-gnueabihf.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/LibGit2.v0.28.2-1.arm-linux-gnueabihf.tar.gz/md5	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+8abf5ba687e262efa27c065cb20ecf20
diff -pruN 1.3.1+dfsg-1/deps/checksums/LibGit2.v0.28.2-1.arm-linux-gnueabihf.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/LibGit2.v0.28.2-1.arm-linux-gnueabihf.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/LibGit2.v0.28.2-1.arm-linux-gnueabihf.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/LibGit2.v0.28.2-1.arm-linux-gnueabihf.tar.gz/sha512	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+36e7f475622721b426180d63c13421bdd6f3147a9179831c82b8fccb8935c69b3b0f6dbdc42c937f83ccedae269cf743b09a689d8c46eb2b155749f8e6a94f80
diff -pruN 1.3.1+dfsg-1/deps/checksums/LibGit2.v0.28.2-1.arm-linux-musleabihf.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/LibGit2.v0.28.2-1.arm-linux-musleabihf.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/LibGit2.v0.28.2-1.arm-linux-musleabihf.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/LibGit2.v0.28.2-1.arm-linux-musleabihf.tar.gz/md5	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+c552d40dd57d25e288ecbe9cc6824df1
diff -pruN 1.3.1+dfsg-1/deps/checksums/LibGit2.v0.28.2-1.arm-linux-musleabihf.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/LibGit2.v0.28.2-1.arm-linux-musleabihf.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/LibGit2.v0.28.2-1.arm-linux-musleabihf.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/LibGit2.v0.28.2-1.arm-linux-musleabihf.tar.gz/sha512	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+96fab06657d2f90e1290db1229da94637fbc2b2d96e5882fb0cc237f0f6036f67c3295b6bb7a3671938e8aaa8fb9e75dc1ed7ad00c14e9cc50873396dc6748ef
diff -pruN 1.3.1+dfsg-1/deps/checksums/LibGit2.v0.28.2-1.i686-linux-gnu.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/LibGit2.v0.28.2-1.i686-linux-gnu.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/LibGit2.v0.28.2-1.i686-linux-gnu.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/LibGit2.v0.28.2-1.i686-linux-gnu.tar.gz/md5	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+a7b0088acfadf471b226a3e13aaa1e52
diff -pruN 1.3.1+dfsg-1/deps/checksums/LibGit2.v0.28.2-1.i686-linux-gnu.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/LibGit2.v0.28.2-1.i686-linux-gnu.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/LibGit2.v0.28.2-1.i686-linux-gnu.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/LibGit2.v0.28.2-1.i686-linux-gnu.tar.gz/sha512	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+ce2842de3f5d5e96d7213f4f84216beed3264f4170fe1f3e550dc2429abd8ef5e12b5336dbf618362ca76a0458fef62c4096a2c4634dde05dcb9d0a8a7bfdad3
diff -pruN 1.3.1+dfsg-1/deps/checksums/LibGit2.v0.28.2-1.i686-linux-musl.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/LibGit2.v0.28.2-1.i686-linux-musl.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/LibGit2.v0.28.2-1.i686-linux-musl.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/LibGit2.v0.28.2-1.i686-linux-musl.tar.gz/md5	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+b58d9b986c0949a456c3351289122d03
diff -pruN 1.3.1+dfsg-1/deps/checksums/LibGit2.v0.28.2-1.i686-linux-musl.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/LibGit2.v0.28.2-1.i686-linux-musl.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/LibGit2.v0.28.2-1.i686-linux-musl.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/LibGit2.v0.28.2-1.i686-linux-musl.tar.gz/sha512	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+83b79203656fe6b227dc6be7cb284245e027bc85f4cfb5011ca97f7273e269effd0e5990792c6cfbc203ae23230d973eddb8a1b10371ae10e4d988d4f3ebf43a
diff -pruN 1.3.1+dfsg-1/deps/checksums/LibGit2.v0.28.2-1.i686-w64-mingw32.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/LibGit2.v0.28.2-1.i686-w64-mingw32.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/LibGit2.v0.28.2-1.i686-w64-mingw32.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/LibGit2.v0.28.2-1.i686-w64-mingw32.tar.gz/md5	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+8b3512062571498e79d18ece607c2f3a
diff -pruN 1.3.1+dfsg-1/deps/checksums/LibGit2.v0.28.2-1.i686-w64-mingw32.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/LibGit2.v0.28.2-1.i686-w64-mingw32.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/LibGit2.v0.28.2-1.i686-w64-mingw32.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/LibGit2.v0.28.2-1.i686-w64-mingw32.tar.gz/sha512	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+2609cb4c968dc87bb63be88888cdc02d5e7b2333604ecdbef5358883051ba391d2ef66e361d3dd5b79d4af8dce311a80ed11ce3f4be7a746f86c3e834ce97e6e
diff -pruN 1.3.1+dfsg-1/deps/checksums/LibGit2.v0.28.2-1.powerpc64le-linux-gnu.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/LibGit2.v0.28.2-1.powerpc64le-linux-gnu.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/LibGit2.v0.28.2-1.powerpc64le-linux-gnu.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/LibGit2.v0.28.2-1.powerpc64le-linux-gnu.tar.gz/md5	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+091eeeac55b90fb3be253bc0b7294851
diff -pruN 1.3.1+dfsg-1/deps/checksums/LibGit2.v0.28.2-1.powerpc64le-linux-gnu.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/LibGit2.v0.28.2-1.powerpc64le-linux-gnu.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/LibGit2.v0.28.2-1.powerpc64le-linux-gnu.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/LibGit2.v0.28.2-1.powerpc64le-linux-gnu.tar.gz/sha512	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+1f9aa0457c665aa8afb4a808c923816583ee62fd3a1d6aecc0be4814530e599a31e4174b84548856cd0e7d2b1cb3aea177519a25a68c19014938e30a46a57fff
diff -pruN 1.3.1+dfsg-1/deps/checksums/LibGit2.v0.28.2-1.x86_64-apple-darwin14.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/LibGit2.v0.28.2-1.x86_64-apple-darwin14.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/LibGit2.v0.28.2-1.x86_64-apple-darwin14.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/LibGit2.v0.28.2-1.x86_64-apple-darwin14.tar.gz/md5	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+ade2d1d1f0215a63607cfaa3b491834c
diff -pruN 1.3.1+dfsg-1/deps/checksums/LibGit2.v0.28.2-1.x86_64-apple-darwin14.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/LibGit2.v0.28.2-1.x86_64-apple-darwin14.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/LibGit2.v0.28.2-1.x86_64-apple-darwin14.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/LibGit2.v0.28.2-1.x86_64-apple-darwin14.tar.gz/sha512	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+6e56fc5fbae06c091cd07ef353d9fa023cbeaced6d85cf80c9b13c80524587d4ac9026bf92f10d2c1f698783804e208385b8f1821e491f44c7d522dbcddf657c
diff -pruN 1.3.1+dfsg-1/deps/checksums/LibGit2.v0.28.2-1.x86_64-linux-gnu.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/LibGit2.v0.28.2-1.x86_64-linux-gnu.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/LibGit2.v0.28.2-1.x86_64-linux-gnu.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/LibGit2.v0.28.2-1.x86_64-linux-gnu.tar.gz/md5	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+71d9f246db80a4d2f60e6c12bd9a79e8
diff -pruN 1.3.1+dfsg-1/deps/checksums/LibGit2.v0.28.2-1.x86_64-linux-gnu.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/LibGit2.v0.28.2-1.x86_64-linux-gnu.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/LibGit2.v0.28.2-1.x86_64-linux-gnu.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/LibGit2.v0.28.2-1.x86_64-linux-gnu.tar.gz/sha512	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+4cf4dd2ccaa218c2cc0223eaf19a4b3e834d7c36cf992e8e96a011c3e429347665774e44fdcc913b71c24a74232608fe3a8ce66e75184c58640ce5bb495a07f5
diff -pruN 1.3.1+dfsg-1/deps/checksums/LibGit2.v0.28.2-1.x86_64-linux-musl.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/LibGit2.v0.28.2-1.x86_64-linux-musl.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/LibGit2.v0.28.2-1.x86_64-linux-musl.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/LibGit2.v0.28.2-1.x86_64-linux-musl.tar.gz/md5	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+405902170ac8d62e8dcb985ca952c4e5
diff -pruN 1.3.1+dfsg-1/deps/checksums/LibGit2.v0.28.2-1.x86_64-linux-musl.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/LibGit2.v0.28.2-1.x86_64-linux-musl.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/LibGit2.v0.28.2-1.x86_64-linux-musl.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/LibGit2.v0.28.2-1.x86_64-linux-musl.tar.gz/sha512	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+95f9f17d541d80ed06e915486d7ed73e605197d88f08cb34fdebf2ad89efb9144149cd05dc096c3b1583d3b93e02bbcc27a66d341cc2421d08d3f46ffb7cd733
diff -pruN 1.3.1+dfsg-1/deps/checksums/LibGit2.v0.28.2-1.x86_64-unknown-freebsd11.1.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/LibGit2.v0.28.2-1.x86_64-unknown-freebsd11.1.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/LibGit2.v0.28.2-1.x86_64-unknown-freebsd11.1.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/LibGit2.v0.28.2-1.x86_64-unknown-freebsd11.1.tar.gz/md5	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+7e4c7190e4e7994cdb2d9b8cdc1b3bad
diff -pruN 1.3.1+dfsg-1/deps/checksums/LibGit2.v0.28.2-1.x86_64-unknown-freebsd11.1.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/LibGit2.v0.28.2-1.x86_64-unknown-freebsd11.1.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/LibGit2.v0.28.2-1.x86_64-unknown-freebsd11.1.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/LibGit2.v0.28.2-1.x86_64-unknown-freebsd11.1.tar.gz/sha512	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+64efd8bb016aa1e9ef8c36004d0b5feb9d433a303687d70eb88fd3eb7dfb3e11081cd6b8eaeb34a2ddd226f3133ed080f615ed2f56c0af5688ad57eafe7937c7
diff -pruN 1.3.1+dfsg-1/deps/checksums/LibGit2.v0.28.2-1.x86_64-w64-mingw32.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/LibGit2.v0.28.2-1.x86_64-w64-mingw32.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/LibGit2.v0.28.2-1.x86_64-w64-mingw32.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/LibGit2.v0.28.2-1.x86_64-w64-mingw32.tar.gz/md5	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+cb35d78529b0e4896c2a6101ad01800c
diff -pruN 1.3.1+dfsg-1/deps/checksums/LibGit2.v0.28.2-1.x86_64-w64-mingw32.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/LibGit2.v0.28.2-1.x86_64-w64-mingw32.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/LibGit2.v0.28.2-1.x86_64-w64-mingw32.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/LibGit2.v0.28.2-1.x86_64-w64-mingw32.tar.gz/sha512	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+dd02d1ad28befbc47a6ddfaaf748895e6ce5a9ead8ec76d81ba19e0004099746187fb5f8e6cd647c0fd1ec611393b65890e4e64de4d042c8288b162c1554f9b6
diff -pruN 1.3.1+dfsg-1/deps/checksums/LibSSH2.v1.9.0-0.aarch64-linux-gnu.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/LibSSH2.v1.9.0-0.aarch64-linux-gnu.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/LibSSH2.v1.9.0-0.aarch64-linux-gnu.tar.gz/md5	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/LibSSH2.v1.9.0-0.aarch64-linux-gnu.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-1de9f0816b41dd7c15640d6fd7bb8d5e
diff -pruN 1.3.1+dfsg-1/deps/checksums/LibSSH2.v1.9.0-0.aarch64-linux-gnu.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/LibSSH2.v1.9.0-0.aarch64-linux-gnu.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/LibSSH2.v1.9.0-0.aarch64-linux-gnu.tar.gz/sha512	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/LibSSH2.v1.9.0-0.aarch64-linux-gnu.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-c2dbbd47befc923c11efa66f05ec1e1d38a3e3da438dcd5da29748f2e6c6ec944ac1d5e8f0062f4c46513faa39e903c8194df8f680b816458e0337d60ccbd9fa
diff -pruN 1.3.1+dfsg-1/deps/checksums/LibSSH2.v1.9.0-0.aarch64-linux-musl.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/LibSSH2.v1.9.0-0.aarch64-linux-musl.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/LibSSH2.v1.9.0-0.aarch64-linux-musl.tar.gz/md5	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/LibSSH2.v1.9.0-0.aarch64-linux-musl.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-6d7a76ebedd2425b53d23ccebd6a4592
diff -pruN 1.3.1+dfsg-1/deps/checksums/LibSSH2.v1.9.0-0.aarch64-linux-musl.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/LibSSH2.v1.9.0-0.aarch64-linux-musl.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/LibSSH2.v1.9.0-0.aarch64-linux-musl.tar.gz/sha512	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/LibSSH2.v1.9.0-0.aarch64-linux-musl.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-b62666ef1f84c8236924188cb31701070356e36f7587d2d3bf13c4049996df06c96e3c4cdf4527fa0091491c5b3103cdfbf07a8fe37601359b86fe87741a2db4
diff -pruN 1.3.1+dfsg-1/deps/checksums/LibSSH2.v1.9.0-0.arm-linux-gnueabihf.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/LibSSH2.v1.9.0-0.arm-linux-gnueabihf.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/LibSSH2.v1.9.0-0.arm-linux-gnueabihf.tar.gz/md5	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/LibSSH2.v1.9.0-0.arm-linux-gnueabihf.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-ecc04e3bd5dfde850c58506320810c6e
diff -pruN 1.3.1+dfsg-1/deps/checksums/LibSSH2.v1.9.0-0.arm-linux-gnueabihf.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/LibSSH2.v1.9.0-0.arm-linux-gnueabihf.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/LibSSH2.v1.9.0-0.arm-linux-gnueabihf.tar.gz/sha512	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/LibSSH2.v1.9.0-0.arm-linux-gnueabihf.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-93f7f3f92834d375da5a1fb2e766a7097628422c2d1dcdcc2f5e2388f31d1fbb2736ad8df3bf68c6a0b17e843c76b27c9c0d01b39bb2ea4df57cf6d5b753d322
diff -pruN 1.3.1+dfsg-1/deps/checksums/LibSSH2.v1.9.0-0.arm-linux-musleabihf.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/LibSSH2.v1.9.0-0.arm-linux-musleabihf.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/LibSSH2.v1.9.0-0.arm-linux-musleabihf.tar.gz/md5	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/LibSSH2.v1.9.0-0.arm-linux-musleabihf.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-d9bc4c981347f8efa5083eaa9be8198a
diff -pruN 1.3.1+dfsg-1/deps/checksums/LibSSH2.v1.9.0-0.arm-linux-musleabihf.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/LibSSH2.v1.9.0-0.arm-linux-musleabihf.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/LibSSH2.v1.9.0-0.arm-linux-musleabihf.tar.gz/sha512	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/LibSSH2.v1.9.0-0.arm-linux-musleabihf.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-8a24b413f144499d866cace7dd32d3f366e6ba43bd170bf7a4924c985781144fa050573afcef9e1f4cedb0f70ec75625752656f6b71c208d95df2f067d9a04fc
diff -pruN 1.3.1+dfsg-1/deps/checksums/LibSSH2.v1.9.0-0.i686-linux-gnu.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/LibSSH2.v1.9.0-0.i686-linux-gnu.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/LibSSH2.v1.9.0-0.i686-linux-gnu.tar.gz/md5	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/LibSSH2.v1.9.0-0.i686-linux-gnu.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-65d5f6fa0a77175cf62ddb6a157715d7
diff -pruN 1.3.1+dfsg-1/deps/checksums/LibSSH2.v1.9.0-0.i686-linux-gnu.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/LibSSH2.v1.9.0-0.i686-linux-gnu.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/LibSSH2.v1.9.0-0.i686-linux-gnu.tar.gz/sha512	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/LibSSH2.v1.9.0-0.i686-linux-gnu.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-ef93dc51651338e42b23039fbcee8a48e4cfea7e4b9dcd1d0f4049a752e7ec563ed1f0a951157a5402be8b206def82da253f7fa3652c1480a1507bc6faaae382
diff -pruN 1.3.1+dfsg-1/deps/checksums/LibSSH2.v1.9.0-0.i686-linux-musl.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/LibSSH2.v1.9.0-0.i686-linux-musl.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/LibSSH2.v1.9.0-0.i686-linux-musl.tar.gz/md5	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/LibSSH2.v1.9.0-0.i686-linux-musl.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-de5c00c9e4b0a9a4d26afe0a73d528b9
diff -pruN 1.3.1+dfsg-1/deps/checksums/LibSSH2.v1.9.0-0.i686-linux-musl.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/LibSSH2.v1.9.0-0.i686-linux-musl.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/LibSSH2.v1.9.0-0.i686-linux-musl.tar.gz/sha512	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/LibSSH2.v1.9.0-0.i686-linux-musl.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-7c496df3e147991994bd3c37497e2c51c0ce00e709adb86a8789c8b252af7e8148f7e2e71439e435e78fde4cd7695444a8f532e02529698fc8c795f8ebafff10
diff -pruN 1.3.1+dfsg-1/deps/checksums/LibSSH2.v1.9.0-0.i686-w64-mingw32.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/LibSSH2.v1.9.0-0.i686-w64-mingw32.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/LibSSH2.v1.9.0-0.i686-w64-mingw32.tar.gz/md5	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/LibSSH2.v1.9.0-0.i686-w64-mingw32.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-6908e848c335c58c8685859916ca840e
diff -pruN 1.3.1+dfsg-1/deps/checksums/LibSSH2.v1.9.0-0.i686-w64-mingw32.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/LibSSH2.v1.9.0-0.i686-w64-mingw32.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/LibSSH2.v1.9.0-0.i686-w64-mingw32.tar.gz/sha512	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/LibSSH2.v1.9.0-0.i686-w64-mingw32.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-f4a004e919b95bba227f0fa2595a60c7caab168f3558ad5559d6f7ab2777dec70eefb434294e8fbafe7414ea15d6669f6a8d09e882183cb8a6efc59298517b1f
diff -pruN 1.3.1+dfsg-1/deps/checksums/LibSSH2.v1.9.0-0.powerpc64le-linux-gnu.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/LibSSH2.v1.9.0-0.powerpc64le-linux-gnu.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/LibSSH2.v1.9.0-0.powerpc64le-linux-gnu.tar.gz/md5	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/LibSSH2.v1.9.0-0.powerpc64le-linux-gnu.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-72ab7a7bb11e4961036b935c1dd4dfd7
diff -pruN 1.3.1+dfsg-1/deps/checksums/LibSSH2.v1.9.0-0.powerpc64le-linux-gnu.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/LibSSH2.v1.9.0-0.powerpc64le-linux-gnu.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/LibSSH2.v1.9.0-0.powerpc64le-linux-gnu.tar.gz/sha512	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/LibSSH2.v1.9.0-0.powerpc64le-linux-gnu.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-aaf4e21768ab22a91848116615aea6eb1d9763894a7080bbd88ca50a40382488ad42dde61e220a730ad30a4062f658c233ef0ac298913e7a35f3de62476a31f6
diff -pruN 1.3.1+dfsg-1/deps/checksums/LibSSH2.v1.9.0-0.x86_64-apple-darwin14.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/LibSSH2.v1.9.0-0.x86_64-apple-darwin14.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/LibSSH2.v1.9.0-0.x86_64-apple-darwin14.tar.gz/md5	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/LibSSH2.v1.9.0-0.x86_64-apple-darwin14.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-f383418e3c79f80a8b808e5a11653acb
diff -pruN 1.3.1+dfsg-1/deps/checksums/LibSSH2.v1.9.0-0.x86_64-apple-darwin14.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/LibSSH2.v1.9.0-0.x86_64-apple-darwin14.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/LibSSH2.v1.9.0-0.x86_64-apple-darwin14.tar.gz/sha512	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/LibSSH2.v1.9.0-0.x86_64-apple-darwin14.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-5a49877bd90cb314628e1acd120a6c15319e1b10e7b6326cb3f420f6d1921348c0e2331b50af52388fbc31309cf54bdb31235f1c58571f870756fbe3947cfa22
diff -pruN 1.3.1+dfsg-1/deps/checksums/LibSSH2.v1.9.0-0.x86_64-linux-gnu.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/LibSSH2.v1.9.0-0.x86_64-linux-gnu.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/LibSSH2.v1.9.0-0.x86_64-linux-gnu.tar.gz/md5	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/LibSSH2.v1.9.0-0.x86_64-linux-gnu.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-dcab51c5abd84cea28ab5eb8f279fae4
diff -pruN 1.3.1+dfsg-1/deps/checksums/LibSSH2.v1.9.0-0.x86_64-linux-gnu.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/LibSSH2.v1.9.0-0.x86_64-linux-gnu.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/LibSSH2.v1.9.0-0.x86_64-linux-gnu.tar.gz/sha512	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/LibSSH2.v1.9.0-0.x86_64-linux-gnu.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-a7888e271801b0992b8b61d1e8d6e4fa3cf69920655bc756d35aafbb685d07df8a2f5af48217b47135edc6bad50748f2c122181bf6c8e7ac77a08ab5c2206ada
diff -pruN 1.3.1+dfsg-1/deps/checksums/LibSSH2.v1.9.0-0.x86_64-linux-musl.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/LibSSH2.v1.9.0-0.x86_64-linux-musl.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/LibSSH2.v1.9.0-0.x86_64-linux-musl.tar.gz/md5	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/LibSSH2.v1.9.0-0.x86_64-linux-musl.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-7d64466c8210cd691295ae9ecbb3ae7e
diff -pruN 1.3.1+dfsg-1/deps/checksums/LibSSH2.v1.9.0-0.x86_64-linux-musl.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/LibSSH2.v1.9.0-0.x86_64-linux-musl.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/LibSSH2.v1.9.0-0.x86_64-linux-musl.tar.gz/sha512	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/LibSSH2.v1.9.0-0.x86_64-linux-musl.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-87f0beae3ec9a82cd4df54a480c84b1b04c401fed0cec1515665832aa4a5a2b86923e97beaa37dad8eb259fc1e707b4a47e05747ad88137def12becf1d82a144
diff -pruN 1.3.1+dfsg-1/deps/checksums/LibSSH2.v1.9.0-0.x86_64-unknown-freebsd11.1.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/LibSSH2.v1.9.0-0.x86_64-unknown-freebsd11.1.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/LibSSH2.v1.9.0-0.x86_64-unknown-freebsd11.1.tar.gz/md5	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/LibSSH2.v1.9.0-0.x86_64-unknown-freebsd11.1.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-82147c4cfe14c5e9213776dc8a3162fe
diff -pruN 1.3.1+dfsg-1/deps/checksums/LibSSH2.v1.9.0-0.x86_64-unknown-freebsd11.1.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/LibSSH2.v1.9.0-0.x86_64-unknown-freebsd11.1.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/LibSSH2.v1.9.0-0.x86_64-unknown-freebsd11.1.tar.gz/sha512	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/LibSSH2.v1.9.0-0.x86_64-unknown-freebsd11.1.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-ce64acd2655fc2b6af56ec00c910ff0123b32995bb62af9e1d6cf48194ef994fecb3e4f2b16d0e8060c9740206fae178e3b6fe89cf95992289e7dee8fdccb982
diff -pruN 1.3.1+dfsg-1/deps/checksums/LibSSH2.v1.9.0-0.x86_64-w64-mingw32.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/LibSSH2.v1.9.0-0.x86_64-w64-mingw32.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/LibSSH2.v1.9.0-0.x86_64-w64-mingw32.tar.gz/md5	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/LibSSH2.v1.9.0-0.x86_64-w64-mingw32.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-5e751cb7817a151a88b828dc077f0982
diff -pruN 1.3.1+dfsg-1/deps/checksums/LibSSH2.v1.9.0-0.x86_64-w64-mingw32.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/LibSSH2.v1.9.0-0.x86_64-w64-mingw32.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/LibSSH2.v1.9.0-0.x86_64-w64-mingw32.tar.gz/sha512	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/LibSSH2.v1.9.0-0.x86_64-w64-mingw32.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-8e8c70a993a30e88e06c11eb7042d7ec45f2737790eda7d14bca8e8689d713eda7ca791b4011bbfe5bbec16039c4bfd5cec068bf0194c104fcaf446d48bf0c1a
diff -pruN 1.3.1+dfsg-1/deps/checksums/LibSSH2.v1.9.0-1.aarch64-linux-gnu.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/LibSSH2.v1.9.0-1.aarch64-linux-gnu.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/LibSSH2.v1.9.0-1.aarch64-linux-gnu.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/LibSSH2.v1.9.0-1.aarch64-linux-gnu.tar.gz/md5	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+36ef163789d9123a0af39bd96e8ff79f
diff -pruN 1.3.1+dfsg-1/deps/checksums/LibSSH2.v1.9.0-1.aarch64-linux-gnu.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/LibSSH2.v1.9.0-1.aarch64-linux-gnu.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/LibSSH2.v1.9.0-1.aarch64-linux-gnu.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/LibSSH2.v1.9.0-1.aarch64-linux-gnu.tar.gz/sha512	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+e4a64003193d9e25a4e1a23e67b8f1a52c478984cab43ed6c75a5e8fcebb4050b5b574cc553ed18c39a26b06327ebd4d73bec0dd680cfbd8f9ac6e431503a05f
diff -pruN 1.3.1+dfsg-1/deps/checksums/LibSSH2.v1.9.0-1.aarch64-linux-musl.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/LibSSH2.v1.9.0-1.aarch64-linux-musl.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/LibSSH2.v1.9.0-1.aarch64-linux-musl.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/LibSSH2.v1.9.0-1.aarch64-linux-musl.tar.gz/md5	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+620dd756343f22afe53b6b00a25462ef
diff -pruN 1.3.1+dfsg-1/deps/checksums/LibSSH2.v1.9.0-1.aarch64-linux-musl.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/LibSSH2.v1.9.0-1.aarch64-linux-musl.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/LibSSH2.v1.9.0-1.aarch64-linux-musl.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/LibSSH2.v1.9.0-1.aarch64-linux-musl.tar.gz/sha512	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+7ac0e9a28647b4d411dd4e0ab76b2592f488ba76ba5c2651f42acc7e647f62c9804bd271225b2a652c697e6c4767a74ec70d7ba6e2682babd59a92dc9f0b089c
diff -pruN 1.3.1+dfsg-1/deps/checksums/LibSSH2.v1.9.0-1.arm-linux-gnueabihf.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/LibSSH2.v1.9.0-1.arm-linux-gnueabihf.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/LibSSH2.v1.9.0-1.arm-linux-gnueabihf.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/LibSSH2.v1.9.0-1.arm-linux-gnueabihf.tar.gz/md5	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+4a271ec41134206741057b1d073aa0e2
diff -pruN 1.3.1+dfsg-1/deps/checksums/LibSSH2.v1.9.0-1.arm-linux-gnueabihf.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/LibSSH2.v1.9.0-1.arm-linux-gnueabihf.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/LibSSH2.v1.9.0-1.arm-linux-gnueabihf.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/LibSSH2.v1.9.0-1.arm-linux-gnueabihf.tar.gz/sha512	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+a33d5e96070310b4f7c1a0dc6d17e5ff665deede4264526817b298bb32cd3554c34ca2b42fefeb1ca6f4077c9b42c62330cd60fdc9b101ca0063712f957a7723
diff -pruN 1.3.1+dfsg-1/deps/checksums/LibSSH2.v1.9.0-1.arm-linux-musleabihf.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/LibSSH2.v1.9.0-1.arm-linux-musleabihf.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/LibSSH2.v1.9.0-1.arm-linux-musleabihf.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/LibSSH2.v1.9.0-1.arm-linux-musleabihf.tar.gz/md5	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+052b885ac693514f3065bfa7768b70a5
diff -pruN 1.3.1+dfsg-1/deps/checksums/LibSSH2.v1.9.0-1.arm-linux-musleabihf.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/LibSSH2.v1.9.0-1.arm-linux-musleabihf.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/LibSSH2.v1.9.0-1.arm-linux-musleabihf.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/LibSSH2.v1.9.0-1.arm-linux-musleabihf.tar.gz/sha512	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+1af323ce0ed7d8d3cad594dd2e23bdc88ad2e1f0bd30d4ae6fadb19de4966398ec021203619873bce668d7b8afab0e16c1584b0c95faa4b8eb3535985fe300e6
diff -pruN 1.3.1+dfsg-1/deps/checksums/LibSSH2.v1.9.0-1.i686-linux-gnu.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/LibSSH2.v1.9.0-1.i686-linux-gnu.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/LibSSH2.v1.9.0-1.i686-linux-gnu.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/LibSSH2.v1.9.0-1.i686-linux-gnu.tar.gz/md5	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+0e7ebeec5b7dc73f9ce2d2f3f81ee87a
diff -pruN 1.3.1+dfsg-1/deps/checksums/LibSSH2.v1.9.0-1.i686-linux-gnu.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/LibSSH2.v1.9.0-1.i686-linux-gnu.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/LibSSH2.v1.9.0-1.i686-linux-gnu.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/LibSSH2.v1.9.0-1.i686-linux-gnu.tar.gz/sha512	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+c8b34527d47d5a2c91a3eabe36513d7e1c14998d14ca5e8561e0dcd219cf8f0c0e998229eb2755bda7d891f78d0d3326aa38efd58334fb4508dd10df12e5398b
diff -pruN 1.3.1+dfsg-1/deps/checksums/LibSSH2.v1.9.0-1.i686-linux-musl.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/LibSSH2.v1.9.0-1.i686-linux-musl.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/LibSSH2.v1.9.0-1.i686-linux-musl.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/LibSSH2.v1.9.0-1.i686-linux-musl.tar.gz/md5	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+be9ecaa94737cdb551f2c1c8b880f2a6
diff -pruN 1.3.1+dfsg-1/deps/checksums/LibSSH2.v1.9.0-1.i686-linux-musl.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/LibSSH2.v1.9.0-1.i686-linux-musl.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/LibSSH2.v1.9.0-1.i686-linux-musl.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/LibSSH2.v1.9.0-1.i686-linux-musl.tar.gz/sha512	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+ff23a8437ae12a7f0f1f844d14f1853a54260cdcd0d3be4f0bc6032e3cb561290e25aac20f7532aa5561d3af66081fb7cd3cf5ed480b1799ffe86950383870a9
diff -pruN 1.3.1+dfsg-1/deps/checksums/LibSSH2.v1.9.0-1.i686-w64-mingw32.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/LibSSH2.v1.9.0-1.i686-w64-mingw32.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/LibSSH2.v1.9.0-1.i686-w64-mingw32.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/LibSSH2.v1.9.0-1.i686-w64-mingw32.tar.gz/md5	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+b323bb6d450bd5d6e2943dfbf66de570
diff -pruN 1.3.1+dfsg-1/deps/checksums/LibSSH2.v1.9.0-1.i686-w64-mingw32.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/LibSSH2.v1.9.0-1.i686-w64-mingw32.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/LibSSH2.v1.9.0-1.i686-w64-mingw32.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/LibSSH2.v1.9.0-1.i686-w64-mingw32.tar.gz/sha512	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+044c673057552f18009510c012b90b98e50f9a2ac086b18e3faeef4cc7ca28aa1d894f4083c96f014ba4d0d38cfcb2e5c704c21de2101b834efb60c8940a05b0
diff -pruN 1.3.1+dfsg-1/deps/checksums/LibSSH2.v1.9.0-1.powerpc64le-linux-gnu.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/LibSSH2.v1.9.0-1.powerpc64le-linux-gnu.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/LibSSH2.v1.9.0-1.powerpc64le-linux-gnu.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/LibSSH2.v1.9.0-1.powerpc64le-linux-gnu.tar.gz/md5	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+64fa75fec57f25a758e42cab73b4dde5
diff -pruN 1.3.1+dfsg-1/deps/checksums/LibSSH2.v1.9.0-1.powerpc64le-linux-gnu.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/LibSSH2.v1.9.0-1.powerpc64le-linux-gnu.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/LibSSH2.v1.9.0-1.powerpc64le-linux-gnu.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/LibSSH2.v1.9.0-1.powerpc64le-linux-gnu.tar.gz/sha512	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+1d911876ee40d02c7ce81298652e6d62e7133ce6a408dc7ac9b93e8bf73cc89e1836ebccf9c946c3cf908fe5cc56648eed992351a1856ed7085d5af42683338a
diff -pruN 1.3.1+dfsg-1/deps/checksums/LibSSH2.v1.9.0-1.x86_64-apple-darwin14.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/LibSSH2.v1.9.0-1.x86_64-apple-darwin14.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/LibSSH2.v1.9.0-1.x86_64-apple-darwin14.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/LibSSH2.v1.9.0-1.x86_64-apple-darwin14.tar.gz/md5	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+5e88e48a97ab8a5cfefb7538d4f1e070
diff -pruN 1.3.1+dfsg-1/deps/checksums/LibSSH2.v1.9.0-1.x86_64-apple-darwin14.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/LibSSH2.v1.9.0-1.x86_64-apple-darwin14.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/LibSSH2.v1.9.0-1.x86_64-apple-darwin14.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/LibSSH2.v1.9.0-1.x86_64-apple-darwin14.tar.gz/sha512	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+20cf8fe1c2e5d7735bb11f3f464ef9fac1f6f5178dc40a42abdb640a39b6d08724c6ab76f5c2ddf9ed29c9ff6898acf204702fc576a8cf2985e8c511075f8adf
diff -pruN 1.3.1+dfsg-1/deps/checksums/LibSSH2.v1.9.0-1.x86_64-linux-gnu.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/LibSSH2.v1.9.0-1.x86_64-linux-gnu.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/LibSSH2.v1.9.0-1.x86_64-linux-gnu.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/LibSSH2.v1.9.0-1.x86_64-linux-gnu.tar.gz/md5	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+e1413e4b8017b830f722ec41e12b1d20
diff -pruN 1.3.1+dfsg-1/deps/checksums/LibSSH2.v1.9.0-1.x86_64-linux-gnu.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/LibSSH2.v1.9.0-1.x86_64-linux-gnu.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/LibSSH2.v1.9.0-1.x86_64-linux-gnu.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/LibSSH2.v1.9.0-1.x86_64-linux-gnu.tar.gz/sha512	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+ad2a951e581c3ef46bce3a79ba6e19c35e2ea403b2cd6417b539d7f8520488f57dc63e19ad516a1dcfd3b0f1cf68686d7ac9e050c07f5c16ca92b4322eda22d3
diff -pruN 1.3.1+dfsg-1/deps/checksums/LibSSH2.v1.9.0-1.x86_64-linux-musl.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/LibSSH2.v1.9.0-1.x86_64-linux-musl.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/LibSSH2.v1.9.0-1.x86_64-linux-musl.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/LibSSH2.v1.9.0-1.x86_64-linux-musl.tar.gz/md5	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+4d89b52c247a366985b37ba94998898e
diff -pruN 1.3.1+dfsg-1/deps/checksums/LibSSH2.v1.9.0-1.x86_64-linux-musl.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/LibSSH2.v1.9.0-1.x86_64-linux-musl.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/LibSSH2.v1.9.0-1.x86_64-linux-musl.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/LibSSH2.v1.9.0-1.x86_64-linux-musl.tar.gz/sha512	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+81e8e9731c5ff5b2349bf2c389a7da9eb57ac252ee5328e315b7562ef39a14b3cb274abebf5bb30215faff126569dd963802c1156fecfe19314a7bddff670939
diff -pruN 1.3.1+dfsg-1/deps/checksums/LibSSH2.v1.9.0-1.x86_64-unknown-freebsd11.1.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/LibSSH2.v1.9.0-1.x86_64-unknown-freebsd11.1.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/LibSSH2.v1.9.0-1.x86_64-unknown-freebsd11.1.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/LibSSH2.v1.9.0-1.x86_64-unknown-freebsd11.1.tar.gz/md5	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+ce0354563496eabe705db1716cbb4aa2
diff -pruN 1.3.1+dfsg-1/deps/checksums/LibSSH2.v1.9.0-1.x86_64-unknown-freebsd11.1.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/LibSSH2.v1.9.0-1.x86_64-unknown-freebsd11.1.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/LibSSH2.v1.9.0-1.x86_64-unknown-freebsd11.1.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/LibSSH2.v1.9.0-1.x86_64-unknown-freebsd11.1.tar.gz/sha512	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+9b29b82aa53d44e580959465132ce39acbbf785c24fe0d141429f925509ce81dc3cb134a2793425c143064db9ba556418d941b5d7f59a1d5e641df9e7ce9a5a8
diff -pruN 1.3.1+dfsg-1/deps/checksums/LibSSH2.v1.9.0-1.x86_64-w64-mingw32.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/LibSSH2.v1.9.0-1.x86_64-w64-mingw32.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/LibSSH2.v1.9.0-1.x86_64-w64-mingw32.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/LibSSH2.v1.9.0-1.x86_64-w64-mingw32.tar.gz/md5	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+49460ec6b30eeb99a786f75d42facfda
diff -pruN 1.3.1+dfsg-1/deps/checksums/LibSSH2.v1.9.0-1.x86_64-w64-mingw32.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/LibSSH2.v1.9.0-1.x86_64-w64-mingw32.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/LibSSH2.v1.9.0-1.x86_64-w64-mingw32.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/LibSSH2.v1.9.0-1.x86_64-w64-mingw32.tar.gz/sha512	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+467d0ebff3af6d3d8f47db82543fd2bbf38fdc4b26a2694c24bb468f765e3b5f23abefdfe41c5d609f55aac6a41b24a7aa7d0ba0d72971f9fe192f257ef515f6
diff -pruN 1.3.1+dfsg-1/deps/checksums/llvm-8.0.1.src.tar.xz/md5 1.4.0+dfsg-1/deps/checksums/llvm-8.0.1.src.tar.xz/md5
--- 1.3.1+dfsg-1/deps/checksums/llvm-8.0.1.src.tar.xz/md5	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/llvm-8.0.1.src.tar.xz/md5	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+9a3b63df01c52556f7afb5617934e79e
diff -pruN 1.3.1+dfsg-1/deps/checksums/llvm-8.0.1.src.tar.xz/sha512 1.4.0+dfsg-1/deps/checksums/llvm-8.0.1.src.tar.xz/sha512
--- 1.3.1+dfsg-1/deps/checksums/llvm-8.0.1.src.tar.xz/sha512	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/llvm-8.0.1.src.tar.xz/sha512	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+82e120be5cabdfd5111aebbea68a663fe229c8861d73802d6ab09a3bf48f60de333e07e61f8fb61beaa14ac2bea24fcd74fa6f761acaf62469f536b79fcb1e16
diff -pruN 1.3.1+dfsg-1/deps/checksums/llvm-9.0.0.src.tar.xz/md5 1.4.0+dfsg-1/deps/checksums/llvm-9.0.0.src.tar.xz/md5
--- 1.3.1+dfsg-1/deps/checksums/llvm-9.0.0.src.tar.xz/md5	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/llvm-9.0.0.src.tar.xz/md5	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+0fd4283ff485dffb71a4f1cc8fd3fc72
diff -pruN 1.3.1+dfsg-1/deps/checksums/llvm-9.0.0.src.tar.xz/sha512 1.4.0+dfsg-1/deps/checksums/llvm-9.0.0.src.tar.xz/sha512
--- 1.3.1+dfsg-1/deps/checksums/llvm-9.0.0.src.tar.xz/sha512	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/llvm-9.0.0.src.tar.xz/sha512	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+1bb3341e1d231559b948f1505b33c2e2e03989f9b8bbfef0e0cdaff5ac43f85574c9ec5ac53399b914f497d6899425d861411024e8d7e1d1a338c1c6951ac658
diff -pruN 1.3.1+dfsg-1/deps/checksums/LLVM_full_assert.v8.0.1-0.aarch64-linux-gnu-cxx03.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/LLVM_full_assert.v8.0.1-0.aarch64-linux-gnu-cxx03.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/LLVM_full_assert.v8.0.1-0.aarch64-linux-gnu-cxx03.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/LLVM_full_assert.v8.0.1-0.aarch64-linux-gnu-cxx03.tar.gz/md5	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+59bebffb94f168e171f64ab064d99510
diff -pruN 1.3.1+dfsg-1/deps/checksums/LLVM_full_assert.v8.0.1-0.aarch64-linux-gnu-cxx03.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/LLVM_full_assert.v8.0.1-0.aarch64-linux-gnu-cxx03.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/LLVM_full_assert.v8.0.1-0.aarch64-linux-gnu-cxx03.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/LLVM_full_assert.v8.0.1-0.aarch64-linux-gnu-cxx03.tar.gz/sha512	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+6ba3c1876451952d77907ec12fb0bbbf575d6379b2896739dc32501e7481ab7a209c0fabaca027050443aeb67216f9ec3be5331b3613e63224ecdc86dd138564
diff -pruN 1.3.1+dfsg-1/deps/checksums/LLVM_full_assert.v8.0.1-0.aarch64-linux-gnu-cxx11.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/LLVM_full_assert.v8.0.1-0.aarch64-linux-gnu-cxx11.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/LLVM_full_assert.v8.0.1-0.aarch64-linux-gnu-cxx11.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/LLVM_full_assert.v8.0.1-0.aarch64-linux-gnu-cxx11.tar.gz/md5	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+98267af9647881bbd3a2ce8f38720134
diff -pruN 1.3.1+dfsg-1/deps/checksums/LLVM_full_assert.v8.0.1-0.aarch64-linux-gnu-cxx11.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/LLVM_full_assert.v8.0.1-0.aarch64-linux-gnu-cxx11.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/LLVM_full_assert.v8.0.1-0.aarch64-linux-gnu-cxx11.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/LLVM_full_assert.v8.0.1-0.aarch64-linux-gnu-cxx11.tar.gz/sha512	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+eea55ae9fe832bcc7bb3c6659eacd42a93ff91bad04b84858817a67bb056dcc4343b2a2e547fea4994ab8000ef20332c7a8803fedac02850bcd021ce3a06565b
diff -pruN 1.3.1+dfsg-1/deps/checksums/LLVM_full_assert.v8.0.1-0.aarch64-linux-musl-cxx03.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/LLVM_full_assert.v8.0.1-0.aarch64-linux-musl-cxx03.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/LLVM_full_assert.v8.0.1-0.aarch64-linux-musl-cxx03.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/LLVM_full_assert.v8.0.1-0.aarch64-linux-musl-cxx03.tar.gz/md5	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+3299a19e079c642520cba3ad61b45d85
diff -pruN 1.3.1+dfsg-1/deps/checksums/LLVM_full_assert.v8.0.1-0.aarch64-linux-musl-cxx03.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/LLVM_full_assert.v8.0.1-0.aarch64-linux-musl-cxx03.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/LLVM_full_assert.v8.0.1-0.aarch64-linux-musl-cxx03.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/LLVM_full_assert.v8.0.1-0.aarch64-linux-musl-cxx03.tar.gz/sha512	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+63c913dcb925660cece1e7db6f42e03be21b8a2a06b5fb657a47546ea238b774f1f9d7d1897e57bdf8fab634d663d5532f1d4702dfaeeb650b30499d84e78eae
diff -pruN 1.3.1+dfsg-1/deps/checksums/LLVM_full_assert.v8.0.1-0.aarch64-linux-musl-cxx11.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/LLVM_full_assert.v8.0.1-0.aarch64-linux-musl-cxx11.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/LLVM_full_assert.v8.0.1-0.aarch64-linux-musl-cxx11.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/LLVM_full_assert.v8.0.1-0.aarch64-linux-musl-cxx11.tar.gz/md5	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+b5b4342c83c59e7e8fa08b9954533201
diff -pruN 1.3.1+dfsg-1/deps/checksums/LLVM_full_assert.v8.0.1-0.aarch64-linux-musl-cxx11.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/LLVM_full_assert.v8.0.1-0.aarch64-linux-musl-cxx11.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/LLVM_full_assert.v8.0.1-0.aarch64-linux-musl-cxx11.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/LLVM_full_assert.v8.0.1-0.aarch64-linux-musl-cxx11.tar.gz/sha512	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+df9c4f81a984ba33f669ef2e7c39f49016d2a590f46928402010b5a57b0d1e4a6028624f8b61ad3611773da2fd3e74b94138c387412c991d1d33ca959ddae214
diff -pruN 1.3.1+dfsg-1/deps/checksums/LLVM_full_assert.v8.0.1-0.arm-linux-gnueabihf-cxx03.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/LLVM_full_assert.v8.0.1-0.arm-linux-gnueabihf-cxx03.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/LLVM_full_assert.v8.0.1-0.arm-linux-gnueabihf-cxx03.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/LLVM_full_assert.v8.0.1-0.arm-linux-gnueabihf-cxx03.tar.gz/md5	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+10a68e2e502548e605d4c8ce91275030
diff -pruN 1.3.1+dfsg-1/deps/checksums/LLVM_full_assert.v8.0.1-0.arm-linux-gnueabihf-cxx03.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/LLVM_full_assert.v8.0.1-0.arm-linux-gnueabihf-cxx03.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/LLVM_full_assert.v8.0.1-0.arm-linux-gnueabihf-cxx03.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/LLVM_full_assert.v8.0.1-0.arm-linux-gnueabihf-cxx03.tar.gz/sha512	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+fd2102e79b3e818f7783adcf688c5a3dbbc159cff476aad1e55b4cf983817fa8de9ec2084cfdb2c801aa347e331fedd005f906dceb4f4a8a6360cd0c7a06122d
diff -pruN 1.3.1+dfsg-1/deps/checksums/LLVM_full_assert.v8.0.1-0.arm-linux-gnueabihf-cxx11.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/LLVM_full_assert.v8.0.1-0.arm-linux-gnueabihf-cxx11.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/LLVM_full_assert.v8.0.1-0.arm-linux-gnueabihf-cxx11.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/LLVM_full_assert.v8.0.1-0.arm-linux-gnueabihf-cxx11.tar.gz/md5	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+462644259315e24f54ef677c5955c8f3
diff -pruN 1.3.1+dfsg-1/deps/checksums/LLVM_full_assert.v8.0.1-0.arm-linux-gnueabihf-cxx11.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/LLVM_full_assert.v8.0.1-0.arm-linux-gnueabihf-cxx11.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/LLVM_full_assert.v8.0.1-0.arm-linux-gnueabihf-cxx11.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/LLVM_full_assert.v8.0.1-0.arm-linux-gnueabihf-cxx11.tar.gz/sha512	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+488ab892de11e0ab86f923d1c302c248eacc8ece3daebefadad9dc4a1d98b4cd2368edf82884b2189958362ee40a3acd61ba8675654833dfbd2b7c6bb6de768c
diff -pruN 1.3.1+dfsg-1/deps/checksums/LLVM_full_assert.v8.0.1-0.arm-linux-musleabihf-cxx03.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/LLVM_full_assert.v8.0.1-0.arm-linux-musleabihf-cxx03.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/LLVM_full_assert.v8.0.1-0.arm-linux-musleabihf-cxx03.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/LLVM_full_assert.v8.0.1-0.arm-linux-musleabihf-cxx03.tar.gz/md5	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+47fdc91cc5d4ccb6d61891139bd1908c
diff -pruN 1.3.1+dfsg-1/deps/checksums/LLVM_full_assert.v8.0.1-0.arm-linux-musleabihf-cxx03.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/LLVM_full_assert.v8.0.1-0.arm-linux-musleabihf-cxx03.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/LLVM_full_assert.v8.0.1-0.arm-linux-musleabihf-cxx03.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/LLVM_full_assert.v8.0.1-0.arm-linux-musleabihf-cxx03.tar.gz/sha512	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+1596fc94e2579ca5ba5cd8b65cd07744e7dd590424a8233ec2c3eb1e8844fa24024d0247c3b9b2dd23ada4edf022103ec6381a15c5c82396902e67daa8bd278d
diff -pruN 1.3.1+dfsg-1/deps/checksums/LLVM_full_assert.v8.0.1-0.arm-linux-musleabihf-cxx11.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/LLVM_full_assert.v8.0.1-0.arm-linux-musleabihf-cxx11.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/LLVM_full_assert.v8.0.1-0.arm-linux-musleabihf-cxx11.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/LLVM_full_assert.v8.0.1-0.arm-linux-musleabihf-cxx11.tar.gz/md5	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+b57956ac6664e5d13643512881f6d35f
diff -pruN 1.3.1+dfsg-1/deps/checksums/LLVM_full_assert.v8.0.1-0.arm-linux-musleabihf-cxx11.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/LLVM_full_assert.v8.0.1-0.arm-linux-musleabihf-cxx11.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/LLVM_full_assert.v8.0.1-0.arm-linux-musleabihf-cxx11.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/LLVM_full_assert.v8.0.1-0.arm-linux-musleabihf-cxx11.tar.gz/sha512	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+3a114b1d2d7f69170f4a740d08c80f091cd09d98d0f5999be659d96474a01641c8552ee6582165e96e137596e079cfa4b65029618e6cfbfa731dd1b57aeca4e3
diff -pruN 1.3.1+dfsg-1/deps/checksums/LLVM_full_assert.v8.0.1-0.i686-linux-gnu-cxx03.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/LLVM_full_assert.v8.0.1-0.i686-linux-gnu-cxx03.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/LLVM_full_assert.v8.0.1-0.i686-linux-gnu-cxx03.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/LLVM_full_assert.v8.0.1-0.i686-linux-gnu-cxx03.tar.gz/md5	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+37076fadfcfdc4d8589128c4146f2c30
diff -pruN 1.3.1+dfsg-1/deps/checksums/LLVM_full_assert.v8.0.1-0.i686-linux-gnu-cxx03.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/LLVM_full_assert.v8.0.1-0.i686-linux-gnu-cxx03.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/LLVM_full_assert.v8.0.1-0.i686-linux-gnu-cxx03.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/LLVM_full_assert.v8.0.1-0.i686-linux-gnu-cxx03.tar.gz/sha512	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+5a99aa713783d40cd4504ecc4c84f776441638f9c0d5b371c2bc15a30d2bfef530dffa3c9036a078472d496f2e4194bbbafcba6b584735a692cb71c695ceb441
diff -pruN 1.3.1+dfsg-1/deps/checksums/LLVM_full_assert.v8.0.1-0.i686-linux-gnu-cxx11.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/LLVM_full_assert.v8.0.1-0.i686-linux-gnu-cxx11.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/LLVM_full_assert.v8.0.1-0.i686-linux-gnu-cxx11.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/LLVM_full_assert.v8.0.1-0.i686-linux-gnu-cxx11.tar.gz/md5	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+6917b0ea73071980ba77e26de197e258
diff -pruN 1.3.1+dfsg-1/deps/checksums/LLVM_full_assert.v8.0.1-0.i686-linux-gnu-cxx11.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/LLVM_full_assert.v8.0.1-0.i686-linux-gnu-cxx11.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/LLVM_full_assert.v8.0.1-0.i686-linux-gnu-cxx11.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/LLVM_full_assert.v8.0.1-0.i686-linux-gnu-cxx11.tar.gz/sha512	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+cec0b092e66174eda6e635d633f9b842cdd6a7f373470cd25946fcbad9cbe53b61f21c72f7a93c3c3f3e3b678a57e84b4dc17741527f334d570cfbb4bac95776
diff -pruN 1.3.1+dfsg-1/deps/checksums/LLVM_full_assert.v8.0.1-0.i686-linux-musl-cxx03.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/LLVM_full_assert.v8.0.1-0.i686-linux-musl-cxx03.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/LLVM_full_assert.v8.0.1-0.i686-linux-musl-cxx03.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/LLVM_full_assert.v8.0.1-0.i686-linux-musl-cxx03.tar.gz/md5	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+e6e9e115f9a3c335b203955caaf56ad2
diff -pruN 1.3.1+dfsg-1/deps/checksums/LLVM_full_assert.v8.0.1-0.i686-linux-musl-cxx03.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/LLVM_full_assert.v8.0.1-0.i686-linux-musl-cxx03.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/LLVM_full_assert.v8.0.1-0.i686-linux-musl-cxx03.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/LLVM_full_assert.v8.0.1-0.i686-linux-musl-cxx03.tar.gz/sha512	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+964a068db799501be63773693e126392c7985865a7d751132bf38fb4c04ace2d2eb9d35a19731f5eb6cdf4dd4062810bf0f537cb871efaf5af1db3102ee235b0
diff -pruN 1.3.1+dfsg-1/deps/checksums/LLVM_full_assert.v8.0.1-0.i686-linux-musl-cxx11.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/LLVM_full_assert.v8.0.1-0.i686-linux-musl-cxx11.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/LLVM_full_assert.v8.0.1-0.i686-linux-musl-cxx11.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/LLVM_full_assert.v8.0.1-0.i686-linux-musl-cxx11.tar.gz/md5	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+21084cd69251ad1eba12bf857f54168b
diff -pruN 1.3.1+dfsg-1/deps/checksums/LLVM_full_assert.v8.0.1-0.i686-linux-musl-cxx11.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/LLVM_full_assert.v8.0.1-0.i686-linux-musl-cxx11.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/LLVM_full_assert.v8.0.1-0.i686-linux-musl-cxx11.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/LLVM_full_assert.v8.0.1-0.i686-linux-musl-cxx11.tar.gz/sha512	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+a4579d427a726f2541820267e3ef41e6531f8a9a45dee7af1a3af93ed5f59d7bc46cc0aec8280b106fb2d2a485988c2d21464fdbfa76bf8a3f564c61d557dc9a
diff -pruN 1.3.1+dfsg-1/deps/checksums/LLVM_full_assert.v8.0.1-0.i686-w64-mingw32-cxx03.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/LLVM_full_assert.v8.0.1-0.i686-w64-mingw32-cxx03.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/LLVM_full_assert.v8.0.1-0.i686-w64-mingw32-cxx03.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/LLVM_full_assert.v8.0.1-0.i686-w64-mingw32-cxx03.tar.gz/md5	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+f5221eb8fb0d04b1c1b3e8f29ac1ef66
diff -pruN 1.3.1+dfsg-1/deps/checksums/LLVM_full_assert.v8.0.1-0.i686-w64-mingw32-cxx03.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/LLVM_full_assert.v8.0.1-0.i686-w64-mingw32-cxx03.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/LLVM_full_assert.v8.0.1-0.i686-w64-mingw32-cxx03.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/LLVM_full_assert.v8.0.1-0.i686-w64-mingw32-cxx03.tar.gz/sha512	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+33be306969c5f895f372c3052c2ab09dfa1a032b8ff96af328d24dbcc3985bf2e664f3b14bd3e0646b5bd02def9aa6fddcb6b7c85d8b066ea6081f0831979603
diff -pruN 1.3.1+dfsg-1/deps/checksums/LLVM_full_assert.v8.0.1-0.i686-w64-mingw32-cxx11.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/LLVM_full_assert.v8.0.1-0.i686-w64-mingw32-cxx11.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/LLVM_full_assert.v8.0.1-0.i686-w64-mingw32-cxx11.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/LLVM_full_assert.v8.0.1-0.i686-w64-mingw32-cxx11.tar.gz/md5	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+b2126d9a7b7d5be88d199cc36da1a005
diff -pruN 1.3.1+dfsg-1/deps/checksums/LLVM_full_assert.v8.0.1-0.i686-w64-mingw32-cxx11.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/LLVM_full_assert.v8.0.1-0.i686-w64-mingw32-cxx11.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/LLVM_full_assert.v8.0.1-0.i686-w64-mingw32-cxx11.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/LLVM_full_assert.v8.0.1-0.i686-w64-mingw32-cxx11.tar.gz/sha512	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+cf7c106ca80c2f7eac8ffdff35e9d6b19cfb2f61c7431e99bf25a3c7eca673d84b3b5647f06be3093bc43289b28e29cbd2a410435ed587dfcfcb803c80f35f4d
diff -pruN 1.3.1+dfsg-1/deps/checksums/LLVM_full_assert.v8.0.1-0.powerpc64le-linux-gnu-cxx03.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/LLVM_full_assert.v8.0.1-0.powerpc64le-linux-gnu-cxx03.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/LLVM_full_assert.v8.0.1-0.powerpc64le-linux-gnu-cxx03.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/LLVM_full_assert.v8.0.1-0.powerpc64le-linux-gnu-cxx03.tar.gz/md5	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+918dfd0f158a56943f3f7bbf50902086
diff -pruN 1.3.1+dfsg-1/deps/checksums/LLVM_full_assert.v8.0.1-0.powerpc64le-linux-gnu-cxx03.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/LLVM_full_assert.v8.0.1-0.powerpc64le-linux-gnu-cxx03.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/LLVM_full_assert.v8.0.1-0.powerpc64le-linux-gnu-cxx03.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/LLVM_full_assert.v8.0.1-0.powerpc64le-linux-gnu-cxx03.tar.gz/sha512	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+dcbc2ba2acc5a3ac0fa0012ffa7e0475f419067a5d3de3471f244b792d201ed13e2f162d5797478bdbe666783ea4ec88659895a0c35e8af463d29d093236ee0d
diff -pruN 1.3.1+dfsg-1/deps/checksums/LLVM_full_assert.v8.0.1-0.powerpc64le-linux-gnu-cxx11.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/LLVM_full_assert.v8.0.1-0.powerpc64le-linux-gnu-cxx11.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/LLVM_full_assert.v8.0.1-0.powerpc64le-linux-gnu-cxx11.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/LLVM_full_assert.v8.0.1-0.powerpc64le-linux-gnu-cxx11.tar.gz/md5	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+44213f1430188bdcaf8e6463b7346ea4
diff -pruN 1.3.1+dfsg-1/deps/checksums/LLVM_full_assert.v8.0.1-0.powerpc64le-linux-gnu-cxx11.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/LLVM_full_assert.v8.0.1-0.powerpc64le-linux-gnu-cxx11.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/LLVM_full_assert.v8.0.1-0.powerpc64le-linux-gnu-cxx11.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/LLVM_full_assert.v8.0.1-0.powerpc64le-linux-gnu-cxx11.tar.gz/sha512	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+550e68899d6dbc143f3f32bc8a31856e03f0d250228681078cbbf7661fafcb9cbbfb42a8390ddbf174d9875799912accc92f41f168e07599f61e5a3d41455871
diff -pruN 1.3.1+dfsg-1/deps/checksums/LLVM_full_assert.v8.0.1-0.x86_64-apple-darwin14-cxx03.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/LLVM_full_assert.v8.0.1-0.x86_64-apple-darwin14-cxx03.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/LLVM_full_assert.v8.0.1-0.x86_64-apple-darwin14-cxx03.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/LLVM_full_assert.v8.0.1-0.x86_64-apple-darwin14-cxx03.tar.gz/md5	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+3c9873a1631fba4ae4f43a463941ea00
diff -pruN 1.3.1+dfsg-1/deps/checksums/LLVM_full_assert.v8.0.1-0.x86_64-apple-darwin14-cxx03.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/LLVM_full_assert.v8.0.1-0.x86_64-apple-darwin14-cxx03.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/LLVM_full_assert.v8.0.1-0.x86_64-apple-darwin14-cxx03.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/LLVM_full_assert.v8.0.1-0.x86_64-apple-darwin14-cxx03.tar.gz/sha512	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+ff979f710e83997b1bac64544131e1a575796d8b38155043a242d7dfae6cccece1cde8d1bc109be99b726ae7ed311bce92b1b2bfab8dfa531bb0c5dc2a999a7a
diff -pruN 1.3.1+dfsg-1/deps/checksums/LLVM_full_assert.v8.0.1-0.x86_64-apple-darwin14-cxx11.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/LLVM_full_assert.v8.0.1-0.x86_64-apple-darwin14-cxx11.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/LLVM_full_assert.v8.0.1-0.x86_64-apple-darwin14-cxx11.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/LLVM_full_assert.v8.0.1-0.x86_64-apple-darwin14-cxx11.tar.gz/md5	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+0d18c53213f3c8df0865a80232a3540a
diff -pruN 1.3.1+dfsg-1/deps/checksums/LLVM_full_assert.v8.0.1-0.x86_64-apple-darwin14-cxx11.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/LLVM_full_assert.v8.0.1-0.x86_64-apple-darwin14-cxx11.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/LLVM_full_assert.v8.0.1-0.x86_64-apple-darwin14-cxx11.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/LLVM_full_assert.v8.0.1-0.x86_64-apple-darwin14-cxx11.tar.gz/sha512	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+c03556ad1dc36159ae1a68acc9082a630d020f58c03d090dd1496c531554c941c48714199888c6b6371721ebe510f1a473aeaadabcb89d6e6e4f92efca02fc43
diff -pruN 1.3.1+dfsg-1/deps/checksums/LLVM_full_assert.v8.0.1-0.x86_64-linux-gnu-cxx03.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/LLVM_full_assert.v8.0.1-0.x86_64-linux-gnu-cxx03.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/LLVM_full_assert.v8.0.1-0.x86_64-linux-gnu-cxx03.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/LLVM_full_assert.v8.0.1-0.x86_64-linux-gnu-cxx03.tar.gz/md5	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+9de979deeecaa0c69807f97e556f5774
diff -pruN 1.3.1+dfsg-1/deps/checksums/LLVM_full_assert.v8.0.1-0.x86_64-linux-gnu-cxx03.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/LLVM_full_assert.v8.0.1-0.x86_64-linux-gnu-cxx03.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/LLVM_full_assert.v8.0.1-0.x86_64-linux-gnu-cxx03.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/LLVM_full_assert.v8.0.1-0.x86_64-linux-gnu-cxx03.tar.gz/sha512	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+da89d16b49af3f3316bc25663b488ed824401e7fd680a5598ab274359036cfb52f87b6f9007b0ac9d7da4a7610889fc396ce427202a643fa3db3a7fc89aa7887
diff -pruN 1.3.1+dfsg-1/deps/checksums/LLVM_full_assert.v8.0.1-0.x86_64-linux-gnu-cxx11.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/LLVM_full_assert.v8.0.1-0.x86_64-linux-gnu-cxx11.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/LLVM_full_assert.v8.0.1-0.x86_64-linux-gnu-cxx11.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/LLVM_full_assert.v8.0.1-0.x86_64-linux-gnu-cxx11.tar.gz/md5	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+83b026881768c439c58943f6403a3674
diff -pruN 1.3.1+dfsg-1/deps/checksums/LLVM_full_assert.v8.0.1-0.x86_64-linux-gnu-cxx11.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/LLVM_full_assert.v8.0.1-0.x86_64-linux-gnu-cxx11.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/LLVM_full_assert.v8.0.1-0.x86_64-linux-gnu-cxx11.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/LLVM_full_assert.v8.0.1-0.x86_64-linux-gnu-cxx11.tar.gz/sha512	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+bff30000f8be685350d5af0efa93d0c5c6af8b60fffa6093156baef27354f488d6aa587a391f8e7cd266924ca39f4cba572417acf638d2646adbd9965254371e
diff -pruN 1.3.1+dfsg-1/deps/checksums/LLVM_full_assert.v8.0.1-0.x86_64-linux-musl-cxx03.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/LLVM_full_assert.v8.0.1-0.x86_64-linux-musl-cxx03.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/LLVM_full_assert.v8.0.1-0.x86_64-linux-musl-cxx03.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/LLVM_full_assert.v8.0.1-0.x86_64-linux-musl-cxx03.tar.gz/md5	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+c1ceb6bd34dc40901b7aebf097269658
diff -pruN 1.3.1+dfsg-1/deps/checksums/LLVM_full_assert.v8.0.1-0.x86_64-linux-musl-cxx03.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/LLVM_full_assert.v8.0.1-0.x86_64-linux-musl-cxx03.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/LLVM_full_assert.v8.0.1-0.x86_64-linux-musl-cxx03.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/LLVM_full_assert.v8.0.1-0.x86_64-linux-musl-cxx03.tar.gz/sha512	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+c68e3f9a741d408bddf8b2a538bb0a3f84871fb1b18d299f32fe5bc9eb071e51e7c48604a464aad0672574e8e72cf94da86e8aac23563270495b6eacb2530c76
diff -pruN 1.3.1+dfsg-1/deps/checksums/LLVM_full_assert.v8.0.1-0.x86_64-linux-musl-cxx11.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/LLVM_full_assert.v8.0.1-0.x86_64-linux-musl-cxx11.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/LLVM_full_assert.v8.0.1-0.x86_64-linux-musl-cxx11.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/LLVM_full_assert.v8.0.1-0.x86_64-linux-musl-cxx11.tar.gz/md5	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+4bb970a1bc4642410101100cc22add0d
diff -pruN 1.3.1+dfsg-1/deps/checksums/LLVM_full_assert.v8.0.1-0.x86_64-linux-musl-cxx11.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/LLVM_full_assert.v8.0.1-0.x86_64-linux-musl-cxx11.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/LLVM_full_assert.v8.0.1-0.x86_64-linux-musl-cxx11.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/LLVM_full_assert.v8.0.1-0.x86_64-linux-musl-cxx11.tar.gz/sha512	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+83f45574172b1b0403a8ca1337d7afbe54d9de91ca702796354600388868ab7c54d9c9561fc4e5ffcb1e5b3b791e1322b72232be3dee436cffaca111cde3faca
diff -pruN 1.3.1+dfsg-1/deps/checksums/LLVM_full_assert.v8.0.1-0.x86_64-unknown-freebsd11.1-cxx03.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/LLVM_full_assert.v8.0.1-0.x86_64-unknown-freebsd11.1-cxx03.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/LLVM_full_assert.v8.0.1-0.x86_64-unknown-freebsd11.1-cxx03.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/LLVM_full_assert.v8.0.1-0.x86_64-unknown-freebsd11.1-cxx03.tar.gz/md5	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+20e761b6d8641170d45205a0b3c2a6fb
diff -pruN 1.3.1+dfsg-1/deps/checksums/LLVM_full_assert.v8.0.1-0.x86_64-unknown-freebsd11.1-cxx03.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/LLVM_full_assert.v8.0.1-0.x86_64-unknown-freebsd11.1-cxx03.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/LLVM_full_assert.v8.0.1-0.x86_64-unknown-freebsd11.1-cxx03.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/LLVM_full_assert.v8.0.1-0.x86_64-unknown-freebsd11.1-cxx03.tar.gz/sha512	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+bb20e17023ee33e0e5f9d209a85c7f91792fe8777901a942d17f2933a88a759971f684efeec3e7a47aa667af0114fcc879e4ba6d53582a9ec8672261d2536e32
diff -pruN 1.3.1+dfsg-1/deps/checksums/LLVM_full_assert.v8.0.1-0.x86_64-unknown-freebsd11.1-cxx11.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/LLVM_full_assert.v8.0.1-0.x86_64-unknown-freebsd11.1-cxx11.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/LLVM_full_assert.v8.0.1-0.x86_64-unknown-freebsd11.1-cxx11.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/LLVM_full_assert.v8.0.1-0.x86_64-unknown-freebsd11.1-cxx11.tar.gz/md5	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+5ba5405e04a5de586ab79e832b639085
diff -pruN 1.3.1+dfsg-1/deps/checksums/LLVM_full_assert.v8.0.1-0.x86_64-unknown-freebsd11.1-cxx11.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/LLVM_full_assert.v8.0.1-0.x86_64-unknown-freebsd11.1-cxx11.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/LLVM_full_assert.v8.0.1-0.x86_64-unknown-freebsd11.1-cxx11.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/LLVM_full_assert.v8.0.1-0.x86_64-unknown-freebsd11.1-cxx11.tar.gz/sha512	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+e73b4be82afa783d8112846fae26e61ea84da80758c29f93a12564541cf55e91a39bdc40203e9b20cc86dfd0d0df1ec4587f68ca86b595956a8e3957366b4c45
diff -pruN 1.3.1+dfsg-1/deps/checksums/LLVM_full_assert.v8.0.1-0.x86_64-w64-mingw32-cxx03.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/LLVM_full_assert.v8.0.1-0.x86_64-w64-mingw32-cxx03.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/LLVM_full_assert.v8.0.1-0.x86_64-w64-mingw32-cxx03.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/LLVM_full_assert.v8.0.1-0.x86_64-w64-mingw32-cxx03.tar.gz/md5	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+d93b9c736cee8c093ac981634140438f
diff -pruN 1.3.1+dfsg-1/deps/checksums/LLVM_full_assert.v8.0.1-0.x86_64-w64-mingw32-cxx03.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/LLVM_full_assert.v8.0.1-0.x86_64-w64-mingw32-cxx03.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/LLVM_full_assert.v8.0.1-0.x86_64-w64-mingw32-cxx03.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/LLVM_full_assert.v8.0.1-0.x86_64-w64-mingw32-cxx03.tar.gz/sha512	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+f7606b1237d900bf5acf48da38308e2a3bc8d155bdcf471ed6a55399f5f0d6eb1a662aef75f198db2d7aabadaa8b86edd86a9fa8fa3b846327279c3fbe0a368a
diff -pruN 1.3.1+dfsg-1/deps/checksums/LLVM_full_assert.v8.0.1-0.x86_64-w64-mingw32-cxx11.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/LLVM_full_assert.v8.0.1-0.x86_64-w64-mingw32-cxx11.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/LLVM_full_assert.v8.0.1-0.x86_64-w64-mingw32-cxx11.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/LLVM_full_assert.v8.0.1-0.x86_64-w64-mingw32-cxx11.tar.gz/md5	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+8aedb98d36bbafbd4c966162795ba599
diff -pruN 1.3.1+dfsg-1/deps/checksums/LLVM_full_assert.v8.0.1-0.x86_64-w64-mingw32-cxx11.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/LLVM_full_assert.v8.0.1-0.x86_64-w64-mingw32-cxx11.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/LLVM_full_assert.v8.0.1-0.x86_64-w64-mingw32-cxx11.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/LLVM_full_assert.v8.0.1-0.x86_64-w64-mingw32-cxx11.tar.gz/sha512	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+e22e692ac8fdca881d4a1a69c221300707d87a5dd67ca9a41682aeaaadbd3c695a00f11723ab9857d2f5a6e5b919d4ba8e2d3a67be7a947b78f62809a01f4bc8
diff -pruN 1.3.1+dfsg-1/deps/checksums/LLVM_full.v8.0.1-0.aarch64-linux-gnu-cxx03.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/LLVM_full.v8.0.1-0.aarch64-linux-gnu-cxx03.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/LLVM_full.v8.0.1-0.aarch64-linux-gnu-cxx03.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/LLVM_full.v8.0.1-0.aarch64-linux-gnu-cxx03.tar.gz/md5	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+d01b227aa4dc1886fb804e60bc3b3af3
diff -pruN 1.3.1+dfsg-1/deps/checksums/LLVM_full.v8.0.1-0.aarch64-linux-gnu-cxx03.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/LLVM_full.v8.0.1-0.aarch64-linux-gnu-cxx03.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/LLVM_full.v8.0.1-0.aarch64-linux-gnu-cxx03.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/LLVM_full.v8.0.1-0.aarch64-linux-gnu-cxx03.tar.gz/sha512	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+50b889f5fdea091b31dafcdff2bc34ba71ba745f61a52cc81dedf7d146d46287673c7b0476af60ebf6fc8db6a664490de607524371cae649e7210dcacae6c745
diff -pruN 1.3.1+dfsg-1/deps/checksums/LLVM_full.v8.0.1-0.aarch64-linux-gnu-cxx11.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/LLVM_full.v8.0.1-0.aarch64-linux-gnu-cxx11.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/LLVM_full.v8.0.1-0.aarch64-linux-gnu-cxx11.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/LLVM_full.v8.0.1-0.aarch64-linux-gnu-cxx11.tar.gz/md5	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+fafb0f42ce1cf6d23e82910767a12c6c
diff -pruN 1.3.1+dfsg-1/deps/checksums/LLVM_full.v8.0.1-0.aarch64-linux-gnu-cxx11.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/LLVM_full.v8.0.1-0.aarch64-linux-gnu-cxx11.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/LLVM_full.v8.0.1-0.aarch64-linux-gnu-cxx11.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/LLVM_full.v8.0.1-0.aarch64-linux-gnu-cxx11.tar.gz/sha512	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+1543c0f7756b6f2eb410f5dc9e5c425fb525ec3f68afbbb0678857d4dcc2949a52677dcb022e403f0e1a39a1a526ee574c45f4df87b44b1ea7b2b139a97aad88
diff -pruN 1.3.1+dfsg-1/deps/checksums/LLVM_full.v8.0.1-0.aarch64-linux-musl-cxx03.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/LLVM_full.v8.0.1-0.aarch64-linux-musl-cxx03.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/LLVM_full.v8.0.1-0.aarch64-linux-musl-cxx03.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/LLVM_full.v8.0.1-0.aarch64-linux-musl-cxx03.tar.gz/md5	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+a171b6a69115b90e83a13ccdcfec02af
diff -pruN 1.3.1+dfsg-1/deps/checksums/LLVM_full.v8.0.1-0.aarch64-linux-musl-cxx03.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/LLVM_full.v8.0.1-0.aarch64-linux-musl-cxx03.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/LLVM_full.v8.0.1-0.aarch64-linux-musl-cxx03.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/LLVM_full.v8.0.1-0.aarch64-linux-musl-cxx03.tar.gz/sha512	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+52482d323b321e003be5cca3db93abb6ef6fbe7e12c676e928f84a7c25103c7529974366b4e8712966c49a20f548bd72e9de88d9472195858f6492a158cc89cf
diff -pruN 1.3.1+dfsg-1/deps/checksums/LLVM_full.v8.0.1-0.aarch64-linux-musl-cxx11.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/LLVM_full.v8.0.1-0.aarch64-linux-musl-cxx11.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/LLVM_full.v8.0.1-0.aarch64-linux-musl-cxx11.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/LLVM_full.v8.0.1-0.aarch64-linux-musl-cxx11.tar.gz/md5	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+035dde0f92e3b376036e0fa67b810a11
diff -pruN 1.3.1+dfsg-1/deps/checksums/LLVM_full.v8.0.1-0.aarch64-linux-musl-cxx11.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/LLVM_full.v8.0.1-0.aarch64-linux-musl-cxx11.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/LLVM_full.v8.0.1-0.aarch64-linux-musl-cxx11.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/LLVM_full.v8.0.1-0.aarch64-linux-musl-cxx11.tar.gz/sha512	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+81789fa2cd495814c18fb2de841509d9d6bb070792040fcfcfa1e80e8e879ba24bed3c4547033025fa2382fc9b9111e09f668f05cfa6c5d9cbb5abee93526767
diff -pruN 1.3.1+dfsg-1/deps/checksums/LLVM_full.v8.0.1-0.arm-linux-gnueabihf-cxx03.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/LLVM_full.v8.0.1-0.arm-linux-gnueabihf-cxx03.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/LLVM_full.v8.0.1-0.arm-linux-gnueabihf-cxx03.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/LLVM_full.v8.0.1-0.arm-linux-gnueabihf-cxx03.tar.gz/md5	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+781b6205b952a95969d12c032a616ba3
diff -pruN 1.3.1+dfsg-1/deps/checksums/LLVM_full.v8.0.1-0.arm-linux-gnueabihf-cxx03.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/LLVM_full.v8.0.1-0.arm-linux-gnueabihf-cxx03.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/LLVM_full.v8.0.1-0.arm-linux-gnueabihf-cxx03.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/LLVM_full.v8.0.1-0.arm-linux-gnueabihf-cxx03.tar.gz/sha512	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+ed793f0cafe16767f9bd1d0b13c7617a06fe8f6531f42843bd349e39969eb11998f6b0f7b92ffe68319995fb8c057abc4eda0037126bfd735b61420280809f21
diff -pruN 1.3.1+dfsg-1/deps/checksums/LLVM_full.v8.0.1-0.arm-linux-gnueabihf-cxx11.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/LLVM_full.v8.0.1-0.arm-linux-gnueabihf-cxx11.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/LLVM_full.v8.0.1-0.arm-linux-gnueabihf-cxx11.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/LLVM_full.v8.0.1-0.arm-linux-gnueabihf-cxx11.tar.gz/md5	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+3adc58a9bcb0329277a89fcd86061c60
diff -pruN 1.3.1+dfsg-1/deps/checksums/LLVM_full.v8.0.1-0.arm-linux-gnueabihf-cxx11.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/LLVM_full.v8.0.1-0.arm-linux-gnueabihf-cxx11.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/LLVM_full.v8.0.1-0.arm-linux-gnueabihf-cxx11.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/LLVM_full.v8.0.1-0.arm-linux-gnueabihf-cxx11.tar.gz/sha512	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+b9e96c022a7e7b3d96e0bb1e20245052e225cca76d1da42f16ef80bd30dfbba2800fefccd814e16c9a86295888cb840b3a26fa996a7f6e714d761990ccd682d2
diff -pruN 1.3.1+dfsg-1/deps/checksums/LLVM_full.v8.0.1-0.arm-linux-musleabihf-cxx03.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/LLVM_full.v8.0.1-0.arm-linux-musleabihf-cxx03.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/LLVM_full.v8.0.1-0.arm-linux-musleabihf-cxx03.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/LLVM_full.v8.0.1-0.arm-linux-musleabihf-cxx03.tar.gz/md5	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+686f88526778f94775fbd1039400439b
diff -pruN 1.3.1+dfsg-1/deps/checksums/LLVM_full.v8.0.1-0.arm-linux-musleabihf-cxx03.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/LLVM_full.v8.0.1-0.arm-linux-musleabihf-cxx03.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/LLVM_full.v8.0.1-0.arm-linux-musleabihf-cxx03.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/LLVM_full.v8.0.1-0.arm-linux-musleabihf-cxx03.tar.gz/sha512	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+d984f1cb7a92c7820ea2f569d9c30fc396d44059ebfb5f30f8b5f059160d23d061eda778c14165dfd72d9bc0a61ec762690ec713d440e41513645817e3c93c7b
diff -pruN 1.3.1+dfsg-1/deps/checksums/LLVM_full.v8.0.1-0.arm-linux-musleabihf-cxx11.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/LLVM_full.v8.0.1-0.arm-linux-musleabihf-cxx11.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/LLVM_full.v8.0.1-0.arm-linux-musleabihf-cxx11.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/LLVM_full.v8.0.1-0.arm-linux-musleabihf-cxx11.tar.gz/md5	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+f76166ecbf3bbefc30c281d5e0d1c4bd
diff -pruN 1.3.1+dfsg-1/deps/checksums/LLVM_full.v8.0.1-0.arm-linux-musleabihf-cxx11.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/LLVM_full.v8.0.1-0.arm-linux-musleabihf-cxx11.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/LLVM_full.v8.0.1-0.arm-linux-musleabihf-cxx11.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/LLVM_full.v8.0.1-0.arm-linux-musleabihf-cxx11.tar.gz/sha512	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+46a6e9f8f188efbd2d835dc284394524976a258a64ce4afef16a37822ba13061b505b68316c4e7c3249353d1ad38aac8382b36f5b84a3fcb0190c33807901f1e
diff -pruN 1.3.1+dfsg-1/deps/checksums/LLVM_full.v8.0.1-0.i686-linux-gnu-cxx03.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/LLVM_full.v8.0.1-0.i686-linux-gnu-cxx03.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/LLVM_full.v8.0.1-0.i686-linux-gnu-cxx03.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/LLVM_full.v8.0.1-0.i686-linux-gnu-cxx03.tar.gz/md5	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+bceb4b2297c8c0dd62d147266057c0e1
diff -pruN 1.3.1+dfsg-1/deps/checksums/LLVM_full.v8.0.1-0.i686-linux-gnu-cxx03.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/LLVM_full.v8.0.1-0.i686-linux-gnu-cxx03.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/LLVM_full.v8.0.1-0.i686-linux-gnu-cxx03.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/LLVM_full.v8.0.1-0.i686-linux-gnu-cxx03.tar.gz/sha512	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+bc436a872dad810c2976b6f8be42052c06ab7e9af8f73886258e366b0621beb100c83096995bf1f32cebb4c38165b4fe5dcfdbb6df96410334a7e4337b101429
diff -pruN 1.3.1+dfsg-1/deps/checksums/LLVM_full.v8.0.1-0.i686-linux-gnu-cxx11.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/LLVM_full.v8.0.1-0.i686-linux-gnu-cxx11.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/LLVM_full.v8.0.1-0.i686-linux-gnu-cxx11.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/LLVM_full.v8.0.1-0.i686-linux-gnu-cxx11.tar.gz/md5	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+8afae950529737cbb682f2c60d4f14ac
diff -pruN 1.3.1+dfsg-1/deps/checksums/LLVM_full.v8.0.1-0.i686-linux-gnu-cxx11.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/LLVM_full.v8.0.1-0.i686-linux-gnu-cxx11.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/LLVM_full.v8.0.1-0.i686-linux-gnu-cxx11.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/LLVM_full.v8.0.1-0.i686-linux-gnu-cxx11.tar.gz/sha512	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+4a6e0aefdc1f614341233eadc3a5227396bc2416f2f614beab6980419f5357838c70f48596bfbb698f72cae2a0cb1b06421a809f959a71fd270ceaa6db3724d0
diff -pruN 1.3.1+dfsg-1/deps/checksums/LLVM_full.v8.0.1-0.i686-linux-musl-cxx03.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/LLVM_full.v8.0.1-0.i686-linux-musl-cxx03.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/LLVM_full.v8.0.1-0.i686-linux-musl-cxx03.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/LLVM_full.v8.0.1-0.i686-linux-musl-cxx03.tar.gz/md5	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+59522dd6fed0e2e57a705746c7c351e2
diff -pruN 1.3.1+dfsg-1/deps/checksums/LLVM_full.v8.0.1-0.i686-linux-musl-cxx03.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/LLVM_full.v8.0.1-0.i686-linux-musl-cxx03.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/LLVM_full.v8.0.1-0.i686-linux-musl-cxx03.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/LLVM_full.v8.0.1-0.i686-linux-musl-cxx03.tar.gz/sha512	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+02efd244c437ecc030b7d6dabe2cc9e0d57674899241877b80e6393be42cf732ecdbf60ae5629b9c49b180007ba4940d0b03e177e5b067a36af5a759c1f87aa4
diff -pruN 1.3.1+dfsg-1/deps/checksums/LLVM_full.v8.0.1-0.i686-linux-musl-cxx11.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/LLVM_full.v8.0.1-0.i686-linux-musl-cxx11.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/LLVM_full.v8.0.1-0.i686-linux-musl-cxx11.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/LLVM_full.v8.0.1-0.i686-linux-musl-cxx11.tar.gz/md5	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+1f82ea08885a2d48593ebc5cf6b2b714
diff -pruN 1.3.1+dfsg-1/deps/checksums/LLVM_full.v8.0.1-0.i686-linux-musl-cxx11.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/LLVM_full.v8.0.1-0.i686-linux-musl-cxx11.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/LLVM_full.v8.0.1-0.i686-linux-musl-cxx11.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/LLVM_full.v8.0.1-0.i686-linux-musl-cxx11.tar.gz/sha512	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+693627bbbb904e8d11b57039348319f4b84c6d503e1384e5bebb0451ab773fdf93390329f2c8594944e106e73f99784c6008e4a7a39ce283129a74bbb202f2b9
diff -pruN 1.3.1+dfsg-1/deps/checksums/LLVM_full.v8.0.1-0.i686-w64-mingw32-cxx03.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/LLVM_full.v8.0.1-0.i686-w64-mingw32-cxx03.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/LLVM_full.v8.0.1-0.i686-w64-mingw32-cxx03.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/LLVM_full.v8.0.1-0.i686-w64-mingw32-cxx03.tar.gz/md5	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+6852aa385061cb9469bf178e57701b21
diff -pruN 1.3.1+dfsg-1/deps/checksums/LLVM_full.v8.0.1-0.i686-w64-mingw32-cxx03.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/LLVM_full.v8.0.1-0.i686-w64-mingw32-cxx03.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/LLVM_full.v8.0.1-0.i686-w64-mingw32-cxx03.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/LLVM_full.v8.0.1-0.i686-w64-mingw32-cxx03.tar.gz/sha512	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+91ac4223afe90fc4c5bda15b5acc868f2ce0f11772da31694c2eecfff72351b2db2a7b251c3fa802e194ccfe22df828c7c29c813200c19af5018e58ba45008ba
diff -pruN 1.3.1+dfsg-1/deps/checksums/LLVM_full.v8.0.1-0.i686-w64-mingw32-cxx11.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/LLVM_full.v8.0.1-0.i686-w64-mingw32-cxx11.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/LLVM_full.v8.0.1-0.i686-w64-mingw32-cxx11.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/LLVM_full.v8.0.1-0.i686-w64-mingw32-cxx11.tar.gz/md5	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+86b57360301fe0edc3e73410f78060bc
diff -pruN 1.3.1+dfsg-1/deps/checksums/LLVM_full.v8.0.1-0.i686-w64-mingw32-cxx11.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/LLVM_full.v8.0.1-0.i686-w64-mingw32-cxx11.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/LLVM_full.v8.0.1-0.i686-w64-mingw32-cxx11.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/LLVM_full.v8.0.1-0.i686-w64-mingw32-cxx11.tar.gz/sha512	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+f7cc2b80435f4c0465e427b6092369a51d554105210f2badea6f7fd4d801791005d03a1a5d565ef896ec0ab2401be4e07a37a415f4bfcdf147e40320c63925c1
diff -pruN 1.3.1+dfsg-1/deps/checksums/LLVM_full.v8.0.1-0.powerpc64le-linux-gnu-cxx03.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/LLVM_full.v8.0.1-0.powerpc64le-linux-gnu-cxx03.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/LLVM_full.v8.0.1-0.powerpc64le-linux-gnu-cxx03.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/LLVM_full.v8.0.1-0.powerpc64le-linux-gnu-cxx03.tar.gz/md5	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+7191af4c222676987dccff7249e2f431
diff -pruN 1.3.1+dfsg-1/deps/checksums/LLVM_full.v8.0.1-0.powerpc64le-linux-gnu-cxx03.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/LLVM_full.v8.0.1-0.powerpc64le-linux-gnu-cxx03.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/LLVM_full.v8.0.1-0.powerpc64le-linux-gnu-cxx03.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/LLVM_full.v8.0.1-0.powerpc64le-linux-gnu-cxx03.tar.gz/sha512	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+78bb4a095020802848c60bfa97b578fde897b1373417cc3035b648b80eb59ec515307090aff762ca84d5b3ca7c5eacd5ac3d395a759198526d88dbe38119ca30
diff -pruN 1.3.1+dfsg-1/deps/checksums/LLVM_full.v8.0.1-0.powerpc64le-linux-gnu-cxx11.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/LLVM_full.v8.0.1-0.powerpc64le-linux-gnu-cxx11.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/LLVM_full.v8.0.1-0.powerpc64le-linux-gnu-cxx11.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/LLVM_full.v8.0.1-0.powerpc64le-linux-gnu-cxx11.tar.gz/md5	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+1e766aeb1cf2c1dd03e7ae54f1f3c8b2
diff -pruN 1.3.1+dfsg-1/deps/checksums/LLVM_full.v8.0.1-0.powerpc64le-linux-gnu-cxx11.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/LLVM_full.v8.0.1-0.powerpc64le-linux-gnu-cxx11.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/LLVM_full.v8.0.1-0.powerpc64le-linux-gnu-cxx11.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/LLVM_full.v8.0.1-0.powerpc64le-linux-gnu-cxx11.tar.gz/sha512	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+03be308c50a181d6a0fa475886bb97a2c10be4bafd72574e561605e9a76c17555b978f54668c21bf943188be1c1eb867de6baca3a884150322b85c0499deb21b
diff -pruN 1.3.1+dfsg-1/deps/checksums/LLVM_full.v8.0.1-0.x86_64-apple-darwin14-cxx03.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/LLVM_full.v8.0.1-0.x86_64-apple-darwin14-cxx03.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/LLVM_full.v8.0.1-0.x86_64-apple-darwin14-cxx03.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/LLVM_full.v8.0.1-0.x86_64-apple-darwin14-cxx03.tar.gz/md5	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+8a81505f2c9ab3697677564f7f85fef6
diff -pruN 1.3.1+dfsg-1/deps/checksums/LLVM_full.v8.0.1-0.x86_64-apple-darwin14-cxx03.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/LLVM_full.v8.0.1-0.x86_64-apple-darwin14-cxx03.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/LLVM_full.v8.0.1-0.x86_64-apple-darwin14-cxx03.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/LLVM_full.v8.0.1-0.x86_64-apple-darwin14-cxx03.tar.gz/sha512	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+b19dc60bcb9b23449d31530b1e1902aa808758f219e546d6692f3821879f13367158ae8f93561f32b839ade45e5cfeb0929b218e9a550f94d9c33e2bce97a5f0
diff -pruN 1.3.1+dfsg-1/deps/checksums/LLVM_full.v8.0.1-0.x86_64-apple-darwin14-cxx11.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/LLVM_full.v8.0.1-0.x86_64-apple-darwin14-cxx11.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/LLVM_full.v8.0.1-0.x86_64-apple-darwin14-cxx11.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/LLVM_full.v8.0.1-0.x86_64-apple-darwin14-cxx11.tar.gz/md5	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+89a0064f8b856cc6ecfd0acf092b5086
diff -pruN 1.3.1+dfsg-1/deps/checksums/LLVM_full.v8.0.1-0.x86_64-apple-darwin14-cxx11.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/LLVM_full.v8.0.1-0.x86_64-apple-darwin14-cxx11.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/LLVM_full.v8.0.1-0.x86_64-apple-darwin14-cxx11.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/LLVM_full.v8.0.1-0.x86_64-apple-darwin14-cxx11.tar.gz/sha512	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+13f6ffae778c6fb4f0abd8ad0195d4b8759858ccc23e1dd6e78ef41927d764ad516cce60d29f5987255caccdabeac1b8067ce02c16e4670a120283812d0a3527
diff -pruN 1.3.1+dfsg-1/deps/checksums/LLVM_full.v8.0.1-0.x86_64-linux-gnu-cxx03.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/LLVM_full.v8.0.1-0.x86_64-linux-gnu-cxx03.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/LLVM_full.v8.0.1-0.x86_64-linux-gnu-cxx03.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/LLVM_full.v8.0.1-0.x86_64-linux-gnu-cxx03.tar.gz/md5	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+5604ec1e07e6dc75ca4934fa9a368dc1
diff -pruN 1.3.1+dfsg-1/deps/checksums/LLVM_full.v8.0.1-0.x86_64-linux-gnu-cxx03.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/LLVM_full.v8.0.1-0.x86_64-linux-gnu-cxx03.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/LLVM_full.v8.0.1-0.x86_64-linux-gnu-cxx03.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/LLVM_full.v8.0.1-0.x86_64-linux-gnu-cxx03.tar.gz/sha512	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+3e572f5821bca54dbe45c71b6d332bdafa0973c6e42f5777e376bb59aa520ecdd7c289ddfb0206eaca4f348fd40dec100646a05700c2434860d72fcb7292e901
diff -pruN 1.3.1+dfsg-1/deps/checksums/LLVM_full.v8.0.1-0.x86_64-linux-gnu-cxx11.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/LLVM_full.v8.0.1-0.x86_64-linux-gnu-cxx11.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/LLVM_full.v8.0.1-0.x86_64-linux-gnu-cxx11.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/LLVM_full.v8.0.1-0.x86_64-linux-gnu-cxx11.tar.gz/md5	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+8a34db181bf0c0e4fcb36c070bf0e5ec
diff -pruN 1.3.1+dfsg-1/deps/checksums/LLVM_full.v8.0.1-0.x86_64-linux-gnu-cxx11.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/LLVM_full.v8.0.1-0.x86_64-linux-gnu-cxx11.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/LLVM_full.v8.0.1-0.x86_64-linux-gnu-cxx11.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/LLVM_full.v8.0.1-0.x86_64-linux-gnu-cxx11.tar.gz/sha512	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+36f43fe65e69c45fa8e38c9e1bcb95a356dd1c5ee5065bb600acf63cacdc47ed99ddc8ba996feb78baab6c2d599fd3f77483ad7d95d8f6a413666e3cc3d17dc2
diff -pruN 1.3.1+dfsg-1/deps/checksums/LLVM_full.v8.0.1-0.x86_64-linux-musl-cxx03.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/LLVM_full.v8.0.1-0.x86_64-linux-musl-cxx03.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/LLVM_full.v8.0.1-0.x86_64-linux-musl-cxx03.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/LLVM_full.v8.0.1-0.x86_64-linux-musl-cxx03.tar.gz/md5	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+4253e03f727a763bbd277dc9f374e329
diff -pruN 1.3.1+dfsg-1/deps/checksums/LLVM_full.v8.0.1-0.x86_64-linux-musl-cxx03.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/LLVM_full.v8.0.1-0.x86_64-linux-musl-cxx03.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/LLVM_full.v8.0.1-0.x86_64-linux-musl-cxx03.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/LLVM_full.v8.0.1-0.x86_64-linux-musl-cxx03.tar.gz/sha512	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+aca8d46637c91f8784cfe9a88fadf6b63227d910f985a74ebe0e1ce9bbec3c63284ac9e6f38a95ad2120f32728062562f0fb44f7500f5453f3d4a87ea956efdb
diff -pruN 1.3.1+dfsg-1/deps/checksums/LLVM_full.v8.0.1-0.x86_64-linux-musl-cxx11.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/LLVM_full.v8.0.1-0.x86_64-linux-musl-cxx11.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/LLVM_full.v8.0.1-0.x86_64-linux-musl-cxx11.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/LLVM_full.v8.0.1-0.x86_64-linux-musl-cxx11.tar.gz/md5	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+ec724038dc0a30ab95ef815f78bd22ed
diff -pruN 1.3.1+dfsg-1/deps/checksums/LLVM_full.v8.0.1-0.x86_64-linux-musl-cxx11.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/LLVM_full.v8.0.1-0.x86_64-linux-musl-cxx11.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/LLVM_full.v8.0.1-0.x86_64-linux-musl-cxx11.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/LLVM_full.v8.0.1-0.x86_64-linux-musl-cxx11.tar.gz/sha512	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+bb8fd62d99ef6847be3c8216c5cc75dbdaf6276cce6aacf6cf6f33e5ce632e8056f91501cbfae7339f614f23b4ec9aa87ecb252257ef0e241785203b196f0620
diff -pruN 1.3.1+dfsg-1/deps/checksums/LLVM_full.v8.0.1-0.x86_64-unknown-freebsd11.1-cxx03.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/LLVM_full.v8.0.1-0.x86_64-unknown-freebsd11.1-cxx03.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/LLVM_full.v8.0.1-0.x86_64-unknown-freebsd11.1-cxx03.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/LLVM_full.v8.0.1-0.x86_64-unknown-freebsd11.1-cxx03.tar.gz/md5	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+9c514b1f02f6b3a93e63d4f6887287d6
diff -pruN 1.3.1+dfsg-1/deps/checksums/LLVM_full.v8.0.1-0.x86_64-unknown-freebsd11.1-cxx03.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/LLVM_full.v8.0.1-0.x86_64-unknown-freebsd11.1-cxx03.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/LLVM_full.v8.0.1-0.x86_64-unknown-freebsd11.1-cxx03.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/LLVM_full.v8.0.1-0.x86_64-unknown-freebsd11.1-cxx03.tar.gz/sha512	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+ce233631ec16504b040c69afd6241f87af81281f968851d5d133e4e4401a11c7ae594b545392c99af2f5ad9fdb9f9f8ef94ced11767116ada3712893cb5082f8
diff -pruN 1.3.1+dfsg-1/deps/checksums/LLVM_full.v8.0.1-0.x86_64-unknown-freebsd11.1-cxx11.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/LLVM_full.v8.0.1-0.x86_64-unknown-freebsd11.1-cxx11.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/LLVM_full.v8.0.1-0.x86_64-unknown-freebsd11.1-cxx11.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/LLVM_full.v8.0.1-0.x86_64-unknown-freebsd11.1-cxx11.tar.gz/md5	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+6043020aabefc9283d7509311384f368
diff -pruN 1.3.1+dfsg-1/deps/checksums/LLVM_full.v8.0.1-0.x86_64-unknown-freebsd11.1-cxx11.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/LLVM_full.v8.0.1-0.x86_64-unknown-freebsd11.1-cxx11.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/LLVM_full.v8.0.1-0.x86_64-unknown-freebsd11.1-cxx11.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/LLVM_full.v8.0.1-0.x86_64-unknown-freebsd11.1-cxx11.tar.gz/sha512	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+c01c01902971f4972135f1c7fdc46a8e34525039004d26784113d664673307d99518d11bb33616df0c7f9364dbb6936e53b6e7bb5e1a18eefe79b93cde8accfa
diff -pruN 1.3.1+dfsg-1/deps/checksums/LLVM_full.v8.0.1-0.x86_64-w64-mingw32-cxx03.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/LLVM_full.v8.0.1-0.x86_64-w64-mingw32-cxx03.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/LLVM_full.v8.0.1-0.x86_64-w64-mingw32-cxx03.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/LLVM_full.v8.0.1-0.x86_64-w64-mingw32-cxx03.tar.gz/md5	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+10284a30656c400640940b6ee83a7c53
diff -pruN 1.3.1+dfsg-1/deps/checksums/LLVM_full.v8.0.1-0.x86_64-w64-mingw32-cxx03.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/LLVM_full.v8.0.1-0.x86_64-w64-mingw32-cxx03.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/LLVM_full.v8.0.1-0.x86_64-w64-mingw32-cxx03.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/LLVM_full.v8.0.1-0.x86_64-w64-mingw32-cxx03.tar.gz/sha512	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+f077ae66b805d742c3215896850977b9cc90fe53d3617b779cd060aae5f1ee1d07f92bd8d970c8105bc7caa063dac7298891a5457a0bdaa3bd6824c1b6e5dc2b
diff -pruN 1.3.1+dfsg-1/deps/checksums/LLVM_full.v8.0.1-0.x86_64-w64-mingw32-cxx11.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/LLVM_full.v8.0.1-0.x86_64-w64-mingw32-cxx11.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/LLVM_full.v8.0.1-0.x86_64-w64-mingw32-cxx11.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/LLVM_full.v8.0.1-0.x86_64-w64-mingw32-cxx11.tar.gz/md5	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+b1a633e31a01c61a8c3a47cd7e92ee8a
diff -pruN 1.3.1+dfsg-1/deps/checksums/LLVM_full.v8.0.1-0.x86_64-w64-mingw32-cxx11.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/LLVM_full.v8.0.1-0.x86_64-w64-mingw32-cxx11.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/LLVM_full.v8.0.1-0.x86_64-w64-mingw32-cxx11.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/LLVM_full.v8.0.1-0.x86_64-w64-mingw32-cxx11.tar.gz/sha512	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+8ce3a01e20ed84344c24996baf67375dfcb19cf26fc97fdec085502319eebf684a2fdc347054c7178cd286768899da61c5e3cdbae107c4722ae97186f71062b6
diff -pruN 1.3.1+dfsg-1/deps/checksums/LLVM.v6.0.1-7+nowasm.aarch64-linux-gnu-gcc4.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/LLVM.v6.0.1-7+nowasm.aarch64-linux-gnu-gcc4.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/LLVM.v6.0.1-7+nowasm.aarch64-linux-gnu-gcc4.tar.gz/md5	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/LLVM.v6.0.1-7+nowasm.aarch64-linux-gnu-gcc4.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-32c5f933b5e8758e35c87f5054afa26c
diff -pruN 1.3.1+dfsg-1/deps/checksums/LLVM.v6.0.1-7+nowasm.aarch64-linux-gnu-gcc4.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/LLVM.v6.0.1-7+nowasm.aarch64-linux-gnu-gcc4.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/LLVM.v6.0.1-7+nowasm.aarch64-linux-gnu-gcc4.tar.gz/sha512	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/LLVM.v6.0.1-7+nowasm.aarch64-linux-gnu-gcc4.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-93c65ed59636696b98860c8227e8750636a5b40f0061bc1eb9d0811b4fb813c823fe631fc03ea74446306b9bf4643c0534ee6cafd6bc8aacf44a02a4ca11a572
diff -pruN 1.3.1+dfsg-1/deps/checksums/LLVM.v6.0.1-7+nowasm.aarch64-linux-gnu-gcc7.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/LLVM.v6.0.1-7+nowasm.aarch64-linux-gnu-gcc7.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/LLVM.v6.0.1-7+nowasm.aarch64-linux-gnu-gcc7.tar.gz/md5	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/LLVM.v6.0.1-7+nowasm.aarch64-linux-gnu-gcc7.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-9658cbfc2e72d0176d358f51c11367e7
diff -pruN 1.3.1+dfsg-1/deps/checksums/LLVM.v6.0.1-7+nowasm.aarch64-linux-gnu-gcc7.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/LLVM.v6.0.1-7+nowasm.aarch64-linux-gnu-gcc7.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/LLVM.v6.0.1-7+nowasm.aarch64-linux-gnu-gcc7.tar.gz/sha512	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/LLVM.v6.0.1-7+nowasm.aarch64-linux-gnu-gcc7.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-ba3bf88bfba4da816c9a5a68f16e3af0b9d7cb5999d605a9a63d06a241c8c342beb46d96db1130eebb00ae46aed958fd9541868fd7f9cb1c51d0b3305509fcc0
diff -pruN 1.3.1+dfsg-1/deps/checksums/LLVM.v6.0.1-7+nowasm.aarch64-linux-gnu-gcc8.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/LLVM.v6.0.1-7+nowasm.aarch64-linux-gnu-gcc8.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/LLVM.v6.0.1-7+nowasm.aarch64-linux-gnu-gcc8.tar.gz/md5	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/LLVM.v6.0.1-7+nowasm.aarch64-linux-gnu-gcc8.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-0b0920e2a2e279e92e739e3fffd18d6e
diff -pruN 1.3.1+dfsg-1/deps/checksums/LLVM.v6.0.1-7+nowasm.aarch64-linux-gnu-gcc8.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/LLVM.v6.0.1-7+nowasm.aarch64-linux-gnu-gcc8.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/LLVM.v6.0.1-7+nowasm.aarch64-linux-gnu-gcc8.tar.gz/sha512	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/LLVM.v6.0.1-7+nowasm.aarch64-linux-gnu-gcc8.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-9ca4f3967c83ed3b5a51ec97a44169218e4822eb40c8b1a7d8060258709f72290f4d76dc9c26e6ae41a9bb6eddf76b3908dcc01b839a7b9b7e62ccbb6446e948
diff -pruN 1.3.1+dfsg-1/deps/checksums/LLVM.v6.0.1-7+nowasm.arm-linux-gnueabihf-gcc4.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/LLVM.v6.0.1-7+nowasm.arm-linux-gnueabihf-gcc4.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/LLVM.v6.0.1-7+nowasm.arm-linux-gnueabihf-gcc4.tar.gz/md5	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/LLVM.v6.0.1-7+nowasm.arm-linux-gnueabihf-gcc4.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-c3ad727fb901f0f663175b307de5b1b8
diff -pruN 1.3.1+dfsg-1/deps/checksums/LLVM.v6.0.1-7+nowasm.arm-linux-gnueabihf-gcc4.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/LLVM.v6.0.1-7+nowasm.arm-linux-gnueabihf-gcc4.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/LLVM.v6.0.1-7+nowasm.arm-linux-gnueabihf-gcc4.tar.gz/sha512	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/LLVM.v6.0.1-7+nowasm.arm-linux-gnueabihf-gcc4.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-63f351c3c58f8858db69dd964f909f6ea4891f836c20ff18d7344f787e57f5764febce79237aaa6b25a02964eb470c81d2881878aab25c753e79e210c8f7c8af
diff -pruN 1.3.1+dfsg-1/deps/checksums/LLVM.v6.0.1-7+nowasm.arm-linux-gnueabihf-gcc7.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/LLVM.v6.0.1-7+nowasm.arm-linux-gnueabihf-gcc7.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/LLVM.v6.0.1-7+nowasm.arm-linux-gnueabihf-gcc7.tar.gz/md5	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/LLVM.v6.0.1-7+nowasm.arm-linux-gnueabihf-gcc7.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-f7f0818187f0d0b3291a7d27e83a1d53
diff -pruN 1.3.1+dfsg-1/deps/checksums/LLVM.v6.0.1-7+nowasm.arm-linux-gnueabihf-gcc7.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/LLVM.v6.0.1-7+nowasm.arm-linux-gnueabihf-gcc7.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/LLVM.v6.0.1-7+nowasm.arm-linux-gnueabihf-gcc7.tar.gz/sha512	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/LLVM.v6.0.1-7+nowasm.arm-linux-gnueabihf-gcc7.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-cae860ca5aeda88742a8916caa4e74d382d3b631f8b5f7b1ebbc62540a7cb2d9890a8a6c8249ab13e3ec3edb4b928ec622b5044066995ec5b91afb851922671c
diff -pruN 1.3.1+dfsg-1/deps/checksums/LLVM.v6.0.1-7+nowasm.arm-linux-gnueabihf-gcc8.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/LLVM.v6.0.1-7+nowasm.arm-linux-gnueabihf-gcc8.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/LLVM.v6.0.1-7+nowasm.arm-linux-gnueabihf-gcc8.tar.gz/md5	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/LLVM.v6.0.1-7+nowasm.arm-linux-gnueabihf-gcc8.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-8d832d7c4a1ffe5057ac9257ae417d2c
diff -pruN 1.3.1+dfsg-1/deps/checksums/LLVM.v6.0.1-7+nowasm.arm-linux-gnueabihf-gcc8.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/LLVM.v6.0.1-7+nowasm.arm-linux-gnueabihf-gcc8.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/LLVM.v6.0.1-7+nowasm.arm-linux-gnueabihf-gcc8.tar.gz/sha512	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/LLVM.v6.0.1-7+nowasm.arm-linux-gnueabihf-gcc8.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-0ea0b64f64de19a24c3184d790772535c2985355d0eb7113d58c3f4bffa66c9c9edff33640c169cc05c3edca6d0abe025e0cf0552a81c0d1e612c3047fb96804
diff -pruN 1.3.1+dfsg-1/deps/checksums/LLVM.v6.0.1-7+nowasm.i686-linux-gnu-gcc4.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/LLVM.v6.0.1-7+nowasm.i686-linux-gnu-gcc4.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/LLVM.v6.0.1-7+nowasm.i686-linux-gnu-gcc4.tar.gz/md5	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/LLVM.v6.0.1-7+nowasm.i686-linux-gnu-gcc4.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-de0f9114398066ee9e4dc7ad2dc5239a
diff -pruN 1.3.1+dfsg-1/deps/checksums/LLVM.v6.0.1-7+nowasm.i686-linux-gnu-gcc4.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/LLVM.v6.0.1-7+nowasm.i686-linux-gnu-gcc4.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/LLVM.v6.0.1-7+nowasm.i686-linux-gnu-gcc4.tar.gz/sha512	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/LLVM.v6.0.1-7+nowasm.i686-linux-gnu-gcc4.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-5811214cd654a08e44a7a103bd5a21e574d45336b579d862485c248464792ca96800ee47490a01387df8aa2af8affa8dac9b8a7a9a5a35815eede112df162325
diff -pruN 1.3.1+dfsg-1/deps/checksums/LLVM.v6.0.1-7+nowasm.i686-linux-gnu-gcc7.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/LLVM.v6.0.1-7+nowasm.i686-linux-gnu-gcc7.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/LLVM.v6.0.1-7+nowasm.i686-linux-gnu-gcc7.tar.gz/md5	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/LLVM.v6.0.1-7+nowasm.i686-linux-gnu-gcc7.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-9d076399fbc7e0d400e6b4723223de70
diff -pruN 1.3.1+dfsg-1/deps/checksums/LLVM.v6.0.1-7+nowasm.i686-linux-gnu-gcc7.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/LLVM.v6.0.1-7+nowasm.i686-linux-gnu-gcc7.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/LLVM.v6.0.1-7+nowasm.i686-linux-gnu-gcc7.tar.gz/sha512	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/LLVM.v6.0.1-7+nowasm.i686-linux-gnu-gcc7.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-a4903d8af622fa5f08d0f790dbbc4d1cf7e46b05d44407b1bc757f86b8ddf1f45f728b406fc82b10b8e5c92cd029d182d99b6ab1344d7de645ef343247c66af1
diff -pruN 1.3.1+dfsg-1/deps/checksums/LLVM.v6.0.1-7+nowasm.i686-linux-gnu-gcc8.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/LLVM.v6.0.1-7+nowasm.i686-linux-gnu-gcc8.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/LLVM.v6.0.1-7+nowasm.i686-linux-gnu-gcc8.tar.gz/md5	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/LLVM.v6.0.1-7+nowasm.i686-linux-gnu-gcc8.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-9df643893cf28239e4f2ec1a302178ef
diff -pruN 1.3.1+dfsg-1/deps/checksums/LLVM.v6.0.1-7+nowasm.i686-linux-gnu-gcc8.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/LLVM.v6.0.1-7+nowasm.i686-linux-gnu-gcc8.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/LLVM.v6.0.1-7+nowasm.i686-linux-gnu-gcc8.tar.gz/sha512	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/LLVM.v6.0.1-7+nowasm.i686-linux-gnu-gcc8.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-8b22d1ae21746d8ce2f73a75b05cae169c68eed8b2a64cebbfe286e377b31887d2412c68d001dc6e0b92c65a4500779e3a7b9a21d7ef0dbc88c43c6037319eb5
diff -pruN 1.3.1+dfsg-1/deps/checksums/LLVM.v6.0.1-7+nowasm.i686-w64-mingw32-gcc4.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/LLVM.v6.0.1-7+nowasm.i686-w64-mingw32-gcc4.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/LLVM.v6.0.1-7+nowasm.i686-w64-mingw32-gcc4.tar.gz/md5	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/LLVM.v6.0.1-7+nowasm.i686-w64-mingw32-gcc4.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-e2962033d78f4562aed94f1d7e0ec396
diff -pruN 1.3.1+dfsg-1/deps/checksums/LLVM.v6.0.1-7+nowasm.i686-w64-mingw32-gcc4.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/LLVM.v6.0.1-7+nowasm.i686-w64-mingw32-gcc4.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/LLVM.v6.0.1-7+nowasm.i686-w64-mingw32-gcc4.tar.gz/sha512	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/LLVM.v6.0.1-7+nowasm.i686-w64-mingw32-gcc4.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-2bd15d7c3d86534ee34097c5a5d31e4f4497979664b8e85f51dbd79e2a48eb25aa1925fa67325581f4717711ee82d91a5d8f6805f0aa3eac1198817814b9d675
diff -pruN 1.3.1+dfsg-1/deps/checksums/LLVM.v6.0.1-7+nowasm.i686-w64-mingw32-gcc7.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/LLVM.v6.0.1-7+nowasm.i686-w64-mingw32-gcc7.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/LLVM.v6.0.1-7+nowasm.i686-w64-mingw32-gcc7.tar.gz/md5	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/LLVM.v6.0.1-7+nowasm.i686-w64-mingw32-gcc7.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-e6d9664644ce47046334290735b3f508
diff -pruN 1.3.1+dfsg-1/deps/checksums/LLVM.v6.0.1-7+nowasm.i686-w64-mingw32-gcc7.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/LLVM.v6.0.1-7+nowasm.i686-w64-mingw32-gcc7.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/LLVM.v6.0.1-7+nowasm.i686-w64-mingw32-gcc7.tar.gz/sha512	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/LLVM.v6.0.1-7+nowasm.i686-w64-mingw32-gcc7.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-4df060f23066788d93a8122ca6ea6abf7fa76cdde0c05d1cd50188298504150bf48fd115e2a78e332ee12ebd240e2e53397daf21d82235db9eafaf09b5df8347
diff -pruN 1.3.1+dfsg-1/deps/checksums/LLVM.v6.0.1-7+nowasm.i686-w64-mingw32-gcc8.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/LLVM.v6.0.1-7+nowasm.i686-w64-mingw32-gcc8.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/LLVM.v6.0.1-7+nowasm.i686-w64-mingw32-gcc8.tar.gz/md5	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/LLVM.v6.0.1-7+nowasm.i686-w64-mingw32-gcc8.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-2db2bccfa589095c8d1f4254d9cfa253
diff -pruN 1.3.1+dfsg-1/deps/checksums/LLVM.v6.0.1-7+nowasm.i686-w64-mingw32-gcc8.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/LLVM.v6.0.1-7+nowasm.i686-w64-mingw32-gcc8.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/LLVM.v6.0.1-7+nowasm.i686-w64-mingw32-gcc8.tar.gz/sha512	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/LLVM.v6.0.1-7+nowasm.i686-w64-mingw32-gcc8.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-0be45ceb79877f6037d9b0c8ba7439ffe2873b681a949c57573ba9a73c4b224a05c8fcdac6cbde9df7c8ddab324f3f44b9e91c1d120ce427baf4f35ef152bef3
diff -pruN 1.3.1+dfsg-1/deps/checksums/LLVM.v6.0.1-7+nowasm.powerpc64le-linux-gnu-gcc4.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/LLVM.v6.0.1-7+nowasm.powerpc64le-linux-gnu-gcc4.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/LLVM.v6.0.1-7+nowasm.powerpc64le-linux-gnu-gcc4.tar.gz/md5	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/LLVM.v6.0.1-7+nowasm.powerpc64le-linux-gnu-gcc4.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-8cf440fc1f74d790954a513e81e1334f
diff -pruN 1.3.1+dfsg-1/deps/checksums/LLVM.v6.0.1-7+nowasm.powerpc64le-linux-gnu-gcc4.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/LLVM.v6.0.1-7+nowasm.powerpc64le-linux-gnu-gcc4.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/LLVM.v6.0.1-7+nowasm.powerpc64le-linux-gnu-gcc4.tar.gz/sha512	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/LLVM.v6.0.1-7+nowasm.powerpc64le-linux-gnu-gcc4.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-5ecaf6d3343d3afe6b43686b835c75e35b925c1766459af47ed18bc140e615203a59e6f1df63c4803f0cf7603e406b0e72b824cc8b77a765f894bc40a8d1a8b8
diff -pruN 1.3.1+dfsg-1/deps/checksums/LLVM.v6.0.1-7+nowasm.powerpc64le-linux-gnu-gcc7.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/LLVM.v6.0.1-7+nowasm.powerpc64le-linux-gnu-gcc7.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/LLVM.v6.0.1-7+nowasm.powerpc64le-linux-gnu-gcc7.tar.gz/md5	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/LLVM.v6.0.1-7+nowasm.powerpc64le-linux-gnu-gcc7.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-71c9a128b6a41dde8672da7540ceb5a1
diff -pruN 1.3.1+dfsg-1/deps/checksums/LLVM.v6.0.1-7+nowasm.powerpc64le-linux-gnu-gcc7.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/LLVM.v6.0.1-7+nowasm.powerpc64le-linux-gnu-gcc7.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/LLVM.v6.0.1-7+nowasm.powerpc64le-linux-gnu-gcc7.tar.gz/sha512	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/LLVM.v6.0.1-7+nowasm.powerpc64le-linux-gnu-gcc7.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-11d3719960c8ba4e68aa02a0c6364bb997a2fa734451c19c4b02027c81240c87355f71c2df776c25eac6d62967c9f06a20af7e502bd3a7def6698a0a0d01de16
diff -pruN 1.3.1+dfsg-1/deps/checksums/LLVM.v6.0.1-7+nowasm.powerpc64le-linux-gnu-gcc8.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/LLVM.v6.0.1-7+nowasm.powerpc64le-linux-gnu-gcc8.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/LLVM.v6.0.1-7+nowasm.powerpc64le-linux-gnu-gcc8.tar.gz/md5	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/LLVM.v6.0.1-7+nowasm.powerpc64le-linux-gnu-gcc8.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-c2ce6cffa40a4dadf59e99d04ad495b6
diff -pruN 1.3.1+dfsg-1/deps/checksums/LLVM.v6.0.1-7+nowasm.powerpc64le-linux-gnu-gcc8.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/LLVM.v6.0.1-7+nowasm.powerpc64le-linux-gnu-gcc8.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/LLVM.v6.0.1-7+nowasm.powerpc64le-linux-gnu-gcc8.tar.gz/sha512	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/LLVM.v6.0.1-7+nowasm.powerpc64le-linux-gnu-gcc8.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-854c5269e252aa1f076b75a0b8afb369a0ada62ee91365b30d3d108e01008785ebeb511575e65c03080e489c6e3db12db88c6e1729462bf2c6e95e3d757450e2
diff -pruN 1.3.1+dfsg-1/deps/checksums/LLVM.v6.0.1-7+nowasm.x86_64-apple-darwin14-gcc4.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/LLVM.v6.0.1-7+nowasm.x86_64-apple-darwin14-gcc4.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/LLVM.v6.0.1-7+nowasm.x86_64-apple-darwin14-gcc4.tar.gz/md5	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/LLVM.v6.0.1-7+nowasm.x86_64-apple-darwin14-gcc4.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-acc66103bc030b0691da5425de12d0d4
diff -pruN 1.3.1+dfsg-1/deps/checksums/LLVM.v6.0.1-7+nowasm.x86_64-apple-darwin14-gcc4.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/LLVM.v6.0.1-7+nowasm.x86_64-apple-darwin14-gcc4.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/LLVM.v6.0.1-7+nowasm.x86_64-apple-darwin14-gcc4.tar.gz/sha512	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/LLVM.v6.0.1-7+nowasm.x86_64-apple-darwin14-gcc4.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-e7fc442db075a588995def014174f8f631b7a06fec3cc21b2f2f4f42a4416fbd9f840d054bc89ab04b20e4e2614ed33fc7c75f7189a10c46b40b06ebb8b6589d
diff -pruN 1.3.1+dfsg-1/deps/checksums/LLVM.v6.0.1-7+nowasm.x86_64-apple-darwin14-gcc7.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/LLVM.v6.0.1-7+nowasm.x86_64-apple-darwin14-gcc7.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/LLVM.v6.0.1-7+nowasm.x86_64-apple-darwin14-gcc7.tar.gz/md5	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/LLVM.v6.0.1-7+nowasm.x86_64-apple-darwin14-gcc7.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-7dc70a32fd21745441387b7f7b7b71cc
diff -pruN 1.3.1+dfsg-1/deps/checksums/LLVM.v6.0.1-7+nowasm.x86_64-apple-darwin14-gcc7.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/LLVM.v6.0.1-7+nowasm.x86_64-apple-darwin14-gcc7.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/LLVM.v6.0.1-7+nowasm.x86_64-apple-darwin14-gcc7.tar.gz/sha512	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/LLVM.v6.0.1-7+nowasm.x86_64-apple-darwin14-gcc7.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-a858cdb39074e02d4b2d02fc168df8605181bb100ca5877ad8607d2a49603b591e010a6dd8ce5bb97828bde7f948e9e85f537a00ac01a709914663d69566baec
diff -pruN 1.3.1+dfsg-1/deps/checksums/LLVM.v6.0.1-7+nowasm.x86_64-apple-darwin14-gcc8.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/LLVM.v6.0.1-7+nowasm.x86_64-apple-darwin14-gcc8.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/LLVM.v6.0.1-7+nowasm.x86_64-apple-darwin14-gcc8.tar.gz/md5	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/LLVM.v6.0.1-7+nowasm.x86_64-apple-darwin14-gcc8.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-f2dcde5881cb4d47c4c954210013c4db
diff -pruN 1.3.1+dfsg-1/deps/checksums/LLVM.v6.0.1-7+nowasm.x86_64-apple-darwin14-gcc8.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/LLVM.v6.0.1-7+nowasm.x86_64-apple-darwin14-gcc8.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/LLVM.v6.0.1-7+nowasm.x86_64-apple-darwin14-gcc8.tar.gz/sha512	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/LLVM.v6.0.1-7+nowasm.x86_64-apple-darwin14-gcc8.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-a900666f3827cdd67953d4caaf2084d5beb680d2cd1a73d8f2640144fc88107d2a7ff8357c7907d57e541be8a1ca3b751c281597840c790837238ec292635203
diff -pruN 1.3.1+dfsg-1/deps/checksums/LLVM.v6.0.1-7+nowasm.x86_64-linux-gnu-gcc4.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/LLVM.v6.0.1-7+nowasm.x86_64-linux-gnu-gcc4.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/LLVM.v6.0.1-7+nowasm.x86_64-linux-gnu-gcc4.tar.gz/md5	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/LLVM.v6.0.1-7+nowasm.x86_64-linux-gnu-gcc4.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-88ca9ab7847a5cc7136a356a7c91a7cc
diff -pruN 1.3.1+dfsg-1/deps/checksums/LLVM.v6.0.1-7+nowasm.x86_64-linux-gnu-gcc4.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/LLVM.v6.0.1-7+nowasm.x86_64-linux-gnu-gcc4.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/LLVM.v6.0.1-7+nowasm.x86_64-linux-gnu-gcc4.tar.gz/sha512	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/LLVM.v6.0.1-7+nowasm.x86_64-linux-gnu-gcc4.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-6139c8df8232f749beb718b480d3093ef5b7640526a559c0affefdd2c09223d3df859a0a21c4a7d40fc7797acb7e2a6784aea78b742584d09faff16d01943f7b
diff -pruN 1.3.1+dfsg-1/deps/checksums/LLVM.v6.0.1-7+nowasm.x86_64-linux-gnu-gcc7.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/LLVM.v6.0.1-7+nowasm.x86_64-linux-gnu-gcc7.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/LLVM.v6.0.1-7+nowasm.x86_64-linux-gnu-gcc7.tar.gz/md5	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/LLVM.v6.0.1-7+nowasm.x86_64-linux-gnu-gcc7.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-8a88e8676ebe377f9245d751fbcb3295
diff -pruN 1.3.1+dfsg-1/deps/checksums/LLVM.v6.0.1-7+nowasm.x86_64-linux-gnu-gcc7.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/LLVM.v6.0.1-7+nowasm.x86_64-linux-gnu-gcc7.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/LLVM.v6.0.1-7+nowasm.x86_64-linux-gnu-gcc7.tar.gz/sha512	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/LLVM.v6.0.1-7+nowasm.x86_64-linux-gnu-gcc7.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-404238618223d952de2366601b55eeae18f0cfd4d02f5eabe70ee504791fb5dd2131001826cbd1b2f642d914f91ded47379be8439818d20b8234885c64d4a908
diff -pruN 1.3.1+dfsg-1/deps/checksums/LLVM.v6.0.1-7+nowasm.x86_64-linux-gnu-gcc8.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/LLVM.v6.0.1-7+nowasm.x86_64-linux-gnu-gcc8.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/LLVM.v6.0.1-7+nowasm.x86_64-linux-gnu-gcc8.tar.gz/md5	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/LLVM.v6.0.1-7+nowasm.x86_64-linux-gnu-gcc8.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-6e48d53154e7697e7f01c1bb47e8e54e
diff -pruN 1.3.1+dfsg-1/deps/checksums/LLVM.v6.0.1-7+nowasm.x86_64-linux-gnu-gcc8.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/LLVM.v6.0.1-7+nowasm.x86_64-linux-gnu-gcc8.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/LLVM.v6.0.1-7+nowasm.x86_64-linux-gnu-gcc8.tar.gz/sha512	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/LLVM.v6.0.1-7+nowasm.x86_64-linux-gnu-gcc8.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-17adb6066b6962a76d06b0ae492a9d7330db51b26b9fe1925ebbd3874981a8a8848794fff88bf924fb405cf71ddb48e1efe6c4bf30293c28d342e4c160053702
diff -pruN 1.3.1+dfsg-1/deps/checksums/LLVM.v6.0.1-7+nowasm.x86_64-linux-musl-gcc4.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/LLVM.v6.0.1-7+nowasm.x86_64-linux-musl-gcc4.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/LLVM.v6.0.1-7+nowasm.x86_64-linux-musl-gcc4.tar.gz/md5	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/LLVM.v6.0.1-7+nowasm.x86_64-linux-musl-gcc4.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-b320e6bcb0184851cc5c8f776424b73f
diff -pruN 1.3.1+dfsg-1/deps/checksums/LLVM.v6.0.1-7+nowasm.x86_64-linux-musl-gcc4.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/LLVM.v6.0.1-7+nowasm.x86_64-linux-musl-gcc4.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/LLVM.v6.0.1-7+nowasm.x86_64-linux-musl-gcc4.tar.gz/sha512	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/LLVM.v6.0.1-7+nowasm.x86_64-linux-musl-gcc4.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-fd3f5a20f29d64173f02b35e0d9edc6a4df6a81a5e7c2355dd0f925869b8fb7258ab43ec0911c4e91d10a3c59432d9c709cbfa845f29c393a59daabf1c7172ae
diff -pruN 1.3.1+dfsg-1/deps/checksums/LLVM.v6.0.1-7+nowasm.x86_64-linux-musl-gcc7.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/LLVM.v6.0.1-7+nowasm.x86_64-linux-musl-gcc7.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/LLVM.v6.0.1-7+nowasm.x86_64-linux-musl-gcc7.tar.gz/md5	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/LLVM.v6.0.1-7+nowasm.x86_64-linux-musl-gcc7.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-d0e5df7f099640b46be8ff5a66e4b6e1
diff -pruN 1.3.1+dfsg-1/deps/checksums/LLVM.v6.0.1-7+nowasm.x86_64-linux-musl-gcc7.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/LLVM.v6.0.1-7+nowasm.x86_64-linux-musl-gcc7.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/LLVM.v6.0.1-7+nowasm.x86_64-linux-musl-gcc7.tar.gz/sha512	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/LLVM.v6.0.1-7+nowasm.x86_64-linux-musl-gcc7.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-e3fd81ca6a5c9b5fc23700c59ef610bf649213bda34940d7e625f90cfbf09dd6f086fb4614d02c022cf9c4eb912e7487219badc2e30eef058b60d8ecdb2219ed
diff -pruN 1.3.1+dfsg-1/deps/checksums/LLVM.v6.0.1-7+nowasm.x86_64-linux-musl-gcc8.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/LLVM.v6.0.1-7+nowasm.x86_64-linux-musl-gcc8.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/LLVM.v6.0.1-7+nowasm.x86_64-linux-musl-gcc8.tar.gz/md5	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/LLVM.v6.0.1-7+nowasm.x86_64-linux-musl-gcc8.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-c07804931969bb9e569468416b60db6c
diff -pruN 1.3.1+dfsg-1/deps/checksums/LLVM.v6.0.1-7+nowasm.x86_64-linux-musl-gcc8.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/LLVM.v6.0.1-7+nowasm.x86_64-linux-musl-gcc8.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/LLVM.v6.0.1-7+nowasm.x86_64-linux-musl-gcc8.tar.gz/sha512	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/LLVM.v6.0.1-7+nowasm.x86_64-linux-musl-gcc8.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-9ccd6bc350e406e782d52d821c1b9ded8adf67c332d90072657b3c0a8d3c42b65f48d891efe855a2b5067467fff542a86cf564675cd73defed828a07814365eb
diff -pruN 1.3.1+dfsg-1/deps/checksums/LLVM.v6.0.1-7+nowasm.x86_64-unknown-freebsd11.1-gcc4.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/LLVM.v6.0.1-7+nowasm.x86_64-unknown-freebsd11.1-gcc4.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/LLVM.v6.0.1-7+nowasm.x86_64-unknown-freebsd11.1-gcc4.tar.gz/md5	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/LLVM.v6.0.1-7+nowasm.x86_64-unknown-freebsd11.1-gcc4.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-adf71aff58ce0f5ad224cca2d9c849d1
diff -pruN 1.3.1+dfsg-1/deps/checksums/LLVM.v6.0.1-7+nowasm.x86_64-unknown-freebsd11.1-gcc4.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/LLVM.v6.0.1-7+nowasm.x86_64-unknown-freebsd11.1-gcc4.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/LLVM.v6.0.1-7+nowasm.x86_64-unknown-freebsd11.1-gcc4.tar.gz/sha512	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/LLVM.v6.0.1-7+nowasm.x86_64-unknown-freebsd11.1-gcc4.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-52cea3cfd56099777f35c2d04e4313c084f348598502d1c9c045a941bb8ec2767de81dd88abc181883c7a2fb0ec916e651a042a9666b89712162ef3b33ac6c9f
diff -pruN 1.3.1+dfsg-1/deps/checksums/LLVM.v6.0.1-7+nowasm.x86_64-unknown-freebsd11.1-gcc7.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/LLVM.v6.0.1-7+nowasm.x86_64-unknown-freebsd11.1-gcc7.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/LLVM.v6.0.1-7+nowasm.x86_64-unknown-freebsd11.1-gcc7.tar.gz/md5	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/LLVM.v6.0.1-7+nowasm.x86_64-unknown-freebsd11.1-gcc7.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-8f7ea4ba9465fdfe5a1fb182db51f1c6
diff -pruN 1.3.1+dfsg-1/deps/checksums/LLVM.v6.0.1-7+nowasm.x86_64-unknown-freebsd11.1-gcc7.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/LLVM.v6.0.1-7+nowasm.x86_64-unknown-freebsd11.1-gcc7.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/LLVM.v6.0.1-7+nowasm.x86_64-unknown-freebsd11.1-gcc7.tar.gz/sha512	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/LLVM.v6.0.1-7+nowasm.x86_64-unknown-freebsd11.1-gcc7.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-a1e0fdf3a92dae0a2c0bcc81d278003453521bc7b636e0e62565152a600996b1e24720669ee0e9d8fb65e19f8c0c53865168dd5904368e2ac0e1fcbca4eb8903
diff -pruN 1.3.1+dfsg-1/deps/checksums/LLVM.v6.0.1-7+nowasm.x86_64-unknown-freebsd11.1-gcc8.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/LLVM.v6.0.1-7+nowasm.x86_64-unknown-freebsd11.1-gcc8.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/LLVM.v6.0.1-7+nowasm.x86_64-unknown-freebsd11.1-gcc8.tar.gz/md5	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/LLVM.v6.0.1-7+nowasm.x86_64-unknown-freebsd11.1-gcc8.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-354fe85d08d3d142404dbbdc172ce655
diff -pruN 1.3.1+dfsg-1/deps/checksums/LLVM.v6.0.1-7+nowasm.x86_64-unknown-freebsd11.1-gcc8.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/LLVM.v6.0.1-7+nowasm.x86_64-unknown-freebsd11.1-gcc8.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/LLVM.v6.0.1-7+nowasm.x86_64-unknown-freebsd11.1-gcc8.tar.gz/sha512	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/LLVM.v6.0.1-7+nowasm.x86_64-unknown-freebsd11.1-gcc8.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-b4844ef9c3c0c8be95c2fe07de9a4c2afbcf8e100699d38cf8f6caa38ad6c804812f2063faf1c669d680355c3d6e16b115618b8984313c2aee2cd37f4a6796de
diff -pruN 1.3.1+dfsg-1/deps/checksums/LLVM.v6.0.1-7+nowasm.x86_64-w64-mingw32-gcc4.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/LLVM.v6.0.1-7+nowasm.x86_64-w64-mingw32-gcc4.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/LLVM.v6.0.1-7+nowasm.x86_64-w64-mingw32-gcc4.tar.gz/md5	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/LLVM.v6.0.1-7+nowasm.x86_64-w64-mingw32-gcc4.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-09e636495833682b7b636a379ece3835
diff -pruN 1.3.1+dfsg-1/deps/checksums/LLVM.v6.0.1-7+nowasm.x86_64-w64-mingw32-gcc4.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/LLVM.v6.0.1-7+nowasm.x86_64-w64-mingw32-gcc4.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/LLVM.v6.0.1-7+nowasm.x86_64-w64-mingw32-gcc4.tar.gz/sha512	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/LLVM.v6.0.1-7+nowasm.x86_64-w64-mingw32-gcc4.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-0deeb5229bb55b010212feb80c79d39804a776eec988fc877636df9541ac1135c7114d0814d19a02ced312c42bd84683a8886c50e680e4a6c71582521dca42bd
diff -pruN 1.3.1+dfsg-1/deps/checksums/LLVM.v6.0.1-7+nowasm.x86_64-w64-mingw32-gcc7.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/LLVM.v6.0.1-7+nowasm.x86_64-w64-mingw32-gcc7.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/LLVM.v6.0.1-7+nowasm.x86_64-w64-mingw32-gcc7.tar.gz/md5	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/LLVM.v6.0.1-7+nowasm.x86_64-w64-mingw32-gcc7.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-40041e58babe9172b34716829867763a
diff -pruN 1.3.1+dfsg-1/deps/checksums/LLVM.v6.0.1-7+nowasm.x86_64-w64-mingw32-gcc7.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/LLVM.v6.0.1-7+nowasm.x86_64-w64-mingw32-gcc7.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/LLVM.v6.0.1-7+nowasm.x86_64-w64-mingw32-gcc7.tar.gz/sha512	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/LLVM.v6.0.1-7+nowasm.x86_64-w64-mingw32-gcc7.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-e6acd7f2baab220768df9b21374c0548d20eef6e93ffba613e286d3cd0f31464a3fd2d14f65089460113f9603d3852a40a18331bddfee855b24986ab6720c29f
diff -pruN 1.3.1+dfsg-1/deps/checksums/LLVM.v6.0.1-7+nowasm.x86_64-w64-mingw32-gcc8.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/LLVM.v6.0.1-7+nowasm.x86_64-w64-mingw32-gcc8.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/LLVM.v6.0.1-7+nowasm.x86_64-w64-mingw32-gcc8.tar.gz/md5	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/LLVM.v6.0.1-7+nowasm.x86_64-w64-mingw32-gcc8.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-bd952c914461b396924e48a67765445e
diff -pruN 1.3.1+dfsg-1/deps/checksums/LLVM.v6.0.1-7+nowasm.x86_64-w64-mingw32-gcc8.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/LLVM.v6.0.1-7+nowasm.x86_64-w64-mingw32-gcc8.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/LLVM.v6.0.1-7+nowasm.x86_64-w64-mingw32-gcc8.tar.gz/sha512	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/LLVM.v6.0.1-7+nowasm.x86_64-w64-mingw32-gcc8.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-2c51c8ffd9d1c936fdbab2395cf29bc83f416473f3444ee5613a9f1b261c8693c7102bc2c2b53d2c2b5e473ffd94bd0db2d7cfc2e20d32c11129d1c3884b6214
diff -pruN 1.3.1+dfsg-1/deps/checksums/MbedTLS.v2.16.0-1.aarch64-linux-gnu.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/MbedTLS.v2.16.0-1.aarch64-linux-gnu.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/MbedTLS.v2.16.0-1.aarch64-linux-gnu.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/MbedTLS.v2.16.0-1.aarch64-linux-gnu.tar.gz/md5	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+84175a5d9fc8347e2b9aa4ed7e8a69b8
diff -pruN 1.3.1+dfsg-1/deps/checksums/MbedTLS.v2.16.0-1.aarch64-linux-gnu.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/MbedTLS.v2.16.0-1.aarch64-linux-gnu.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/MbedTLS.v2.16.0-1.aarch64-linux-gnu.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/MbedTLS.v2.16.0-1.aarch64-linux-gnu.tar.gz/sha512	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+701ce72a948d5006a5d925acd6a5f8f3fe8409857d11fb94099f0e2ec39200aabd48f0312102d50bdf0099334661ae97c63606631255c286c93703b5791c6e14
diff -pruN 1.3.1+dfsg-1/deps/checksums/MbedTLS.v2.16.0-1.aarch64-linux-musl.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/MbedTLS.v2.16.0-1.aarch64-linux-musl.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/MbedTLS.v2.16.0-1.aarch64-linux-musl.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/MbedTLS.v2.16.0-1.aarch64-linux-musl.tar.gz/md5	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+f34a99ee2f7d506aeaad73e7bff6f59e
diff -pruN 1.3.1+dfsg-1/deps/checksums/MbedTLS.v2.16.0-1.aarch64-linux-musl.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/MbedTLS.v2.16.0-1.aarch64-linux-musl.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/MbedTLS.v2.16.0-1.aarch64-linux-musl.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/MbedTLS.v2.16.0-1.aarch64-linux-musl.tar.gz/sha512	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+61c04d0a48e3e5e1e6820996e351891bb9ae57398e9d0148604ddde077b63f80cf52f0d61a2e5bf3eb4717bfc1f92d1d8e088c5f443e3d6739547e27b9413b8d
diff -pruN 1.3.1+dfsg-1/deps/checksums/MbedTLS.v2.16.0-1.arm-linux-gnueabihf.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/MbedTLS.v2.16.0-1.arm-linux-gnueabihf.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/MbedTLS.v2.16.0-1.arm-linux-gnueabihf.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/MbedTLS.v2.16.0-1.arm-linux-gnueabihf.tar.gz/md5	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+146c9b4402a2d78cc8fafc9c0b332f86
diff -pruN 1.3.1+dfsg-1/deps/checksums/MbedTLS.v2.16.0-1.arm-linux-gnueabihf.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/MbedTLS.v2.16.0-1.arm-linux-gnueabihf.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/MbedTLS.v2.16.0-1.arm-linux-gnueabihf.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/MbedTLS.v2.16.0-1.arm-linux-gnueabihf.tar.gz/sha512	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+4bce90f403c1f245decfbc5371b80fe46f142e865fe32a6c9055aa7a6909e2334234500ef9bfc653e7450a9f415101f11036cbf23f9c14ee491dce9bfa84d7ec
diff -pruN 1.3.1+dfsg-1/deps/checksums/MbedTLS.v2.16.0-1.arm-linux-musleabihf.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/MbedTLS.v2.16.0-1.arm-linux-musleabihf.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/MbedTLS.v2.16.0-1.arm-linux-musleabihf.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/MbedTLS.v2.16.0-1.arm-linux-musleabihf.tar.gz/md5	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+427676696934a1f434ce051ad98d7722
diff -pruN 1.3.1+dfsg-1/deps/checksums/MbedTLS.v2.16.0-1.arm-linux-musleabihf.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/MbedTLS.v2.16.0-1.arm-linux-musleabihf.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/MbedTLS.v2.16.0-1.arm-linux-musleabihf.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/MbedTLS.v2.16.0-1.arm-linux-musleabihf.tar.gz/sha512	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+7f13355d6b2261efa79dcf38177da911bb2a049dbbf3c83b37c3875e3247daff7b52081a2688585ee93c1ccd31aaa21f45861369401ebb6a2cb5c248634977a8
diff -pruN 1.3.1+dfsg-1/deps/checksums/MbedTLS.v2.16.0-1.i686-linux-gnu.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/MbedTLS.v2.16.0-1.i686-linux-gnu.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/MbedTLS.v2.16.0-1.i686-linux-gnu.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/MbedTLS.v2.16.0-1.i686-linux-gnu.tar.gz/md5	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+35c1711cf9943da73f2dba9005d1e765
diff -pruN 1.3.1+dfsg-1/deps/checksums/MbedTLS.v2.16.0-1.i686-linux-gnu.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/MbedTLS.v2.16.0-1.i686-linux-gnu.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/MbedTLS.v2.16.0-1.i686-linux-gnu.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/MbedTLS.v2.16.0-1.i686-linux-gnu.tar.gz/sha512	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+316926f0b6ba84942e527a154a6e2751edf698e3c289d8ca92d1cede18c7793b9ea39a7245bd818c3bf2091e2f58aabd9ac93311ea472f629d88d6c00a035ff4
diff -pruN 1.3.1+dfsg-1/deps/checksums/MbedTLS.v2.16.0-1.i686-linux-musl.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/MbedTLS.v2.16.0-1.i686-linux-musl.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/MbedTLS.v2.16.0-1.i686-linux-musl.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/MbedTLS.v2.16.0-1.i686-linux-musl.tar.gz/md5	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+8a834419657970331b6e2b44b8fe4a5c
diff -pruN 1.3.1+dfsg-1/deps/checksums/MbedTLS.v2.16.0-1.i686-linux-musl.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/MbedTLS.v2.16.0-1.i686-linux-musl.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/MbedTLS.v2.16.0-1.i686-linux-musl.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/MbedTLS.v2.16.0-1.i686-linux-musl.tar.gz/sha512	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+c5d7329be655511273b3511712bc68874250984665a083d552970af1d08db292bc191dfe5296cf9ebc45c51090b5bb299d17525801447fd992e5926ffd21b1f4
diff -pruN 1.3.1+dfsg-1/deps/checksums/MbedTLS.v2.16.0-1.i686-w64-mingw32.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/MbedTLS.v2.16.0-1.i686-w64-mingw32.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/MbedTLS.v2.16.0-1.i686-w64-mingw32.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/MbedTLS.v2.16.0-1.i686-w64-mingw32.tar.gz/md5	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+93a90d234ada9f8e0979d8aa53a31d5b
diff -pruN 1.3.1+dfsg-1/deps/checksums/MbedTLS.v2.16.0-1.i686-w64-mingw32.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/MbedTLS.v2.16.0-1.i686-w64-mingw32.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/MbedTLS.v2.16.0-1.i686-w64-mingw32.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/MbedTLS.v2.16.0-1.i686-w64-mingw32.tar.gz/sha512	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+3506e157dec0f0e3351fe2b4d0580bc38747f199a2c6f0cbbee781aa81b8a093f7a31fbe864aa938f32f6686aaac92ccdff534e43065d669ecd1172f2bf1a40d
diff -pruN 1.3.1+dfsg-1/deps/checksums/MbedTLS.v2.16.0-1.powerpc64le-linux-gnu.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/MbedTLS.v2.16.0-1.powerpc64le-linux-gnu.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/MbedTLS.v2.16.0-1.powerpc64le-linux-gnu.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/MbedTLS.v2.16.0-1.powerpc64le-linux-gnu.tar.gz/md5	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+f260bdc7f05fb81303bf22ffc5357548
diff -pruN 1.3.1+dfsg-1/deps/checksums/MbedTLS.v2.16.0-1.powerpc64le-linux-gnu.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/MbedTLS.v2.16.0-1.powerpc64le-linux-gnu.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/MbedTLS.v2.16.0-1.powerpc64le-linux-gnu.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/MbedTLS.v2.16.0-1.powerpc64le-linux-gnu.tar.gz/sha512	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+0a7ff35e8b6f0358459ea7bae059fc11b57f8e626bb5bd5fc8586f39254b9c2db044eef470095c77aa35139cd2867414ad0a3155fc67cc848224b71178971a46
diff -pruN 1.3.1+dfsg-1/deps/checksums/MbedTLS.v2.16.0-1.x86_64-apple-darwin14.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/MbedTLS.v2.16.0-1.x86_64-apple-darwin14.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/MbedTLS.v2.16.0-1.x86_64-apple-darwin14.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/MbedTLS.v2.16.0-1.x86_64-apple-darwin14.tar.gz/md5	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+35ea69e501f16196bb0a0c2d8baee77f
diff -pruN 1.3.1+dfsg-1/deps/checksums/MbedTLS.v2.16.0-1.x86_64-apple-darwin14.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/MbedTLS.v2.16.0-1.x86_64-apple-darwin14.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/MbedTLS.v2.16.0-1.x86_64-apple-darwin14.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/MbedTLS.v2.16.0-1.x86_64-apple-darwin14.tar.gz/sha512	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+6809ced55c67233ae0c16807e21bb1a327642a7cd2a041aab7683b15770a5cd41b40c98a8b6a8c67757ec98e3041509ee79b5af756c97737af00ac23d1b0f545
diff -pruN 1.3.1+dfsg-1/deps/checksums/MbedTLS.v2.16.0-1.x86_64-linux-gnu.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/MbedTLS.v2.16.0-1.x86_64-linux-gnu.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/MbedTLS.v2.16.0-1.x86_64-linux-gnu.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/MbedTLS.v2.16.0-1.x86_64-linux-gnu.tar.gz/md5	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+44b6ef27dff86636b481782a81b670ff
diff -pruN 1.3.1+dfsg-1/deps/checksums/MbedTLS.v2.16.0-1.x86_64-linux-gnu.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/MbedTLS.v2.16.0-1.x86_64-linux-gnu.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/MbedTLS.v2.16.0-1.x86_64-linux-gnu.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/MbedTLS.v2.16.0-1.x86_64-linux-gnu.tar.gz/sha512	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+d5bdbbfbe997dcf6a066f97642d3c15641fdb44e6005e7b5c89a56609ffffda70db1d1df3dbb8c07f922e690ca22eeba1605ee6c0db4eb94d7683cfffd5a1a03
diff -pruN 1.3.1+dfsg-1/deps/checksums/MbedTLS.v2.16.0-1.x86_64-linux-musl.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/MbedTLS.v2.16.0-1.x86_64-linux-musl.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/MbedTLS.v2.16.0-1.x86_64-linux-musl.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/MbedTLS.v2.16.0-1.x86_64-linux-musl.tar.gz/md5	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+72259058d1151efe5bb7a6b5b8228525
diff -pruN 1.3.1+dfsg-1/deps/checksums/MbedTLS.v2.16.0-1.x86_64-linux-musl.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/MbedTLS.v2.16.0-1.x86_64-linux-musl.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/MbedTLS.v2.16.0-1.x86_64-linux-musl.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/MbedTLS.v2.16.0-1.x86_64-linux-musl.tar.gz/sha512	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+2c06b8fcf71f7aa4a62f12522508e027cc5bd719e9eea23d55fa317803e831e7ac310f086af9b6ca27fc9dd68af0fc1a92e9e3eb9e3cd48d4888653e4bd758ae
diff -pruN 1.3.1+dfsg-1/deps/checksums/MbedTLS.v2.16.0-1.x86_64-unknown-freebsd11.1.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/MbedTLS.v2.16.0-1.x86_64-unknown-freebsd11.1.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/MbedTLS.v2.16.0-1.x86_64-unknown-freebsd11.1.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/MbedTLS.v2.16.0-1.x86_64-unknown-freebsd11.1.tar.gz/md5	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+3539981369c2b7a54126e617e510db97
diff -pruN 1.3.1+dfsg-1/deps/checksums/MbedTLS.v2.16.0-1.x86_64-unknown-freebsd11.1.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/MbedTLS.v2.16.0-1.x86_64-unknown-freebsd11.1.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/MbedTLS.v2.16.0-1.x86_64-unknown-freebsd11.1.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/MbedTLS.v2.16.0-1.x86_64-unknown-freebsd11.1.tar.gz/sha512	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+ab7078bba347b8e4b67561969a016bdc5e7b032e7db5c513cdd578df531a52c8274609862f4fd2732b7eb68abe2795f920fbe9f021a0a6090f4d6c9fcc2213f3
diff -pruN 1.3.1+dfsg-1/deps/checksums/MbedTLS.v2.16.0-1.x86_64-w64-mingw32.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/MbedTLS.v2.16.0-1.x86_64-w64-mingw32.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/MbedTLS.v2.16.0-1.x86_64-w64-mingw32.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/MbedTLS.v2.16.0-1.x86_64-w64-mingw32.tar.gz/md5	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+e625b6e3e8bf2200a633dcdabf5ddba3
diff -pruN 1.3.1+dfsg-1/deps/checksums/MbedTLS.v2.16.0-1.x86_64-w64-mingw32.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/MbedTLS.v2.16.0-1.x86_64-w64-mingw32.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/MbedTLS.v2.16.0-1.x86_64-w64-mingw32.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/MbedTLS.v2.16.0-1.x86_64-w64-mingw32.tar.gz/sha512	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+09e24f2bf8af07f86897015e4c1139058af4c0c7266a6d5ea31bb88cb3c24b4a995fac285a2c3b600725a3ad6670bb874c2ee70aa7f99ddc370bf78768c3ac24
diff -pruN 1.3.1+dfsg-1/deps/checksums/MbedTLS.v2.16.0-v0.17.0.aarch64-linux-gnu.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/MbedTLS.v2.16.0-v0.17.0.aarch64-linux-gnu.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/MbedTLS.v2.16.0-v0.17.0.aarch64-linux-gnu.tar.gz/md5	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/MbedTLS.v2.16.0-v0.17.0.aarch64-linux-gnu.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-0f65b4f1db6eb913fc442bfb9a1cacf1
diff -pruN 1.3.1+dfsg-1/deps/checksums/MbedTLS.v2.16.0-v0.17.0.aarch64-linux-gnu.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/MbedTLS.v2.16.0-v0.17.0.aarch64-linux-gnu.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/MbedTLS.v2.16.0-v0.17.0.aarch64-linux-gnu.tar.gz/sha512	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/MbedTLS.v2.16.0-v0.17.0.aarch64-linux-gnu.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-8a370af19cfc19c0d04495291eb0c18793ab029d5eec8c631b0726eadbf2db93fe6c62f40f27f8111fb919f9e5b49e80958800f0ad2cd77fcd061ac94ecfbaa9
diff -pruN 1.3.1+dfsg-1/deps/checksums/MbedTLS.v2.16.0-v0.17.0.aarch64-linux-musl.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/MbedTLS.v2.16.0-v0.17.0.aarch64-linux-musl.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/MbedTLS.v2.16.0-v0.17.0.aarch64-linux-musl.tar.gz/md5	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/MbedTLS.v2.16.0-v0.17.0.aarch64-linux-musl.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-cde903351d0f20805aa7382e3a187f55
diff -pruN 1.3.1+dfsg-1/deps/checksums/MbedTLS.v2.16.0-v0.17.0.aarch64-linux-musl.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/MbedTLS.v2.16.0-v0.17.0.aarch64-linux-musl.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/MbedTLS.v2.16.0-v0.17.0.aarch64-linux-musl.tar.gz/sha512	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/MbedTLS.v2.16.0-v0.17.0.aarch64-linux-musl.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-6db4cd910716fc7c37bbd80e912c9890603f4bd7b63452338eee945e7bf4cec2fe1d989edc064a4562ea1e81062673ab363ab087ba29fcb175800fcaf6f2678d
diff -pruN 1.3.1+dfsg-1/deps/checksums/MbedTLS.v2.16.0-v0.17.0.arm-linux-gnueabihf.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/MbedTLS.v2.16.0-v0.17.0.arm-linux-gnueabihf.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/MbedTLS.v2.16.0-v0.17.0.arm-linux-gnueabihf.tar.gz/md5	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/MbedTLS.v2.16.0-v0.17.0.arm-linux-gnueabihf.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-29c08a9e3a32ffbe6a4c4d0929fce3a2
diff -pruN 1.3.1+dfsg-1/deps/checksums/MbedTLS.v2.16.0-v0.17.0.arm-linux-gnueabihf.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/MbedTLS.v2.16.0-v0.17.0.arm-linux-gnueabihf.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/MbedTLS.v2.16.0-v0.17.0.arm-linux-gnueabihf.tar.gz/sha512	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/MbedTLS.v2.16.0-v0.17.0.arm-linux-gnueabihf.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-24310aa24f55b91c80726344d8844f024a09882b298f806a8af6601e1405e40b78b8ab18893912e01c12537554709a9e781d294d3f42dd501ba7cb01c9f10996
diff -pruN 1.3.1+dfsg-1/deps/checksums/MbedTLS.v2.16.0-v0.17.0.arm-linux-musleabihf.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/MbedTLS.v2.16.0-v0.17.0.arm-linux-musleabihf.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/MbedTLS.v2.16.0-v0.17.0.arm-linux-musleabihf.tar.gz/md5	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/MbedTLS.v2.16.0-v0.17.0.arm-linux-musleabihf.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-078fc8029579eb40c68e7744f0bd6af6
diff -pruN 1.3.1+dfsg-1/deps/checksums/MbedTLS.v2.16.0-v0.17.0.arm-linux-musleabihf.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/MbedTLS.v2.16.0-v0.17.0.arm-linux-musleabihf.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/MbedTLS.v2.16.0-v0.17.0.arm-linux-musleabihf.tar.gz/sha512	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/MbedTLS.v2.16.0-v0.17.0.arm-linux-musleabihf.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-17f3ecfc46799663679562e9dd7021b315db06562687836f376d6168f5778d9ce82d85d4f1a992b3872777931d61585070759b68b213c5f5d6f93a849c772b42
diff -pruN 1.3.1+dfsg-1/deps/checksums/MbedTLS.v2.16.0-v0.17.0.i686-linux-gnu.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/MbedTLS.v2.16.0-v0.17.0.i686-linux-gnu.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/MbedTLS.v2.16.0-v0.17.0.i686-linux-gnu.tar.gz/md5	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/MbedTLS.v2.16.0-v0.17.0.i686-linux-gnu.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-01c763bd84533879267d18752fc59bb1
diff -pruN 1.3.1+dfsg-1/deps/checksums/MbedTLS.v2.16.0-v0.17.0.i686-linux-gnu.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/MbedTLS.v2.16.0-v0.17.0.i686-linux-gnu.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/MbedTLS.v2.16.0-v0.17.0.i686-linux-gnu.tar.gz/sha512	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/MbedTLS.v2.16.0-v0.17.0.i686-linux-gnu.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-365610732ca83b28ea521004b817688edf145eb3808591d228d2c6926106d5630232dec9be6dff6428d86400d9bf3ace15b65e8269cacfb60556db2ebc9d3c64
diff -pruN 1.3.1+dfsg-1/deps/checksums/MbedTLS.v2.16.0-v0.17.0.i686-linux-musl.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/MbedTLS.v2.16.0-v0.17.0.i686-linux-musl.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/MbedTLS.v2.16.0-v0.17.0.i686-linux-musl.tar.gz/md5	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/MbedTLS.v2.16.0-v0.17.0.i686-linux-musl.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-a3ebddf1cedc9b5b82266f79f7b35e4a
diff -pruN 1.3.1+dfsg-1/deps/checksums/MbedTLS.v2.16.0-v0.17.0.i686-linux-musl.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/MbedTLS.v2.16.0-v0.17.0.i686-linux-musl.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/MbedTLS.v2.16.0-v0.17.0.i686-linux-musl.tar.gz/sha512	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/MbedTLS.v2.16.0-v0.17.0.i686-linux-musl.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-69abbe0e0aa6f276d20e30b2d40824c5c60a41d628eb3f4fc83083eefa775e059ab33176c5177db8dbe911dc90f5baa7aedd1b9ecc075d2781bb906bc237e10f
diff -pruN 1.3.1+dfsg-1/deps/checksums/MbedTLS.v2.16.0-v0.17.0.i686-w64-mingw32.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/MbedTLS.v2.16.0-v0.17.0.i686-w64-mingw32.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/MbedTLS.v2.16.0-v0.17.0.i686-w64-mingw32.tar.gz/md5	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/MbedTLS.v2.16.0-v0.17.0.i686-w64-mingw32.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-78de097a872a587afcd593e087119bf3
diff -pruN 1.3.1+dfsg-1/deps/checksums/MbedTLS.v2.16.0-v0.17.0.i686-w64-mingw32.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/MbedTLS.v2.16.0-v0.17.0.i686-w64-mingw32.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/MbedTLS.v2.16.0-v0.17.0.i686-w64-mingw32.tar.gz/sha512	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/MbedTLS.v2.16.0-v0.17.0.i686-w64-mingw32.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-596f10ae384e1d66e1c3410997857dde5908af83fe6e8f6aa047aa3dd703eab703e9c67c0759d72ba736a45f5813edb933417a5ce48bcdb7d694c08207239291
diff -pruN 1.3.1+dfsg-1/deps/checksums/MbedTLS.v2.16.0-v0.17.0.powerpc64le-linux-gnu.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/MbedTLS.v2.16.0-v0.17.0.powerpc64le-linux-gnu.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/MbedTLS.v2.16.0-v0.17.0.powerpc64le-linux-gnu.tar.gz/md5	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/MbedTLS.v2.16.0-v0.17.0.powerpc64le-linux-gnu.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-8df9b36147cf90789d621dd080c5ec9c
diff -pruN 1.3.1+dfsg-1/deps/checksums/MbedTLS.v2.16.0-v0.17.0.powerpc64le-linux-gnu.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/MbedTLS.v2.16.0-v0.17.0.powerpc64le-linux-gnu.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/MbedTLS.v2.16.0-v0.17.0.powerpc64le-linux-gnu.tar.gz/sha512	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/MbedTLS.v2.16.0-v0.17.0.powerpc64le-linux-gnu.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-8bc7dffece424e346664c5edf31531787a7e0ed52509e8211b499df0b396170d3949d813a76f4bfb3ab7d0c60a1914486f915159b1058876994aa3638d0625ee
diff -pruN 1.3.1+dfsg-1/deps/checksums/MbedTLS.v2.16.0-v0.17.0.x86_64-apple-darwin14.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/MbedTLS.v2.16.0-v0.17.0.x86_64-apple-darwin14.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/MbedTLS.v2.16.0-v0.17.0.x86_64-apple-darwin14.tar.gz/md5	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/MbedTLS.v2.16.0-v0.17.0.x86_64-apple-darwin14.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-40ce3e865f293c5772bc67c132777038
diff -pruN 1.3.1+dfsg-1/deps/checksums/MbedTLS.v2.16.0-v0.17.0.x86_64-apple-darwin14.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/MbedTLS.v2.16.0-v0.17.0.x86_64-apple-darwin14.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/MbedTLS.v2.16.0-v0.17.0.x86_64-apple-darwin14.tar.gz/sha512	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/MbedTLS.v2.16.0-v0.17.0.x86_64-apple-darwin14.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-fd34b1330cdae41dd4f492c6feff9a663fc6d373c065d664420e6bb982d653e8877185f90533d651ed1cdbed9722eacc095925833dab36c1e9a87857f9ef4d5a
diff -pruN 1.3.1+dfsg-1/deps/checksums/MbedTLS.v2.16.0-v0.17.0.x86_64-linux-gnu.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/MbedTLS.v2.16.0-v0.17.0.x86_64-linux-gnu.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/MbedTLS.v2.16.0-v0.17.0.x86_64-linux-gnu.tar.gz/md5	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/MbedTLS.v2.16.0-v0.17.0.x86_64-linux-gnu.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-50ac733ba0dd518cefd3e9b5ec03cdb7
diff -pruN 1.3.1+dfsg-1/deps/checksums/MbedTLS.v2.16.0-v0.17.0.x86_64-linux-gnu.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/MbedTLS.v2.16.0-v0.17.0.x86_64-linux-gnu.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/MbedTLS.v2.16.0-v0.17.0.x86_64-linux-gnu.tar.gz/sha512	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/MbedTLS.v2.16.0-v0.17.0.x86_64-linux-gnu.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-c0a8796673f8a9cd8be9c697228ba2c57991255d277da719209dbf0a830e4d0a09631d6e25618908cc265e3c9c1952743f30e4fb9dbec5023f0fc79215dbbec5
diff -pruN 1.3.1+dfsg-1/deps/checksums/MbedTLS.v2.16.0-v0.17.0.x86_64-linux-musl.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/MbedTLS.v2.16.0-v0.17.0.x86_64-linux-musl.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/MbedTLS.v2.16.0-v0.17.0.x86_64-linux-musl.tar.gz/md5	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/MbedTLS.v2.16.0-v0.17.0.x86_64-linux-musl.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-3cea65e78200e1c5685f1303a97ee98d
diff -pruN 1.3.1+dfsg-1/deps/checksums/MbedTLS.v2.16.0-v0.17.0.x86_64-linux-musl.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/MbedTLS.v2.16.0-v0.17.0.x86_64-linux-musl.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/MbedTLS.v2.16.0-v0.17.0.x86_64-linux-musl.tar.gz/sha512	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/MbedTLS.v2.16.0-v0.17.0.x86_64-linux-musl.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-dd08fb48f217b272a1887cbe2afc1c33e218e2d4683ff47a14909829e6781f61eb6667f12b8fb1a6d6d95a7555796bbd156831f1f61f946ed29c58962f3e1989
diff -pruN 1.3.1+dfsg-1/deps/checksums/MbedTLS.v2.16.0-v0.17.0.x86_64-unknown-freebsd11.1.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/MbedTLS.v2.16.0-v0.17.0.x86_64-unknown-freebsd11.1.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/MbedTLS.v2.16.0-v0.17.0.x86_64-unknown-freebsd11.1.tar.gz/md5	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/MbedTLS.v2.16.0-v0.17.0.x86_64-unknown-freebsd11.1.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-7dcb4b2f84470fce6a0eb530fb858cc1
diff -pruN 1.3.1+dfsg-1/deps/checksums/MbedTLS.v2.16.0-v0.17.0.x86_64-unknown-freebsd11.1.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/MbedTLS.v2.16.0-v0.17.0.x86_64-unknown-freebsd11.1.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/MbedTLS.v2.16.0-v0.17.0.x86_64-unknown-freebsd11.1.tar.gz/sha512	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/MbedTLS.v2.16.0-v0.17.0.x86_64-unknown-freebsd11.1.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-3b84efc17aa2f9030d40a5cd9f605d9e6388557b57279752e2df086128c311be64412b826bd9ef4562398641d773f3293e349bbef5f94cda83493b30df105552
diff -pruN 1.3.1+dfsg-1/deps/checksums/MbedTLS.v2.16.0-v0.17.0.x86_64-w64-mingw32.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/MbedTLS.v2.16.0-v0.17.0.x86_64-w64-mingw32.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/MbedTLS.v2.16.0-v0.17.0.x86_64-w64-mingw32.tar.gz/md5	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/MbedTLS.v2.16.0-v0.17.0.x86_64-w64-mingw32.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-0505e986a2ef7acdd5aa46db0db9087c
diff -pruN 1.3.1+dfsg-1/deps/checksums/MbedTLS.v2.16.0-v0.17.0.x86_64-w64-mingw32.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/MbedTLS.v2.16.0-v0.17.0.x86_64-w64-mingw32.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/MbedTLS.v2.16.0-v0.17.0.x86_64-w64-mingw32.tar.gz/sha512	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/MbedTLS.v2.16.0-v0.17.0.x86_64-w64-mingw32.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-b8bf73f025d8b2f49498ff4d02fc3c35e37a45af487e49e41da7167c74cd2e70e68fccd32e2e3c2fccb5f0fd72a95312e9fe4abb26271d9fb59f61f8b30abe40
diff -pruN 1.3.1+dfsg-1/deps/checksums/MPFR.v4.0.2-0.aarch64-linux-gnu.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/MPFR.v4.0.2-0.aarch64-linux-gnu.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/MPFR.v4.0.2-0.aarch64-linux-gnu.tar.gz/md5	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/MPFR.v4.0.2-0.aarch64-linux-gnu.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-1cda9d8886b5b87a496caaa08a65c087
diff -pruN 1.3.1+dfsg-1/deps/checksums/MPFR.v4.0.2-0.aarch64-linux-gnu.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/MPFR.v4.0.2-0.aarch64-linux-gnu.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/MPFR.v4.0.2-0.aarch64-linux-gnu.tar.gz/sha512	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/MPFR.v4.0.2-0.aarch64-linux-gnu.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-481683f1d7abc3346b003c275c44e199b4ff89358ef12c4b2dab7458c68237b0aafb76792de2932ac91e5228c23360b7fa5fa2ef92c0994157e3c33bb24cbea9
diff -pruN 1.3.1+dfsg-1/deps/checksums/MPFR.v4.0.2-0.aarch64-linux-musl.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/MPFR.v4.0.2-0.aarch64-linux-musl.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/MPFR.v4.0.2-0.aarch64-linux-musl.tar.gz/md5	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/MPFR.v4.0.2-0.aarch64-linux-musl.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-108305a6eb6fb76df7ce2ff4f410b786
diff -pruN 1.3.1+dfsg-1/deps/checksums/MPFR.v4.0.2-0.aarch64-linux-musl.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/MPFR.v4.0.2-0.aarch64-linux-musl.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/MPFR.v4.0.2-0.aarch64-linux-musl.tar.gz/sha512	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/MPFR.v4.0.2-0.aarch64-linux-musl.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-26a82a851ff11e81f33741ae05bb53cfa8bd3af32f466efcf4048e8d6577daa5e8ede67cf19efabfba152b3e93db7eacb5434c6864a0d1ec2c5030d10c5d568e
diff -pruN 1.3.1+dfsg-1/deps/checksums/MPFR.v4.0.2-0.arm-linux-gnueabihf.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/MPFR.v4.0.2-0.arm-linux-gnueabihf.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/MPFR.v4.0.2-0.arm-linux-gnueabihf.tar.gz/md5	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/MPFR.v4.0.2-0.arm-linux-gnueabihf.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-2fdc41279fc93d071d239a7f6a6cf28c
diff -pruN 1.3.1+dfsg-1/deps/checksums/MPFR.v4.0.2-0.arm-linux-gnueabihf.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/MPFR.v4.0.2-0.arm-linux-gnueabihf.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/MPFR.v4.0.2-0.arm-linux-gnueabihf.tar.gz/sha512	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/MPFR.v4.0.2-0.arm-linux-gnueabihf.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-654566a5a7a540c29fbf4b925f1bc444c6471a3b5b13bdd1a1f927e01dc9f9cd4a8f4d16b35aed6c06b790cdc4fc9703ec63995492bab138e5b4fd2562f95158
diff -pruN 1.3.1+dfsg-1/deps/checksums/MPFR.v4.0.2-0.arm-linux-musleabihf.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/MPFR.v4.0.2-0.arm-linux-musleabihf.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/MPFR.v4.0.2-0.arm-linux-musleabihf.tar.gz/md5	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/MPFR.v4.0.2-0.arm-linux-musleabihf.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-87606da70ab6faf6a6d3d918cf58581b
diff -pruN 1.3.1+dfsg-1/deps/checksums/MPFR.v4.0.2-0.arm-linux-musleabihf.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/MPFR.v4.0.2-0.arm-linux-musleabihf.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/MPFR.v4.0.2-0.arm-linux-musleabihf.tar.gz/sha512	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/MPFR.v4.0.2-0.arm-linux-musleabihf.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-316233ff37ac60a63fd9e3604b1412e2365f5a3a69c0af5557978b937816bb81c5d06e6cba188322e62983d62daee1e56dd1f28b05d6076333fbb5b8bbc56c25
diff -pruN 1.3.1+dfsg-1/deps/checksums/MPFR.v4.0.2-0.i686-linux-gnu.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/MPFR.v4.0.2-0.i686-linux-gnu.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/MPFR.v4.0.2-0.i686-linux-gnu.tar.gz/md5	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/MPFR.v4.0.2-0.i686-linux-gnu.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-86f289a10058ef62cea59ffa063ce989
diff -pruN 1.3.1+dfsg-1/deps/checksums/MPFR.v4.0.2-0.i686-linux-gnu.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/MPFR.v4.0.2-0.i686-linux-gnu.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/MPFR.v4.0.2-0.i686-linux-gnu.tar.gz/sha512	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/MPFR.v4.0.2-0.i686-linux-gnu.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-ff66362191a8307972d5f47c35eafc788067fe2a38be60d38d4a1ee9ae2004dcbd7c3e062db8ebd3914804c97ce46776eaa9723fc9b533813f3476f6e701cbd8
diff -pruN 1.3.1+dfsg-1/deps/checksums/MPFR.v4.0.2-0.i686-linux-musl.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/MPFR.v4.0.2-0.i686-linux-musl.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/MPFR.v4.0.2-0.i686-linux-musl.tar.gz/md5	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/MPFR.v4.0.2-0.i686-linux-musl.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-3e7a14eb121371420838253b519c2995
diff -pruN 1.3.1+dfsg-1/deps/checksums/MPFR.v4.0.2-0.i686-linux-musl.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/MPFR.v4.0.2-0.i686-linux-musl.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/MPFR.v4.0.2-0.i686-linux-musl.tar.gz/sha512	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/MPFR.v4.0.2-0.i686-linux-musl.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-76b57dd91f811dc22cab9d530b62150196992af4dd0202544888fd5497cad8587c98ee2868a0af8603d436b5b90cf41879d3c1209c2ace2f86c44018efd1c5fc
diff -pruN 1.3.1+dfsg-1/deps/checksums/MPFR.v4.0.2-0.i686-w64-mingw32.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/MPFR.v4.0.2-0.i686-w64-mingw32.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/MPFR.v4.0.2-0.i686-w64-mingw32.tar.gz/md5	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/MPFR.v4.0.2-0.i686-w64-mingw32.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-bbe44a832c11166ac346abb3e1c6519a
diff -pruN 1.3.1+dfsg-1/deps/checksums/MPFR.v4.0.2-0.i686-w64-mingw32.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/MPFR.v4.0.2-0.i686-w64-mingw32.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/MPFR.v4.0.2-0.i686-w64-mingw32.tar.gz/sha512	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/MPFR.v4.0.2-0.i686-w64-mingw32.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-d373b6877e398502beb729ccf8a4add6c5307f7b7bc221621ea801f0edd4e558c2e534935354e403a5633ffb24e668c6e10b645beba6fee43fe87d550eb099f8
diff -pruN 1.3.1+dfsg-1/deps/checksums/MPFR.v4.0.2-0.powerpc64le-linux-gnu.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/MPFR.v4.0.2-0.powerpc64le-linux-gnu.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/MPFR.v4.0.2-0.powerpc64le-linux-gnu.tar.gz/md5	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/MPFR.v4.0.2-0.powerpc64le-linux-gnu.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-28739b75f4d7db50fe15712c3b6426e2
diff -pruN 1.3.1+dfsg-1/deps/checksums/MPFR.v4.0.2-0.powerpc64le-linux-gnu.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/MPFR.v4.0.2-0.powerpc64le-linux-gnu.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/MPFR.v4.0.2-0.powerpc64le-linux-gnu.tar.gz/sha512	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/MPFR.v4.0.2-0.powerpc64le-linux-gnu.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-6a8e6eee1f5103e741572571757ce76c9ad6dfa6ade899e8d3cb1de7b252c8113edd36f3ea08031f502ea52662447b49c5385d07dfd864fce466352367dd06bb
diff -pruN 1.3.1+dfsg-1/deps/checksums/MPFR.v4.0.2-0.x86_64-apple-darwin14.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/MPFR.v4.0.2-0.x86_64-apple-darwin14.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/MPFR.v4.0.2-0.x86_64-apple-darwin14.tar.gz/md5	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/MPFR.v4.0.2-0.x86_64-apple-darwin14.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-94391984c1fffc5a6bf96817dc810aa5
diff -pruN 1.3.1+dfsg-1/deps/checksums/MPFR.v4.0.2-0.x86_64-apple-darwin14.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/MPFR.v4.0.2-0.x86_64-apple-darwin14.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/MPFR.v4.0.2-0.x86_64-apple-darwin14.tar.gz/sha512	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/MPFR.v4.0.2-0.x86_64-apple-darwin14.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-ae272e7e79b92bde359a4ec1abbade2c68f5f13a56f4acc5a15908b59537c5fe2e828bc111845653bffd6c91eef4678bd6a07c60f07500f9e07b233d6c59c6e9
diff -pruN 1.3.1+dfsg-1/deps/checksums/MPFR.v4.0.2-0.x86_64-linux-gnu.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/MPFR.v4.0.2-0.x86_64-linux-gnu.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/MPFR.v4.0.2-0.x86_64-linux-gnu.tar.gz/md5	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/MPFR.v4.0.2-0.x86_64-linux-gnu.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-d95283e761522992ef10fe667bc22d71
diff -pruN 1.3.1+dfsg-1/deps/checksums/MPFR.v4.0.2-0.x86_64-linux-gnu.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/MPFR.v4.0.2-0.x86_64-linux-gnu.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/MPFR.v4.0.2-0.x86_64-linux-gnu.tar.gz/sha512	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/MPFR.v4.0.2-0.x86_64-linux-gnu.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-f8a58ef2d3475faea97dbffcf4280cc9bb8f61255bf6a0573ff0ffeddbe3b93d764922e2a0d75e20a796cd9821affcd1a4e1672448ef3d0763117db497847c26
diff -pruN 1.3.1+dfsg-1/deps/checksums/MPFR.v4.0.2-0.x86_64-linux-musl.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/MPFR.v4.0.2-0.x86_64-linux-musl.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/MPFR.v4.0.2-0.x86_64-linux-musl.tar.gz/md5	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/MPFR.v4.0.2-0.x86_64-linux-musl.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-d2b4ebe667e5b94343579b29d8339775
diff -pruN 1.3.1+dfsg-1/deps/checksums/MPFR.v4.0.2-0.x86_64-linux-musl.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/MPFR.v4.0.2-0.x86_64-linux-musl.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/MPFR.v4.0.2-0.x86_64-linux-musl.tar.gz/sha512	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/MPFR.v4.0.2-0.x86_64-linux-musl.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-466dc9336ca5edff5f689fe52573b68b1d59caa4421b3911f2a2bff4e7bd2e021f57f6c316b9549822592ac7c8a2d9c2ea21090272bc9546ba15dca973f94088
diff -pruN 1.3.1+dfsg-1/deps/checksums/MPFR.v4.0.2-0.x86_64-unknown-freebsd11.1.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/MPFR.v4.0.2-0.x86_64-unknown-freebsd11.1.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/MPFR.v4.0.2-0.x86_64-unknown-freebsd11.1.tar.gz/md5	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/MPFR.v4.0.2-0.x86_64-unknown-freebsd11.1.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-e33148a1c822b30eb12a807a50630e8b
diff -pruN 1.3.1+dfsg-1/deps/checksums/MPFR.v4.0.2-0.x86_64-unknown-freebsd11.1.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/MPFR.v4.0.2-0.x86_64-unknown-freebsd11.1.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/MPFR.v4.0.2-0.x86_64-unknown-freebsd11.1.tar.gz/sha512	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/MPFR.v4.0.2-0.x86_64-unknown-freebsd11.1.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-cd7a0138818f91f1fa92c48c3f669c187041dc44a5e5612041766ea1ea2b6d706a45d86b36efdd1074a7c0f38b416ef7dd2052c2b13dfbec07316fbd5dd5a80a
diff -pruN 1.3.1+dfsg-1/deps/checksums/MPFR.v4.0.2-0.x86_64-w64-mingw32.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/MPFR.v4.0.2-0.x86_64-w64-mingw32.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/MPFR.v4.0.2-0.x86_64-w64-mingw32.tar.gz/md5	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/MPFR.v4.0.2-0.x86_64-w64-mingw32.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-c0aa9b2115d5abbfc3e9d588d8d88c77
diff -pruN 1.3.1+dfsg-1/deps/checksums/MPFR.v4.0.2-0.x86_64-w64-mingw32.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/MPFR.v4.0.2-0.x86_64-w64-mingw32.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/MPFR.v4.0.2-0.x86_64-w64-mingw32.tar.gz/sha512	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/MPFR.v4.0.2-0.x86_64-w64-mingw32.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-fb7f4df983a29d278cee60770afba369e3a2dccac17634409a670237869d0048c998ab8a3315cde7c351dfcbaaacf0a724456d47f8920ab31e90b1b6e2c397e6
diff -pruN 1.3.1+dfsg-1/deps/checksums/MPFR.v4.0.2-2.aarch64-linux-gnu.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/MPFR.v4.0.2-2.aarch64-linux-gnu.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/MPFR.v4.0.2-2.aarch64-linux-gnu.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/MPFR.v4.0.2-2.aarch64-linux-gnu.tar.gz/md5	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+507490d14cf6c77b0d70e1064fc930f9
diff -pruN 1.3.1+dfsg-1/deps/checksums/MPFR.v4.0.2-2.aarch64-linux-gnu.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/MPFR.v4.0.2-2.aarch64-linux-gnu.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/MPFR.v4.0.2-2.aarch64-linux-gnu.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/MPFR.v4.0.2-2.aarch64-linux-gnu.tar.gz/sha512	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+03b4b43ecbefa66b8e7ae9b1f2f8ba90c835286d2a3cfe84a40f18f17a1919e4cbe90ba2a4d03c687553e5de67567ffb6d2caa35ecb04f757b6e284d740b5acb
diff -pruN 1.3.1+dfsg-1/deps/checksums/MPFR.v4.0.2-2.aarch64-linux-musl.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/MPFR.v4.0.2-2.aarch64-linux-musl.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/MPFR.v4.0.2-2.aarch64-linux-musl.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/MPFR.v4.0.2-2.aarch64-linux-musl.tar.gz/md5	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+a7c87302eae5a9f2bb10206f6b9196c1
diff -pruN 1.3.1+dfsg-1/deps/checksums/MPFR.v4.0.2-2.aarch64-linux-musl.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/MPFR.v4.0.2-2.aarch64-linux-musl.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/MPFR.v4.0.2-2.aarch64-linux-musl.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/MPFR.v4.0.2-2.aarch64-linux-musl.tar.gz/sha512	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+1993e890639d96d25db08601294f66bd91dd71d597336a43e434e9fec060aa106729c3d37b55e6305c254bef0680dd62d5aebe752e3d5e76763f51b0cdb18f5c
diff -pruN 1.3.1+dfsg-1/deps/checksums/MPFR.v4.0.2-2.arm-linux-gnueabihf.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/MPFR.v4.0.2-2.arm-linux-gnueabihf.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/MPFR.v4.0.2-2.arm-linux-gnueabihf.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/MPFR.v4.0.2-2.arm-linux-gnueabihf.tar.gz/md5	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+8192403639a9f7f1cb590783d3a19c10
diff -pruN 1.3.1+dfsg-1/deps/checksums/MPFR.v4.0.2-2.arm-linux-gnueabihf.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/MPFR.v4.0.2-2.arm-linux-gnueabihf.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/MPFR.v4.0.2-2.arm-linux-gnueabihf.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/MPFR.v4.0.2-2.arm-linux-gnueabihf.tar.gz/sha512	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+e2d39b4c84187e19a0a013da4bbdf6637b82cbb5bf9c1c8d0dd9e346c677bc58ddda6692441c33c80415206c21756751d2adfab54b089bd9220417e0e1428e97
diff -pruN 1.3.1+dfsg-1/deps/checksums/MPFR.v4.0.2-2.arm-linux-musleabihf.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/MPFR.v4.0.2-2.arm-linux-musleabihf.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/MPFR.v4.0.2-2.arm-linux-musleabihf.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/MPFR.v4.0.2-2.arm-linux-musleabihf.tar.gz/md5	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+ca0022a3753e4a344a76b41bfa073c13
diff -pruN 1.3.1+dfsg-1/deps/checksums/MPFR.v4.0.2-2.arm-linux-musleabihf.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/MPFR.v4.0.2-2.arm-linux-musleabihf.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/MPFR.v4.0.2-2.arm-linux-musleabihf.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/MPFR.v4.0.2-2.arm-linux-musleabihf.tar.gz/sha512	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+be390b6cfccdaf62b93f06703af97375db7dcf35b675a159fa212f1a6c59b06bbbcd3df1a8602527bd89fb3bbd42d2ae8d462f7fd051d4d0c030cb9b4ed3fff9
diff -pruN 1.3.1+dfsg-1/deps/checksums/MPFR.v4.0.2-2.i686-linux-gnu.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/MPFR.v4.0.2-2.i686-linux-gnu.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/MPFR.v4.0.2-2.i686-linux-gnu.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/MPFR.v4.0.2-2.i686-linux-gnu.tar.gz/md5	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+fba74415b78fd21fb3377589d1323b1d
diff -pruN 1.3.1+dfsg-1/deps/checksums/MPFR.v4.0.2-2.i686-linux-gnu.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/MPFR.v4.0.2-2.i686-linux-gnu.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/MPFR.v4.0.2-2.i686-linux-gnu.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/MPFR.v4.0.2-2.i686-linux-gnu.tar.gz/sha512	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+ee0cd3bc38cbce5198693d10dca4b8a02cfb9c1c444d2ffe985d5d0dbcf20f21ce23540c1c75d337ca3989277dfda895bcf41c635050ca92556af8dc8591b22d
diff -pruN 1.3.1+dfsg-1/deps/checksums/MPFR.v4.0.2-2.i686-linux-musl.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/MPFR.v4.0.2-2.i686-linux-musl.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/MPFR.v4.0.2-2.i686-linux-musl.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/MPFR.v4.0.2-2.i686-linux-musl.tar.gz/md5	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+9de4bb265570a319166182926b7d7a02
diff -pruN 1.3.1+dfsg-1/deps/checksums/MPFR.v4.0.2-2.i686-linux-musl.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/MPFR.v4.0.2-2.i686-linux-musl.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/MPFR.v4.0.2-2.i686-linux-musl.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/MPFR.v4.0.2-2.i686-linux-musl.tar.gz/sha512	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+c74d736c679e277a9ebb319298a16eb68f372c7fba01f91de996b8e227ccfdf0bd6dd51f41577de7ee9129f20062ff0ea586a193916583c54ccdad8336861732
diff -pruN 1.3.1+dfsg-1/deps/checksums/MPFR.v4.0.2-2.i686-w64-mingw32.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/MPFR.v4.0.2-2.i686-w64-mingw32.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/MPFR.v4.0.2-2.i686-w64-mingw32.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/MPFR.v4.0.2-2.i686-w64-mingw32.tar.gz/md5	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+e35556e0236d46ff5a166156a83628f3
diff -pruN 1.3.1+dfsg-1/deps/checksums/MPFR.v4.0.2-2.i686-w64-mingw32.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/MPFR.v4.0.2-2.i686-w64-mingw32.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/MPFR.v4.0.2-2.i686-w64-mingw32.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/MPFR.v4.0.2-2.i686-w64-mingw32.tar.gz/sha512	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+6cc6e82af3af71639ba6373fe8028d1ff532f56df0ec71cecf857e727bf61b55b70e2d1b0b8be27648bcb43eb44eb575fce45a36e188de688c06824394a6aa93
diff -pruN 1.3.1+dfsg-1/deps/checksums/MPFR.v4.0.2-2.powerpc64le-linux-gnu.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/MPFR.v4.0.2-2.powerpc64le-linux-gnu.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/MPFR.v4.0.2-2.powerpc64le-linux-gnu.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/MPFR.v4.0.2-2.powerpc64le-linux-gnu.tar.gz/md5	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+cd05dd0535d53a6dca7f4da057093490
diff -pruN 1.3.1+dfsg-1/deps/checksums/MPFR.v4.0.2-2.powerpc64le-linux-gnu.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/MPFR.v4.0.2-2.powerpc64le-linux-gnu.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/MPFR.v4.0.2-2.powerpc64le-linux-gnu.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/MPFR.v4.0.2-2.powerpc64le-linux-gnu.tar.gz/sha512	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+c876d7c6e69832b16f056cf6ab7a39a12c51e98f75b0bac7aecfd050d1c5b7eb74dad35294364a8805f4ec2d16caba6eda9e4fee80ca7b00ad839fe9d0bce883
diff -pruN 1.3.1+dfsg-1/deps/checksums/MPFR.v4.0.2-2.x86_64-apple-darwin14.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/MPFR.v4.0.2-2.x86_64-apple-darwin14.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/MPFR.v4.0.2-2.x86_64-apple-darwin14.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/MPFR.v4.0.2-2.x86_64-apple-darwin14.tar.gz/md5	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+af1f4de432d8af2f5df5ef648469369d
diff -pruN 1.3.1+dfsg-1/deps/checksums/MPFR.v4.0.2-2.x86_64-apple-darwin14.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/MPFR.v4.0.2-2.x86_64-apple-darwin14.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/MPFR.v4.0.2-2.x86_64-apple-darwin14.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/MPFR.v4.0.2-2.x86_64-apple-darwin14.tar.gz/sha512	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+d65145fbfe369f6b8226911abcaadaae773b71fae9d889ccb13387bb20f0c0d53ec4841337d2300ab61a65faf71376beb20f9754d96998fa87346d5854737bdf
diff -pruN 1.3.1+dfsg-1/deps/checksums/MPFR.v4.0.2-2.x86_64-linux-gnu.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/MPFR.v4.0.2-2.x86_64-linux-gnu.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/MPFR.v4.0.2-2.x86_64-linux-gnu.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/MPFR.v4.0.2-2.x86_64-linux-gnu.tar.gz/md5	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+a70dde369fbaa76d048ab13a1266aef2
diff -pruN 1.3.1+dfsg-1/deps/checksums/MPFR.v4.0.2-2.x86_64-linux-gnu.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/MPFR.v4.0.2-2.x86_64-linux-gnu.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/MPFR.v4.0.2-2.x86_64-linux-gnu.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/MPFR.v4.0.2-2.x86_64-linux-gnu.tar.gz/sha512	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+9fea8872ff25aca2a9925981a8fe4f4618423644262e893aa8821b80c14b449e407770b4296ecc8334557f369cb119c56ff3c9870d8399b31ec68935a6c7abfe
diff -pruN 1.3.1+dfsg-1/deps/checksums/MPFR.v4.0.2-2.x86_64-linux-musl.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/MPFR.v4.0.2-2.x86_64-linux-musl.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/MPFR.v4.0.2-2.x86_64-linux-musl.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/MPFR.v4.0.2-2.x86_64-linux-musl.tar.gz/md5	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+8eccd81b2800ebedc0dfb97a114318da
diff -pruN 1.3.1+dfsg-1/deps/checksums/MPFR.v4.0.2-2.x86_64-linux-musl.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/MPFR.v4.0.2-2.x86_64-linux-musl.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/MPFR.v4.0.2-2.x86_64-linux-musl.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/MPFR.v4.0.2-2.x86_64-linux-musl.tar.gz/sha512	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+87a7a8f8b816c044b0312547b9ca2e16494107b4daa0b280bee315c9bad47dc4c341ac961a6e2eb9abdcdc702fd6a545675409489c006ba783fb7e4ac9777979
diff -pruN 1.3.1+dfsg-1/deps/checksums/MPFR.v4.0.2-2.x86_64-unknown-freebsd11.1.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/MPFR.v4.0.2-2.x86_64-unknown-freebsd11.1.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/MPFR.v4.0.2-2.x86_64-unknown-freebsd11.1.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/MPFR.v4.0.2-2.x86_64-unknown-freebsd11.1.tar.gz/md5	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+86c07156b4462b9ca59a835d7d360b21
diff -pruN 1.3.1+dfsg-1/deps/checksums/MPFR.v4.0.2-2.x86_64-unknown-freebsd11.1.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/MPFR.v4.0.2-2.x86_64-unknown-freebsd11.1.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/MPFR.v4.0.2-2.x86_64-unknown-freebsd11.1.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/MPFR.v4.0.2-2.x86_64-unknown-freebsd11.1.tar.gz/sha512	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+0ab98879ac3e3cf367176b2eacad68cb42d7f860529d5c5e9cc69e772b44d5f1e169d3e839e8a09d9dbf9b9facdb1c92e9b47998dbd0eb0749735f80b26556bc
diff -pruN 1.3.1+dfsg-1/deps/checksums/MPFR.v4.0.2-2.x86_64-w64-mingw32.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/MPFR.v4.0.2-2.x86_64-w64-mingw32.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/MPFR.v4.0.2-2.x86_64-w64-mingw32.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/MPFR.v4.0.2-2.x86_64-w64-mingw32.tar.gz/md5	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+44d465d21cb73242b1e75a7efa73393c
diff -pruN 1.3.1+dfsg-1/deps/checksums/MPFR.v4.0.2-2.x86_64-w64-mingw32.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/MPFR.v4.0.2-2.x86_64-w64-mingw32.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/MPFR.v4.0.2-2.x86_64-w64-mingw32.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/MPFR.v4.0.2-2.x86_64-w64-mingw32.tar.gz/sha512	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+a894afdff49c786835ef75ed9b89543200d50f34ce8c8e37bf9c3f07928a6170157e018075cff6600d97e79bfa956908b43fd607d47bb6036b23dc42f7e8877f
diff -pruN 1.3.1+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-1.aarch64-linux-gnu-gcc4.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-1.aarch64-linux-gnu-gcc4.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-1.aarch64-linux-gnu-gcc4.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-1.aarch64-linux-gnu-gcc4.tar.gz/md5	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+4b54f9f78817e6c73929398e21e61ffb
diff -pruN 1.3.1+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-1.aarch64-linux-gnu-gcc4.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-1.aarch64-linux-gnu-gcc4.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-1.aarch64-linux-gnu-gcc4.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-1.aarch64-linux-gnu-gcc4.tar.gz/sha512	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+0ba7785354e7527b8c5e16b04e4a004e924b57d038c40d5b39ea03bcb110e623bd568ba658e9e0c0e756483f57776a2f20df1522cbfb8e8a7edd20614044354a
diff -pruN 1.3.1+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-1.aarch64-linux-gnu-gcc7.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-1.aarch64-linux-gnu-gcc7.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-1.aarch64-linux-gnu-gcc7.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-1.aarch64-linux-gnu-gcc7.tar.gz/md5	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+facb889c36411371eeb5f3a0a572ea29
diff -pruN 1.3.1+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-1.aarch64-linux-gnu-gcc7.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-1.aarch64-linux-gnu-gcc7.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-1.aarch64-linux-gnu-gcc7.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-1.aarch64-linux-gnu-gcc7.tar.gz/sha512	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+428077bfe05c8f12a8dd7f1372a905b9fa7d3da13d391df47a4c23efe4420a98cfab16bfd4daa62977a9d7fc95ee56d32761f5eb7f10eff785df59cb3339bc18
diff -pruN 1.3.1+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-1.aarch64-linux-gnu-gcc8.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-1.aarch64-linux-gnu-gcc8.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-1.aarch64-linux-gnu-gcc8.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-1.aarch64-linux-gnu-gcc8.tar.gz/md5	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+427398ebb09c8400983c467d4182ab89
diff -pruN 1.3.1+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-1.aarch64-linux-gnu-gcc8.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-1.aarch64-linux-gnu-gcc8.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-1.aarch64-linux-gnu-gcc8.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-1.aarch64-linux-gnu-gcc8.tar.gz/sha512	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+8c549842b70015a3c7fbe98a92cabf75191ff36ebf0fa89532a53622bbbc7cac23c549a05cd4a0791102cc33e8bd5acd073416c43939dd104898f4574a2a7869
diff -pruN 1.3.1+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-1.aarch64-linux-musl-gcc4.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-1.aarch64-linux-musl-gcc4.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-1.aarch64-linux-musl-gcc4.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-1.aarch64-linux-musl-gcc4.tar.gz/md5	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+2bc510613d6ee06094582b8d423d72bd
diff -pruN 1.3.1+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-1.aarch64-linux-musl-gcc4.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-1.aarch64-linux-musl-gcc4.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-1.aarch64-linux-musl-gcc4.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-1.aarch64-linux-musl-gcc4.tar.gz/sha512	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+d353955cffc52c82dfa4fd8fa3c2c3b62dc28bc49fbe096a6b96686f35fc45541c0912337a3d6fbd601aca56e6a1eaf65f8f8ee340a2a853ecd976feab13f522
diff -pruN 1.3.1+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-1.aarch64-linux-musl-gcc7.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-1.aarch64-linux-musl-gcc7.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-1.aarch64-linux-musl-gcc7.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-1.aarch64-linux-musl-gcc7.tar.gz/md5	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+49a4230c8c599500d6a6a7ec3d76b328
diff -pruN 1.3.1+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-1.aarch64-linux-musl-gcc7.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-1.aarch64-linux-musl-gcc7.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-1.aarch64-linux-musl-gcc7.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-1.aarch64-linux-musl-gcc7.tar.gz/sha512	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+eb7de3ecac20f5021d1d98589126bca5e6c9469e330077c6f695af6f597626b0e240a27f2572ba304c8d4e1ed186e9638b4bd54fda7ce5c07236d08e06fd2c16
diff -pruN 1.3.1+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-1.aarch64-linux-musl-gcc8.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-1.aarch64-linux-musl-gcc8.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-1.aarch64-linux-musl-gcc8.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-1.aarch64-linux-musl-gcc8.tar.gz/md5	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+06362a9c09a08d724c41d68dec67de6d
diff -pruN 1.3.1+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-1.aarch64-linux-musl-gcc8.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-1.aarch64-linux-musl-gcc8.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-1.aarch64-linux-musl-gcc8.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-1.aarch64-linux-musl-gcc8.tar.gz/sha512	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+493a8a16bf6a369408ddd904c68ee25c5b6a9b18955a5dd661587bce001a8e37cd4cb30af77c0ed024ae4168b0d9bf5c341ba0837983e8565ddfe45c7f03273b
diff -pruN 1.3.1+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-1.arm-linux-gnueabihf-gcc4.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-1.arm-linux-gnueabihf-gcc4.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-1.arm-linux-gnueabihf-gcc4.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-1.arm-linux-gnueabihf-gcc4.tar.gz/md5	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+b7072566dd86e1b432726c5a832e5164
diff -pruN 1.3.1+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-1.arm-linux-gnueabihf-gcc4.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-1.arm-linux-gnueabihf-gcc4.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-1.arm-linux-gnueabihf-gcc4.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-1.arm-linux-gnueabihf-gcc4.tar.gz/sha512	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+5602a8dd47d24bbdd6c2303d8fd8836f0ddf6ec9371888ac57eff7f1cb65a8c33da7fec9b794108bb6c140e2f69a1508a2a2ee48951c897b9bdf79c6071b2100
diff -pruN 1.3.1+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-1.arm-linux-gnueabihf-gcc7.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-1.arm-linux-gnueabihf-gcc7.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-1.arm-linux-gnueabihf-gcc7.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-1.arm-linux-gnueabihf-gcc7.tar.gz/md5	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+29e0423db67d2886cc35022bb0b0a67e
diff -pruN 1.3.1+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-1.arm-linux-gnueabihf-gcc7.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-1.arm-linux-gnueabihf-gcc7.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-1.arm-linux-gnueabihf-gcc7.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-1.arm-linux-gnueabihf-gcc7.tar.gz/sha512	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+48f17505a6dd8efdd79fcebee263004c30da350c00649bba5286d1df1acf369fdb050ad3d47fff5336252691d891949ee916896504f327ab53f7a1bbbc0a6b13
diff -pruN 1.3.1+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-1.arm-linux-gnueabihf-gcc8.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-1.arm-linux-gnueabihf-gcc8.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-1.arm-linux-gnueabihf-gcc8.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-1.arm-linux-gnueabihf-gcc8.tar.gz/md5	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+cec0a1c2ce1128102b0cbf8c3e4ca3d9
diff -pruN 1.3.1+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-1.arm-linux-gnueabihf-gcc8.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-1.arm-linux-gnueabihf-gcc8.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-1.arm-linux-gnueabihf-gcc8.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-1.arm-linux-gnueabihf-gcc8.tar.gz/sha512	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+42ee1534dab01b56827c8344e2bccc14b5e2b6e0ac1cca40edd3ca22e1917559448482f2c41e9a32b90fdf6dc6ec5c56f5bde11360bad45cdfe65dc6416b007c
diff -pruN 1.3.1+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-1.arm-linux-musleabihf-gcc4.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-1.arm-linux-musleabihf-gcc4.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-1.arm-linux-musleabihf-gcc4.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-1.arm-linux-musleabihf-gcc4.tar.gz/md5	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+960d183ee1167e0d9e6cc31ac60631e8
diff -pruN 1.3.1+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-1.arm-linux-musleabihf-gcc4.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-1.arm-linux-musleabihf-gcc4.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-1.arm-linux-musleabihf-gcc4.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-1.arm-linux-musleabihf-gcc4.tar.gz/sha512	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+15fed065cb9c15d0c1762c36658b36913566873b5646f5079154e31e531623f0f5ac0902ed69261909501b123471d224251e9ae0206b3a97927376e9f7b344c4
diff -pruN 1.3.1+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-1.arm-linux-musleabihf-gcc7.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-1.arm-linux-musleabihf-gcc7.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-1.arm-linux-musleabihf-gcc7.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-1.arm-linux-musleabihf-gcc7.tar.gz/md5	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+4a9fae8c02809e702bec6b4928cd4b8a
diff -pruN 1.3.1+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-1.arm-linux-musleabihf-gcc7.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-1.arm-linux-musleabihf-gcc7.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-1.arm-linux-musleabihf-gcc7.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-1.arm-linux-musleabihf-gcc7.tar.gz/sha512	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+0ee62ea2facfe3ddf617916193c9eeaa58a18d4b2a5fb93f4ae8173b67a0b021c6494f241395c2adbef4c61ec050747fd19c627be596ae338f22074076f9bcb6
diff -pruN 1.3.1+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-1.arm-linux-musleabihf-gcc8.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-1.arm-linux-musleabihf-gcc8.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-1.arm-linux-musleabihf-gcc8.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-1.arm-linux-musleabihf-gcc8.tar.gz/md5	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+7cb36a0d4de4dde8b0b3fda27dabaf51
diff -pruN 1.3.1+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-1.arm-linux-musleabihf-gcc8.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-1.arm-linux-musleabihf-gcc8.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-1.arm-linux-musleabihf-gcc8.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-1.arm-linux-musleabihf-gcc8.tar.gz/sha512	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+535a50389776066415ccbb3dbf3798123d6311be674d1ec90ef6d96d146890bb29684d0710c2cf05b5e5f941cc293653c96b510f8136e49d265f58da4f28b1c8
diff -pruN 1.3.1+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-1.i686-linux-gnu-gcc4.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-1.i686-linux-gnu-gcc4.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-1.i686-linux-gnu-gcc4.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-1.i686-linux-gnu-gcc4.tar.gz/md5	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+d6a8d32f64d2e3ed388f305f7d54665b
diff -pruN 1.3.1+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-1.i686-linux-gnu-gcc4.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-1.i686-linux-gnu-gcc4.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-1.i686-linux-gnu-gcc4.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-1.i686-linux-gnu-gcc4.tar.gz/sha512	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+1b67ffdfbaf2b9afe47fb85e8aeb71f3ad05472c49bb8f5de60416cfa0544b6c697ea570e803e7768b1a6dbc617dd14484de231bad2b4a38ca6aaae2ea1af6d0
diff -pruN 1.3.1+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-1.i686-linux-gnu-gcc7.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-1.i686-linux-gnu-gcc7.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-1.i686-linux-gnu-gcc7.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-1.i686-linux-gnu-gcc7.tar.gz/md5	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+76dfc6c75fe481a9545303a1145dc203
diff -pruN 1.3.1+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-1.i686-linux-gnu-gcc7.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-1.i686-linux-gnu-gcc7.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-1.i686-linux-gnu-gcc7.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-1.i686-linux-gnu-gcc7.tar.gz/sha512	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+00f6deb7ac6dcdf505299ebbdb2c988f56a06c2055908e9a28975b3a1844891282bf7657baf048f83015935f10b433eccad51def4e5b8340718a5f06be150970
diff -pruN 1.3.1+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-1.i686-linux-gnu-gcc8.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-1.i686-linux-gnu-gcc8.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-1.i686-linux-gnu-gcc8.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-1.i686-linux-gnu-gcc8.tar.gz/md5	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+cf77a12eb81573147e366d3c7388ec3f
diff -pruN 1.3.1+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-1.i686-linux-gnu-gcc8.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-1.i686-linux-gnu-gcc8.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-1.i686-linux-gnu-gcc8.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-1.i686-linux-gnu-gcc8.tar.gz/sha512	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+27e9aadae513edd93f3de15230de5f4259a0d798c50b9c1166dc78b53b620622a52fc8415ffed7bfde4b616f8ac383a138ef8db7035eba57e7b286d6448ec636
diff -pruN 1.3.1+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-1.i686-linux-musl-gcc4.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-1.i686-linux-musl-gcc4.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-1.i686-linux-musl-gcc4.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-1.i686-linux-musl-gcc4.tar.gz/md5	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+82a6940c6df54d193bd801857fa20ef4
diff -pruN 1.3.1+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-1.i686-linux-musl-gcc4.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-1.i686-linux-musl-gcc4.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-1.i686-linux-musl-gcc4.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-1.i686-linux-musl-gcc4.tar.gz/sha512	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+3b08899507e1a473e53c3b0d6264c8cbc939b30c6aa8b00674f16c31c657b0c4cab008580fa5ca439d8a3819a471495a0d3f38d68af9b66a89c2780be7cdd155
diff -pruN 1.3.1+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-1.i686-linux-musl-gcc7.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-1.i686-linux-musl-gcc7.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-1.i686-linux-musl-gcc7.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-1.i686-linux-musl-gcc7.tar.gz/md5	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+5c50251f4b9ce27c4756557bda16e24b
diff -pruN 1.3.1+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-1.i686-linux-musl-gcc7.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-1.i686-linux-musl-gcc7.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-1.i686-linux-musl-gcc7.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-1.i686-linux-musl-gcc7.tar.gz/sha512	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+307e6fd7e596b75d25aa3c19b0e6901347c7e6c20afc366c2da9f838c132bf21f86d0c6735cb0e431aec1638bfaa0ceab2915236bca4c5cc507011f16df0b54e
diff -pruN 1.3.1+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-1.i686-linux-musl-gcc8.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-1.i686-linux-musl-gcc8.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-1.i686-linux-musl-gcc8.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-1.i686-linux-musl-gcc8.tar.gz/md5	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+5414363d8e5b6a7348ead693eac3dd09
diff -pruN 1.3.1+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-1.i686-linux-musl-gcc8.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-1.i686-linux-musl-gcc8.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-1.i686-linux-musl-gcc8.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-1.i686-linux-musl-gcc8.tar.gz/sha512	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+fb1681ceb11beeb041afc88699047a509ca35f070af072f11a0a1730796dc9d7b71eb5d60c7c9360b20cf693ac773207ddb544ffda25eec2fa2a5aa4fd40f653
diff -pruN 1.3.1+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-1.i686-w64-mingw32-gcc4.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-1.i686-w64-mingw32-gcc4.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-1.i686-w64-mingw32-gcc4.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-1.i686-w64-mingw32-gcc4.tar.gz/md5	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+500da909e94415818b984bdaef4c36c5
diff -pruN 1.3.1+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-1.i686-w64-mingw32-gcc4.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-1.i686-w64-mingw32-gcc4.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-1.i686-w64-mingw32-gcc4.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-1.i686-w64-mingw32-gcc4.tar.gz/sha512	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+cebbc454b62343e89d9dbf7a4ac61a5f56d9f09bdaf7f82923cac334f885368bb08042b8ffc4719cdeecca44f7d5c0152b9544215d56639fc833a4398f3ba006
diff -pruN 1.3.1+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-1.i686-w64-mingw32-gcc7.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-1.i686-w64-mingw32-gcc7.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-1.i686-w64-mingw32-gcc7.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-1.i686-w64-mingw32-gcc7.tar.gz/md5	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+a96e3f7c5f1e843cdff68a6e51215e11
diff -pruN 1.3.1+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-1.i686-w64-mingw32-gcc7.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-1.i686-w64-mingw32-gcc7.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-1.i686-w64-mingw32-gcc7.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-1.i686-w64-mingw32-gcc7.tar.gz/sha512	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+37eedd4ce58fa6a9064864860345c3e7ee9102d12c3c8a7c61e6d996b33c0da77efd1193e6d7cf8d535da1212143d92a73fcb352c5da5a8c71533dd8d1f582ff
diff -pruN 1.3.1+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-1.i686-w64-mingw32-gcc8.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-1.i686-w64-mingw32-gcc8.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-1.i686-w64-mingw32-gcc8.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-1.i686-w64-mingw32-gcc8.tar.gz/md5	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+b6370238bf188c08d486f01819f65097
diff -pruN 1.3.1+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-1.i686-w64-mingw32-gcc8.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-1.i686-w64-mingw32-gcc8.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-1.i686-w64-mingw32-gcc8.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-1.i686-w64-mingw32-gcc8.tar.gz/sha512	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+d78d99fca9f2479203539d03ec10b00cca37cc7b9678a90ab2f909fff22e49a149c959ec6615c588e56ab3bb415479643fa39d105f8685298b06a037bfb982cf
diff -pruN 1.3.1+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-1.powerpc64le-linux-gnu-gcc4.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-1.powerpc64le-linux-gnu-gcc4.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-1.powerpc64le-linux-gnu-gcc4.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-1.powerpc64le-linux-gnu-gcc4.tar.gz/md5	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+1bfba2b3094584bad91af3ff7a6d6590
diff -pruN 1.3.1+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-1.powerpc64le-linux-gnu-gcc4.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-1.powerpc64le-linux-gnu-gcc4.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-1.powerpc64le-linux-gnu-gcc4.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-1.powerpc64le-linux-gnu-gcc4.tar.gz/sha512	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+efc7066927dcde4290946ab25483a68a3dba2f2b0260de0874387421f4b5e6636c309e39f7fb26d9b2c8eb1d24dd3b01d13b547d01b56e2477e15e40be3fe2aa
diff -pruN 1.3.1+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-1.powerpc64le-linux-gnu-gcc7.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-1.powerpc64le-linux-gnu-gcc7.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-1.powerpc64le-linux-gnu-gcc7.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-1.powerpc64le-linux-gnu-gcc7.tar.gz/md5	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+a2c7e2214432defab74eb1a172f1e544
diff -pruN 1.3.1+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-1.powerpc64le-linux-gnu-gcc7.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-1.powerpc64le-linux-gnu-gcc7.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-1.powerpc64le-linux-gnu-gcc7.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-1.powerpc64le-linux-gnu-gcc7.tar.gz/sha512	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+a433b0a38c9890a562724beb4c68ff1e1e91c18c8bd44cc64a47084fd89f4280d734cdb13d538236fbc051e471ee8004ca0c222c2849890ad25dbe2ead83d621
diff -pruN 1.3.1+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-1.powerpc64le-linux-gnu-gcc8.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-1.powerpc64le-linux-gnu-gcc8.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-1.powerpc64le-linux-gnu-gcc8.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-1.powerpc64le-linux-gnu-gcc8.tar.gz/md5	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+cc7170026c7447dbf7cc8435d912f730
diff -pruN 1.3.1+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-1.powerpc64le-linux-gnu-gcc8.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-1.powerpc64le-linux-gnu-gcc8.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-1.powerpc64le-linux-gnu-gcc8.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-1.powerpc64le-linux-gnu-gcc8.tar.gz/sha512	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+3940c7786b8aebd45dc55fe61a00b2702c5da4468ff608ae92c763b199fc318042c849d268b965dbbe52aef12e4defb71fb978beb875e9aeb4b62679fbd4bdc3
diff -pruN 1.3.1+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-1.x86_64-apple-darwin14-gcc4.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-1.x86_64-apple-darwin14-gcc4.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-1.x86_64-apple-darwin14-gcc4.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-1.x86_64-apple-darwin14-gcc4.tar.gz/md5	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+f8a5b84b34fb4f7f3b3e5dbd8fd47eb8
diff -pruN 1.3.1+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-1.x86_64-apple-darwin14-gcc4.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-1.x86_64-apple-darwin14-gcc4.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-1.x86_64-apple-darwin14-gcc4.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-1.x86_64-apple-darwin14-gcc4.tar.gz/sha512	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+0789f4072861d91574019ac41000f092d71e354279dc6ca8866599c79035a068d5b7597a33d6c907047231e77872a127c5aa5075da9bd276585d2d183308fbbf
diff -pruN 1.3.1+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-1.x86_64-apple-darwin14-gcc7.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-1.x86_64-apple-darwin14-gcc7.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-1.x86_64-apple-darwin14-gcc7.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-1.x86_64-apple-darwin14-gcc7.tar.gz/md5	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+5a426bcf510648aa7610551fa987765d
diff -pruN 1.3.1+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-1.x86_64-apple-darwin14-gcc7.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-1.x86_64-apple-darwin14-gcc7.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-1.x86_64-apple-darwin14-gcc7.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-1.x86_64-apple-darwin14-gcc7.tar.gz/sha512	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+1842acbcb51808d70f77ae4bff9b44feef37488452775bc3c9b748df8acbf40cef555072c004c17165b24682de9f5381fc818f65722a54ad90be1d5556326b48
diff -pruN 1.3.1+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-1.x86_64-apple-darwin14-gcc8.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-1.x86_64-apple-darwin14-gcc8.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-1.x86_64-apple-darwin14-gcc8.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-1.x86_64-apple-darwin14-gcc8.tar.gz/md5	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+e3c6fc9fa847b1c55091c037ecbbb017
diff -pruN 1.3.1+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-1.x86_64-apple-darwin14-gcc8.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-1.x86_64-apple-darwin14-gcc8.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-1.x86_64-apple-darwin14-gcc8.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-1.x86_64-apple-darwin14-gcc8.tar.gz/sha512	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+4cef0b9728f28cab4666c0a094b6e50f57d5c2e99acd35eec8f1b3500317f52141cae0961c129b05fc0c97290d6c6e82da588542f2275e2501c21f46c539073d
diff -pruN 1.3.1+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-1.x86_64-linux-gnu-gcc4.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-1.x86_64-linux-gnu-gcc4.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-1.x86_64-linux-gnu-gcc4.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-1.x86_64-linux-gnu-gcc4.tar.gz/md5	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+412be2937b18d57ae3ab4e45ea8abe7b
diff -pruN 1.3.1+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-1.x86_64-linux-gnu-gcc4.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-1.x86_64-linux-gnu-gcc4.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-1.x86_64-linux-gnu-gcc4.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-1.x86_64-linux-gnu-gcc4.tar.gz/sha512	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+381fd4b554682755e7e76aa0853408c2bbe6bec8ec752483f771fcee7e974cc9da08ad04b67be2858ca162259a4aae83471d8f1caceb493a6fdf57eaf48f74e2
diff -pruN 1.3.1+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-1.x86_64-linux-gnu-gcc7.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-1.x86_64-linux-gnu-gcc7.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-1.x86_64-linux-gnu-gcc7.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-1.x86_64-linux-gnu-gcc7.tar.gz/md5	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+39c39519a806c4ba5da9c31692f503bc
diff -pruN 1.3.1+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-1.x86_64-linux-gnu-gcc7.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-1.x86_64-linux-gnu-gcc7.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-1.x86_64-linux-gnu-gcc7.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-1.x86_64-linux-gnu-gcc7.tar.gz/sha512	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+67ab7a4457a16d32de08c92b95c0b544dd34af7c74a9d64207706c668008c225d684deb989c80f459f038aecb02e47e3463b377c5a6439aa4131a32690048917
diff -pruN 1.3.1+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-1.x86_64-linux-gnu-gcc8.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-1.x86_64-linux-gnu-gcc8.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-1.x86_64-linux-gnu-gcc8.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-1.x86_64-linux-gnu-gcc8.tar.gz/md5	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+0142970d754e2006ef86a94c51ff2875
diff -pruN 1.3.1+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-1.x86_64-linux-gnu-gcc8.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-1.x86_64-linux-gnu-gcc8.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-1.x86_64-linux-gnu-gcc8.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-1.x86_64-linux-gnu-gcc8.tar.gz/sha512	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+e56cb6f67e43eec60207d700f4a4b9a0b84f5b988792ab4ca2c2559045ff2966e4ece95da2abe545fe2f9317ddc57afc4be41866dc319435fc7add74b6e3e3d7
diff -pruN 1.3.1+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-1.x86_64-linux-musl-gcc4.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-1.x86_64-linux-musl-gcc4.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-1.x86_64-linux-musl-gcc4.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-1.x86_64-linux-musl-gcc4.tar.gz/md5	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+824ce91e7e4c63304a741e9813d72d3d
diff -pruN 1.3.1+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-1.x86_64-linux-musl-gcc4.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-1.x86_64-linux-musl-gcc4.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-1.x86_64-linux-musl-gcc4.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-1.x86_64-linux-musl-gcc4.tar.gz/sha512	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+3a7b88c18a457c25d71f59c037b9c483d81ba408cd2d8e01acb79e56faf197062dd92343f8dc1439ad726d26b7de60dd86b336af5ef1cec1f5d469212d2bf557
diff -pruN 1.3.1+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-1.x86_64-linux-musl-gcc7.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-1.x86_64-linux-musl-gcc7.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-1.x86_64-linux-musl-gcc7.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-1.x86_64-linux-musl-gcc7.tar.gz/md5	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+b2024e2cf83e8a15272d373639dae4a3
diff -pruN 1.3.1+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-1.x86_64-linux-musl-gcc7.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-1.x86_64-linux-musl-gcc7.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-1.x86_64-linux-musl-gcc7.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-1.x86_64-linux-musl-gcc7.tar.gz/sha512	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+5e982c38501ffdf2424189e7d9510ad4397b6bd72b1b39b80eae048b6fe7435540973138a3d15258c4cfbe4b8d2cac507e5aacd2a9c579753e540b8b466a81dc
diff -pruN 1.3.1+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-1.x86_64-linux-musl-gcc8.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-1.x86_64-linux-musl-gcc8.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-1.x86_64-linux-musl-gcc8.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-1.x86_64-linux-musl-gcc8.tar.gz/md5	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+b8233eba5d2e69d84a53c0dfbe96c797
diff -pruN 1.3.1+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-1.x86_64-linux-musl-gcc8.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-1.x86_64-linux-musl-gcc8.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-1.x86_64-linux-musl-gcc8.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-1.x86_64-linux-musl-gcc8.tar.gz/sha512	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+419e943b1242208f172b668534473ff8760c9de8e7b5478486c2299bd8396488ac7c574965740b7523c5703168f4c968986eef331bb070b0ee3af55a764da643
diff -pruN 1.3.1+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-1.x86_64-unknown-freebsd11.1-gcc4.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-1.x86_64-unknown-freebsd11.1-gcc4.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-1.x86_64-unknown-freebsd11.1-gcc4.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-1.x86_64-unknown-freebsd11.1-gcc4.tar.gz/md5	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+119786c4238669e70cbb202f57e18097
diff -pruN 1.3.1+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-1.x86_64-unknown-freebsd11.1-gcc4.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-1.x86_64-unknown-freebsd11.1-gcc4.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-1.x86_64-unknown-freebsd11.1-gcc4.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-1.x86_64-unknown-freebsd11.1-gcc4.tar.gz/sha512	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+18b3a57d4dd71938483d6e1720192e1d1235eefcbe502f49eba0f7d4898c08876fc92f6aec9330ed1e2c8a918568a9149dea88e761ef1effc90916b23b8ef2a4
diff -pruN 1.3.1+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-1.x86_64-unknown-freebsd11.1-gcc7.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-1.x86_64-unknown-freebsd11.1-gcc7.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-1.x86_64-unknown-freebsd11.1-gcc7.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-1.x86_64-unknown-freebsd11.1-gcc7.tar.gz/md5	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+6b9f214df55cba9ffc49c3a32b340a66
diff -pruN 1.3.1+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-1.x86_64-unknown-freebsd11.1-gcc7.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-1.x86_64-unknown-freebsd11.1-gcc7.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-1.x86_64-unknown-freebsd11.1-gcc7.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-1.x86_64-unknown-freebsd11.1-gcc7.tar.gz/sha512	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+e486f11c6b1c8941d4613422a2a764ba655882320ee0373b04adceb080e93bb6ed46c20890b1ed86378f5c51e183f92b7c5fd63c228ec9c74764b830113c1427
diff -pruN 1.3.1+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-1.x86_64-unknown-freebsd11.1-gcc8.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-1.x86_64-unknown-freebsd11.1-gcc8.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-1.x86_64-unknown-freebsd11.1-gcc8.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-1.x86_64-unknown-freebsd11.1-gcc8.tar.gz/md5	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+088622a020360fc4c24c26e096a74cad
diff -pruN 1.3.1+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-1.x86_64-unknown-freebsd11.1-gcc8.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-1.x86_64-unknown-freebsd11.1-gcc8.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-1.x86_64-unknown-freebsd11.1-gcc8.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-1.x86_64-unknown-freebsd11.1-gcc8.tar.gz/sha512	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+2b00c525e1a038d43b39151672245cef881e3713b59014e7a85eefc17a13b94064b60e618b09c7452fcca554a015bb294f746547d19a692ea2276bbc7fc32846
diff -pruN 1.3.1+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-1.x86_64-w64-mingw32-gcc4.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-1.x86_64-w64-mingw32-gcc4.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-1.x86_64-w64-mingw32-gcc4.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-1.x86_64-w64-mingw32-gcc4.tar.gz/md5	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+5aae708824826fb624440dfa9bdeff23
diff -pruN 1.3.1+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-1.x86_64-w64-mingw32-gcc4.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-1.x86_64-w64-mingw32-gcc4.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-1.x86_64-w64-mingw32-gcc4.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-1.x86_64-w64-mingw32-gcc4.tar.gz/sha512	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+db15905d0255d645e178b85450ced8736bd96c5f94900a81c5b0d7c3a18ce26dd1b594f2f4dcc04662d529ae8c59fe2e8c08ea748330dc0de3f2be9d4eb1689a
diff -pruN 1.3.1+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-1.x86_64-w64-mingw32-gcc7.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-1.x86_64-w64-mingw32-gcc7.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-1.x86_64-w64-mingw32-gcc7.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-1.x86_64-w64-mingw32-gcc7.tar.gz/md5	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+426b68729a688e5256396a979ea704d5
diff -pruN 1.3.1+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-1.x86_64-w64-mingw32-gcc7.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-1.x86_64-w64-mingw32-gcc7.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-1.x86_64-w64-mingw32-gcc7.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-1.x86_64-w64-mingw32-gcc7.tar.gz/sha512	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+840b961fb389d5090ea17fcf4d4a8a9c43160355e2a0622342cf8e24d0d3f8d1e65285058ba1ef54881997b0b122d328e5e08c41ecb5eaeddd0a0f75806927e7
diff -pruN 1.3.1+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-1.x86_64-w64-mingw32-gcc8.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-1.x86_64-w64-mingw32-gcc8.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-1.x86_64-w64-mingw32-gcc8.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-1.x86_64-w64-mingw32-gcc8.tar.gz/md5	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+d3e4d22ec02cace792dc2ac5ec62cfe4
diff -pruN 1.3.1+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-1.x86_64-w64-mingw32-gcc8.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-1.x86_64-w64-mingw32-gcc8.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-1.x86_64-w64-mingw32-gcc8.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-1.x86_64-w64-mingw32-gcc8.tar.gz/sha512	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+e719cdb2660b51a79c83dfe23dddb296a2fc788af3b2cfd5cfbe4d603de53325f92386402e02644717a80167a1aa1d8743b078dbf42614bac73a7c23032cdf9e
diff -pruN 1.3.1+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-2.aarch64-linux-gnu-gcc4.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-2.aarch64-linux-gnu-gcc4.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-2.aarch64-linux-gnu-gcc4.tar.gz/md5	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-2.aarch64-linux-gnu-gcc4.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-14d62da838b053ab78c3c84a8df7c429
diff -pruN 1.3.1+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-2.aarch64-linux-gnu-gcc4.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-2.aarch64-linux-gnu-gcc4.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-2.aarch64-linux-gnu-gcc4.tar.gz/sha512	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-2.aarch64-linux-gnu-gcc4.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-0141f903dbc62ccdcf01d8722ce7b03c74d94c661be796c1a242b0f385f891c15daf015331029b8ed692867d2e7f8303fa3d5c443ee65a9cfb9b78e3663617ab
diff -pruN 1.3.1+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-2.aarch64-linux-gnu-gcc7.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-2.aarch64-linux-gnu-gcc7.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-2.aarch64-linux-gnu-gcc7.tar.gz/md5	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-2.aarch64-linux-gnu-gcc7.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-a16f6e2bffd56d76735d64a36852f650
diff -pruN 1.3.1+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-2.aarch64-linux-gnu-gcc7.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-2.aarch64-linux-gnu-gcc7.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-2.aarch64-linux-gnu-gcc7.tar.gz/sha512	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-2.aarch64-linux-gnu-gcc7.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-cc164665889562b2e86c4387f85175bd20bd665fc0ce2842a28107eea7f67d49f58067c2face4d768fffec7eb6ca17450c9f07b927b897bed4114e43bde0e83a
diff -pruN 1.3.1+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-2.aarch64-linux-gnu-gcc8.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-2.aarch64-linux-gnu-gcc8.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-2.aarch64-linux-gnu-gcc8.tar.gz/md5	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-2.aarch64-linux-gnu-gcc8.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-8d492b89b0b1c09e620647976df19512
diff -pruN 1.3.1+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-2.aarch64-linux-gnu-gcc8.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-2.aarch64-linux-gnu-gcc8.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-2.aarch64-linux-gnu-gcc8.tar.gz/sha512	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-2.aarch64-linux-gnu-gcc8.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-ff3de25afefc10577c7860cd3fb9496585b763aad683ee39ccbbb596223910ace4b8411fc1f20a3b5708098cafcfe31b873009cf12777cd9b9c4b8d462122fd6
diff -pruN 1.3.1+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-2.aarch64-linux-musl-gcc4.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-2.aarch64-linux-musl-gcc4.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-2.aarch64-linux-musl-gcc4.tar.gz/md5	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-2.aarch64-linux-musl-gcc4.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-9d7a69fe6ed99592087f3b81c6b1c8a1
diff -pruN 1.3.1+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-2.aarch64-linux-musl-gcc4.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-2.aarch64-linux-musl-gcc4.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-2.aarch64-linux-musl-gcc4.tar.gz/sha512	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-2.aarch64-linux-musl-gcc4.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-7c2029a0e9f9efc59813f99fd220a7c8796989db47758857da31b8c794d92de167f35992d399301d79641f79f3b2831afe83af1e85ad99fe4153248dbe5badaf
diff -pruN 1.3.1+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-2.aarch64-linux-musl-gcc7.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-2.aarch64-linux-musl-gcc7.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-2.aarch64-linux-musl-gcc7.tar.gz/md5	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-2.aarch64-linux-musl-gcc7.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-93a1250c75e7cec00a52c091a6fa89cc
diff -pruN 1.3.1+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-2.aarch64-linux-musl-gcc7.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-2.aarch64-linux-musl-gcc7.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-2.aarch64-linux-musl-gcc7.tar.gz/sha512	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-2.aarch64-linux-musl-gcc7.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-1949277d8a762c2f0d8bd37fcc10d97420b82d5a96da2987323ec7d6954b36b7eae52732499e7a054adae1b395158e46eda41daf1e0008c23a02fe4f8059ee3c
diff -pruN 1.3.1+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-2.aarch64-linux-musl-gcc8.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-2.aarch64-linux-musl-gcc8.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-2.aarch64-linux-musl-gcc8.tar.gz/md5	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-2.aarch64-linux-musl-gcc8.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-f8e98218f3a832972531924b770cf8fe
diff -pruN 1.3.1+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-2.aarch64-linux-musl-gcc8.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-2.aarch64-linux-musl-gcc8.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-2.aarch64-linux-musl-gcc8.tar.gz/sha512	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-2.aarch64-linux-musl-gcc8.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-7a4064f5e79dd11cc14d85dc1e37fd923cebaebc92483a1c90e7a73b072d789a87fb3b0c46bfd0668307e4bb32c2c4af3f190eac2da934f37d61d81b980a878b
diff -pruN 1.3.1+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-2.arm-linux-gnueabihf-gcc4.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-2.arm-linux-gnueabihf-gcc4.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-2.arm-linux-gnueabihf-gcc4.tar.gz/md5	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-2.arm-linux-gnueabihf-gcc4.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-636d2d2c14abc9e3b14d1dc546ad8935
diff -pruN 1.3.1+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-2.arm-linux-gnueabihf-gcc4.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-2.arm-linux-gnueabihf-gcc4.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-2.arm-linux-gnueabihf-gcc4.tar.gz/sha512	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-2.arm-linux-gnueabihf-gcc4.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-3394f5ee2f35c168e7f6be9c0653dd157e7da49040b9ec94d6f4d6d1ad2736cdc6f10f6626f08548238c3a11b69ffefa159c5495d1fe58855c0c41c2383641fd
diff -pruN 1.3.1+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-2.arm-linux-gnueabihf-gcc7.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-2.arm-linux-gnueabihf-gcc7.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-2.arm-linux-gnueabihf-gcc7.tar.gz/md5	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-2.arm-linux-gnueabihf-gcc7.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-a336efef9cf11945477b2bb805282810
diff -pruN 1.3.1+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-2.arm-linux-gnueabihf-gcc7.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-2.arm-linux-gnueabihf-gcc7.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-2.arm-linux-gnueabihf-gcc7.tar.gz/sha512	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-2.arm-linux-gnueabihf-gcc7.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-8c0e558aa047f60a5e695229b0f7585363448dd2b61c0a193bdf00d27fffecd3a9c37a0e423821af7beb909c874074fe7a1d4d4cec623bd964205ee20d2e3b23
diff -pruN 1.3.1+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-2.arm-linux-gnueabihf-gcc8.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-2.arm-linux-gnueabihf-gcc8.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-2.arm-linux-gnueabihf-gcc8.tar.gz/md5	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-2.arm-linux-gnueabihf-gcc8.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-28dd6d175a5a6fe86a4d01f9031b76cf
diff -pruN 1.3.1+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-2.arm-linux-gnueabihf-gcc8.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-2.arm-linux-gnueabihf-gcc8.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-2.arm-linux-gnueabihf-gcc8.tar.gz/sha512	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-2.arm-linux-gnueabihf-gcc8.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-986cabd473a353731479036db91f4a462fe6b389ddee35aacb3f66a15df8e1d38956c385d3ef02e399bde70458a3fc6b769466db652f4495abd7d7d2ff0b26b1
diff -pruN 1.3.1+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-2.arm-linux-musleabihf-gcc4.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-2.arm-linux-musleabihf-gcc4.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-2.arm-linux-musleabihf-gcc4.tar.gz/md5	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-2.arm-linux-musleabihf-gcc4.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-1487ee7fb0ff0e2824be40dfa79badff
diff -pruN 1.3.1+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-2.arm-linux-musleabihf-gcc4.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-2.arm-linux-musleabihf-gcc4.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-2.arm-linux-musleabihf-gcc4.tar.gz/sha512	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-2.arm-linux-musleabihf-gcc4.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-ecd8abcb46bd26e72e6ccda2ef463521629dcf6132dd065079b8da71e7291c0561c801bf7c94a467b6aa2839539ee990ccf4b4ea5160f492fb704b2ffcfe0283
diff -pruN 1.3.1+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-2.arm-linux-musleabihf-gcc7.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-2.arm-linux-musleabihf-gcc7.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-2.arm-linux-musleabihf-gcc7.tar.gz/md5	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-2.arm-linux-musleabihf-gcc7.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-c478e1ae81917a27fffbdef01829d79e
diff -pruN 1.3.1+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-2.arm-linux-musleabihf-gcc7.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-2.arm-linux-musleabihf-gcc7.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-2.arm-linux-musleabihf-gcc7.tar.gz/sha512	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-2.arm-linux-musleabihf-gcc7.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-22aef28d214c41556fc45ffc3903073bd7f5b44ec6714f4c9d8f50757200c89c3da3e61d96ab587dc353ec4e88b67b8c553c938ecb32261347b1e3c5e8901c0e
diff -pruN 1.3.1+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-2.arm-linux-musleabihf-gcc8.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-2.arm-linux-musleabihf-gcc8.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-2.arm-linux-musleabihf-gcc8.tar.gz/md5	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-2.arm-linux-musleabihf-gcc8.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-fb6116f48854a9e183d6c6773e889756
diff -pruN 1.3.1+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-2.arm-linux-musleabihf-gcc8.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-2.arm-linux-musleabihf-gcc8.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-2.arm-linux-musleabihf-gcc8.tar.gz/sha512	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-2.arm-linux-musleabihf-gcc8.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-33edfa3fe05f2e6a246eda391813e8db30ed744789032e499cbfb4e1f9f73c67ce6e439dc7ca4795d8b38b9dab6420979f51ef818511e8601398144ef41f7b2e
diff -pruN 1.3.1+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-2.i686-linux-gnu-gcc4.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-2.i686-linux-gnu-gcc4.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-2.i686-linux-gnu-gcc4.tar.gz/md5	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-2.i686-linux-gnu-gcc4.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-15c38ae63c6c70bbcf7e52bff16ec915
diff -pruN 1.3.1+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-2.i686-linux-gnu-gcc4.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-2.i686-linux-gnu-gcc4.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-2.i686-linux-gnu-gcc4.tar.gz/sha512	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-2.i686-linux-gnu-gcc4.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-5f2464ad3b56cec0ca343f301460819141dec3217cf15b171da657768571eae77313ce156d56fd5cc76c6d95758597015dc7d04e209c0ffb0dcbeedb99d788e0
diff -pruN 1.3.1+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-2.i686-linux-gnu-gcc7.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-2.i686-linux-gnu-gcc7.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-2.i686-linux-gnu-gcc7.tar.gz/md5	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-2.i686-linux-gnu-gcc7.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-ad1c639472af0e6245f8faa5cbf65f57
diff -pruN 1.3.1+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-2.i686-linux-gnu-gcc7.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-2.i686-linux-gnu-gcc7.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-2.i686-linux-gnu-gcc7.tar.gz/sha512	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-2.i686-linux-gnu-gcc7.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-fe85b545b4e0787fc1b6c1f2948a4db09eafe365c1bf52a5979430f014d23a8713bb7c1ff29264fa02e16736b9407c7aaf56416354dd3c1e2e2ae9b32a00f5d2
diff -pruN 1.3.1+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-2.i686-linux-gnu-gcc8.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-2.i686-linux-gnu-gcc8.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-2.i686-linux-gnu-gcc8.tar.gz/md5	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-2.i686-linux-gnu-gcc8.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-e25cb820b2eb0d593fb0c875ae2086a1
diff -pruN 1.3.1+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-2.i686-linux-gnu-gcc8.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-2.i686-linux-gnu-gcc8.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-2.i686-linux-gnu-gcc8.tar.gz/sha512	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-2.i686-linux-gnu-gcc8.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-6b5d4f21609f9382d01b4e5c4b7becbf61b50aa3c20f0db6a78736506ad83b0ec7225790f1127d1601bb96ea3318d3704b18e71fd6c1559006147525cb2b3389
diff -pruN 1.3.1+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-2.i686-linux-musl-gcc4.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-2.i686-linux-musl-gcc4.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-2.i686-linux-musl-gcc4.tar.gz/md5	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-2.i686-linux-musl-gcc4.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-f2c96e84acbded44c263270367b6cf9f
diff -pruN 1.3.1+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-2.i686-linux-musl-gcc4.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-2.i686-linux-musl-gcc4.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-2.i686-linux-musl-gcc4.tar.gz/sha512	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-2.i686-linux-musl-gcc4.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-3d0d2fac80ec4760c96740e4607086b192d3309ae5bd5b43288655137b5a2a4c78448b283cd50c935f2ad742348bb4770213446c31216972ed1ecf520e34c629
diff -pruN 1.3.1+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-2.i686-linux-musl-gcc7.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-2.i686-linux-musl-gcc7.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-2.i686-linux-musl-gcc7.tar.gz/md5	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-2.i686-linux-musl-gcc7.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-520372fb05206ac794ff2ac5d23234b4
diff -pruN 1.3.1+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-2.i686-linux-musl-gcc7.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-2.i686-linux-musl-gcc7.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-2.i686-linux-musl-gcc7.tar.gz/sha512	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-2.i686-linux-musl-gcc7.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-92ffc6f2d0fbf6c79dba8f47f44ca7ca11a12e5e6ad43e88d166ba66fcc2b82f62f914ef97ae0831267309ee10c450e191ae0dae51eaf969315e4d3539a8ab57
diff -pruN 1.3.1+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-2.i686-linux-musl-gcc8.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-2.i686-linux-musl-gcc8.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-2.i686-linux-musl-gcc8.tar.gz/md5	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-2.i686-linux-musl-gcc8.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-c94c117ba0d7eeeb59df74ffe3733431
diff -pruN 1.3.1+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-2.i686-linux-musl-gcc8.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-2.i686-linux-musl-gcc8.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-2.i686-linux-musl-gcc8.tar.gz/sha512	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-2.i686-linux-musl-gcc8.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-dd11c827b50e5983ed7705dcebfb50249ebbaf661a371d7d0e4f2a8d7401d9999def5bf2491c2461a4dd9b582e714d9350c70298ef388cb32a4d38060a124d88
diff -pruN 1.3.1+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-2.i686-w64-mingw32-gcc4.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-2.i686-w64-mingw32-gcc4.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-2.i686-w64-mingw32-gcc4.tar.gz/md5	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-2.i686-w64-mingw32-gcc4.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-fb8b0d915623c27936ea293a2eb2850e
diff -pruN 1.3.1+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-2.i686-w64-mingw32-gcc4.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-2.i686-w64-mingw32-gcc4.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-2.i686-w64-mingw32-gcc4.tar.gz/sha512	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-2.i686-w64-mingw32-gcc4.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-e3600b813bc7ba5f736899348bf34965f3affead6fadc71555b8bc5e338b06e90a6865a409186604b0fc2d3bdf84ff2e2bf103909cbf7c253dfaff030bbe21fb
diff -pruN 1.3.1+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-2.i686-w64-mingw32-gcc7.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-2.i686-w64-mingw32-gcc7.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-2.i686-w64-mingw32-gcc7.tar.gz/md5	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-2.i686-w64-mingw32-gcc7.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-5b9eabe82ad7de280d739f2d594e8fdc
diff -pruN 1.3.1+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-2.i686-w64-mingw32-gcc7.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-2.i686-w64-mingw32-gcc7.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-2.i686-w64-mingw32-gcc7.tar.gz/sha512	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-2.i686-w64-mingw32-gcc7.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-a532481b46d1d7999618676b5d9eba5fd527d25dca5ac2666d9a2258245d77aef742bb2909ff70543d7a06e5182a99fd6c356f3c59c8aff822f9280cbcaa9cf3
diff -pruN 1.3.1+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-2.i686-w64-mingw32-gcc8.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-2.i686-w64-mingw32-gcc8.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-2.i686-w64-mingw32-gcc8.tar.gz/md5	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-2.i686-w64-mingw32-gcc8.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-d02eacbfb41fe7827331865396707b4b
diff -pruN 1.3.1+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-2.i686-w64-mingw32-gcc8.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-2.i686-w64-mingw32-gcc8.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-2.i686-w64-mingw32-gcc8.tar.gz/sha512	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-2.i686-w64-mingw32-gcc8.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-8c58b822ecfef7192cf36ff391bf34087eecad299c4417da06fdd990c2e71daf8b717770eabeca7e5b67a020b415b9294d44ac897ccb503a1a34943cd563efc5
diff -pruN 1.3.1+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-2.powerpc64le-linux-gnu-gcc4.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-2.powerpc64le-linux-gnu-gcc4.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-2.powerpc64le-linux-gnu-gcc4.tar.gz/md5	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-2.powerpc64le-linux-gnu-gcc4.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-d1e4a5d1a43e018b67532fa98081206e
diff -pruN 1.3.1+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-2.powerpc64le-linux-gnu-gcc4.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-2.powerpc64le-linux-gnu-gcc4.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-2.powerpc64le-linux-gnu-gcc4.tar.gz/sha512	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-2.powerpc64le-linux-gnu-gcc4.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-4357a9f323739c90e6f1e0797be0d8f11e36fbfa9f8a64a6050833244a786166a8391e2c73b1f8130fa83db3d57b58fd48bf2081ba79992b452ffec57d1759a2
diff -pruN 1.3.1+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-2.powerpc64le-linux-gnu-gcc7.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-2.powerpc64le-linux-gnu-gcc7.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-2.powerpc64le-linux-gnu-gcc7.tar.gz/md5	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-2.powerpc64le-linux-gnu-gcc7.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-2c7930c84ea6cd11c69aa25941087f5c
diff -pruN 1.3.1+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-2.powerpc64le-linux-gnu-gcc7.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-2.powerpc64le-linux-gnu-gcc7.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-2.powerpc64le-linux-gnu-gcc7.tar.gz/sha512	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-2.powerpc64le-linux-gnu-gcc7.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-a53d47e1d7ff25258b20394195e374c9f986b2e7edb0dd66c314a5f12a7d28b4518e5ab87fe5f0feaac99c2f2961292b1ce1d5436ea83104bf089d3d08607d93
diff -pruN 1.3.1+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-2.powerpc64le-linux-gnu-gcc8.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-2.powerpc64le-linux-gnu-gcc8.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-2.powerpc64le-linux-gnu-gcc8.tar.gz/md5	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-2.powerpc64le-linux-gnu-gcc8.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-1b881141039ba34a7f2c29cef9305062
diff -pruN 1.3.1+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-2.powerpc64le-linux-gnu-gcc8.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-2.powerpc64le-linux-gnu-gcc8.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-2.powerpc64le-linux-gnu-gcc8.tar.gz/sha512	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-2.powerpc64le-linux-gnu-gcc8.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-23ab0524b4403e002bdf280f83fb955de11176fdf7cfaed3f9197993f7c09ad5c1fea14dc6402f1756272aa5e427ffd904418db4de02ea9efbc96de60baf6ee5
diff -pruN 1.3.1+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-2.x86_64-apple-darwin14-gcc4.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-2.x86_64-apple-darwin14-gcc4.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-2.x86_64-apple-darwin14-gcc4.tar.gz/md5	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-2.x86_64-apple-darwin14-gcc4.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-eda2584e55dc066e5549048b84b35f05
diff -pruN 1.3.1+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-2.x86_64-apple-darwin14-gcc4.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-2.x86_64-apple-darwin14-gcc4.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-2.x86_64-apple-darwin14-gcc4.tar.gz/sha512	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-2.x86_64-apple-darwin14-gcc4.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-3034f82dc2e06f8f3474ffd6c9692d58186edb59f5f32578de9c21777fbff9def9abe000ca79ae5044be82825f70fab4a9612bbc8df7b0d23dfc77fa28b8f363
diff -pruN 1.3.1+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-2.x86_64-apple-darwin14-gcc7.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-2.x86_64-apple-darwin14-gcc7.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-2.x86_64-apple-darwin14-gcc7.tar.gz/md5	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-2.x86_64-apple-darwin14-gcc7.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-aa649a88f904208bc3e979af833c9ecd
diff -pruN 1.3.1+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-2.x86_64-apple-darwin14-gcc7.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-2.x86_64-apple-darwin14-gcc7.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-2.x86_64-apple-darwin14-gcc7.tar.gz/sha512	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-2.x86_64-apple-darwin14-gcc7.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-c2d7c3a718106de87777beea3addd658ce06f7f1ed5973c5d17fcf97d958741a19df114f62771afc77a7f2c5e25f8302471772cafa30ee40ef7cdfebcec8477b
diff -pruN 1.3.1+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-2.x86_64-apple-darwin14-gcc8.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-2.x86_64-apple-darwin14-gcc8.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-2.x86_64-apple-darwin14-gcc8.tar.gz/md5	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-2.x86_64-apple-darwin14-gcc8.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-f3c53bfaabc5027cd95838524ed1ab4e
diff -pruN 1.3.1+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-2.x86_64-apple-darwin14-gcc8.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-2.x86_64-apple-darwin14-gcc8.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-2.x86_64-apple-darwin14-gcc8.tar.gz/sha512	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-2.x86_64-apple-darwin14-gcc8.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-cd40f1510f66071551ef1d752a64dada6cf82128b725030d8bab7a3cd4b25397b3504763f165498c7231f9c2577c5eddee4cd8b7d8810526221b15d3647ad9cc
diff -pruN 1.3.1+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-2.x86_64-linux-gnu-gcc4.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-2.x86_64-linux-gnu-gcc4.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-2.x86_64-linux-gnu-gcc4.tar.gz/md5	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-2.x86_64-linux-gnu-gcc4.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-d6452ff5d4fd1cf1d77239d22cf6a1b5
diff -pruN 1.3.1+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-2.x86_64-linux-gnu-gcc4.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-2.x86_64-linux-gnu-gcc4.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-2.x86_64-linux-gnu-gcc4.tar.gz/sha512	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-2.x86_64-linux-gnu-gcc4.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-801c374ee8e8f296e6b84536d2d719bee35e1f0380d947ea119d0a5ebfa7151e358a6228078b516338a4957580de63b3fa083d5be08be2930832c105286cfc49
diff -pruN 1.3.1+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-2.x86_64-linux-gnu-gcc7.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-2.x86_64-linux-gnu-gcc7.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-2.x86_64-linux-gnu-gcc7.tar.gz/md5	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-2.x86_64-linux-gnu-gcc7.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-124282a831a7d39036a7d3b391d513ec
diff -pruN 1.3.1+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-2.x86_64-linux-gnu-gcc7.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-2.x86_64-linux-gnu-gcc7.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-2.x86_64-linux-gnu-gcc7.tar.gz/sha512	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-2.x86_64-linux-gnu-gcc7.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-2ff54c2700e5c1c1dd8bca51cbe8654aa364e5b57f871b6f2701f4a5412ff0ad64ce173fbd9ce7443b6625177e4d645991736966bfbf3fdbdc66bc96fc22d4a5
diff -pruN 1.3.1+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-2.x86_64-linux-gnu-gcc8.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-2.x86_64-linux-gnu-gcc8.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-2.x86_64-linux-gnu-gcc8.tar.gz/md5	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-2.x86_64-linux-gnu-gcc8.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-e0822060b13864f9b0a4416149d89336
diff -pruN 1.3.1+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-2.x86_64-linux-gnu-gcc8.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-2.x86_64-linux-gnu-gcc8.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-2.x86_64-linux-gnu-gcc8.tar.gz/sha512	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-2.x86_64-linux-gnu-gcc8.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-8beca6be0853117eae41b84e984601fd61ef15fd5f6555f1d71375d60a22693cdbfbfac93ec76dd14fa476a6d474b29e8c7efe96a4acb2e90433fe8f325690e1
diff -pruN 1.3.1+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-2.x86_64-linux-musl-gcc4.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-2.x86_64-linux-musl-gcc4.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-2.x86_64-linux-musl-gcc4.tar.gz/md5	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-2.x86_64-linux-musl-gcc4.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-4c3dffaacf774f5838cd2d0f178a4e67
diff -pruN 1.3.1+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-2.x86_64-linux-musl-gcc4.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-2.x86_64-linux-musl-gcc4.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-2.x86_64-linux-musl-gcc4.tar.gz/sha512	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-2.x86_64-linux-musl-gcc4.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-9552f805840c48ed24d65ac858ac13db158cb3579753400c778a3aabac39b20d47a59ab36c86293e5c8b15837e8567e8635792f5ee426be83d26cc6de7bfdcb0
diff -pruN 1.3.1+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-2.x86_64-linux-musl-gcc7.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-2.x86_64-linux-musl-gcc7.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-2.x86_64-linux-musl-gcc7.tar.gz/md5	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-2.x86_64-linux-musl-gcc7.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-d0724e5fd3ffdb759e293724f4b9fa73
diff -pruN 1.3.1+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-2.x86_64-linux-musl-gcc7.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-2.x86_64-linux-musl-gcc7.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-2.x86_64-linux-musl-gcc7.tar.gz/sha512	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-2.x86_64-linux-musl-gcc7.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-00b6d2eb995e0c1d973e6d30bd70b92d7d2c5f6d14f9cb1788b16d772e91faef8b095e3ae13729c168088fe005caf2e303d51b9414c243b4e12d8beee7547d3d
diff -pruN 1.3.1+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-2.x86_64-linux-musl-gcc8.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-2.x86_64-linux-musl-gcc8.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-2.x86_64-linux-musl-gcc8.tar.gz/md5	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-2.x86_64-linux-musl-gcc8.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-36258813bf0e72e1566bd73816bd7b6a
diff -pruN 1.3.1+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-2.x86_64-linux-musl-gcc8.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-2.x86_64-linux-musl-gcc8.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-2.x86_64-linux-musl-gcc8.tar.gz/sha512	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-2.x86_64-linux-musl-gcc8.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-289903f344b251e122dd76bb0c9e097323e2da1f3995391dc9882098346355767c8d4933e6d1cc98074f3d85bb326aac5785b716dd6198d122e48f2c7fd072d4
diff -pruN 1.3.1+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-2.x86_64-unknown-freebsd11.1-gcc4.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-2.x86_64-unknown-freebsd11.1-gcc4.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-2.x86_64-unknown-freebsd11.1-gcc4.tar.gz/md5	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-2.x86_64-unknown-freebsd11.1-gcc4.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-457e4f86c5f482d777f41a24eb9642e1
diff -pruN 1.3.1+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-2.x86_64-unknown-freebsd11.1-gcc4.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-2.x86_64-unknown-freebsd11.1-gcc4.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-2.x86_64-unknown-freebsd11.1-gcc4.tar.gz/sha512	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-2.x86_64-unknown-freebsd11.1-gcc4.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-acd3f8b3d42e1fa4c46d82bc9c60042d91985d41b440fd7259b4370b93b19287792d8b14fa7d5a5510945b5201f225aadbbc96ff2edee0ab2c1a254624647247
diff -pruN 1.3.1+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-2.x86_64-unknown-freebsd11.1-gcc7.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-2.x86_64-unknown-freebsd11.1-gcc7.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-2.x86_64-unknown-freebsd11.1-gcc7.tar.gz/md5	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-2.x86_64-unknown-freebsd11.1-gcc7.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-e57e4cb36402d9acb3d1a89a88e37826
diff -pruN 1.3.1+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-2.x86_64-unknown-freebsd11.1-gcc7.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-2.x86_64-unknown-freebsd11.1-gcc7.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-2.x86_64-unknown-freebsd11.1-gcc7.tar.gz/sha512	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-2.x86_64-unknown-freebsd11.1-gcc7.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-b372b1d6fbaacb2e4c9baf585e1c6fa85a72ff37e9dc644a27308586edffa5e1c5c7e0be4245fb965e7cd0c6686f284d0112be60d5456e0892b097737756f4cf
diff -pruN 1.3.1+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-2.x86_64-unknown-freebsd11.1-gcc8.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-2.x86_64-unknown-freebsd11.1-gcc8.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-2.x86_64-unknown-freebsd11.1-gcc8.tar.gz/md5	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-2.x86_64-unknown-freebsd11.1-gcc8.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-61b60d24090c00e38cf8b6af83fd884f
diff -pruN 1.3.1+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-2.x86_64-unknown-freebsd11.1-gcc8.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-2.x86_64-unknown-freebsd11.1-gcc8.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-2.x86_64-unknown-freebsd11.1-gcc8.tar.gz/sha512	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-2.x86_64-unknown-freebsd11.1-gcc8.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-7f6cf4818134353462b08d23ed1adf4360653e58eb848b56bf49aee3c3f591ec91999048f4c1540001a35d15bc5e7795eb09ad8cb549663d56f7613c987b4b7c
diff -pruN 1.3.1+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-2.x86_64-w64-mingw32-gcc4.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-2.x86_64-w64-mingw32-gcc4.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-2.x86_64-w64-mingw32-gcc4.tar.gz/md5	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-2.x86_64-w64-mingw32-gcc4.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-f5c0d5d809ddcf721ae1dc68eaf2c0c4
diff -pruN 1.3.1+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-2.x86_64-w64-mingw32-gcc4.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-2.x86_64-w64-mingw32-gcc4.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-2.x86_64-w64-mingw32-gcc4.tar.gz/sha512	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-2.x86_64-w64-mingw32-gcc4.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-395bdc4a316cf55206966c858bf7320d0f66cdf2f7d6393cc8b3dfd74fc4983a59dc522ac8c18534c6ecde5bf877af57dbc088c83fa6dd8270326f587ceecd6a
diff -pruN 1.3.1+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-2.x86_64-w64-mingw32-gcc7.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-2.x86_64-w64-mingw32-gcc7.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-2.x86_64-w64-mingw32-gcc7.tar.gz/md5	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-2.x86_64-w64-mingw32-gcc7.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-f40e5bc882602ea1298089a92350bf5a
diff -pruN 1.3.1+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-2.x86_64-w64-mingw32-gcc7.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-2.x86_64-w64-mingw32-gcc7.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-2.x86_64-w64-mingw32-gcc7.tar.gz/sha512	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-2.x86_64-w64-mingw32-gcc7.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-c4bc4b6922a57a9806ad007bd3e0655206717acf722e4e794b709f8b06efd6106d4b4e943276061a7632e7191e307317e3f3a205ff46e8ef3b9c0ea8634fe4f3
diff -pruN 1.3.1+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-2.x86_64-w64-mingw32-gcc8.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-2.x86_64-w64-mingw32-gcc8.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-2.x86_64-w64-mingw32-gcc8.tar.gz/md5	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-2.x86_64-w64-mingw32-gcc8.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-617c4587e25dc495446d389fa323c45f
diff -pruN 1.3.1+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-2.x86_64-w64-mingw32-gcc8.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-2.x86_64-w64-mingw32-gcc8.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-2.x86_64-w64-mingw32-gcc8.tar.gz/sha512	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/OpenBLAS.v0.3.5-2.x86_64-w64-mingw32-gcc8.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-63938a2e8ee30807cbeca92589d79d3c438f2aed3eb818735c3ab28e6a6d9835fb7cf250ea7c05fdc8949ba32769f394e6981be46c71b19a389a9b00501962ee
diff -pruN 1.3.1+dfsg-1/deps/checksums/Pkg-9419c70af69153cd5c4276bff90fbb135e0aa3f1.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/Pkg-9419c70af69153cd5c4276bff90fbb135e0aa3f1.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/Pkg-9419c70af69153cd5c4276bff90fbb135e0aa3f1.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/Pkg-9419c70af69153cd5c4276bff90fbb135e0aa3f1.tar.gz/md5	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+a107b2b69d899e5191e7cdbff263df10
diff -pruN 1.3.1+dfsg-1/deps/checksums/Pkg-9419c70af69153cd5c4276bff90fbb135e0aa3f1.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/Pkg-9419c70af69153cd5c4276bff90fbb135e0aa3f1.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/Pkg-9419c70af69153cd5c4276bff90fbb135e0aa3f1.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/Pkg-9419c70af69153cd5c4276bff90fbb135e0aa3f1.tar.gz/sha512	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+beab318b1cf96a2f0957f26d33f2d06e6dfabed405778f3945caf6372cc62ed74ff069e912475f3e553cf3013db73a2c73f2a758a3e3b1ba21db0471b7182dbe
diff -pruN 1.3.1+dfsg-1/deps/checksums/Pkg-f71e2c5a119b9c850f9b357fc8c56068f5b51cc0.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/Pkg-f71e2c5a119b9c850f9b357fc8c56068f5b51cc0.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/Pkg-f71e2c5a119b9c850f9b357fc8c56068f5b51cc0.tar.gz/md5	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/Pkg-f71e2c5a119b9c850f9b357fc8c56068f5b51cc0.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-054eb913fe9bcbe6080c2305980a6c6e
diff -pruN 1.3.1+dfsg-1/deps/checksums/Pkg-f71e2c5a119b9c850f9b357fc8c56068f5b51cc0.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/Pkg-f71e2c5a119b9c850f9b357fc8c56068f5b51cc0.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/Pkg-f71e2c5a119b9c850f9b357fc8c56068f5b51cc0.tar.gz/sha512	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/Pkg-f71e2c5a119b9c850f9b357fc8c56068f5b51cc0.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-31c71b702b2831efe08911cab73b78aa2988524a5563720da902d1012e621c45e6bcad7310abc291e934be0d3f481d884af83e3cb4c63e284d8351938faf211f
diff -pruN 1.3.1+dfsg-1/deps/checksums/Pkg-.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/Pkg-.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/Pkg-.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/Pkg-.tar.gz/md5	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+5ba4a445f0d53782527721c7d281f83b
diff -pruN 1.3.1+dfsg-1/deps/checksums/Pkg-.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/Pkg-.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/Pkg-.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/Pkg-.tar.gz/sha512	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+36809df8a94a0876eabd04f0fcd93a40dbafde921fb6644b461241a651231ae115e81ddfce99fba586d09afc5f692582bb24d40fa7bed1902a5bb7b4cc3a8418
diff -pruN 1.3.1+dfsg-1/deps/checksums/Statistics-a2203d3b67f7413701be5de251622cb85c9cc69d.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/Statistics-a2203d3b67f7413701be5de251622cb85c9cc69d.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/Statistics-a2203d3b67f7413701be5de251622cb85c9cc69d.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/Statistics-a2203d3b67f7413701be5de251622cb85c9cc69d.tar.gz/md5	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+dcb3084255e7072157f8efb820988bb9
diff -pruN 1.3.1+dfsg-1/deps/checksums/Statistics-a2203d3b67f7413701be5de251622cb85c9cc69d.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/Statistics-a2203d3b67f7413701be5de251622cb85c9cc69d.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/Statistics-a2203d3b67f7413701be5de251622cb85c9cc69d.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/Statistics-a2203d3b67f7413701be5de251622cb85c9cc69d.tar.gz/sha512	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+5f4d0a25915f066bed0c78270af61d63ec60514d5a3b9b08a2250fbbe2aea7046c730263e28dd257b9686d930d6dee814c0aa141b3d532a25a78fd7c58c0587f
diff -pruN 1.3.1+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.aarch64-linux-gnu-gcc4.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.aarch64-linux-gnu-gcc4.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.aarch64-linux-gnu-gcc4.tar.gz/md5	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.aarch64-linux-gnu-gcc4.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-33802fc0807417d49abe7b9457a1d356
diff -pruN 1.3.1+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.aarch64-linux-gnu-gcc4.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.aarch64-linux-gnu-gcc4.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.aarch64-linux-gnu-gcc4.tar.gz/sha512	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.aarch64-linux-gnu-gcc4.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-0c7eedc18fd36b7f2f933b258c240d26d5dff4d93ff83e3e8d7bbe8321c1cada5c0bc672744ff3a18e5f91770a3b011c117072a44703c9679a90a4d0b61e985e
diff -pruN 1.3.1+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.aarch64-linux-gnu-gcc7.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.aarch64-linux-gnu-gcc7.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.aarch64-linux-gnu-gcc7.tar.gz/md5	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.aarch64-linux-gnu-gcc7.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-86a2cad460097eccd3cb293f1f50da6b
diff -pruN 1.3.1+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.aarch64-linux-gnu-gcc7.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.aarch64-linux-gnu-gcc7.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.aarch64-linux-gnu-gcc7.tar.gz/sha512	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.aarch64-linux-gnu-gcc7.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-319b394082697de4127a46be37432bfec3c518d95f51753ffdb2c8b445e8644cf1ec7dfd8f361a9a9a0898ec9763807b754229988987bc2cf55a38d10829a9a8
diff -pruN 1.3.1+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.aarch64-linux-gnu-gcc8.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.aarch64-linux-gnu-gcc8.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.aarch64-linux-gnu-gcc8.tar.gz/md5	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.aarch64-linux-gnu-gcc8.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-341dbf803639461111a071c5c99c67ed
diff -pruN 1.3.1+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.aarch64-linux-gnu-gcc8.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.aarch64-linux-gnu-gcc8.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.aarch64-linux-gnu-gcc8.tar.gz/sha512	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.aarch64-linux-gnu-gcc8.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-3f4d5288d0ae59cd7595074f08e471306ddd8559d2e0546d77c8a236f295eeace7ca11de77c6b598c35b85c539b3f919c30aed48fc6afbdc3409a1b0e08da6c9
diff -pruN 1.3.1+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.aarch64-linux-gnu.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.aarch64-linux-gnu.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.aarch64-linux-gnu.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.aarch64-linux-gnu.tar.gz/md5	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+e9def4cc195bd443f5dcd023cfe2c86d
diff -pruN 1.3.1+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.aarch64-linux-gnu.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.aarch64-linux-gnu.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.aarch64-linux-gnu.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.aarch64-linux-gnu.tar.gz/sha512	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+47c600671ea44eedc67a2cf610f521f738d7903b6ff3c8bb7d703f6e667be68ac0572a664b4289b59425d02e23bb3eaa78c5a9f0f66e9f1ed53a23782be3a556
diff -pruN 1.3.1+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.aarch64-linux-musl-gcc4.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.aarch64-linux-musl-gcc4.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.aarch64-linux-musl-gcc4.tar.gz/md5	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.aarch64-linux-musl-gcc4.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-3bd99240bf3b1928e031d6a147c9a9d3
diff -pruN 1.3.1+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.aarch64-linux-musl-gcc4.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.aarch64-linux-musl-gcc4.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.aarch64-linux-musl-gcc4.tar.gz/sha512	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.aarch64-linux-musl-gcc4.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-2bf9a2709fffe257ab0931dde4cd380d8095acea0b7b7acf877d3d0b82cd03bb31d9ef12862297b39fd635632323ccaeedfde7b67b527cb523056580384761c7
diff -pruN 1.3.1+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.aarch64-linux-musl-gcc7.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.aarch64-linux-musl-gcc7.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.aarch64-linux-musl-gcc7.tar.gz/md5	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.aarch64-linux-musl-gcc7.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-10e1889da8fda4af214891a8a3336098
diff -pruN 1.3.1+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.aarch64-linux-musl-gcc7.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.aarch64-linux-musl-gcc7.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.aarch64-linux-musl-gcc7.tar.gz/sha512	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.aarch64-linux-musl-gcc7.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-e190428ff4449c7e0032017845a866aaff8921d95aa5470417499cc09518af95047f65305c473ccc40f8b9c6295f2d2896bb50d3083f3b05e8c57bc00198f88f
diff -pruN 1.3.1+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.aarch64-linux-musl-gcc8.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.aarch64-linux-musl-gcc8.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.aarch64-linux-musl-gcc8.tar.gz/md5	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.aarch64-linux-musl-gcc8.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-0bfb020eb2cecc934c429ed816013663
diff -pruN 1.3.1+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.aarch64-linux-musl-gcc8.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.aarch64-linux-musl-gcc8.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.aarch64-linux-musl-gcc8.tar.gz/sha512	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.aarch64-linux-musl-gcc8.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-a940fecb380c6e9591a2df02e0d3bdf0b5cb544615015595feb2afae075156e4e58b00db7a8c0bc87e09e11429329e5bc343cd7b67dd1f1ec108259f485eb527
diff -pruN 1.3.1+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.aarch64-linux-musl.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.aarch64-linux-musl.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.aarch64-linux-musl.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.aarch64-linux-musl.tar.gz/md5	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+3ad82b9ecccf600a233c9b7d15334886
diff -pruN 1.3.1+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.aarch64-linux-musl.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.aarch64-linux-musl.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.aarch64-linux-musl.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.aarch64-linux-musl.tar.gz/sha512	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+8b3166998d3ea3c0c5549b501f89c84c4de3248805d870e91a5c1deb29e0d8f7b000d5d933fca525382ad29f8dfda50a649cc55c0a7295d4c2ec2ac9c189e422
diff -pruN 1.3.1+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.arm-linux-gnueabihf-gcc4.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.arm-linux-gnueabihf-gcc4.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.arm-linux-gnueabihf-gcc4.tar.gz/md5	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.arm-linux-gnueabihf-gcc4.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-65c8a77030c1bf97c9ecaff5d2ef0a9a
diff -pruN 1.3.1+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.arm-linux-gnueabihf-gcc4.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.arm-linux-gnueabihf-gcc4.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.arm-linux-gnueabihf-gcc4.tar.gz/sha512	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.arm-linux-gnueabihf-gcc4.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-0cb84eebc24f81c5ae8eff91463f40de21e4720e1fb8af9293624de0c45a67c213e914650b2ba27bfd7550422b30294d27c17023089ac8bf295bdab959592538
diff -pruN 1.3.1+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.arm-linux-gnueabihf-gcc7.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.arm-linux-gnueabihf-gcc7.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.arm-linux-gnueabihf-gcc7.tar.gz/md5	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.arm-linux-gnueabihf-gcc7.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-d4f083a1b9bd7798f6cbdbc46d462796
diff -pruN 1.3.1+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.arm-linux-gnueabihf-gcc7.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.arm-linux-gnueabihf-gcc7.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.arm-linux-gnueabihf-gcc7.tar.gz/sha512	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.arm-linux-gnueabihf-gcc7.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-1b93a2652ec2bca334b20509a01f87d166442c8171e9ae2d52696c64937201ac1eb6e5847b4c60ff2faa46169ffa7c132c78e9aecafcf520f775c3492bc77b8b
diff -pruN 1.3.1+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.arm-linux-gnueabihf-gcc8.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.arm-linux-gnueabihf-gcc8.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.arm-linux-gnueabihf-gcc8.tar.gz/md5	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.arm-linux-gnueabihf-gcc8.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-cedef7d2bbf47910d02b194c749ea2e1
diff -pruN 1.3.1+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.arm-linux-gnueabihf-gcc8.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.arm-linux-gnueabihf-gcc8.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.arm-linux-gnueabihf-gcc8.tar.gz/sha512	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.arm-linux-gnueabihf-gcc8.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-c82da88ab436d7ff032b9947181e33700ee21f227a7afb819ebe59da0d1862eda91d021f75f04d382e41b41ac1caf88d144231ca087a2af8f3c38e2584b0d4fc
diff -pruN 1.3.1+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.arm-linux-gnueabihf.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.arm-linux-gnueabihf.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.arm-linux-gnueabihf.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.arm-linux-gnueabihf.tar.gz/md5	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+c3397a1360cdbca789587e7aa1e1166d
diff -pruN 1.3.1+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.arm-linux-gnueabihf.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.arm-linux-gnueabihf.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.arm-linux-gnueabihf.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.arm-linux-gnueabihf.tar.gz/sha512	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+95309a2709be6107b7d1e1fbef7a4e6646173f55845ed1a279398d911ca9b56d5285a96797083a56f3637b20be3001dc21cf8bc1ce7b829bc2ec55f3d9a3e629
diff -pruN 1.3.1+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.arm-linux-musleabihf-gcc4.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.arm-linux-musleabihf-gcc4.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.arm-linux-musleabihf-gcc4.tar.gz/md5	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.arm-linux-musleabihf-gcc4.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-15013619182f33bf162e8822976aa172
diff -pruN 1.3.1+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.arm-linux-musleabihf-gcc4.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.arm-linux-musleabihf-gcc4.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.arm-linux-musleabihf-gcc4.tar.gz/sha512	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.arm-linux-musleabihf-gcc4.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-f2bc71b9700d7b22c382edd275768523252b92fe6bc2d0b33cdaa69092a802205c2ecc96a4bb66a56d22be093d2d4f9170273919c32c9aafd1ab949d735eb2f0
diff -pruN 1.3.1+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.arm-linux-musleabihf-gcc7.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.arm-linux-musleabihf-gcc7.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.arm-linux-musleabihf-gcc7.tar.gz/md5	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.arm-linux-musleabihf-gcc7.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-f736d19b00b2973e0ed4f93bfcbf35fb
diff -pruN 1.3.1+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.arm-linux-musleabihf-gcc7.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.arm-linux-musleabihf-gcc7.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.arm-linux-musleabihf-gcc7.tar.gz/sha512	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.arm-linux-musleabihf-gcc7.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-375ebe191963f9c834bf7e49f3d4d2d5d064c341ae81e913b34baa49222da0b5fd4f8e2036e90f74a55bee081f148ff13ac3d6651e18417aebf8df1a3a66b84b
diff -pruN 1.3.1+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.arm-linux-musleabihf-gcc8.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.arm-linux-musleabihf-gcc8.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.arm-linux-musleabihf-gcc8.tar.gz/md5	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.arm-linux-musleabihf-gcc8.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-6f65cc6930839e1370f315a7a3000cae
diff -pruN 1.3.1+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.arm-linux-musleabihf-gcc8.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.arm-linux-musleabihf-gcc8.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.arm-linux-musleabihf-gcc8.tar.gz/sha512	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.arm-linux-musleabihf-gcc8.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-a7974da5e369976ca83af6324df8337a2bc8a5ae3c2297d4ad108fac784c378a4e9bb151da220cf5a3ef003016b5a318148eef845f4203217ec6c7c7eecc192e
diff -pruN 1.3.1+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.arm-linux-musleabihf.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.arm-linux-musleabihf.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.arm-linux-musleabihf.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.arm-linux-musleabihf.tar.gz/md5	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+0da326aae3b91e39baf6c39b1fc4f71c
diff -pruN 1.3.1+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.arm-linux-musleabihf.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.arm-linux-musleabihf.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.arm-linux-musleabihf.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.arm-linux-musleabihf.tar.gz/sha512	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+3ba1bcb291fcdc24ae95cf0de4b36bea784849bbf5bfba0c6bca9237138e3d73c45f9d5a7869f17084e1c2406e6c452a8080d5d5599645c7d0ae1239a9d58a7f
diff -pruN 1.3.1+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.i686-linux-gnu-gcc4.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.i686-linux-gnu-gcc4.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.i686-linux-gnu-gcc4.tar.gz/md5	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.i686-linux-gnu-gcc4.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-2db4891a429a6d2b8bfaffa1d9cd0efd
diff -pruN 1.3.1+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.i686-linux-gnu-gcc4.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.i686-linux-gnu-gcc4.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.i686-linux-gnu-gcc4.tar.gz/sha512	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.i686-linux-gnu-gcc4.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-5808f20823cc82d4cc07da4a2aec79762209f5f209714ff20c6347e727b4f4d8a1978cd39e6d7513984410fd8aa68ab736da1164ed8d0bee9ef49773cefb1fb9
diff -pruN 1.3.1+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.i686-linux-gnu-gcc7.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.i686-linux-gnu-gcc7.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.i686-linux-gnu-gcc7.tar.gz/md5	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.i686-linux-gnu-gcc7.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-456292494c7f0d93edadb154cb924a34
diff -pruN 1.3.1+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.i686-linux-gnu-gcc7.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.i686-linux-gnu-gcc7.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.i686-linux-gnu-gcc7.tar.gz/sha512	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.i686-linux-gnu-gcc7.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-59d9373ed2bcf64949816c02efe4f297126dee577ef7e5284ef648bb7722a68fd32295bb2dc150785f078431843faec943297b7a8fb25afea9dcfb45ea5637c7
diff -pruN 1.3.1+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.i686-linux-gnu-gcc8.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.i686-linux-gnu-gcc8.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.i686-linux-gnu-gcc8.tar.gz/md5	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.i686-linux-gnu-gcc8.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-d475f17eb7dc9bf0391ee372f055ea82
diff -pruN 1.3.1+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.i686-linux-gnu-gcc8.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.i686-linux-gnu-gcc8.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.i686-linux-gnu-gcc8.tar.gz/sha512	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.i686-linux-gnu-gcc8.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-b66dd84a2f08a437d1ebe82642cd451bee3251c4c8120b47ec2942fbb5ba21f0772c5c34ea1d750c869913f8c144be58c47d9749d5ceb766876bbd1b51a441d6
diff -pruN 1.3.1+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.i686-linux-gnu.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.i686-linux-gnu.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.i686-linux-gnu.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.i686-linux-gnu.tar.gz/md5	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+0fc1d3f0eb2a3c168438491335e64bc5
diff -pruN 1.3.1+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.i686-linux-gnu.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.i686-linux-gnu.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.i686-linux-gnu.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.i686-linux-gnu.tar.gz/sha512	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+c75a59e35a29207273ed13e6386315cc7a0b6a4993c8d8209fb09654f78cbdb8136afc944e2f439ed07a600e9df3a03efad388fb7daafa26a037e8b040fe9fb2
diff -pruN 1.3.1+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.i686-linux-musl-gcc4.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.i686-linux-musl-gcc4.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.i686-linux-musl-gcc4.tar.gz/md5	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.i686-linux-musl-gcc4.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-c58f7cc55ccf7fda770ee3059853ba43
diff -pruN 1.3.1+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.i686-linux-musl-gcc4.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.i686-linux-musl-gcc4.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.i686-linux-musl-gcc4.tar.gz/sha512	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.i686-linux-musl-gcc4.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-62023c8af152a93e5a287337cc923775923a164291f9e91ceb8f2982e7b4ea52069039f178ea2c017439b5891edbf6f512e64abf3de89985d47c70320c55ea35
diff -pruN 1.3.1+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.i686-linux-musl-gcc7.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.i686-linux-musl-gcc7.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.i686-linux-musl-gcc7.tar.gz/md5	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.i686-linux-musl-gcc7.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-47dd149f3260f04ec6ca641c4accd671
diff -pruN 1.3.1+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.i686-linux-musl-gcc7.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.i686-linux-musl-gcc7.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.i686-linux-musl-gcc7.tar.gz/sha512	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.i686-linux-musl-gcc7.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-13ab1dcaf06a804bebb3b5be9fc7c5a7bd0d238afac2c89a9f02f8527ac738369513f3b82eee2371536a85aadd940cea29b071e603a192e573da46e1cdc85da8
diff -pruN 1.3.1+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.i686-linux-musl-gcc8.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.i686-linux-musl-gcc8.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.i686-linux-musl-gcc8.tar.gz/md5	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.i686-linux-musl-gcc8.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-d2193e3c71f7967e10cd4ee9f4a8fb20
diff -pruN 1.3.1+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.i686-linux-musl-gcc8.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.i686-linux-musl-gcc8.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.i686-linux-musl-gcc8.tar.gz/sha512	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.i686-linux-musl-gcc8.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-e155e0ed62fdd8dc48c50bc31b69df87e9ad3d1e298cbe5b18622a82407066a651a2906b104ed941c7fa8eaedd2ddfd2d08d2d4b2ca547c45c1c80d174a94f3e
diff -pruN 1.3.1+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.i686-linux-musl.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.i686-linux-musl.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.i686-linux-musl.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.i686-linux-musl.tar.gz/md5	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+1a5f88323f0444f4a08e94f53fdc0e04
diff -pruN 1.3.1+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.i686-linux-musl.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.i686-linux-musl.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.i686-linux-musl.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.i686-linux-musl.tar.gz/sha512	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+e6d6256afd40c09cafcd8e5c7acf5daf474e129d345e637a65fb7973a9b7fd8ea45bde73452154b50a6ebcd78c7363e123f239fd641c3dae6d7335e10d789352
diff -pruN 1.3.1+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.i686-w64-mingw32-gcc4.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.i686-w64-mingw32-gcc4.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.i686-w64-mingw32-gcc4.tar.gz/md5	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.i686-w64-mingw32-gcc4.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-c0a8ad36a88378cd5af4c3f0e3e702e1
diff -pruN 1.3.1+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.i686-w64-mingw32-gcc4.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.i686-w64-mingw32-gcc4.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.i686-w64-mingw32-gcc4.tar.gz/sha512	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.i686-w64-mingw32-gcc4.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-e1914f96b3bd4027c36001d14b1d1e588d4c36fe5342e265329bb687678f5a5e9d55f11862d8ae609c0eed64cd5b6dd7b6fbeb10a2610fed9674313a0b49e574
diff -pruN 1.3.1+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.i686-w64-mingw32-gcc7.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.i686-w64-mingw32-gcc7.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.i686-w64-mingw32-gcc7.tar.gz/md5	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.i686-w64-mingw32-gcc7.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-832e3888e5e3e5e88e587b8d9ce6854b
diff -pruN 1.3.1+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.i686-w64-mingw32-gcc7.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.i686-w64-mingw32-gcc7.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.i686-w64-mingw32-gcc7.tar.gz/sha512	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.i686-w64-mingw32-gcc7.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-49a6774dcf281ea1e0bb518b3e50ff1c5cdc357f5a6de38e20e3d7d6bd01067ef8cc192137c063d9dd2cfd955324cd51fd4c3045cd775747f112374832bda231
diff -pruN 1.3.1+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.i686-w64-mingw32-gcc8.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.i686-w64-mingw32-gcc8.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.i686-w64-mingw32-gcc8.tar.gz/md5	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.i686-w64-mingw32-gcc8.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-0ebae94bc5e4acb92be1bebbf8ead972
diff -pruN 1.3.1+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.i686-w64-mingw32-gcc8.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.i686-w64-mingw32-gcc8.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.i686-w64-mingw32-gcc8.tar.gz/sha512	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.i686-w64-mingw32-gcc8.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-4938e865cab6304e27e33bf30b4c45c55e2416f4ad8dc2218f635136282f8be05c44c1413c027433e933bbac2c350255871cb57550839e6e06ae4bcac0bccb7f
diff -pruN 1.3.1+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.i686-w64-mingw32.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.i686-w64-mingw32.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.i686-w64-mingw32.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.i686-w64-mingw32.tar.gz/md5	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+d38c285b955a6c8143340ea4631c66a0
diff -pruN 1.3.1+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.i686-w64-mingw32.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.i686-w64-mingw32.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.i686-w64-mingw32.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.i686-w64-mingw32.tar.gz/sha512	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+e0c9569725c8d60112eb2b906dd00ddfbee4927b38fe52c999c216cdb78cfbc30ba592a96475b671a726fa4a84b3c10c534d8f10f3eb0739f32e5b03875d9be7
diff -pruN 1.3.1+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.powerpc64le-linux-gnu-gcc4.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.powerpc64le-linux-gnu-gcc4.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.powerpc64le-linux-gnu-gcc4.tar.gz/md5	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.powerpc64le-linux-gnu-gcc4.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-5e1ecdb356352fad2bdf0998ce0a11a5
diff -pruN 1.3.1+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.powerpc64le-linux-gnu-gcc4.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.powerpc64le-linux-gnu-gcc4.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.powerpc64le-linux-gnu-gcc4.tar.gz/sha512	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.powerpc64le-linux-gnu-gcc4.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-ccbb6d78e05d3536247d734320e74112c93e7461a7f93b2a19dd2537bf6b181405190100ec7244cb56e79f72cc5639e0dd297b67fb97400fe528b1f5ef2e189c
diff -pruN 1.3.1+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.powerpc64le-linux-gnu-gcc7.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.powerpc64le-linux-gnu-gcc7.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.powerpc64le-linux-gnu-gcc7.tar.gz/md5	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.powerpc64le-linux-gnu-gcc7.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-16ab7487eb5bad9ab569ac892bb94ef7
diff -pruN 1.3.1+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.powerpc64le-linux-gnu-gcc7.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.powerpc64le-linux-gnu-gcc7.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.powerpc64le-linux-gnu-gcc7.tar.gz/sha512	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.powerpc64le-linux-gnu-gcc7.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-346c2a570ef2b007b4218f70192a257ad784065a28bdb684c6bd1957c138920a223d54278ba508d1707e5356c58e3eabb930f4ec1e408974c9e251a43b793c37
diff -pruN 1.3.1+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.powerpc64le-linux-gnu-gcc8.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.powerpc64le-linux-gnu-gcc8.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.powerpc64le-linux-gnu-gcc8.tar.gz/md5	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.powerpc64le-linux-gnu-gcc8.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-c572e9f037f1de515c354b2049718e69
diff -pruN 1.3.1+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.powerpc64le-linux-gnu-gcc8.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.powerpc64le-linux-gnu-gcc8.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.powerpc64le-linux-gnu-gcc8.tar.gz/sha512	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.powerpc64le-linux-gnu-gcc8.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-d591b7228376497b93032cefc8763e8017db0247c33ed4651ee6706bbc8bca8fd8dd2dcb66622cda4a7bf853dfcf62421655fc4b13c3ff1697e047775ac1d830
diff -pruN 1.3.1+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.powerpc64le-linux-gnu.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.powerpc64le-linux-gnu.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.powerpc64le-linux-gnu.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.powerpc64le-linux-gnu.tar.gz/md5	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+0355565cc9134146ae8568d1f1515a51
diff -pruN 1.3.1+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.powerpc64le-linux-gnu.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.powerpc64le-linux-gnu.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.powerpc64le-linux-gnu.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.powerpc64le-linux-gnu.tar.gz/sha512	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+20735973904bfec25e819a70ef138e63bd04c273f23d1230b17b84803f3c871a24eb90f9fd05fca02be9395bd4c59253df307134099952c90e41607b5924b022
diff -pruN 1.3.1+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.x86_64-apple-darwin14-gcc4.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.x86_64-apple-darwin14-gcc4.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.x86_64-apple-darwin14-gcc4.tar.gz/md5	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.x86_64-apple-darwin14-gcc4.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-d58a378917e0660b61874ee7153af90b
diff -pruN 1.3.1+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.x86_64-apple-darwin14-gcc4.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.x86_64-apple-darwin14-gcc4.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.x86_64-apple-darwin14-gcc4.tar.gz/sha512	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.x86_64-apple-darwin14-gcc4.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-4667a9aaab3abe48d2b4cfb355606d9101a51153c8cd039a37bec50825b7544ad9c0bf8a77c06f832b3d9538b02e8bbf5070f18fa554405f762757c4cc218bc5
diff -pruN 1.3.1+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.x86_64-apple-darwin14-gcc7.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.x86_64-apple-darwin14-gcc7.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.x86_64-apple-darwin14-gcc7.tar.gz/md5	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.x86_64-apple-darwin14-gcc7.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-55cc3aee91a1870d66e07ae5ae89a33d
diff -pruN 1.3.1+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.x86_64-apple-darwin14-gcc7.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.x86_64-apple-darwin14-gcc7.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.x86_64-apple-darwin14-gcc7.tar.gz/sha512	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.x86_64-apple-darwin14-gcc7.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-6b870b963954f15112f5259ef92e97eb494edf529cc79ed35db0a71a73e80d5f83c99c10f5d4030517be200f702a1af5c30afd51e7dbcfae4961a1738115d5d6
diff -pruN 1.3.1+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.x86_64-apple-darwin14-gcc8.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.x86_64-apple-darwin14-gcc8.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.x86_64-apple-darwin14-gcc8.tar.gz/md5	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.x86_64-apple-darwin14-gcc8.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-eacc60bd53a2836eacf25e3da66b515d
diff -pruN 1.3.1+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.x86_64-apple-darwin14-gcc8.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.x86_64-apple-darwin14-gcc8.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.x86_64-apple-darwin14-gcc8.tar.gz/sha512	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.x86_64-apple-darwin14-gcc8.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-f3c0c61debd1a61dbacfc1c1c75cfe9ad4cad66bd6cbed5df6c9216a09aa9e07c6285993b4cda2aea29d6321ca18689963bebe9d0676d55f7019d75678475ff6
diff -pruN 1.3.1+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.x86_64-apple-darwin14.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.x86_64-apple-darwin14.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.x86_64-apple-darwin14.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.x86_64-apple-darwin14.tar.gz/md5	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+fe61da26d62e6e7d59fbe15d422d3e83
diff -pruN 1.3.1+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.x86_64-apple-darwin14.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.x86_64-apple-darwin14.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.x86_64-apple-darwin14.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.x86_64-apple-darwin14.tar.gz/sha512	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+8135da3f211d7917c92f771c4a9ffa165534544ed853bfffc7457c2ce4cc10feda19b322eb4e0373a06ec9c4ccb22c9caf50e19bcf998bd78d7e9a3453e71642
diff -pruN 1.3.1+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.x86_64-linux-gnu-gcc4.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.x86_64-linux-gnu-gcc4.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.x86_64-linux-gnu-gcc4.tar.gz/md5	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.x86_64-linux-gnu-gcc4.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-ce3cbb0c43d1ba9aee2f530638dba41b
diff -pruN 1.3.1+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.x86_64-linux-gnu-gcc4.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.x86_64-linux-gnu-gcc4.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.x86_64-linux-gnu-gcc4.tar.gz/sha512	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.x86_64-linux-gnu-gcc4.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-d04d962704c670eb887bd0be1c059677337056d238690df816591fb30a23118d0179ef52eecd99d37a3f63f0fc7ba46df2d5fe72a39bf33657f8f87bc2b47d56
diff -pruN 1.3.1+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.x86_64-linux-gnu-gcc7.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.x86_64-linux-gnu-gcc7.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.x86_64-linux-gnu-gcc7.tar.gz/md5	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.x86_64-linux-gnu-gcc7.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-370ccfbf711b302c4422ebb7ec8a1a23
diff -pruN 1.3.1+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.x86_64-linux-gnu-gcc7.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.x86_64-linux-gnu-gcc7.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.x86_64-linux-gnu-gcc7.tar.gz/sha512	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.x86_64-linux-gnu-gcc7.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-53fb0cbdc145d655c41d9d6c5209f0dfb5883691ca0277ae2b29272703e6d56e48dc4a51a0f54142944dbfa94903c2c01463bfbf01dda3902c20e0fb9f9b4639
diff -pruN 1.3.1+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.x86_64-linux-gnu-gcc8.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.x86_64-linux-gnu-gcc8.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.x86_64-linux-gnu-gcc8.tar.gz/md5	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.x86_64-linux-gnu-gcc8.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-86758655145158b9894f6165f19834fa
diff -pruN 1.3.1+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.x86_64-linux-gnu-gcc8.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.x86_64-linux-gnu-gcc8.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.x86_64-linux-gnu-gcc8.tar.gz/sha512	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.x86_64-linux-gnu-gcc8.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-8e704caa6d5023469aa453c6c5704465a81c4c9ee5b5679e0aa43e331bd45d1f2a921548b7cd2d080fa25e6e3035470f098347a602e7327b7ab6f943aa971c2b
diff -pruN 1.3.1+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.x86_64-linux-gnu.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.x86_64-linux-gnu.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.x86_64-linux-gnu.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.x86_64-linux-gnu.tar.gz/md5	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+6599294734126f3b9ccb051954d84ec8
diff -pruN 1.3.1+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.x86_64-linux-gnu.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.x86_64-linux-gnu.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.x86_64-linux-gnu.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.x86_64-linux-gnu.tar.gz/sha512	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+5922994e1aad3565f19e8d96dceebe5f6cb24d9fae7bcb137d86e4e7ae4d3a1accd28f86f13e109b35e116344b6c780704d49e5c5d68348de9c3c5e2db0de5b3
diff -pruN 1.3.1+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.x86_64-linux-musl-gcc4.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.x86_64-linux-musl-gcc4.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.x86_64-linux-musl-gcc4.tar.gz/md5	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.x86_64-linux-musl-gcc4.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-fc56c9c3ce78494fc2cfddfc3b40a4a8
diff -pruN 1.3.1+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.x86_64-linux-musl-gcc4.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.x86_64-linux-musl-gcc4.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.x86_64-linux-musl-gcc4.tar.gz/sha512	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.x86_64-linux-musl-gcc4.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-3bbf6176c7ebfa7098fa2b30ff9a3f8cd45f5e0d394e35240695ccac6644686e53e04b69e2d464c3f1eec12a813be7e5c7c52345241dae59e52d5b0f1d2f73c5
diff -pruN 1.3.1+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.x86_64-linux-musl-gcc7.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.x86_64-linux-musl-gcc7.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.x86_64-linux-musl-gcc7.tar.gz/md5	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.x86_64-linux-musl-gcc7.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-e3b1e1d8af656cde81d2befeefd4972d
diff -pruN 1.3.1+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.x86_64-linux-musl-gcc7.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.x86_64-linux-musl-gcc7.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.x86_64-linux-musl-gcc7.tar.gz/sha512	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.x86_64-linux-musl-gcc7.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-b9823d1655c3014c38405ac5d4348e57fbabdfc0299c05c9f7af3145e64dda32b57218bd2b786e0293d997cef56b9b3a83ae7ed4423ffd7bb4a32b2a6ea11bbe
diff -pruN 1.3.1+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.x86_64-linux-musl-gcc8.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.x86_64-linux-musl-gcc8.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.x86_64-linux-musl-gcc8.tar.gz/md5	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.x86_64-linux-musl-gcc8.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-4b612c7a888ad37d25d0dae69f2a7673
diff -pruN 1.3.1+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.x86_64-linux-musl-gcc8.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.x86_64-linux-musl-gcc8.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.x86_64-linux-musl-gcc8.tar.gz/sha512	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.x86_64-linux-musl-gcc8.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-54a1097aecde4235741bd3207d93d11b34521a0d66b5c6a59a03394812be11b96c0b5ffeb80673b325b7a61baeca6652ebf969c371def567decb192290305ac2
diff -pruN 1.3.1+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.x86_64-linux-musl.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.x86_64-linux-musl.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.x86_64-linux-musl.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.x86_64-linux-musl.tar.gz/md5	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+e5e2e4b696c3974800094272bcbf1e0d
diff -pruN 1.3.1+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.x86_64-linux-musl.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.x86_64-linux-musl.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.x86_64-linux-musl.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.x86_64-linux-musl.tar.gz/sha512	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+4ff5681e51eed9adaf93195353aaf64f53607279f0c13cdb162c157abc80eac55fb617f186979bc8320765a243618b29f78b7b43489d51bc4a16dca872e8f63b
diff -pruN 1.3.1+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.x86_64-unknown-freebsd11.1-gcc4.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.x86_64-unknown-freebsd11.1-gcc4.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.x86_64-unknown-freebsd11.1-gcc4.tar.gz/md5	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.x86_64-unknown-freebsd11.1-gcc4.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-2fa695b19c357c9086f8c46a7c1bae77
diff -pruN 1.3.1+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.x86_64-unknown-freebsd11.1-gcc4.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.x86_64-unknown-freebsd11.1-gcc4.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.x86_64-unknown-freebsd11.1-gcc4.tar.gz/sha512	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.x86_64-unknown-freebsd11.1-gcc4.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-5efed959f24fca19b7e1697b9e5510e3aeb4c5ce9a36d79217c9673c715f1b7d93dfb2b051708556430aff483549e8e89a002e8115815bd08836aa22e421f328
diff -pruN 1.3.1+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.x86_64-unknown-freebsd11.1-gcc7.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.x86_64-unknown-freebsd11.1-gcc7.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.x86_64-unknown-freebsd11.1-gcc7.tar.gz/md5	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.x86_64-unknown-freebsd11.1-gcc7.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-9b7299fc0c230990601c70b0dfc8ba1c
diff -pruN 1.3.1+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.x86_64-unknown-freebsd11.1-gcc7.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.x86_64-unknown-freebsd11.1-gcc7.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.x86_64-unknown-freebsd11.1-gcc7.tar.gz/sha512	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.x86_64-unknown-freebsd11.1-gcc7.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-6de8ca419ea11e4b55273dc23ee3581e76b1c3459d7f5159a61efe0c485520e6d3e604eb937c5e477e83dbe52d734a462d37dc0d4385aac151f3120d0b0564d1
diff -pruN 1.3.1+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.x86_64-unknown-freebsd11.1-gcc8.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.x86_64-unknown-freebsd11.1-gcc8.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.x86_64-unknown-freebsd11.1-gcc8.tar.gz/md5	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.x86_64-unknown-freebsd11.1-gcc8.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-dd2b5517ff2d34dbdbe37b97faa0ee75
diff -pruN 1.3.1+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.x86_64-unknown-freebsd11.1-gcc8.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.x86_64-unknown-freebsd11.1-gcc8.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.x86_64-unknown-freebsd11.1-gcc8.tar.gz/sha512	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.x86_64-unknown-freebsd11.1-gcc8.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-4a9a1cbedf1e1a29d246a7c800916ad822b450bd8064d45d1f7850e3637600eb073454e4943bb92d7096d44e945bb0d4294d7bc733d6a415afcb7135dc42fd08
diff -pruN 1.3.1+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.x86_64-unknown-freebsd11.1.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.x86_64-unknown-freebsd11.1.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.x86_64-unknown-freebsd11.1.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.x86_64-unknown-freebsd11.1.tar.gz/md5	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+18808d5bdf779552941c5109d1ba9f15
diff -pruN 1.3.1+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.x86_64-unknown-freebsd11.1.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.x86_64-unknown-freebsd11.1.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.x86_64-unknown-freebsd11.1.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.x86_64-unknown-freebsd11.1.tar.gz/sha512	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+05984642873aec6d953e918f7df2b6d1990f224cf40e0350bc4ba17b75ff3ff0228a900e0b2d6933732cb1435c706cff2214f7214d3dccfafdda3b0b88612f44
diff -pruN 1.3.1+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.x86_64-w64-mingw32-gcc4.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.x86_64-w64-mingw32-gcc4.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.x86_64-w64-mingw32-gcc4.tar.gz/md5	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.x86_64-w64-mingw32-gcc4.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-bdbf2315d86856cde07b34ebeeb48fd5
diff -pruN 1.3.1+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.x86_64-w64-mingw32-gcc4.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.x86_64-w64-mingw32-gcc4.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.x86_64-w64-mingw32-gcc4.tar.gz/sha512	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.x86_64-w64-mingw32-gcc4.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-67a83ca4ce9a4c4e39c2d1146fd44b0af7b7ab5abbfaf1519de4c9037c473163c5f76ac9f19178b4e73072ec06d38adee8ccc008a564661033ced05540eeab80
diff -pruN 1.3.1+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.x86_64-w64-mingw32-gcc7.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.x86_64-w64-mingw32-gcc7.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.x86_64-w64-mingw32-gcc7.tar.gz/md5	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.x86_64-w64-mingw32-gcc7.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-3adc6ddc72b36ea3b77eddf9ee4d6cfd
diff -pruN 1.3.1+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.x86_64-w64-mingw32-gcc7.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.x86_64-w64-mingw32-gcc7.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.x86_64-w64-mingw32-gcc7.tar.gz/sha512	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.x86_64-w64-mingw32-gcc7.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-71ca221448bbde73f277433ac4a51d96a58bec7ffffa19f0cf18208bd84429921abaa1a7b3b198d69bc165e3372fe15182a3f007bbc67584128d38963dd220dc
diff -pruN 1.3.1+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.x86_64-w64-mingw32-gcc8.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.x86_64-w64-mingw32-gcc8.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.x86_64-w64-mingw32-gcc8.tar.gz/md5	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.x86_64-w64-mingw32-gcc8.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-aa15f78375b270e87e51c628da2163ef
diff -pruN 1.3.1+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.x86_64-w64-mingw32-gcc8.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.x86_64-w64-mingw32-gcc8.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.x86_64-w64-mingw32-gcc8.tar.gz/sha512	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.x86_64-w64-mingw32-gcc8.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-f69a68890b563a0c71c6642754c0836387a24b316694022120347905f55bb9f0b6a9f2bb3235470a7ec30c452590fab7ebd0fc13ca53fe3a5a102c26c4a47371
diff -pruN 1.3.1+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.x86_64-w64-mingw32.tar.gz/md5 1.4.0+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.x86_64-w64-mingw32.tar.gz/md5
--- 1.3.1+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.x86_64-w64-mingw32.tar.gz/md5	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.x86_64-w64-mingw32.tar.gz/md5	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+9be054e1d6bf9c1099ee5b3bfbb5256d
diff -pruN 1.3.1+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.x86_64-w64-mingw32.tar.gz/sha512 1.4.0+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.x86_64-w64-mingw32.tar.gz/sha512
--- 1.3.1+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.x86_64-w64-mingw32.tar.gz/sha512	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/checksums/SuiteSparse.v5.4.0-2.x86_64-w64-mingw32.tar.gz/sha512	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1 @@
+a70796b5e2735ba1e70f37d113db858e6c69165939ee753787eb78624203d18d79e4ec588fb88398ba46feb157b9cc41866cba2005cc3985d8c4d8297f39aab0
diff -pruN 1.3.1+dfsg-1/deps/curl.mk 1.4.0+dfsg-1/deps/curl.mk
--- 1.3.1+dfsg-1/deps/curl.mk	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/curl.mk	2020-03-21 16:36:32.000000000 +0000
@@ -70,7 +70,7 @@ check-curl: $(BUILDDIR)/curl-$(CURL_VER)
 
 else # USE_BINARYBUILDER_CURL
 
-CURL_BB_URL_BASE := https://github.com/JuliaPackaging/Yggdrasil/releases/download/LibCURL-v$(CURL_VER)-$(CURL_BB_REL)
+CURL_BB_URL_BASE := https://github.com/JuliaBinaryWrappers/LibCURL_jll.jl/releases/download/LibCURL-v$(CURL_VER)+$(CURL_BB_REL)
 CURL_BB_NAME := LibCURL.v$(CURL_VER)
 
 $(eval $(call bb-install,curl,CURL,false))
diff -pruN 1.3.1+dfsg-1/deps/libgit2.mk 1.4.0+dfsg-1/deps/libgit2.mk
--- 1.3.1+dfsg-1/deps/libgit2.mk	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/libgit2.mk	2020-03-21 16:36:32.000000000 +0000
@@ -97,7 +97,7 @@ $(build_prefix)/manifest/libgit2: $(buil
 
 else # USE_BINARYBUILDER_LIBGIT2
 
-LIBGIT2_BB_URL_BASE := https://github.com/JuliaPackaging/Yggdrasil/releases/download/LibGit2-v$(LIBGIT2_VER)+$(LIBGIT2_BB_REL)
+LIBGIT2_BB_URL_BASE := https://github.com/JuliaBinaryWrappers/LibGit2_jll.jl/releases/download/LibGit2-v$(LIBGIT2_VER)+$(LIBGIT2_BB_REL)
 LIBGIT2_BB_NAME := LibGit2.v$(LIBGIT2_VER)
 $(eval $(call bb-install,libgit2,LIBGIT2,false))
 
diff -pruN 1.3.1+dfsg-1/deps/libssh2.mk 1.4.0+dfsg-1/deps/libssh2.mk
--- 1.3.1+dfsg-1/deps/libssh2.mk	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/libssh2.mk	2020-03-21 16:36:32.000000000 +0000
@@ -64,7 +64,7 @@ check-libssh2: $(BUILDDIR)/$(LIBSSH2_SRC
 
 else # USE_BINARYBUILDER_LIBSSH2
 
-LIBSSH2_BB_URL_BASE := https://github.com/JuliaPackaging/Yggdrasil/releases/download/LibSSH2-v$(LIBSSH2_VER)+$(LIBSSH2_BB_REL)
+LIBSSH2_BB_URL_BASE := https://github.com/JuliaBinaryWrappers/LibSSH2_jll.jl/releases/download/LibSSH2-v$(LIBSSH2_VER)+$(LIBSSH2_BB_REL)
 LIBSSH2_BB_NAME := LibSSH2.v$(LIBSSH2_VER)
 
 $(eval $(call bb-install,libssh2,LIBSSH2,false))
diff -pruN 1.3.1+dfsg-1/deps/libuv.mk 1.4.0+dfsg-1/deps/libuv.mk
--- 1.3.1+dfsg-1/deps/libuv.mk	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/libuv.mk	2020-03-21 16:36:32.000000000 +0000
@@ -42,7 +42,7 @@ $(LIBUV_BUILDDIR)/build-compiled: $(LIBU
 
 $(LIBUV_BUILDDIR)/build-checked: $(LIBUV_BUILDDIR)/build-compiled
 ifeq ($(OS),$(BUILD_OS))
-	-$(MAKE) -C $(dir $@) check
+	$(MAKE) -C $(dir $@) check
 endif
 	echo 1 > $@
 
diff -pruN 1.3.1+dfsg-1/deps/llvm.mk 1.4.0+dfsg-1/deps/llvm.mk
--- 1.3.1+dfsg-1/deps/llvm.mk	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/llvm.mk	2020-03-21 16:36:32.000000000 +0000
@@ -2,14 +2,7 @@
 include $(SRCDIR)/llvm-ver.make
 
 ifneq ($(USE_BINARYBUILDER_LLVM), 1)
-LLVM_GIT_URL_BASE ?= http://llvm.org/git
-LLVM_GIT_URL_LLVM ?= $(LLVM_GIT_URL_BASE)/llvm.git
-LLVM_GIT_URL_CLANG ?= $(LLVM_GIT_URL_BASE)/clang.git
-LLVM_GIT_URL_COMPILER_RT ?= $(LLVM_GIT_URL_BASE)/compiler-rt.git
-LLVM_GIT_URL_LLDB ?= $(LLVM_GIT_URL_BASE)/lldb.git
-LLVM_GIT_URL_LIBCXX ?= $(LLVM_GIT_URL_BASE)/libcxx.git
-LLVM_GIT_URL_LIBCXXABI ?= $(LLVM_GIT_URL_BASE)/libcxxabi.git
-LLVM_GIT_URL_POLLY ?= $(LLVM_GIT_URL_BASE)/polly.git
+LLVM_GIT_URL ?= https://github.com/llvm/llvm-project.git
 
 ifeq ($(BUILD_LLDB), 1)
 BUILD_LLVM_CLANG := 1
@@ -24,6 +17,18 @@ endif
 endif
 endif
 
+# for Monorepo
+LLVM_ENABLE_PROJECTS :=
+ifeq ($(BUILD_LLVM_CLANG), 1)
+LLVM_ENABLE_PROJECTS := $(LLVM_ENABLE_PROJECTS);clang;compiler-rt
+endif
+ifeq ($(USE_POLLY), 1)
+LLVM_ENABLE_PROJECTS := $(LLVM_ENABLE_PROJECTS);polly
+endif
+ifeq ($(BUILD_LLDB), 1)
+LLVM_ENABLE_PROJECTS := $(LLVM_ENABLE_PROJECTS);lldb
+endif
+
 include $(SRCDIR)/llvm-options.mk
 LLVM_LIB_FILE := libLLVMCodeGen.a
 
@@ -51,8 +56,7 @@ endif
 endif # LLVM_VER != svn
 
 # Figure out which targets to build
-LLVM_TARGETS := host;NVPTX;AMDGPU
-LLVM_EXPERIMENTAL_TARGETS := WebAssembly
+LLVM_TARGETS := host;NVPTX;AMDGPU;WebAssembly
 
 LLVM_CFLAGS :=
 LLVM_CXXFLAGS :=
@@ -60,12 +64,17 @@ LLVM_CPPFLAGS :=
 LLVM_LDFLAGS :=
 LLVM_CMAKE :=
 
+# MONOREPO
+ifeq ($(LLVM_VER),svn)
+LLVM_CMAKE += -DLLVM_ENABLE_PROJECTS="$(LLVM_ENABLE_PROJECTS)"
+endif
+
 # Allow adding LLVM specific flags
 LLVM_CFLAGS += $(CFLAGS)
 LLVM_CXXFLAGS += $(CXXFLAGS)
 LLVM_CPPFLAGS += $(CPPFLAGS)
 LLVM_LDFLAGS += $(LDFLAGS)
-LLVM_CMAKE += -DLLVM_TARGETS_TO_BUILD:STRING="$(LLVM_TARGETS)" -DLLVM_EXPERIMENTAL_TARGETS_TO_BUILD="$(LLVM_EXPERIMENTAL_TARGETS)" -DCMAKE_BUILD_TYPE="$(LLVM_CMAKE_BUILDTYPE)"
+LLVM_CMAKE += -DLLVM_TARGETS_TO_BUILD:STRING="$(LLVM_TARGETS)" -DCMAKE_BUILD_TYPE="$(LLVM_CMAKE_BUILDTYPE)"
 LLVM_CMAKE += -DLLVM_ENABLE_ZLIB=OFF -DLLVM_ENABLE_LIBXML2=OFF -DLLVM_HOST_TRIPLE="$(or $(XC_HOST),$(BUILD_MACHINE))"
 ifeq ($(USE_POLLY_ACC),1)
 LLVM_CMAKE += -DPOLLY_ENABLE_GPGPU_CODEGEN=ON
@@ -171,7 +180,17 @@ ifeq ($(BUILD_LLDB),0)
 LLVM_CMAKE += -DLLVM_TOOL_LLDB_BUILD=OFF
 endif
 
+ifneq ($(LLVM_VER),svn)
+ifeq (,$(findstring rc,$(LLVM_VER)))
+ifeq ($(shell [ x"$(LLVM_VER)" = x"8.0.1" ]; echo $$?),0)
+LLVM_SRC_URL := https://github.com/llvm/llvm-project/releases/download/llvmorg-$(LLVM_VER)
+else
 LLVM_SRC_URL := http://releases.llvm.org/$(LLVM_VER)
+endif
+else
+LLVM_VER_SPLIT := $(subst rc, ,$(LLVM_VER))
+LLVM_SRC_URL := https://prereleases.llvm.org/$(word 1,$(LLVM_VER_SPLIT))/rc$(word 2,$(LLVM_VER_SPLIT))
+endif
 
 ifneq ($(LLVM_CLANG_TAR),)
 $(LLVM_CLANG_TAR): | $(SRCCACHE)
@@ -199,6 +218,7 @@ ifeq ($(BUILD_LLDB),1)
 $(LLVM_SRC_DIR)/tools/lldb:
 $(LLVM_SRC_DIR)/source-extracted: $(LLVM_SRC_DIR)/tools/lldb
 endif
+endif
 
 # LLDB still relies on plenty of python 2.x infrastructure, without checking
 llvm_python_location=$(shell /usr/bin/env python2 -c 'import sys; print(sys.executable)')
@@ -233,27 +253,17 @@ else
 BUILT_UNWIND :=
 endif # Building libunwind
 
-$(LLVM_SRC_DIR)/projects/libcxx: $(LLVM_LIBCXX_TAR) | $(LLVM_SRC_DIR)/source-extracted
-	([ ! -d $@ ] && \
-	git clone $(LLVM_GIT_URL_LIBCXX) $@  ) || \
-	(cd $@  && \
-	git pull --ff-only)
-$(LLVM_SRC_DIR)/projects/libcxx/.git/HEAD: | $(LLVM_SRC_DIR)/projects/libcxx
-$(LLVM_SRC_DIR)/projects/libcxxabi: $(LLVM_LIBCXXABI_TAR) | $(LLVM_SRC_DIR)/source-extracted
-	([ ! -d $@ ] && \
-	git clone $(LLVM_GIT_URL_LIBCXXABI) $@ ) || \
-	(cd $@ && \
-	git pull --ff-only)
-$(LLVM_SRC_DIR)/projects/libcxxabi/.git/HEAD: | $(LLVM_SRC_DIR)/projects/libcxxabi
-$(LLVM_BUILD_DIR)/libcxx-build/Makefile: | $(LLVM_SRC_DIR)/projects/libcxx $(LLVM_SRC_DIR)/projects/libcxxabi $(BUILT_UNWIND)
+$(LIBCXX_ROOT_DIR)/libcxx: $(LLVM_LIBCXX_TAR) | $(LLVM_SRC_DIR)/source-extracted
+$(LIBCXX_ROOT_DIR)/libcxxabi: $(LLVM_LIBCXXABI_TAR) | $(LLVM_SRC_DIR)/source-extracted
+$(LLVM_BUILD_DIR)/libcxx-build/Makefile: | $(LIBCXX_ROOT_DIR)/libcxx $(LIBCXX_ROOT_DIR)/libcxxabi $(BUILT_UNWIND)
 	mkdir -p $(dir $@)
 	cd $(dir $@) && \
-		$(CMAKE) -G "Unix Makefiles" $(CMAKE_COMMON) $(LLVM_CMAKE_LIBCXX) -DLIBCXX_CXX_ABI=libcxxabi -DLIBCXX_CXX_ABI_INCLUDE_PATHS="$(LLVM_SRC_DIR)/projects/libcxxabi/include" $(LLVM_SRC_DIR)/projects/libcxx -DCMAKE_SHARED_LINKER_FLAGS="$(LDFLAGS) -L$(build_libdir) $(LIBCXX_EXTRA_FLAGS)"
-$(LLVM_BUILD_DIR)/libcxxabi-build/Makefile: | $(LLVM_SRC_DIR)/projects/libcxxabi $(LLVM_SRC_DIR)/projects/libcxx $(BUILT_UNWIND)
+		$(CMAKE) -G "Unix Makefiles" $(CMAKE_COMMON) $(LLVM_CMAKE_LIBCXX) -DLIBCXX_CXX_ABI=libcxxabi -DLIBCXX_CXX_ABI_INCLUDE_PATHS="$(LIBCXX_ROOT_DIR)/libcxxabi/include" $(LIBCXX_ROOT_DIR)/libcxx -DCMAKE_SHARED_LINKER_FLAGS="$(LDFLAGS) -L$(build_libdir) $(LIBCXX_EXTRA_FLAGS)"
+$(LLVM_BUILD_DIR)/libcxxabi-build/Makefile: | $(LIBCXX_ROOT_DIR)/libcxxabi $(LIBCXX_ROOT_DIR)/libcxx $(BUILT_UNWIND)
 	mkdir -p $(dir $@)
 	cd $(dir $@) && \
-		$(CMAKE) -G "Unix Makefiles" $(CMAKE_COMMON) $(LLVM_CMAKE_LIBCXX) -DLLVM_ABI_BREAKING_CHECKS="WITH_ASSERTS" -DLLVM_PATH="$(LLVM_SRC_DIR)" $(LLVM_SRC_DIR)/projects/libcxxabi -DLIBCXXABI_CXX_ABI_LIBRARIES="$(LIBCXX_EXTRA_FLAGS)" -DCMAKE_CXX_FLAGS="$(LLVM_CPPFLAGS) $(LLVM_CXXFLAGS) -std=c++11"
-$(LLVM_BUILD_DIR)/libcxxabi-build/lib/libc++abi.so.1.0: $(LLVM_BUILD_DIR)/libcxxabi-build/Makefile $(LLVM_SRC_DIR)/projects/libcxxabi/.git/HEAD
+		$(CMAKE) -G "Unix Makefiles" $(CMAKE_COMMON) $(LLVM_CMAKE_LIBCXX) -DLLVM_ABI_BREAKING_CHECKS="WITH_ASSERTS" -DLLVM_PATH="$(LLVM_SRC_DIR)" $(LIBCXX_ROOT_DIR)/libcxxabi -DLIBCXXABI_CXX_ABI_LIBRARIES="$(LIBCXX_EXTRA_FLAGS)" -DCMAKE_CXX_FLAGS="$(LLVM_CPPFLAGS) $(LLVM_CXXFLAGS) -std=c++11"
+$(LLVM_BUILD_DIR)/libcxxabi-build/lib/libc++abi.so.1.0: $(LLVM_BUILD_DIR)/libcxxabi-build/Makefile $(LIBCXX_ROOT_DIR)/libcxxabi/.git/HEAD
 	$(MAKE) -C $(LLVM_BUILD_DIR)/libcxxabi-build
 	touch -c $@
 $(build_libdir)/libc++abi.so.1.0: $(LLVM_BUILD_DIR)/libcxxabi-build/lib/libc++abi.so.1.0
@@ -261,21 +271,22 @@ $(build_libdir)/libc++abi.so.1.0: $(LLVM
 	touch -c $@
 	# Building this library installs these headers, which breaks other dependencies
 	-rm -rf $(build_includedir)/c++
-$(LLVM_BUILD_DIR)/libcxx-build/lib/libc++.so.1.0: $(build_libdir)/libc++abi.so.1.0 $(LLVM_BUILD_DIR)/libcxx-build/Makefile $(LLVM_SRC_DIR)/projects/libcxx/.git/HEAD
+$(LLVM_BUILD_DIR)/libcxx-build/lib/libc++.so.1.0: $(build_libdir)/libc++abi.so.1.0 $(LLVM_BUILD_DIR)/libcxx-build/Makefile $(LIBCXX_ROOT_DIR)/libcxx/.git/HEAD
 	$(MAKE) -C $(LLVM_BUILD_DIR)/libcxx-build
 $(build_libdir)/libc++.so.1.0: $(LLVM_BUILD_DIR)/libcxx-build/lib/libc++.so.1.0
 	$(MAKE) -C $(LLVM_BUILD_DIR)/libcxx-build install
 	touch -c $@
 	# Building this library installs these headers, which breaks other dependencies
 	-rm -rf $(build_includedir)/c++
-get-libcxx: $(LLVM_SRC_DIR)/projects/libcxx
-get-libcxxabi: $(LLVM_SRC_DIR)/projects/libcxxabi
+get-libcxx: $(LIBCXX_ROOT_DIR)/libcxx
+get-libcxxabi: $(LIBCXX_ROOT_DIR)/libcxxabi
 install-libcxxabi: $(build_libdir)/libc++abi.so.1.0
 install-libcxx: $(build_libdir)/libc++.so.1.0
 endif # BUILD_CUSTOM_LIBCXX
 
 # We want to be able to clean without having to pass BUILD_CUSTOM_LIBCXX=1, so define these
-# outside of the conditional above
+# outside of the conditional above, can't use `LIBCXX_ROOT_DIR` since that might come from
+# the monorepo.
 clean-libcxx:
 	-$(MAKE) -C $(LLVM_BUILD_DIR)/libcxx-build clean
 clean-libcxxabi:
@@ -290,6 +301,11 @@ distclean-libcxxabi:
 LLVM_CMAKE += -DCMAKE_EXE_LINKER_FLAGS="$(LLVM_LDFLAGS) $(LLVM_LIBCXX_LDFLAGS)" \
 	-DCMAKE_SHARED_LINKER_FLAGS="$(LLVM_LDFLAGS) $(LLVM_LIBCXX_LDFLAGS)"
 
+# change the SONAME of Julia's private LLVM
+# i.e. libLLVM-6.0jl.so
+# see #32462
+LLVM_CMAKE += -DLLVM_VERSION_SUFFIX:STRING="jl"
+
 ifeq ($(BUILD_CUSTOM_LIBCXX),1)
 LIBCXX_DEPENDENCY := $(build_libdir)/libc++abi.so.1.0 $(build_libdir)/libc++.so.1.0
 get-llvm: get-libcxx get-libcxxabi
@@ -316,12 +332,12 @@ ifneq ($(LLVM_VER),svn)
 	mkdir -p $(LLVM_SRC_DIR)
 	$(TAR) -C $(LLVM_SRC_DIR) --strip-components 1 -xf $(LLVM_TAR)
 else
-	([ ! -d $(LLVM_SRC_DIR) ] && \
-		git clone $(LLVM_GIT_URL_LLVM) $(LLVM_SRC_DIR) ) || \
-		(cd $(LLVM_SRC_DIR) && \
+	([ ! -d $(LLVM_MONOSRC_DIR) ] && \
+		git clone $(LLVM_GIT_URL) $(LLVM_MONOSRC_DIR) ) || \
+		(cd $(LLVM_MONOSRC_DIR) && \
 		git pull --ff-only)
 ifneq ($(LLVM_GIT_VER),)
-	(cd $(LLVM_SRC_DIR) && \
+	(cd $(LLVM_MONOSRC_DIR) && \
 		git checkout $(LLVM_GIT_VER))
 endif # LLVM_GIT_VER
 	# Debug output only. Disable pager and ignore error.
@@ -341,41 +357,6 @@ ifneq ($(LLVM_LLDB_TAR),)
 	mkdir -p $(LLVM_SRC_DIR)/tools/lldb
 	$(TAR) -C $(LLVM_SRC_DIR)/tools/lldb --strip-components 1 -xf $(LLVM_LLDB_TAR)
 endif # LLVM_LLDB_TAR
-else # LLVM_VER
-ifeq ($(BUILD_LLVM_CLANG),1)
-	([ ! -d $(LLVM_SRC_DIR)/tools/clang ] && \
-		git clone $(LLVM_GIT_URL_CLANG) $(LLVM_SRC_DIR)/tools/clang  ) || \
-		(cd $(LLVM_SRC_DIR)/tools/clang  && \
-		git pull --ff-only)
-	([ ! -d $(LLVM_SRC_DIR)/projects/compiler-rt ] && \
-		git clone $(LLVM_GIT_URL_COMPILER_RT) $(LLVM_SRC_DIR)/projects/compiler-rt  ) || \
-		(cd $(LLVM_SRC_DIR)/projects/compiler-rt  && \
-		git pull --ff-only)
-ifneq ($(LLVM_GIT_VER_CLANG),)
-	(cd $(LLVM_SRC_DIR)/tools/clang && \
-		git checkout $(LLVM_GIT_VER_CLANG))
-endif # LLVM_GIT_VER_CLANG
-endif # BUILD_LLVM_CLANG
-ifeq ($(BUILD_LLDB),1)
-	([ ! -d $(LLVM_SRC_DIR)/tools/lldb ] && \
-		git clone $(LLVM_GIT_URL_LLDB) $(LLVM_SRC_DIR)/tools/lldb  ) || \
-		(cd $(LLVM_SRC_DIR)/tools/lldb  && \
-		git pull --ff-only)
-ifneq ($(LLVM_GIT_VER_LLDB),)
-	(cd $(LLVM_SRC_DIR)/tools/lldb && \
-		git checkout $(LLVM_GIT_VER_LLDB))
-endif # LLVM_GIT_VER_CLANG
-endif # BUILD_LLDB
-ifeq ($(USE_POLLY),1)
-	([ ! -d $(LLVM_SRC_DIR)/tools/polly ] && \
-		git clone $(LLVM_GIT_URL_POLLY) $(LLVM_SRC_DIR)/tools/polly  ) || \
-		(cd $(LLVM_SRC_DIR)/tools/polly  && \
-		git pull --ff-only)
-ifneq ($(LLVM_GIT_VER_POLLY),)
-	(cd $(LLVM_SRC_DIR)/tools/polly && \
-		git checkout $(LLVM_GIT_VER_POLLY))
-endif # LLVM_GIT_VER_POLLY
-endif # USE_POLLY
 endif # LLVM_VER
 	# touch some extra files to ensure bisect works pretty well
 	touch -c $(LLVM_SRC_DIR).extracted
@@ -439,9 +420,9 @@ $(eval $(call LLVM_PATCH,llvm-D51842-win
 $(eval $(call LLVM_PATCH,llvm-D57118-powerpc))
 $(eval $(call LLVM_PATCH,llvm-r355582-avxminmax)) # remove for 8.0
 $(eval $(call LLVM_PATCH,llvm-rL349068-llvm-config)) # remove for 8.0
-$(eval $(call LLVM_PATCH,llvm-6.0-D63688-wasm-isLocal))
-$(eval $(call LLVM_PATCH,llvm-6.0-D64032-cmake-cross))
-$(eval $(call LLVM_PATCH,llvm-6.0-D64225-cmake-cross2))
+$(eval $(call LLVM_PATCH,llvm-6.0-D63688-wasm-isLocal)) # remove for 9.0
+$(eval $(call LLVM_PATCH,llvm-6.0-D64032-cmake-cross)) # remove for 9.0
+$(eval $(call LLVM_PATCH,llvm-6.0-D64225-cmake-cross2)) # remove for 9.0
 $(eval $(call LLVM_PATCH,llvm6-WASM-addrspaces)) # WebAssembly
 endif # LLVM_VER 6.0
 
@@ -459,6 +440,7 @@ $(eval $(call LLVM_PATCH,llvm7-D51842-wi
 $(eval $(call LLVM_PATCH,llvm-D57118-powerpc))
 $(eval $(call LLVM_PATCH,llvm-rL349068-llvm-config)) # remove for 8.0
 $(eval $(call LLVM_PATCH,llvm7-WASM-addrspaces)) # WebAssembly
+$(eval $(call LLVM_PATCH,llvm7-revert-D44485))
 endif # LLVM_VER 7.0
 
 ifeq ($(LLVM_VER_SHORT),8.0)
@@ -472,8 +454,35 @@ $(eval $(call LLVM_PATCH,llvm-8.0-D50167
 $(eval $(call LLVM_PATCH,llvm7-windows-race))
 $(eval $(call LLVM_PATCH,llvm-D57118-powerpc)) # remove for 9.0
 $(eval $(call LLVM_PATCH,llvm8-WASM-addrspaces)) # WebAssembly
+$(eval $(call LLVM_PATCH,llvm-exegesis-mingw)) # mingw build
+$(eval $(call LLVM_PATCH,llvm-test-plugin-mingw)) # mingw build
+$(eval $(call LLVM_PATCH,llvm-8.0-D66401-mingw-reloc)) # remove for 9.0
+$(eval $(call LLVM_PATCH,llvm7-revert-D44485))
+$(eval $(call LLVM_PATCH,llvm-8.0-D63688-wasm-isLocal)) # remove for 9.0
+$(eval $(call LLVM_PATCH,llvm-8.0-D55758-tablegen-cond)) # remove for 9.0
+$(eval $(call LLVM_PATCH,llvm-8.0-D59389-refactor-wmma)) # remove for 9.0
+$(eval $(call LLVM_PATCH,llvm-8.0-D59393-mma-ptx63-fix)) # remove for 9.0
+$(eval $(call LLVM_PATCH,llvm-8.0-D66657-codegen-degenerate)) # remove for 10.0
+$(eval $(call LLVM_PATCH,llvm-8.0-D71495-vectorize-freduce)) # remove for 10.0
 endif # LLVM_VER 8.0
 
+ifeq ($(LLVM_VER_SHORT),9.0)
+$(eval $(call LLVM_PATCH,llvm-D27629-AArch64-large_model_6.0.1))
+$(eval $(call LLVM_PATCH,llvm8-D34078-vectorize-fdiv))
+$(eval $(call LLVM_PATCH,llvm-6.0-NVPTX-addrspaces)) # NVPTX -- warning: this fails check-llvm-codegen-nvptx
+$(eval $(call LLVM_PATCH,llvm-7.0-D44650)) # mingw32 build fix
+$(eval $(call LLVM_PATCH,llvm-6.0-DISABLE_ABI_CHECKS))
+#$(eval $(call LLVM_PATCH,llvm7-D50010-VNCoercion-ni)) # TODO
+#$(eval $(call LLVM_PATCH,llvm7-windows-race)) # TODO
+$(eval $(call LLVM_PATCH,llvm8-WASM-addrspaces)) # WebAssembly
+$(eval $(call LLVM_PATCH,llvm-exegesis-mingw)) # mingw build
+$(eval $(call LLVM_PATCH,llvm-test-plugin-mingw)) # mingw build
+$(eval $(call LLVM_PATCH,llvm7-revert-D44485))
+$(eval $(call LLVM_PATCH,llvm-8.0-D66657-codegen-degenerate)) # remove for 10.0
+$(eval $(call LLVM_PATCH,llvm-8.0-D71495-vectorize-freduce)) # remove for 10.0
+endif # LLVM_VER 9.0
+
+
 # Add a JL prefix to the version map. DO NOT REMOVE
 ifneq ($(LLVM_VER), svn)
 ifeq ($(LLVM_VER_SHORT), 6.0)
@@ -552,22 +561,19 @@ check-llvm: $(LLVM_BUILDDIR_withtype)/bu
 
 ifeq ($(LLVM_VER),svn)
 update-llvm:
-	(cd $(LLVM_SRC_DIR); git pull --ff-only)
-	([ -d "$(LLVM_SRC_DIR)/tools/clang"  ] || exit 0;          cd $(LLVM_SRC_DIR)/tools/clang; git pull --ff-only)
-	([ -d "$(LLVM_SRC_DIR)/projects/compiler-rt" ] || exit 0;  cd $(LLVM_SRC_DIR)/projects/compiler-rt; git pull --ff-only)
-	([ -d "$(LLVM_SRC_DIR)/tools/lldb" ] || exit 0;            cd $(LLVM_SRC_DIR)/tools/lldb; git pull --ff-only)
-ifeq ($(USE_POLLY),1)
-	([ -d "$(LLVM_SRC_DIR)/tools/polly" ] || exit 0;           cd $(LLVM_SRC_DIR)/tools/polly; git pull --ff-only)
-endif
+	cd $(LLVM_MONOSRC_DIR) && \
+		git pull --ff-only
 endif
 else # USE_BINARYBUILDER_LLVM
-LLVM_BB_URL_BASE := https://github.com/JuliaPackaging/Yggdrasil/releases/download/LLVM-v$(LLVM_VER)-$(LLVM_BB_REL)
 ifneq ($(BINARYBUILDER_LLVM_ASSERTS), 1)
-LLVM_BB_NAME := LLVM.v$(LLVM_VER)
+LLVM_BB_REPO_NAME := LLVM_full
 else
+LLVM_BB_REPO_NAME := LLVM_full_assert
 LLVM_BB_NAME := LLVM.asserts.v$(LLVM_VER)
 endif
+LLVM_BB_NAME := $(LLVM_BB_REPO_NAME).v$(LLVM_VER)
+LLVM_BB_URL_BASE := https://github.com/JuliaBinaryWrappers/$(LLVM_BB_REPO_NAME)_jll.jl/releases/download/$(LLVM_BB_REPO_NAME)-v$(LLVM_VER)+$(LLVM_BB_REL)
 
-$(eval $(call bb-install,llvm,LLVM,true))
+$(eval $(call bb-install,llvm,LLVM,false,true))
 
 endif # USE_BINARYBUILDER_LLVM
diff -pruN 1.3.1+dfsg-1/deps/llvm-options.mk 1.4.0+dfsg-1/deps/llvm-options.mk
--- 1.3.1+dfsg-1/deps/llvm-options.mk	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/llvm-options.mk	2020-03-21 16:36:32.000000000 +0000
@@ -20,6 +20,15 @@ LLVM_BUILDTYPE := $(LLVM_BUILDTYPE)+ASAN
 endif
 endif
 
+
+ifeq ($(LLVM_VER),svn)
+LLVM_MONOSRC_DIR:=$(SRCCACHE)/llvm-project-$(LLVM_VER)
+LLVM_SRC_DIR:=$(LLVM_MONOSRC_DIR)/llvm
+LIBCXX_ROOT_DIR:=$(LLVM_MONOSRC_DIR)
+else
+LLVM_MONOSRC_DIR:=
 LLVM_SRC_DIR:=$(SRCCACHE)/llvm-$(LLVM_VER)
+LIBCXX_ROOT_DIR:=$(LLVM_SRC_DIR)/projects
+endif
 LLVM_BUILD_DIR:=$(BUILDDIR)/llvm-$(LLVM_VER)
 LLVM_BUILDDIR_withtype := $(LLVM_BUILD_DIR)/build_$(LLVM_BUILDTYPE)
diff -pruN 1.3.1+dfsg-1/deps/Makefile 1.4.0+dfsg-1/deps/Makefile
--- 1.3.1+dfsg-1/deps/Makefile	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/Makefile	2020-03-21 16:36:32.000000000 +0000
@@ -23,19 +23,14 @@ BUILDDIR := $(BUILDDIR)$(MAYBE_HOST)
 # additionally all targets should be listed in the getall target for easier off-line compilation
 # if you are adding a new target, it can help to copy an similar, existing target
 #
-# autoconf configure-driven scripts: llvm pcre unwind gmp mpfr patchelf libuv curl
+# autoconf configure-driven scripts: pcre unwind gmp mpfr patchelf libuv curl
 # custom Makefile rules: openlibm dsfmt suitesparse-wrapper suitesparse lapack openblas utf8proc objconv osxunwind libwhich
-# CMake libs: libgit2 libssh2 mbedtls
+# CMake libs: llvm libgit2 libssh2 mbedtls
 #
-# downloaded from git: llvm-svn, libuv, libopenlibm, utf8proc, libgit2, libssh2
-#
-# there are rules in this file with the . replaced by a %
-# this is some magic Makefile trick that tells make
-# that all targets with a % in them on that line will
-# be rebuilt in a single invocation
+# downloadable via git: llvm-svn, libuv, libopenlibm, utf8proc, libgit2, libssh2
 #
 # to debug 'define' rules, replace eval at the usage site with info or error
-#
+
 
 ## Overall configuration of which rules exist and should be run by default ##
 
@@ -162,7 +157,7 @@ ifneq ($(OS), WINNT)
 DEP_LIBS += libwhich
 endif
 
-DEP_LIBS_STAGED := $(filter-out suitesparse suitesparse-wrapper osxunwind,$(DEP_LIBS)) # unlist targets that have not been converted to use the staged-install
+DEP_LIBS_STAGED := $(filter-out suitesparse-wrapper osxunwind,$(DEP_LIBS)) # unlist targets that have not been converted to use the staged-install
 
 
 ## Common build target prefixes
@@ -176,7 +171,6 @@ check: $(addprefix check-, $(DEP_LIBS))
 fastcheck: $(addprefix fastcheck-, $(DEP_LIBS))
 stage: $(addprefix stage-, $(DEP_LIBS_STAGED))
 install: $(addprefix install-, $(DEP_LIBS))
-uninstall: $(addprefix uninstall-, $(DEP_LIBS_STAGED))
 cleanall: $(addprefix clean-, $(DEP_LIBS))
 distcleanall: $(addprefix distclean-, $(DEP_LIBS))
 	rm -rf $(build_prefix)
@@ -202,3 +196,5 @@ include $(SRCDIR)/libgit2.mk
 include $(SRCDIR)/libwhich.mk
 include $(SRCDIR)/zlib.mk
 include $(SRCDIR)/p7zip.mk
+
+include $(SRCDIR)/tools/uninstallers.mk
diff -pruN 1.3.1+dfsg-1/deps/mbedtls.mk 1.4.0+dfsg-1/deps/mbedtls.mk
--- 1.3.1+dfsg-1/deps/mbedtls.mk	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/mbedtls.mk	2020-03-21 16:36:32.000000000 +0000
@@ -90,7 +90,7 @@ check-mbedtls: $(BUILDDIR)/$(MBEDTLS_SRC
 
 else # USE_BINARYBUILDER_MBEDTLS
 
-MBEDTLS_BB_URL_BASE := https://github.com/JuliaWeb/MbedTLSBuilder/releases/download/$(MBEDTLS_BB_REL)
+MBEDTLS_BB_URL_BASE := https://github.com/JuliaBinaryWrappers/MbedTLS_jll.jl/releases/download/MbedTLS-v$(MBEDTLS_VER)+$(MBEDTLS_BB_REL)
 MBEDTLS_BB_NAME := MbedTLS.v$(MBEDTLS_VER)
 
 $(eval $(call bb-install,mbedtls,MBEDTLS,false))
diff -pruN 1.3.1+dfsg-1/deps/patches/llvm7-revert-D44485.patch 1.4.0+dfsg-1/deps/patches/llvm7-revert-D44485.patch
--- 1.3.1+dfsg-1/deps/patches/llvm7-revert-D44485.patch	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/patches/llvm7-revert-D44485.patch	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1,94 @@
+From 4370214628487ac8495f963ae05960b5ecc31103 Mon Sep 17 00:00:00 2001
+From: Jameson Nash <vtjnash@gmail.com>
+Date: Thu, 12 Sep 2019 11:45:07 -0400
+Subject: [PATCH] Revert "[MC] Always emit relocations for same-section
+ function references"
+
+This reverts commit 9232972575cafac29c3e4817c8714c9aca0e8585.
+---
+ lib/MC/WinCOFFObjectWriter.cpp | 12 +++++-------
+ test/MC/COFF/diff.s            | 25 ++++++++-----------------
+ 2 files changed, 13 insertions(+), 24 deletions(-)
+
+diff --git a/lib/MC/WinCOFFObjectWriter.cpp b/lib/MC/WinCOFFObjectWriter.cpp
+index 9ffecd99df6..0214161e03c 100644
+--- a/lib/MC/WinCOFFObjectWriter.cpp
++++ b/lib/MC/WinCOFFObjectWriter.cpp
+@@ -690,14 +690,12 @@ void WinCOFFObjectWriter::executePostLayoutBinding(MCAssembler &Asm,
+ bool WinCOFFObjectWriter::isSymbolRefDifferenceFullyResolvedImpl(
+     const MCAssembler &Asm, const MCSymbol &SymA, const MCFragment &FB,
+     bool InSet, bool IsPCRel) const {
+-  // Don't drop relocations between functions, even if they are in the same text
+-  // section. Multiple Visual C++ linker features depend on having the
+-  // relocations present. The /INCREMENTAL flag will cause these relocations to
+-  // point to thunks, and the /GUARD:CF flag assumes that it can use relocations
+-  // to approximate the set of all address taken functions. LLD's implementation
+-  // of /GUARD:CF also relies on the existance of these relocations.
++  // MS LINK expects to be able to replace all references to a function with a
++  // thunk to implement their /INCREMENTAL feature.  Make sure we don't optimize
++  // away any relocations to functions.
+   uint16_t Type = cast<MCSymbolCOFF>(SymA).getType();
+-  if ((Type >> COFF::SCT_COMPLEX_TYPE_SHIFT) == COFF::IMAGE_SYM_DTYPE_FUNCTION)
++  if (Asm.isIncrementalLinkerCompatible() &&
++      (Type >> COFF::SCT_COMPLEX_TYPE_SHIFT) == COFF::IMAGE_SYM_DTYPE_FUNCTION)
+     return false;
+   return MCObjectWriter::isSymbolRefDifferenceFullyResolvedImpl(Asm, SymA, FB,
+                                                                 InSet, IsPCRel);
+diff --git a/test/MC/COFF/diff.s b/test/MC/COFF/diff.s
+index f89e4ed8901..d68e628577b 100644
+--- a/test/MC/COFF/diff.s
++++ b/test/MC/COFF/diff.s
+@@ -1,14 +1,19 @@
+ // RUN: llvm-mc -filetype=obj -triple i686-pc-mingw32 %s | llvm-readobj -s -sr -sd | FileCheck %s
+ 
+-// COFF resolves differences between labels in the same section, unless that
+-// label is declared with function type.
+-
+ .section baz, "xr"
++	.def	X
++	.scl	2;
++	.type	32;
++	.endef
+ 	.globl	X
+ X:
+ 	mov	Y-X+42,	%eax
+ 	retl
+ 
++	.def	Y
++	.scl	2;
++	.type	32;
++	.endef
+ 	.globl	Y
+ Y:
+ 	retl
+@@ -25,11 +30,6 @@ _foobar:                                # @foobar
+ # %bb.0:
+ 	ret
+ 
+-	.globl	_baz
+-_baz:
+-	calll	_foobar
+-	retl
+-
+ 	.data
+ 	.globl	_rust_crate             # @rust_crate
+ 	.align	4
+@@ -39,15 +39,6 @@ _rust_crate:
+ 	.long	_foobar-_rust_crate
+ 	.long	_foobar-_rust_crate
+ 
+-// Even though _baz and _foobar are in the same .text section, we keep the
+-// relocation for compatibility with the VC linker's /guard:cf and /incremental
+-// flags, even on mingw.
+-
+-// CHECK:        Name: .text
+-// CHECK:        Relocations [
+-// CHECK-NEXT:     0x12 IMAGE_REL_I386_REL32 _foobar
+-// CHECK-NEXT:   ]
+-
+ // CHECK:        Name: .data
+ // CHECK:        Relocations [
+ // CHECK-NEXT:     0x4 IMAGE_REL_I386_DIR32 _foobar
+-- 
+2.17.1
+
diff -pruN 1.3.1+dfsg-1/deps/patches/llvm-8.0-D55758-tablegen-cond.patch 1.4.0+dfsg-1/deps/patches/llvm-8.0-D55758-tablegen-cond.patch
--- 1.3.1+dfsg-1/deps/patches/llvm-8.0-D55758-tablegen-cond.patch	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/patches/llvm-8.0-D55758-tablegen-cond.patch	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1,794 @@
+From 95135c5a18ee14ca091d3513cc7801521d4eb204 Mon Sep 17 00:00:00 2001
+From: Javed Absar <javed.absar@arm.com>
+Date: Fri, 25 Jan 2019 10:25:25 +0000
+Subject: [PATCH] [TblGen] Extend !if semantics through new feature !cond
+
+This patch extends TableGen language with !cond operator.
+Instead of embedding !if inside !if which can get cumbersome,
+one can now use !cond.
+Below is an example to convert an integer 'x' into a string:
+
+    !cond(!lt(x,0) : "Negative",
+          !eq(x,0) : "Zero",
+          !eq(x,1) : "One,
+          1        : "MoreThanOne")
+
+Reviewed By: hfinkel, simon_tatham, greened
+Differential Revision: https://reviews.llvm.org/D55758
+
+llvm-svn: 352185
+---
+ docs/TableGen/LangIntro.rst          |  14 +++
+ docs/TableGen/LangRef.rst            |  10 +-
+ include/llvm/TableGen/Record.h       |  78 ++++++++++++++++
+ lib/TableGen/Record.cpp              | 131 +++++++++++++++++++++++++++
+ lib/TableGen/TGLexer.cpp             |   1 +
+ lib/TableGen/TGLexer.h               |   2 +-
+ lib/TableGen/TGParser.cpp            |  90 ++++++++++++++++++
+ lib/TableGen/TGParser.h              |   1 +
+ test/TableGen/cond-bitlist.td        |  27 ++++++
+ test/TableGen/cond-default.td        |  11 +++
+ test/TableGen/cond-empty-list-arg.td |   8 ++
+ test/TableGen/cond-inheritance.td    |  22 +++++
+ test/TableGen/cond-let.td            |  36 ++++++++
+ test/TableGen/cond-list.td           |  38 ++++++++
+ test/TableGen/cond-subclass.td       |  27 ++++++
+ test/TableGen/cond-type.td           |  11 +++
+ test/TableGen/cond-usage.td          |  29 ++++++
+ test/TableGen/condsbit.td            |  15 +++
+ 18 files changed, 549 insertions(+), 2 deletions(-)
+ create mode 100644 llvm/test/TableGen/cond-bitlist.td
+ create mode 100644 llvm/test/TableGen/cond-default.td
+ create mode 100644 llvm/test/TableGen/cond-empty-list-arg.td
+ create mode 100644 llvm/test/TableGen/cond-inheritance.td
+ create mode 100644 llvm/test/TableGen/cond-let.td
+ create mode 100644 llvm/test/TableGen/cond-list.td
+ create mode 100644 llvm/test/TableGen/cond-subclass.td
+ create mode 100644 llvm/test/TableGen/cond-type.td
+ create mode 100644 llvm/test/TableGen/cond-usage.td
+ create mode 100644 llvm/test/TableGen/condsbit.td
+
+diff --git a/docs/TableGen/LangIntro.rst b/docs/TableGen/LangIntro.rst
+index ea46550ffc0..390f941f0ca 100644
+--- a/docs/TableGen/LangIntro.rst
++++ b/docs/TableGen/LangIntro.rst
+@@ -258,6 +258,20 @@ supported include:
+ ``!if(a,b,c)``
+   'b' if the result of 'int' or 'bit' operator 'a' is nonzero, 'c' otherwise.
+ 
++``!cond(condition_1 : val1, condition_2 : val2, ..., condition_n : valn)``
++    Instead of embedding !if inside !if which can get cumbersome,
++    one can use !cond. !cond returns 'val1' if the result of 'int' or 'bit'
++    operator 'condition1' is nonzero. Otherwise, it checks 'condition2'.
++    If 'condition2' is nonzero, returns 'val2', and so on.
++    If all conditions are zero, it reports an error.
++
++    Below is an example to convert an integer 'x' into a string:
++
++    !cond(!lt(x,0) : "Negative",
++          !eq(x,0) : "Zero",
++          !eq(x,1) : "One,
++          1        : "MoreThanOne")
++
+ ``!eq(a,b)``
+     'bit 1' if string a is equal to string b, 0 otherwise.  This only operates
+     on string, int and bit objects.  Use !cast<string> to compare other types of
+diff --git a/docs/TableGen/LangRef.rst b/docs/TableGen/LangRef.rst
+index 2efee12ec9d..a3dbf363151 100644
+--- a/docs/TableGen/LangRef.rst
++++ b/docs/TableGen/LangRef.rst
+@@ -102,6 +102,12 @@ wide variety of meanings:
+                :!isa    !dag     !le      !lt        !ge
+                :!gt     !ne
+ 
++TableGen also has !cond operator that needs a slightly different
++syntax compared to other "bang operators":
++
++.. productionlist::
++   CondOperator: !cond
++
+ 
+ Syntax
+ ======
+@@ -140,7 +146,7 @@ considered to define the class if any of the following is true:
+ #. The :token:`Body` in the :token:`ObjectBody` is present and is not empty.
+ #. The :token:`BaseClassList` in the :token:`ObjectBody` is present.
+ 
+-You can declare an empty class by giving and empty :token:`TemplateArgList`
++You can declare an empty class by giving an empty :token:`TemplateArgList`
+ and an empty :token:`ObjectBody`. This can serve as a restricted form of
+ forward declaration: note that records deriving from the forward-declared
+ class will inherit no fields from it since the record expansion is done
+@@ -315,6 +321,8 @@ The initial :token:`DagArg` is called the "operator" of the dag.
+ 
+ .. productionlist::
+    SimpleValue: `BangOperator` ["<" `Type` ">"] "(" `ValueListNE` ")"
++              :| `CondOperator` "(" `CondVal` ("," `CondVal`)* ")"
++   CondVal: `Value` ":" `Value`
+ 
+ Bodies
+ ------
+diff --git a/include/llvm/TableGen/Record.h b/include/llvm/TableGen/Record.h
+index e022bc82b4e..3ca67ec72bd 100644
+--- a/include/llvm/TableGen/Record.h
++++ b/include/llvm/TableGen/Record.h
+@@ -316,6 +316,7 @@ protected:
+     IK_TernOpInit,
+     IK_UnOpInit,
+     IK_LastOpInit,
++    IK_CondOpInit,
+     IK_FoldOpInit,
+     IK_IsAOpInit,
+     IK_StringInit,
+@@ -912,6 +913,83 @@ public:
+   std::string getAsString() const override;
+ };
+ 
++/// !cond(condition_1: value1, ... , condition_n: value)
++/// Selects the first value for which condition is true.
++/// Otherwise reports an error.
++class CondOpInit final : public TypedInit, public FoldingSetNode,
++                      public TrailingObjects<CondOpInit, Init *> {
++  unsigned NumConds;
++  RecTy *ValType;
++
++  CondOpInit(unsigned NC, RecTy *Type)
++    : TypedInit(IK_CondOpInit, Type),
++      NumConds(NC), ValType(Type) {}
++
++  size_t numTrailingObjects(OverloadToken<Init *>) const {
++    return 2*NumConds;
++  }
++
++public:
++  CondOpInit(const CondOpInit &) = delete;
++  CondOpInit &operator=(const CondOpInit &) = delete;
++
++  static bool classof(const Init *I) {
++    return I->getKind() == IK_CondOpInit;
++  }
++
++  static CondOpInit *get(ArrayRef<Init*> C, ArrayRef<Init*> V,
++                        RecTy *Type);
++
++  void Profile(FoldingSetNodeID &ID) const;
++
++  RecTy *getValType() const { return ValType; }
++
++  unsigned getNumConds() const { return NumConds; }
++
++  Init *getCond(unsigned Num) const {
++    assert(Num < NumConds && "Condition number out of range!");
++    return getTrailingObjects<Init *>()[Num];
++  }
++
++  Init *getVal(unsigned Num) const {
++    assert(Num < NumConds && "Val number out of range!");
++    return getTrailingObjects<Init *>()[Num+NumConds];
++  }
++
++  ArrayRef<Init *> getConds() const {
++    return makeArrayRef(getTrailingObjects<Init *>(), NumConds);
++  }
++
++  ArrayRef<Init *> getVals() const {
++    return makeArrayRef(getTrailingObjects<Init *>()+NumConds, NumConds);
++  }
++
++  Init *Fold(Record *CurRec) const;
++
++  Init *resolveReferences(Resolver &R) const override;
++
++  bool isConcrete() const override;
++  bool isComplete() const override;
++  std::string getAsString() const override;
++
++  using const_case_iterator = SmallVectorImpl<Init*>::const_iterator;
++  using const_val_iterator = SmallVectorImpl<Init*>::const_iterator;
++
++  inline const_case_iterator  arg_begin() const { return getConds().begin(); }
++  inline const_case_iterator  arg_end  () const { return getConds().end(); }
++
++  inline size_t              case_size () const { return NumConds; }
++  inline bool                case_empty() const { return NumConds == 0; }
++
++  inline const_val_iterator name_begin() const { return getVals().begin();}
++  inline const_val_iterator name_end  () const { return getVals().end(); }
++
++  inline size_t              val_size () const { return NumConds; }
++  inline bool                val_empty() const { return NumConds == 0; }
++
++  Init *getBit(unsigned Bit) const override;
++};
++
+ /// !foldl (a, b, expr, start, lst) - Fold over a list.
+ class FoldOpInit : public TypedInit, public FoldingSetNode {
+ private:
+diff --git a/lib/TableGen/Record.cpp b/lib/TableGen/Record.cpp
+index cf1685a2e8c..26ffe761b66 100644
+--- a/lib/TableGen/Record.cpp
++++ b/lib/TableGen/Record.cpp
+@@ -1694,6 +1694,137 @@ Init *FieldInit::Fold(Record *CurRec) const {
+   return const_cast<FieldInit *>(this);
+ }
+ 
++static void ProfileCondOpInit(FoldingSetNodeID &ID,
++                             ArrayRef<Init *> CondRange,
++                             ArrayRef<Init *> ValRange,
++                             const RecTy *ValType) {
++  assert(CondRange.size() == ValRange.size() &&
++         "Number of conditions and values must match!");
++  ID.AddPointer(ValType);
++  ArrayRef<Init *>::iterator Case = CondRange.begin();
++  ArrayRef<Init *>::iterator Val = ValRange.begin();
++
++  while (Case != CondRange.end()) {
++    ID.AddPointer(*Case++);
++    ID.AddPointer(*Val++);
++  }
++}
++
++void CondOpInit::Profile(FoldingSetNodeID &ID) const {
++  ProfileCondOpInit(ID,
++      makeArrayRef(getTrailingObjects<Init *>(), NumConds),
++      makeArrayRef(getTrailingObjects<Init *>() + NumConds, NumConds),
++      ValType);
++}
++
++CondOpInit *
++CondOpInit::get(ArrayRef<Init *> CondRange,
++                ArrayRef<Init *> ValRange, RecTy *Ty) {
++  assert(CondRange.size() == ValRange.size() &&
++         "Number of conditions and values must match!");
++
++  static FoldingSet<CondOpInit> ThePool;
++  FoldingSetNodeID ID;
++  ProfileCondOpInit(ID, CondRange, ValRange, Ty);
++
++  void *IP = nullptr;
++  if (CondOpInit *I = ThePool.FindNodeOrInsertPos(ID, IP))
++    return I;
++
++  void *Mem = Allocator.Allocate(totalSizeToAlloc<Init *>(2*CondRange.size()),
++                                 alignof(BitsInit));
++  CondOpInit *I = new(Mem) CondOpInit(CondRange.size(), Ty);
++
++  std::uninitialized_copy(CondRange.begin(), CondRange.end(),
++                          I->getTrailingObjects<Init *>());
++  std::uninitialized_copy(ValRange.begin(), ValRange.end(),
++                          I->getTrailingObjects<Init *>()+CondRange.size());
++  ThePool.InsertNode(I, IP);
++  return I;
++}
++
++Init *CondOpInit::resolveReferences(Resolver &R) const {
++  SmallVector<Init*, 4> NewConds;
++  bool Changed = false;
++  for (const Init *Case : getConds()) {
++    Init *NewCase = Case->resolveReferences(R);
++    NewConds.push_back(NewCase);
++    Changed |= NewCase != Case;
++  }
++
++  SmallVector<Init*, 4> NewVals;
++  for (const Init *Val : getVals()) {
++    Init *NewVal = Val->resolveReferences(R);
++    NewVals.push_back(NewVal);
++    Changed |= NewVal != Val;
++  }
++
++  if (Changed)
++    return (CondOpInit::get(NewConds, NewVals,
++            getValType()))->Fold(R.getCurrentRecord());
++
++  return const_cast<CondOpInit *>(this);
++}
++
++Init *CondOpInit::Fold(Record *CurRec) const {
++  for ( unsigned i = 0; i < NumConds; ++i) {
++    Init *Cond = getCond(i);
++    Init *Val = getVal(i);
++
++    if (IntInit *CondI = dyn_cast_or_null<IntInit>(
++            Cond->convertInitializerTo(IntRecTy::get()))) {
++      if (CondI->getValue())
++        return Val->convertInitializerTo(getValType());
++    } else
++     return const_cast<CondOpInit *>(this);
++  }
++
++  PrintFatalError(CurRec->getLoc(),
++                  CurRec->getName() +
++                  " does not have any true condition in:" +
++                  this->getAsString());
++  return nullptr;
++}
++
++bool CondOpInit::isConcrete() const {
++  for (const Init *Case : getConds())
++    if (!Case->isConcrete())
++      return false;
++
++  for (const Init *Val : getVals())
++    if (!Val->isConcrete())
++      return false;
++
++  return true;
++}
++
++bool CondOpInit::isComplete() const {
++  for (const Init *Case : getConds())
++    if (!Case->isComplete())
++      return false;
++
++  for (const Init *Val : getVals())
++    if (!Val->isConcrete())
++      return false;
++
++  return true;
++}
++
++std::string CondOpInit::getAsString() const {
++  std::string Result = "!cond(";
++  for (unsigned i = 0; i < getNumConds(); i++) {
++    Result += getCond(i)->getAsString() + ": ";
++    Result += getVal(i)->getAsString();
++    if (i != getNumConds()-1)
++      Result += ", ";
++  }
++  return Result + ")";
++}
++
++Init *CondOpInit::getBit(unsigned Bit) const {
++  return VarBitInit::get(const_cast<CondOpInit *>(this), Bit);
++}
++
+ static void ProfileDagInit(FoldingSetNodeID &ID, Init *V, StringInit *VN,
+                            ArrayRef<Init *> ArgRange,
+                            ArrayRef<StringInit *> NameRange) {
+diff --git a/lib/TableGen/TGLexer.cpp b/lib/TableGen/TGLexer.cpp
+index 16aeee56107..f733cc3c134 100644
+--- a/lib/TableGen/TGLexer.cpp
++++ b/lib/TableGen/TGLexer.cpp
+@@ -545,6 +545,7 @@ tgtok::TokKind TGLexer::LexExclaim() {
+     .Case("ge", tgtok::XGe)
+     .Case("gt", tgtok::XGt)
+     .Case("if", tgtok::XIf)
++    .Case("cond", tgtok::XCond)
+     .Case("isa", tgtok::XIsA)
+     .Case("head", tgtok::XHead)
+     .Case("tail", tgtok::XTail)
+diff --git a/lib/TableGen/TGLexer.h b/lib/TableGen/TGLexer.h
+index e9980b36b97..9bdb01cf3dd 100644
+--- a/lib/TableGen/TGLexer.h
++++ b/lib/TableGen/TGLexer.h
+@@ -51,7 +51,7 @@ namespace tgtok {
+ 
+     // !keywords.
+     XConcat, XADD, XAND, XOR, XSRA, XSRL, XSHL, XListConcat, XStrConcat, XCast,
+-    XSubst, XForEach, XFoldl, XHead, XTail, XSize, XEmpty, XIf, XEq, XIsA, XDag,
++    XSubst, XForEach, XFoldl, XHead, XTail, XSize, XEmpty, XIf, XCond, XEq, XIsA, XDag,
+     XNe, XLe, XLt, XGe, XGt,
+ 
+     // Integer value.
+diff --git a/lib/TableGen/TGParser.cpp b/lib/TableGen/TGParser.cpp
+index 1d1f3603c83..200190acd59 100644
+--- a/lib/TableGen/TGParser.cpp
++++ b/lib/TableGen/TGParser.cpp
+@@ -1445,6 +1445,9 @@ Init *TGParser::ParseOperation(Record *CurRec, RecTy *ItemType) {
+     return (TernOpInit::get(Code, LHS, MHS, RHS, Type))->Fold(CurRec);
+   }
+ 
++  case tgtok::XCond:
++    return ParseOperationCond(CurRec, ItemType);
++
+   case tgtok::XFoldl: {
+     // Value ::= !foldl '(' Id ',' Id ',' Value ',' Value ',' Value ')'
+     Lex.Lex(); // eat the operation
+@@ -1603,6 +1606,91 @@ RecTy *TGParser::ParseOperatorType() {
+   return Type;
+ }
+ 
++Init *TGParser::ParseOperationCond(Record *CurRec, RecTy *ItemType) {
++  Lex.Lex();  // eat the operation 'cond'
++
++  if (Lex.getCode() != tgtok::l_paren) {
++     TokError("expected '(' after !cond operator");
++     return nullptr;
++  }
++  Lex.Lex();  // eat the '('
++
++  // Parse through '[Case: Val,]+'
++  SmallVector<Init *, 4> Case;
++  SmallVector<Init *, 4> Val;
++  while (true) {
++    if (Lex.getCode() == tgtok::r_paren) {
++      Lex.Lex(); // eat the ')'
++      break;
++    }
++
++    Init *V = ParseValue(CurRec);
++    if (!V)
++      return nullptr;
++    Case.push_back(V);
++
++    if (Lex.getCode() != tgtok::colon) {
++      TokError("expected ':'  following a condition in !cond operator");
++      return nullptr;
++    }
++    Lex.Lex(); // eat the ':'
++
++    V = ParseValue(CurRec, ItemType);
++    if (!V)
++      return nullptr;
++    Val.push_back(V);
++
++    if (Lex.getCode() == tgtok::r_paren) {
++      Lex.Lex(); // eat the ')'
++      break;
++    }
++
++    if (Lex.getCode() != tgtok::comma) {
++      TokError("expected ',' or ')' following a value in !cond operator");
++      return nullptr;
++    }
++    Lex.Lex();  // eat the ','
++  }
++
++  if (Case.size() < 1) {
++    TokError("there should be at least 1 'condition : value' in the !cond operator");
++    return nullptr;
++  }
++
++  // resolve type
++  RecTy *Type = nullptr;
++  for (Init *V : Val) {
++    RecTy *VTy = nullptr;
++    if (TypedInit *Vt = dyn_cast<TypedInit>(V))
++      VTy = Vt->getType();
++    if (BitsInit *Vbits = dyn_cast<BitsInit>(V))
++      VTy = BitsRecTy::get(Vbits->getNumBits());
++    if (isa<BitInit>(V))
++      VTy = BitRecTy::get();
++
++    if (Type == nullptr) {
++      if (!isa<UnsetInit>(V))
++        Type = VTy;
++    } else {
++      if (!isa<UnsetInit>(V)) {
++        RecTy *RType = resolveTypes(Type, VTy);
++        if (!RType) {
++          TokError(Twine("inconsistent types '") + Type->getAsString() +
++                         "' and '" + VTy->getAsString() + "' for !cond");
++          return nullptr;
++        }
++        Type = RType;
++      }
++    }
++  }
++
++  if (!Type) {
++    TokError("could not determine type for !cond from its arguments");
++    return nullptr;
++  }
++  return CondOpInit::get(Case, Val, Type)->Fold(CurRec);
++}
++
+ /// ParseSimpleValue - Parse a tblgen value.  This returns null on error.
+ ///
+ ///   SimpleValue ::= IDValue
+@@ -1621,6 +1709,7 @@ RecTy *TGParser::ParseOperatorType() {
+ ///   SimpleValue ::= SRLTOK '(' Value ',' Value ')'
+ ///   SimpleValue ::= LISTCONCATTOK '(' Value ',' Value ')'
+ ///   SimpleValue ::= STRCONCATTOK '(' Value ',' Value ')'
++///   SimpleValue ::= COND '(' [Value ':' Value,]+ ')'
+ ///
+ Init *TGParser::ParseSimpleValue(Record *CurRec, RecTy *ItemType,
+                                  IDParseMode Mode) {
+@@ -1933,6 +2022,7 @@ Init *TGParser::ParseSimpleValue(Record *CurRec, RecTy *ItemType,
+   case tgtok::XListConcat:
+   case tgtok::XStrConcat:   // Value ::= !binop '(' Value ',' Value ')'
+   case tgtok::XIf:
++  case tgtok::XCond:
+   case tgtok::XFoldl:
+   case tgtok::XForEach:
+   case tgtok::XSubst: {  // Value ::= !ternop '(' Value ',' Value ',' Value ')'
+diff --git a/lib/TableGen/TGParser.h b/lib/TableGen/TGParser.h
+index e3849043513..215b9dad770 100644
+--- a/lib/TableGen/TGParser.h
++++ b/lib/TableGen/TGParser.h
+@@ -194,6 +194,7 @@ private:  // Parser methods.
+   bool ParseRangePiece(SmallVectorImpl<unsigned> &Ranges);
+   RecTy *ParseType();
+   Init *ParseOperation(Record *CurRec, RecTy *ItemType);
++  Init *ParseOperationCond(Record *CurRec, RecTy *ItemType);
+   RecTy *ParseOperatorType();
+   Init *ParseObjectName(MultiClass *CurMultiClass);
+   Record *ParseClassID();
+diff --git a/test/TableGen/cond-bitlist.td b/test/TableGen/cond-bitlist.td
+new file mode 100644
+index 00000000000..bce615838df
+--- /dev/null
++++ b/test/TableGen/cond-bitlist.td
+@@ -0,0 +1,27 @@
++// RUN: llvm-tblgen %s | FileCheck %s
++// XFAIL: vg_leak
++
++class S<int s> {
++  bits<2> val = !cond(!eq(s, 8):  {0, 0},
++                      !eq(s, 16): 0b01,
++                      !eq(s, 32): 2,
++                      !eq(s, 64): {1, 1},
++                              1 : ?);
++}
++
++def D8  : S<8>;
++def D16 : S<16>;
++def D32 : S<32>;
++def D64 : S<64>;
++def D128: S<128>;
++// CHECK: def D128
++// CHECK-NEXT: bits<2> val = { ?, ? };
++// CHECK: def D16
++// CHECK-NEXT: bits<2> val = { 0, 1 };
++// CHECK: def D32
++// CHECK-NEXT: bits<2> val = { 1, 0 };
++// CHECK: def D64
++// CHECK-NEXT: bits<2> val = { 1, 1 };
++// CHECK: def D8
++// CHECK-NEXT: bits<2> val = { 0, 0 };
++
+diff --git a/test/TableGen/cond-default.td b/test/TableGen/cond-default.td
+new file mode 100644
+index 00000000000..816bf10676f
+--- /dev/null
++++ b/test/TableGen/cond-default.td
+@@ -0,0 +1,11 @@
++// Check that not specifying a valid condition results in error
++
++// RUN: not llvm-tblgen %s 2>&1 | FileCheck %s
++// XFAIL: vg_leak
++
++class C<int x> {
++  string s  = !cond(!lt(x,0) : "negative", !gt(x,0) : "positive");
++}
++
++def Zero : C<0>;
++//CHECK: error: Zero does not have any true condition in:!cond(0: "negative", 0: "positive")
+diff --git a/test/TableGen/cond-empty-list-arg.td b/test/TableGen/cond-empty-list-arg.td
+new file mode 100644
+index 00000000000..5f4ccade169
+--- /dev/null
++++ b/test/TableGen/cond-empty-list-arg.td
+@@ -0,0 +1,8 @@
++// RUN: llvm-tblgen %s
++// XFAIL: vg_leak
++
++class C<bit cond> {
++  bit true = 1;
++  list<int> X = !cond(cond: [1, 2, 3], true : []);
++  list<int> Y = !cond(cond: [], true : [4, 5, 6]);
++}
+diff --git a/test/TableGen/cond-inheritance.td b/test/TableGen/cond-inheritance.td
+new file mode 100644
+index 00000000000..4b4abdf72f3
+--- /dev/null
++++ b/test/TableGen/cond-inheritance.td
+@@ -0,0 +1,22 @@
++// Make sure !cond gets propagated across multiple layers of inheritance.
++// RUN: llvm-tblgen %s | FileCheck %s
++// XFAIL: vg_leak
++
++class getInt<int c> {
++  int ret = !cond(c: 0, 1 : 1);
++}
++
++class I1<int c> {
++  int i = getInt<c>.ret;
++}
++
++class I2<int c> : I1<c>;
++
++def DI1: I1<1>;
++// CHECK: def DI1 {     // I1
++// CHECK-NEXT: int i = 0;
++
++// CHECK: def DI2 {     // I1 I2
++// CHECK-NEXT: int i = 0;
++def DI2: I2<1>;
++
+diff --git a/test/TableGen/cond-let.td b/test/TableGen/cond-let.td
+new file mode 100644
+index 00000000000..044878f2ab8
+--- /dev/null
++++ b/test/TableGen/cond-let.td
+@@ -0,0 +1,36 @@
++// Check support for `!cond' operator as part of a `let' statement.
++// RUN: llvm-tblgen %s | FileCheck %s
++// XFAIL: vg_leak
++
++
++class C<bits<3> x, bits<4> y, bit z> {
++  bits<16> n;
++
++  let n{11}  = !cond(y{3}: 1,
++                     y{2}: x{0},
++                     y{1}: x{1},
++                     y{0}: x{2},
++                     {1} :?);
++  let n{10-9}= !cond(x{2}: y{3-2},
++                     x{1}: y{2-1},
++                     x{1}: y{1-0},
++                     {1} : ?);
++  let n{8-6} = !cond(x{2}: 0b010,  1 : 0b110);
++  let n{5-4} = !cond(x{1}: y{3-2}, 1 :  {0, 1});
++  let n{3-0} = !cond(x{0}: y{3-0}, 1 : {z, y{2}, y{1}, y{0}});
++}
++
++
++def C1 : C<{1, 0, 1}, {0, 1, 0, 1}, 0>;
++def C2 : C<{0, 1, 0}, {1, 0, 1, 0}, 1>;
++def C3 : C<{0, 0, 0}, {1, 0, 1, 0}, 0>;
++def C4 : C<{0, 0, 0}, {0, 0, 0, 0}, 0>;
++
++// CHECK: def C1
++// CHECK-NEXT: bits<16> n = { ?, ?, ?, ?, 1, 0, 1, 0, 1, 0, 0, 1, 0, 1, 0, 1 };
++// CHECK: def C2
++// CHECK-NEXT: bits<16> n = { ?, ?, ?, ?, 1, 0, 1, 1, 1, 0, 1, 0, 1, 0, 1, 0 };
++// CHECK: def C3
++// CHECK-NEXT: bits<16> n = { ?, ?, ?, ?, 1, ?, ?, 1, 1, 0, 0, 1, 0, 0, 1, 0 };
++// CHECK: def C4
++// CHECK-NEXT: bits<16> n = { ?, ?, ?, ?, ?, ?, ?, 1, 1, 0, 0, 1, 0, 0, 0, 0 };
+diff --git a/test/TableGen/cond-list.td b/test/TableGen/cond-list.td
+new file mode 100644
+index 00000000000..aa013cea4e1
+--- /dev/null
++++ b/test/TableGen/cond-list.td
+@@ -0,0 +1,38 @@
++// RUN: llvm-tblgen %s | FileCheck %s
++// XFAIL: vg_leak
++
++
++class A<list<list<int>> vals> {
++  list<int> first = vals[0];
++  list<int> rest  = !cond(!empty(!tail(vals)): vals[0],
++                          1                 : vals[1]);
++}
++
++def A_OneEl : A<[[1,2,3]]>;
++// CHECK:      def A_OneEl {  // A
++// CHECK-NEXT: list<int> first = [1, 2, 3];
++// CHECK-NEXT: list<int> rest = [1, 2, 3];
++// CHECK-NEXT: }
++
++def A_TwoEl : A<[[1,2,3], [4,5,6]]>;
++// CHECK:      def A_TwoEl { // A
++// CHECK-NEXT: list<int> first = [1, 2, 3];
++// CHECK-NEXT: list<int> rest = [4, 5, 6];
++// CHECK-NEXT: }
++
++
++class B<list<int> v> {
++  list<int> vals = v;
++}
++class BB<list<list<int>> vals> : B<!cond(!empty(!tail(vals)): vals[0],  1 : vals[1])>;
++class BBB<list<list<int>> vals> : BB<vals>;
++
++def B_OneEl : BBB<[[1,2,3]]>;
++// CHECK:      def B_OneEl { //  B BB BBB
++// CHECK-NEXT: list<int> vals = [1, 2, 3];
++// CHECK-NEXT: }
++
++def B_TwoEl : BBB<[[1,2,3],[4,5,6]]>;
++// CHECK:      def B_TwoEl { // B BB BBB
++// CHECK-NEXT: list<int> vals = [4, 5, 6];
++// CHECK-NEXT: }
+diff --git a/test/TableGen/cond-subclass.td b/test/TableGen/cond-subclass.td
+new file mode 100644
+index 00000000000..9f6f6e2cb8c
+--- /dev/null
++++ b/test/TableGen/cond-subclass.td
+@@ -0,0 +1,27 @@
++// Check that !cond with operands of different subtypes can
++// initialize a supertype variable.
++// RUN: llvm-tblgen %s | FileCheck %s
++// XFAIL: vg_leak
++
++class E<int dummy> {}
++class E1<int dummy> : E<dummy> {}
++class E2<int dummy> : E<dummy> {}
++
++class EX<int cc, E1 b, E2 c> {
++  E x = !cond(cc: b, 1 : c);
++}
++
++def E1d : E1<0>;
++def E2d : E2<0>;
++
++def EXd1 : EX<1, E1d, E2d>;
++def EXd2 : EX<0, E1d, E2d>;
++
++// CHECK: def EXd1 {
++// CHECK:   E x = E1d;
++// CHECK: }
++//
++// CHECK: def EXd2 {
++// CHECK:   E x = E2d;
++// CHECK: }
++
+diff --git a/test/TableGen/cond-type.td b/test/TableGen/cond-type.td
+new file mode 100644
+index 00000000000..fd2a3cc52b7
+--- /dev/null
++++ b/test/TableGen/cond-type.td
+@@ -0,0 +1,11 @@
++// RUN: not llvm-tblgen %s 2>&1 | FileCheck %s
++// XFAIL: vg_leak
++
++class A<int dummy> {}
++class B<int dummy> : A<dummy> {}
++class C<int dummy> : A<dummy> {}
++
++// CHECK: Value 'x' of type 'C' is incompatible with initializer '{{.*}}' of type 'A'
++class X<int cc, B b, C c> {
++  C x = !cond(cc: b, 1 : c);
++}
+diff --git a/test/TableGen/cond-usage.td b/test/TableGen/cond-usage.td
+new file mode 100644
+index 00000000000..055fd6d7c69
+--- /dev/null
++++ b/test/TableGen/cond-usage.td
+@@ -0,0 +1,29 @@
++// RUN: llvm-tblgen %s | FileCheck %s
++// XFAIL: vg_leak
++
++// Check that !cond picks the first true value
++// CHECK:       class A
++// CHECK-NEXT:  string S = !cond(!eq(A:x, 10): "ten", !eq(A:x, 11): "eleven", !eq(A:x, 10): "TEN", !gt(A:x, 9): "MoreThanNine", 1: "unknown"); 
++// CHECK: B1
++// CHECK-NEXT: string S = "unknown"
++// CHECK: B10
++// CHECK-NEXT: string S = "ten";
++// CHECK: def B11
++// CHECK-NEXT: string S = "eleven";
++// CHECK: def B12
++// CHECK-NEXT:  string S = "MoreThanNine";
++// CHECK: def B9
++// CHECK-NEXT: string S = "unknown"
++
++class A<int x> {
++  string S = !cond(!eq(x,10) : "ten",
++                   !eq(x,11) : "eleven",
++                   !eq(x,10) : "TEN",
++                   !gt(x,9) : "MoreThanNine",
++                   !eq(1,1) : "unknown");
++}
++def B1  : A<1>;
++def B9  : A<9>;
++def B10 : A<10>;
++def B11 : A<11>;
++def B12 : A<12>;
+diff --git a/test/TableGen/condsbit.td b/test/TableGen/condsbit.td
+new file mode 100644
+index 00000000000..e08ac97f68b
+--- /dev/null
++++ b/test/TableGen/condsbit.td
+@@ -0,0 +1,15 @@
++// check that !cond works well with bit conditional values
++// RUN: llvm-tblgen %s | FileCheck %s
++// XFAIL: vg_leak
++// CHECK: a = 6
++// CHECK: a = 5
++
++class A<bit b = 1> {
++  bit true = 1;
++  int a = !cond(b: 5, true : 6);
++  bit c = !cond(b: 0, true : 1);
++  bits<1> d = !cond(b: 0, true : 1);
++}
++
++def X : A<0>;
++def Y : A;
+-- 
+2.17.1
+
diff -pruN 1.3.1+dfsg-1/deps/patches/llvm-8.0-D59389-refactor-wmma.patch 1.4.0+dfsg-1/deps/patches/llvm-8.0-D59389-refactor-wmma.patch
--- 1.3.1+dfsg-1/deps/patches/llvm-8.0-D59389-refactor-wmma.patch	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/patches/llvm-8.0-D59389-refactor-wmma.patch	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1,899 @@
+From e9737bf498597707d084398b9485676dc7421644 Mon Sep 17 00:00:00 2001
+From: Artem Belevich <tra@google.com>
+Date: Thu, 25 Apr 2019 22:27:35 +0000
+Subject: [PATCH] [NVPTX] Refactor generation of MMA intrinsics and
+ instructions. NFC.
+
+Generalized constructions of 'fragments' of MMA operations to provide
+common primitives for construction of the ops. This will make it easier
+to add new variants of the instructions that operate on integer types.
+
+Use nested foreach loops which makes it possible to better control
+naming of the intrinsics.
+
+This patch does not affect LLVM's output, so there are no test changes.
+
+Differential Revision: https://reviews.llvm.org/D59389
+
+llvm-svn: 359245
+---
+ include/llvm/IR/IntrinsicsNVVM.td   | 258 ++++++--------
+ lib/Target/NVPTX/NVPTXIntrinsics.td | 512 ++++++++++------------------
+ 2 files changed, 295 insertions(+), 475 deletions(-)
+
+diff --git a/include/llvm/IR/IntrinsicsNVVM.td b/include/llvm/IR/IntrinsicsNVVM.td
+index 7f694f68969..e30a27613a6 100644
+--- a/include/llvm/IR/IntrinsicsNVVM.td
++++ b/include/llvm/IR/IntrinsicsNVVM.td
+@@ -38,6 +38,69 @@ def llvm_anyi64ptr_ty     : LLVMAnyPointerType<llvm_i64_ty>;     // (space)i64*
+ // MISC
+ //
+ 
++// Helper class for construction of n-element list<LLVMtype> [t,t,...,t]
++class RepLLVMType<int N, LLVMType T> {
++  list<LLVMType> ret = !if(N, !listconcat(RepLLVMType<!add(N,-1), T>.ret, [T]), []);
++}
++
++// Helper class that represents a 'fragment' of an NVPTX *MMA instruction.
++// Geom: m<M>n<N>k<K>. E.g. m8n32k16
++// Frag: [abcd]
++// PtxEltType: PTX type for the element.
++class WMMA_REGS<string Geom, string Frag, string PtxEltType> {
++  string geom = Geom;
++  string frag = Frag;
++  string ptx_elt_type = PtxEltType;
++  string ft = frag#":"#ptx_elt_type;
++  list<LLVMType> regs = !cond(
++    // fp16 -> fp16/fp32 @  m16n16k16/m8n32k16/m32n8k16
++    // All currently supported geometries use the same fragment format,
++    // so we only need to consider {fragment, type}.
++    !eq(ft,"a:f16") : RepLLVMType<8, llvm_v2f16_ty>.ret,
++    !eq(ft,"b:f16") : RepLLVMType<8, llvm_v2f16_ty>.ret,
++    !eq(ft,"c:f16") : RepLLVMType<4, llvm_v2f16_ty>.ret,
++    !eq(ft,"d:f16") : RepLLVMType<4, llvm_v2f16_ty>.ret,
++    !eq(ft,"c:f32") : RepLLVMType<8, llvm_float_ty>.ret,
++    !eq(ft,"d:f32") : RepLLVMType<8, llvm_float_ty>.ret);
++}
++
++class WMMA_NAME_LDST<string Op, WMMA_REGS Frag, string Layout, int WithStride> {
++  string intr = "llvm.nvvm.wmma."
++                # Frag.geom
++                # "." # Op
++                # "." # Frag.frag
++                # "." # Layout
++                # !if(WithStride, ".stride", "")
++                # "." # Frag.ptx_elt_type
++                ;
++  // TODO(tra): record name should ideally use the same field order as the intrinsic.
++  // E.g. string record = !subst("llvm", "int",
++  //                      !subst(".", "_", llvm));
++  string record = "int_nvvm_wmma_"
++                # Frag.geom
++                # "_" # Op
++                # "_" # Frag.frag
++                # "_" # Frag.ptx_elt_type
++                # "_" # Layout
++                # !if(WithStride, "_stride", "");
++}
++
++class WMMA_NAME_MMA<string ALayout, string BLayout,
++                    WMMA_REGS C, WMMA_REGS D,
++                    int Satfinite> {
++  string llvm = "llvm.nvvm.wmma."
++                # C.geom
++                # ".mma"
++                # "." # ALayout
++                # "." # BLayout
++                # "." # D.ptx_elt_type  // Intrinsic encodes 'd' first.
++                # "." # C.ptx_elt_type
++                # !if(Satfinite, ".satfinite", "");
++
++  string record = !subst(".", "_",
++                  !subst("llvm.", "int_", llvm));
++}
++
+ let TargetPrefix = "nvvm" in {
+   def int_nvvm_prmt : GCCBuiltin<"__nvvm_prmt">,
+       Intrinsic<[llvm_i32_ty], [llvm_i32_ty, llvm_i32_ty, llvm_i32_ty],
+@@ -3882,166 +3945,69 @@ def int_nvvm_match_all_sync_i64p :
+ //
+ // WMMA instructions
+ //
+-
+ // WMMA.LOAD
+-class NVVM_WMMA_LD_GALSTS<string Geometry, string Abc, string Layout,
+-                          string Type, LLVMType regty, int WithStride>
+-  : Intrinsic<!if(!eq(Abc#Type,"cf16"),
+-                  [regty, regty, regty, regty],
+-                  [regty, regty, regty, regty,
+-                   regty, regty, regty, regty]),
++class NVVM_WMMA_LD<WMMA_REGS Frag, string Layout, int WithStride>
++  : Intrinsic<Frag.regs,
+               !if(WithStride, [llvm_anyptr_ty, llvm_i32_ty], [llvm_anyptr_ty]),
+               [IntrReadMem, IntrArgMemOnly, ReadOnly<0>, NoCapture<0>],
+-              "llvm.nvvm.wmma."
+-                # Geometry
+-                # ".load"
+-                # "." # Abc
+-                # "." # Layout
+-                # !if(WithStride, ".stride", "")
+-                # "." # Type>;
+-
+-multiclass NVVM_WMMA_LD_GALT<string Geometry, string Abc, string Layout,
+-                             string Type, LLVMType regty> {
+-  def _stride: NVVM_WMMA_LD_GALSTS<Geometry, Abc, Layout, Type, regty, 1>;
+-  def NAME   : NVVM_WMMA_LD_GALSTS<Geometry, Abc, Layout, Type, regty, 0>;
+-}
+-
+-multiclass NVVM_WMMA_LD_GAT<string Geometry, string Abc,
+-                           string Type, LLVMType regty> {
+-  defm _row: NVVM_WMMA_LD_GALT<Geometry, Abc, "row", Type, regty>;
+-  defm _col: NVVM_WMMA_LD_GALT<Geometry, Abc, "col", Type, regty>;
+-}
+-
+-multiclass NVVM_WMMA_LD_G<string Geometry> {
+-  defm _a_f16: NVVM_WMMA_LD_GAT<Geometry, "a", "f16", llvm_v2f16_ty>;
+-  defm _b_f16: NVVM_WMMA_LD_GAT<Geometry, "b", "f16", llvm_v2f16_ty>;
+-  defm _c_f16: NVVM_WMMA_LD_GAT<Geometry, "c", "f16", llvm_v2f16_ty>;
+-  defm _c_f32: NVVM_WMMA_LD_GAT<Geometry, "c", "f32", llvm_float_ty>;
+-}
+-
+-multiclass NVVM_WMMA_LD {
+-  defm _m32n8k16_load: NVVM_WMMA_LD_G<"m32n8k16">;
+-  defm _m16n16k16_load: NVVM_WMMA_LD_G<"m16n16k16">;
+-  defm _m8n32k16_load: NVVM_WMMA_LD_G<"m8n32k16">;
+-}
+-
+-defm int_nvvm_wmma: NVVM_WMMA_LD;
++              WMMA_NAME_LDST<"load", Frag, Layout, WithStride>.intr>;
+ 
+ // WMMA.STORE.D
+-class NVVM_WMMA_STD_GLSTS<string Geometry, string Layout,
+-                          string Type, LLVMType regty, int WithStride,
+-                          // This is only used to create a typed empty array we
+-                          // need to pass to !if below.
+-                          list<LLVMType>Empty=[]>
++class NVVM_WMMA_ST<WMMA_REGS Frag, string Layout, int WithStride>
+   : Intrinsic<[],
+               !listconcat(
+                 [llvm_anyptr_ty],
+-                !if(!eq(Type,"f16"),
+-                    [regty, regty, regty, regty],
+-                    [regty, regty, regty, regty,
+-                     regty, regty, regty, regty]),
+-                !if(WithStride, [llvm_i32_ty], Empty)),
++                Frag.regs,
++                !if(WithStride, [llvm_i32_ty], [])),
+               [IntrWriteMem, IntrArgMemOnly, WriteOnly<0>, NoCapture<0>],
+-              "llvm.nvvm.wmma."
+-                   # Geometry
+-                   # ".store.d"
+-                   # "." # Layout
+-                   # !if(WithStride, ".stride", "")
+-                   # "." # Type>;
+-
+-multiclass NVVM_WMMA_STD_GLT<string Geometry, string Layout,
+-                             string Type, LLVMType regty> {
+-  def _stride: NVVM_WMMA_STD_GLSTS<Geometry, Layout, Type, regty, 1>;
+-  def NAME:    NVVM_WMMA_STD_GLSTS<Geometry, Layout, Type, regty, 0>;
+-}
+-
+-multiclass NVVM_WMMA_STD_GT<string Geometry, string Type, LLVMType regty> {
+-  defm _row: NVVM_WMMA_STD_GLT<Geometry, "row", Type, regty>;
+-  defm _col: NVVM_WMMA_STD_GLT<Geometry, "col", Type, regty>;
+-}
+-multiclass NVVM_WMMA_STD_G<string Geometry> {
+-  defm _d_f16: NVVM_WMMA_STD_GT<Geometry, "f16", llvm_v2f16_ty>;
+-  defm _d_f32: NVVM_WMMA_STD_GT<Geometry, "f32", llvm_float_ty>;
+-}
+-
+-multiclass NVVM_WMMA_STD {
+-  defm _m32n8k16_store:  NVVM_WMMA_STD_G<"m32n8k16">;
+-  defm _m16n16k16_store: NVVM_WMMA_STD_G<"m16n16k16">;
+-  defm _m8n32k16_store:  NVVM_WMMA_STD_G<"m8n32k16">;
++              WMMA_NAME_LDST<"store", Frag, Layout, WithStride>.intr>;
++
++// Create all load/store variants 
++foreach geom = ["m16n16k16", "m32n8k16", "m8n32k16" ] in {
++  foreach layout = ["row", "col"] in {
++    foreach stride = [0, 1] in {
++      foreach frag = [WMMA_REGS<geom, "a", "f16">,
++                      WMMA_REGS<geom, "b", "f16">,
++                      WMMA_REGS<geom, "c", "f16">,
++                      WMMA_REGS<geom, "c", "f32">] in {
++          def WMMA_NAME_LDST<"load", frag, layout, stride>.record
++             : NVVM_WMMA_LD<frag, layout, stride>;
++      }
++      foreach frag = [WMMA_REGS<geom, "d", "f16">,
++                      WMMA_REGS<geom, "d", "f32">] in {
++          def WMMA_NAME_LDST<"store", frag, layout, stride>.record
++             : NVVM_WMMA_ST<frag, layout, stride>;
++      }
++    }
++  }
+ }
+ 
+-defm int_nvvm_wmma: NVVM_WMMA_STD;
+-
+ // WMMA.MMA
+-class NVVM_WMMA_MMA_GABDCS<string Geometry,
+-                           string ALayout, string BLayout,
+-                           string DType, LLVMType d_regty,
+-                           string CType, LLVMType c_regty,
+-                           string Satfinite = "">
+-  : Intrinsic<!if(!eq(DType,"f16"),
+-                      [d_regty, d_regty, d_regty, d_regty],
+-                      [d_regty, d_regty, d_regty, d_regty,
+-                       d_regty, d_regty, d_regty, d_regty]),
++class NVVM_WMMA_MMA<string ALayout, string BLayout,
++                    WMMA_REGS C, WMMA_REGS D, int Satfinite>
++  : Intrinsic<D.regs,
+               !listconcat(
+-                [// A
+-                llvm_v2f16_ty, llvm_v2f16_ty, llvm_v2f16_ty, llvm_v2f16_ty,
+-                llvm_v2f16_ty, llvm_v2f16_ty, llvm_v2f16_ty, llvm_v2f16_ty,
+-                // B
+-                llvm_v2f16_ty, llvm_v2f16_ty, llvm_v2f16_ty, llvm_v2f16_ty,
+-                llvm_v2f16_ty, llvm_v2f16_ty, llvm_v2f16_ty, llvm_v2f16_ty],
+-                !if(!eq(CType,"f16"),
+-                      [c_regty, c_regty, c_regty, c_regty],
+-                      [c_regty, c_regty, c_regty, c_regty,
+-                       c_regty, c_regty, c_regty, c_regty])),
++                WMMA_REGS<C.geom, "a", "f16">.regs,
++                WMMA_REGS<C.geom, "b", "f16">.regs,
++                C.regs),
+               [IntrNoMem],
+-              "llvm.nvvm.wmma."
+-                # Geometry
+-                # ".mma"
+-                # "." # ALayout
+-                # "." # BLayout
+-                # "." # DType
+-                # "." # CType
+-                # Satfinite> {
+-}
+-
+-multiclass NVVM_WMMA_MMA_GABDC<string Geometry, string ALayout, string BLayout,
+-                               string DType, LLVMType d_regty,
+-                               string CType, LLVMType c_regty> {
+-  def NAME : NVVM_WMMA_MMA_GABDCS<Geometry, ALayout, BLayout,
+-                                  DType, d_regty, CType, c_regty>;
+-  def _satfinite: NVVM_WMMA_MMA_GABDCS<Geometry, ALayout, BLayout,
+-                                       DType, d_regty, CType, c_regty,".satfinite">;
+-}
+-
+-multiclass NVVM_WMMA_MMA_GABD<string Geometry, string ALayout, string BLayout,
+-                              string DType, LLVMType d_regty> {
+-  defm _f16: NVVM_WMMA_MMA_GABDC<Geometry, ALayout, BLayout, DType, d_regty,
+-                                "f16", llvm_v2f16_ty>;
+-  defm _f32: NVVM_WMMA_MMA_GABDC<Geometry, ALayout, BLayout, DType, d_regty,
+-                                "f32", llvm_float_ty>;
+-}
+-
+-multiclass NVVM_WMMA_MMA_GAB<string Geometry, string ALayout, string BLayout> {
+-  defm _f16: NVVM_WMMA_MMA_GABD<Geometry, ALayout, BLayout, "f16", llvm_v2f16_ty>;
+-  defm _f32: NVVM_WMMA_MMA_GABD<Geometry, ALayout, BLayout, "f32", llvm_float_ty>;
+-}
+-
+-multiclass NVVM_WMMA_MMA_GA<string Geometry, string ALayout> {
+-  defm _col: NVVM_WMMA_MMA_GAB<Geometry, ALayout, "col">;
+-  defm _row: NVVM_WMMA_MMA_GAB<Geometry, ALayout, "row">;
+-}
+-
+-multiclass NVVM_WMMA_MMA_G<string Geometry> {
+-  defm _col: NVVM_WMMA_MMA_GA<Geometry, "col">;
+-  defm _row: NVVM_WMMA_MMA_GA<Geometry, "row">;
+-}
+-
+-multiclass NVVM_WMMA_MMA {
+-  defm _m32n8k16_mma : NVVM_WMMA_MMA_G<"m32n8k16">;
+-  defm _m16n16k16_mma : NVVM_WMMA_MMA_G<"m16n16k16">;
+-  defm _m8n32k16_mma : NVVM_WMMA_MMA_G<"m8n32k16">;
++              WMMA_NAME_MMA<ALayout, BLayout, C, D, Satfinite>.llvm>;
++
++foreach geom = ["m16n16k16", "m32n8k16", "m8n32k16" ] in {
++  foreach layout_a = ["row", "col"] in {
++    foreach layout_b = ["row", "col"] in {
++      foreach frag_c = [WMMA_REGS<geom, "c", "f16">,
++                        WMMA_REGS<geom, "c", "f32">] in {
++        foreach frag_d = [WMMA_REGS<geom, "d", "f16">,
++                          WMMA_REGS<geom, "d", "f32">] in {
++          foreach satf = [0, 1] in {
++            def WMMA_NAME_MMA<layout_a, layout_b, frag_c, frag_d, satf>.record
++             : NVVM_WMMA_MMA<layout_a, layout_b, frag_c, frag_d, satf>;
++          }
++        }
++      }
++    }
++  }
+ }
+ 
+-defm int_nvvm_wmma : NVVM_WMMA_MMA;
+-
+ } // let TargetPrefix = "nvvm"
+diff --git a/lib/Target/NVPTX/NVPTXIntrinsics.td b/lib/Target/NVPTX/NVPTXIntrinsics.td
+index 47dcdcf6e0b..b9a67ba5ed3 100644
+--- a/lib/Target/NVPTX/NVPTXIntrinsics.td
++++ b/lib/Target/NVPTX/NVPTXIntrinsics.td
+@@ -27,7 +27,17 @@ def immDouble1 : PatLeaf<(fpimm), [{
+     return (d==1.0);
+ }]>;
+ 
+-
++def AS_match {
++  code generic = [{
++   return ChkMemSDNodeAddressSpace(N, llvm::ADDRESS_SPACE_GENERIC);
++  }];
++  code shared = [{
++   return ChkMemSDNodeAddressSpace(N, llvm::ADDRESS_SPACE_SHARED);
++  }];
++  code global = [{
++   return ChkMemSDNodeAddressSpace(N, llvm::ADDRESS_SPACE_GLOBAL);
++  }];
++}
+ 
+ //-----------------------------------
+ // Synchronization and shuffle functions
+@@ -1007,17 +1017,11 @@ def INT_FNS_iii : INT_FNS_MBO<(ins    i32imm:$mask,    i32imm:$base,    i32imm:$
+ //-----------------------------------
+ 
+ class ATOMIC_GLOBAL_CHK <dag ops, dag frag>
+- : PatFrag<ops, frag, [{
+-   return ChkMemSDNodeAddressSpace(N, llvm::ADDRESS_SPACE_GLOBAL);
+-}]>;
++ : PatFrag<ops, frag, AS_match.global>;
+ class ATOMIC_SHARED_CHK <dag ops, dag frag>
+- : PatFrag<ops, frag, [{
+-   return ChkMemSDNodeAddressSpace(N, llvm::ADDRESS_SPACE_SHARED);
+-}]>;
++ : PatFrag<ops, frag, AS_match.shared>;
+ class ATOMIC_GENERIC_CHK <dag ops, dag frag>
+- : PatFrag<ops, frag, [{
+-   return ChkMemSDNodeAddressSpace(N, llvm::ADDRESS_SPACE_GENERIC);
+-}]>;
++ : PatFrag<ops, frag, AS_match.generic>;
+ 
+ multiclass F_ATOMIC_2_imp<NVPTXRegClass ptrclass, NVPTXRegClass regclass,
+   string SpaceStr, string TypeStr, string OpcStr, PatFrag IntOp,
+@@ -7381,36 +7385,60 @@ def INT_PTX_SREG_WARPSIZE :
+     NVPTXInst<(outs Int32Regs:$dst), (ins), "mov.u32 \t$dst, WARP_SZ;",
+               [(set Int32Regs:$dst, (int_nvvm_read_ptx_sreg_warpsize))]>;
+ 
+-//
+-// wmma.load.[a|b|c].sync.[row|col].m16n16k16[|.global|.shared].[f16|f32]
+-//
+-
+ class EmptyNVPTXInst : NVPTXInst<(outs), (ins), "?", []>;
++// Generates list of n sequential register names.
++class RegSeq<int n, string prefix> {
++  list<string> ret = !if(n, !listconcat(RegSeq<!add(n,-1), prefix>.ret,
++                                        [prefix # !add(n, -1)]),
++                            []);
++}
+ 
+-class WMMA_LOAD_GALSTOS<string Geometry, string Abc, string Layout,
+-                        string Space, string Type, NVPTXRegClass regclass,
+-                        DAGOperand SrcOp, bit WithStride>
+-  : EmptyNVPTXInst,
+-    Requires<[!if(!eq(Geometry, "m16n16k16"),
+-                  hasPTX60,
+-                  hasPTX61),
+-              hasSM70]> {
+-  // Pattern (created by WMMA_LOAD_INTR_HELPER below) that matches the intrinsic
+-  // for this function.
+-  PatFrag IntrMatcher = !cast<PatFrag>("INT_WMMA_"
+-                                       # Geometry # "_load_"
+-                                       # !subst("c", "c_" # Type, Abc)
+-                                       # "_" # Layout
+-                                       # !subst(".", "_", Space)
+-                                       # !if(WithStride,"_stride", "")
+-                                       # "_Intr");
+-  dag OutsR03 = (outs regclass:$r0, regclass:$r1, regclass:$r2, regclass:$r3);
+-  dag OutsR47 = (outs regclass:$r4, regclass:$r5, regclass:$r6, regclass:$r7);
+-  dag Outs = !if(!eq(Abc#Type,"cf16"), OutsR03, !con(OutsR03, OutsR47));
+-
+-  dag StrideArg = !if(WithStride, (ins Int32Regs:$ldm), (ins));
+-  dag Ins = !con((ins SrcOp:$src), StrideArg);
++// Helper class that represents a 'fragment' of an NVPTX *MMA instruction.
++// In addition to target-independent fields provided by WMMA_REGS, it adds
++// the fields commonly used to implement specific PTX instruction -- register
++// types and names, constraints, parts of assembly, etc.
++class WMMA_REGINFO<string Geom, string Frag, string PtxEltType>
++      : WMMA_REGS<Geom, Frag, PtxEltType> {
++  // NVPTX register types used to carry fragment data.
++  NVPTXRegClass regclass = !cond(
++    !eq(PtxEltType, "f16") : Float16x2Regs,
++    !eq(PtxEltType, "f32") : Float32Regs);
++
++  // Instruction input/output arguments for the fragment.
++  list<NVPTXRegClass> ptx_regs = !foreach(tmp, regs, regclass);
++
++  // List of register names for the fragment -- ["ra0", "ra1",...]
++  list<string> reg_names = RegSeq<!size(ptx_regs), "r"#frag>.ret;
++  // Generates "{{$r0, $r1,.... $rN-1}}" for use in asm string construction.
++  string regstring = "{{$" # !head(reg_names)
++                           # !foldl("", !tail(reg_names), a, b,
++                                    !strconcat(a, ", $", b))
++                     # "}}";
++
++  // Predicates for particular fragment variant. Technically those are
++  // per-instruction predicates, but currently all fragments that can be used in
++  // a given instruction are subject to the same constraints, so an instruction
++  // can use predicates from any of its fragments. If/when this is no
++  // longer the case, we can concat all per-fragment predicates to enforce that
++  // all fragments of the instruction are viable.
++  list<Predicate> Predicates = !cond(
++    // fp16 -> fp16/fp32 @ m16n16k16
++    !and(!eq(Geom, "m16n16k16"),
++         !or(!eq(PtxEltType, "f16"),
++             !eq(PtxEltType, "f32"))) : [hasSM70, hasPTX60],
++
++    // fp16 -> fp16/fp32 @ m8n32k16/m32n8k16
++    !and(!or(!eq(Geom, "m8n32k16"),
++             !eq(Geom, "m32n8k16")),
++         !or(!eq(PtxEltType, "f16"),
++             !eq(PtxEltType, "f32"))) : [hasSM70, hasPTX61]);
++
++  // template DAGs for instruction inputs/output.
++  dag Outs = !dag(outs, ptx_regs, reg_names);
++  dag Ins = !dag(ins, ptx_regs, reg_names);
++}
+ 
++class BuildPattern<dag Outs, PatFrag IntrMatcher, dag Ins> {
+   // Build a dag pattern that matches the intrinsic call.
+   // We want a dag that looks like this:
+   // (set <output args>, (intrinsic <input arguments>)) where input and
+@@ -7431,277 +7459,127 @@ class WMMA_LOAD_GALSTOS<string Geometry, string Abc, string Layout,
+                               !subst(ins, IntrMatcher, tmp)))));
+   // Finally, consatenate both parts together. !con() requires both dags to have
+   // the same operator, so we wrap PatArgs in a (set ...) dag.
+-  let Pattern = [!con(PatOuts, (set PatArgs))];
+-  let OutOperandList = Outs;
+-  let InOperandList = Ins;
+-  let AsmString = "wmma.load."
+-                  # Abc
+-                  # ".sync"
+-                  # "." # Layout
+-                  # "." # Geometry
+-                  # Space
+-                  # "." # Type # " \t"
+-                  # !if(!eq(Abc#Type, "cf16"),
+-                        "{{$r0, $r1, $r2, $r3}}",
+-                        "{{$r0, $r1, $r2, $r3, $r4, $r5, $r6, $r7}}")
+-                  # ", [$src]"
+-                  # !if(WithStride, ", $ldm", "")
+-                  # ";";
++  dag ret = !con(PatOuts, (set PatArgs));
+ }
+ 
+-class WMMA_LOAD_INTR_HELPER<string Geometry, string Abc, string Layout,
+-                            string Space, string Type, bit WithStride>
++//
++// wmma.load.[a|b|c].sync.[row|col].m16n16k16[|.global|.shared].[f16|f32]
++//
++
++class WMMA_LOAD_INTR_HELPER<WMMA_REGINFO Frag, string Layout, string Space,
++                            bit WithStride>
+                            : PatFrag <(ops),(ops)> {
+   // Intrinsic that matches this instruction.
+-  Intrinsic Intr = !cast<Intrinsic>("int_nvvm_wmma"
+-                                    # "_" # Geometry # "_load_"
+-                                    # Abc # "_" # Type # "_" # Layout
+-                                    # !if(WithStride,"_stride", ""));
+-  code match_generic = [{
+-   return ChkMemSDNodeAddressSpace(N, llvm::ADDRESS_SPACE_GENERIC);
+-  }];
+-  code match_shared = [{
+-   return ChkMemSDNodeAddressSpace(N, llvm::ADDRESS_SPACE_SHARED);
+-  }];
+-  code match_global = [{
+-   return ChkMemSDNodeAddressSpace(N, llvm::ADDRESS_SPACE_GLOBAL);
+-  }];
+-
++  Intrinsic Intr = !cast<Intrinsic>(WMMA_NAME_LDST<"load", Frag, Layout,
++                                                   WithStride>.record);
+   let Operands = !if(WithStride, (ops node:$src, node:$ldm), (ops node:$src));
+   let Fragments = [!foreach(tmp, Operands, !subst(ops, Intr, tmp))];
+-  let PredicateCode = !if(!eq(Space, ".shared"), match_shared,
+-                      !if(!eq(Space, ".global"), match_global, match_generic));
+-}
+-
+-multiclass WMMA_LOAD_GALSTS<string Geometry, string Abc, string Layout,
+-                            string Space, string Type, NVPTXRegClass regclass,
+-                            bit WithStride> {
+-  def _avar:  WMMA_LOAD_GALSTOS<Geometry, Abc, Layout, Space, Type, regclass,
+-                                imem, WithStride>;
+-  def _areg: WMMA_LOAD_GALSTOS<Geometry, Abc, Layout, Space, Type, regclass,
+-                                Int32Regs, WithStride>;
+-  def _areg64: WMMA_LOAD_GALSTOS<Geometry, Abc, Layout, Space, Type, regclass,
+-                                Int64Regs, WithStride>;
+-  def _ari: WMMA_LOAD_GALSTOS<Geometry, Abc, Layout, Space, Type, regclass,
+-                                MEMri, WithStride>;
+-  def _ari64: WMMA_LOAD_GALSTOS<Geometry, Abc, Layout, Space, Type, regclass,
+-                                MEMri64, WithStride>;
++  let PredicateCode = !cond(!eq(Space, ".shared"): AS_match.shared,
++                            !eq(Space, ".global"): AS_match.global,
++                            1: AS_match.generic);
+ }
+ 
+-multiclass WMMA_LOAD_GALSTSh<string Geometry, string Abc, string Layout,
+-                             string Space, string Type, NVPTXRegClass regclass,
+-                             bit WithStride> {
+-  // Define a PatFrag that matches appropriate intrinsic that loads from the
+-  // given address space.
+-  def _Intr:  WMMA_LOAD_INTR_HELPER<Geometry, Abc, Layout, Space, Type,
+-                                    WithStride>;
+-  defm NAME:  WMMA_LOAD_GALSTS<Geometry, Abc, Layout, Space, Type, regclass,
+-                               WithStride>;
+-}
+-
+-multiclass WMMA_LOAD_GALST<string Geometry, string Abc, string Layout,
+-                           string Space, string Type, NVPTXRegClass regclass> {
+-  defm _stride: WMMA_LOAD_GALSTSh<Geometry, Abc, Layout, Space, Type, regclass, 1>;
+-  defm NAME:    WMMA_LOAD_GALSTSh<Geometry, Abc, Layout, Space, Type, regclass, 0>;
+-}
+-
+-multiclass WMMA_LOAD_GALT<string Geometry, string Abc, string Layout,
+-                          string Type, NVPTXRegClass regclass> {
+-  defm _global: WMMA_LOAD_GALST<Geometry, Abc, Layout, ".global",
+-                                Type, regclass>;
+-  defm _shared: WMMA_LOAD_GALST<Geometry, Abc, Layout, ".shared",
+-                                Type, regclass>;
+-  defm NAME:    WMMA_LOAD_GALST<Geometry, Abc, Layout,        "",
+-                                Type, regclass>;
+-}
+-
+-multiclass WMMA_LOAD_GAT<string Geometry, string Abc,
+-                         string Type, NVPTXRegClass regclass> {
+-  defm _row: WMMA_LOAD_GALT<Geometry, Abc, "row", Type, regclass>;
+-  defm _col: WMMA_LOAD_GALT<Geometry, Abc, "col", Type, regclass>;
+-}
++class WMMA_LOAD<WMMA_REGINFO Frag, string Layout, string Space, bit WithStride,
++                DAGOperand SrcOp>
++  : EmptyNVPTXInst,
++    Requires<Frag.Predicates> {
++  // Pattern that matches the intrinsic for this instruction variant.
++  PatFrag IntrMatcher = WMMA_LOAD_INTR_HELPER<Frag, Layout, Space, WithStride>;
++  dag Ins = !con((ins SrcOp:$src), !if(WithStride, (ins Int32Regs:$ldm), (ins)));
+ 
+-multiclass WMMA_LOAD_G<string Geometry> {
+-  defm _load_a: WMMA_LOAD_GAT<Geometry, "a", "f16", Float16x2Regs>;
+-  defm _load_b: WMMA_LOAD_GAT<Geometry, "b", "f16", Float16x2Regs>;
+-  defm _load_c_f16: WMMA_LOAD_GAT<Geometry, "c", "f16", Float16x2Regs>;
+-  defm _load_c_f32: WMMA_LOAD_GAT<Geometry, "c", "f32", Float32Regs>;
++  let Pattern = [BuildPattern<Frag.Outs, IntrMatcher, Ins>.ret];
++  let OutOperandList = Frag.Outs;
++  let InOperandList = Ins;
++  let AsmString = "wmma.load."
++                  # Frag.frag
++                  # ".sync"
++                  # "." # Layout
++                  # "." # Frag.geom
++                  # Space
++                  # "." # Frag.ptx_elt_type # " \t"
++                  # Frag.regstring
++                  # ", [$src]"
++                  # !if(WithStride, ", $ldm", "")
++                  # ";";
+ }
+ 
+-defm INT_WMMA_m32n8k16: WMMA_LOAD_G<"m32n8k16">;
+-defm INT_WMMA_m16n16k16: WMMA_LOAD_G<"m16n16k16">;
+-defm INT_WMMA_m8n32k16: WMMA_LOAD_G<"m8n32k16">;
+-
+ //
+ // wmma.store.d.sync.[row|col].m16n16k16[|.global|.shared].[f16|f32]
+ //
+-class WMMA_STORE_D_GLSTSO<string Geometry, string Layout, string Space,
+-                          string Type, NVPTXRegClass regclass,
+-                          bit WithStride, DAGOperand DstOp>
++class WMMA_STORE_INTR_HELPER<WMMA_REGINFO Frag, string Layout, string Space,
++                             bit WithStride>
++                            : PatFrag <(ops),(ops)> {
++  // Intrinsic that matches this instruction.
++  Intrinsic Intr = !cast<Intrinsic>(WMMA_NAME_LDST<"store", Frag, Layout,
++                                                   WithStride>.record);
++  let Operands = !con((ops node:$dst),
++                      !dag(ops, !foreach(tmp, Frag.regs, node), Frag.reg_names),
++                      !if(WithStride, (ops node:$ldm), (ops)));
++  let Fragments = [!foreach(tmp, Operands, !subst(ops, Intr, tmp))];
++  let PredicateCode = !cond(!eq(Space, ".shared"): AS_match.shared,
++                            !eq(Space, ".global"): AS_match.global,
++                            1: AS_match.generic);
++}
++
++class WMMA_STORE<WMMA_REGINFO Frag, string Layout, string Space, bit WithStride,
++                 DAGOperand DstOp>
+   : EmptyNVPTXInst,
+-    Requires<[!if(!eq(Geometry, "m16n16k16"),
+-                  hasPTX60,
+-                  hasPTX61),
+-              hasSM70]> {
+-  PatFrag IntrMatcher = !cast<PatFrag>("INT_WMMA"
+-                                       # "_" # Geometry # "_store_d"
+-                                       # "_" # Type
+-                                       # "_" # Layout
+-                                       # !subst(".", "_", Space)
+-                                       # !if(WithStride,"_stride", "")
+-                                       # "_Intr");
+-  dag InsR03 = (ins DstOp:$src, regclass:$r0, regclass:$r1,
+-                                regclass:$r2, regclass:$r3);
+-  dag InsR47 = (ins regclass:$r4, regclass:$r5,
+-                    regclass:$r6, regclass:$r7);
+-  dag InsR = !if(!eq(Type,"f16"), InsR03, !con(InsR03, InsR47));
+-  dag StrideArg = !if(WithStride, (ins Int32Regs:$ldm), (ins));
+-  dag Ins = !con(InsR, StrideArg);
+-
+-  // Construct the pattern to match corresponding intrinsic call. See the
+-  // details in the comments in WMMA_LOAD_ALSTOS.
+-  dag PatArgs = !foreach(tmp, Ins,
+-                              !subst(imem, ADDRvar,
+-                              !subst(MEMri64, ADDRri64,
+-                              !subst(MEMri, ADDRri,
+-                              !subst(ins, IntrMatcher, tmp)))));
+-  let Pattern = [PatArgs];
++    Requires<Frag.Predicates> {
++  PatFrag IntrMatcher = WMMA_STORE_INTR_HELPER<Frag, Layout, Space, WithStride>;
++  dag Ins = !con((ins DstOp:$src),
++                 Frag.Ins,
++                 !if(WithStride, (ins Int32Regs:$ldm), (ins)));
++  let Pattern = [BuildPattern<(set), IntrMatcher, Ins>.ret];
+   let OutOperandList = (outs);
+   let InOperandList = Ins;
+   let AsmString = "wmma.store.d.sync."
+                   # Layout
+-                  # "." # Geometry
++                  # "." # Frag.geom
+                   # Space
+-                  # "." # Type
++                  # "." # Frag.ptx_elt_type
+                   # " \t[$src],"
+-                  # !if(!eq(Type,"f16"),
+-                        "{{$r0, $r1, $r2, $r3}}",
+-                        "{{$r0, $r1, $r2, $r3, $r4, $r5, $r6, $r7}}")
++                  # Frag.regstring
+                   # !if(WithStride, ", $ldm", "")
+                   # ";";
+-
+ }
+ 
+-class WMMA_STORE_INTR_HELPER<string Geometry, string Layout, string Space,
+-                             string Type, bit WithStride>
+-                            : PatFrag <(ops),(ops)> {
+-  // Intrinsic that matches this instruction.
+-  Intrinsic Intr = !cast<Intrinsic>("int_nvvm_wmma_"
+-                                    # Geometry
+-                                    # "_store_d"
+-                                    # "_" # Type
+-                                    # "_" # Layout
+-                                    # !if(WithStride, "_stride", ""));
+-  code match_generic = [{
+-   return ChkMemSDNodeAddressSpace(N, llvm::ADDRESS_SPACE_GENERIC);
+-  }];
+-  code match_shared = [{
+-   return ChkMemSDNodeAddressSpace(N, llvm::ADDRESS_SPACE_SHARED);
+-  }];
+-  code match_global = [{
+-   return ChkMemSDNodeAddressSpace(N, llvm::ADDRESS_SPACE_GLOBAL);
+-  }];
+-
+-  dag Args = !if(!eq(Type,"f16"),
+-                 (ops node:$dst, node:$r0, node:$r1, node:$r2, node:$r3),
+-                 (ops node:$dst, node:$r0, node:$r1, node:$r2, node:$r3,
+-                                 node:$r4, node:$r5, node:$r6, node:$r7));
+-  dag StrideArg = !if(WithStride, (ops node:$ldm), (ops));
+-  let Operands = !con(Args, StrideArg);
+-  let Fragments = [!foreach(tmp, Operands, !subst(ops, Intr, tmp))];
+-  let PredicateCode = !if(!eq(Space, ".shared"), match_shared,
+-                      !if(!eq(Space, ".global"), match_global, match_generic));
+-}
+-
+-multiclass WMMA_STORE_D_GLSTS<string Geometry, string Layout, string Space,
+-                              string Type, NVPTXRegClass regclass,
+-                              bit WithStride> {
+-  def _avar:   WMMA_STORE_D_GLSTSO<Geometry, Layout, Space, Type, regclass,
+-                                   WithStride, imem>;
+-  def _areg:   WMMA_STORE_D_GLSTSO<Geometry, Layout, Space, Type, regclass,
+-                                   WithStride, Int32Regs>;
+-  def _areg64: WMMA_STORE_D_GLSTSO<Geometry, Layout, Space, Type, regclass,
+-                                   WithStride, Int64Regs>;
+-  def _ari:    WMMA_STORE_D_GLSTSO<Geometry, Layout, Space, Type, regclass,
+-                                   WithStride, MEMri>;
+-  def _ari64:  WMMA_STORE_D_GLSTSO<Geometry, Layout, Space, Type, regclass,
+-                                   WithStride, MEMri64>;
+-}
+-
+-multiclass WMMA_STORE_D_GLSTSh<string Geometry, string Layout, string Space,
+-                               string Type, NVPTXRegClass regclass,
+-                               bit WithStride> {
+-  // Define a PatFrag that matches appropriate intrinsic that loads from the
+-  // given address space.
+-  def _Intr:    WMMA_STORE_INTR_HELPER<Geometry, Layout, Space, Type,
+-                                       WithStride>;
+-  defm NAME:    WMMA_STORE_D_GLSTS<Geometry, Layout, Space, Type, regclass,
+-                                   WithStride>;
+-}
+-
+-multiclass WMMA_STORE_D_GLST<string Geometry, string Layout, string Space,
+-                             string Type, NVPTXRegClass regclass > {
+-  defm _stride: WMMA_STORE_D_GLSTSh<Geometry, Layout, Space, Type, regclass, 1>;
+-  defm NAME:    WMMA_STORE_D_GLSTSh<Geometry, Layout, Space, Type, regclass, 0>;
+-}
+-
+-multiclass WMMA_STORE_D_GLT<string Geometry, string Layout,
+-                           string Type, NVPTXRegClass regclass> {
+-  defm _global: WMMA_STORE_D_GLST<Geometry, Layout, ".global", Type, regclass>;
+-  defm _shared: WMMA_STORE_D_GLST<Geometry, Layout, ".shared", Type, regclass>;
+-  defm NAME:    WMMA_STORE_D_GLST<Geometry, Layout,        "", Type, regclass>;
+-}
+-
+-multiclass WMMA_STORE_D_GT<string Geometry, string Type,
+-                           NVPTXRegClass regclass> {
+-  defm _row:    WMMA_STORE_D_GLT<Geometry, "row", Type, regclass>;
+-  defm _col:    WMMA_STORE_D_GLT<Geometry, "col", Type, regclass>;
+-}
+-
+-multiclass WMMA_STORE_D_G<string Geometry> {
+-  defm _store_d_f16: WMMA_STORE_D_GT<Geometry, "f16", Float16x2Regs>;
+-  defm _store_d_f32: WMMA_STORE_D_GT<Geometry, "f32", Float32Regs>;
+-}
+-
+-defm INT_WMMA_m32n8k16: WMMA_STORE_D_G<"m32n8k16">;
+-defm INT_WMMA_m16n16k16: WMMA_STORE_D_G<"m16n16k16">;
+-defm INT_WMMA_m8n32k16: WMMA_STORE_D_G<"m8n32k16">;
++// Create all load/store variants
++foreach geom = ["m16n16k16", "m32n8k16", "m8n32k16" ] in {
++  foreach layout = ["row", "col"] in {
++    foreach stride = [0, 1] in {
++      foreach space = [".global", ".shared", ""] in {
++        foreach addr = [imem, Int32Regs, Int64Regs, MEMri, MEMri64] in {
++          foreach frag = [WMMA_REGINFO<geom, "a", "f16">,
++                          WMMA_REGINFO<geom, "b", "f16">,
++                          WMMA_REGINFO<geom, "c", "f16">,
++                          WMMA_REGINFO<geom, "c", "f32">] in {
++              def : WMMA_LOAD<frag, layout, space, stride, addr>;
++          }
++          foreach frag = [WMMA_REGINFO<geom, "d", "f16">,
++                          WMMA_REGINFO<geom, "d", "f32">] in {
++              def : WMMA_STORE<frag, layout, space, stride, addr>;
++          }
++        } // addr
++      } // space
++    } // stride
++  } // layout
++} // geom
+ 
+ // WMMA.MMA
+-class WMMA_MMA_GABDCS<string Geometry, string ALayout, string BLayout,
+-                     string DType, NVPTXRegClass d_reg,
+-                     string CType, NVPTXRegClass c_reg,
+-                     NVPTXRegClass ab_reg,
+-                     string Satfinite = "">
++class WMMA_MMA<WMMA_REGINFO FragA, WMMA_REGINFO FragB,
++               WMMA_REGINFO FragC, WMMA_REGINFO FragD,
++               string ALayout, string BLayout, int Satfinite>
+   : EmptyNVPTXInst,
+-    Requires<[!if(!eq(Geometry, "m16n16k16"),
+-                  hasPTX60,
+-                  hasPTX61),
+-              hasSM70]> {
+-  Intrinsic Intr = !cast<Intrinsic>("int_nvvm_wmma_"
+-                                    # Geometry
+-                                    # "_mma"
+-                                    # "_" # ALayout
+-                                    # "_" # BLayout
+-                                    # "_" # DType
+-                                    # "_" # CType
+-                                    # !subst(".", "_", Satfinite));
+-  dag Outs = !if(!eq(DType,"f16"),
+-                 (outs d_reg:$d0, d_reg:$d1, d_reg:$d2, d_reg:$d3),
+-                 (outs d_reg:$d0, d_reg:$d1, d_reg:$d2, d_reg:$d3,
+-                       d_reg:$d4, d_reg:$d5, d_reg:$d6, d_reg:$d7));
+-  dag InsExtraCArgs = !if(!eq(CType,"f16"),
+-                          (ins),
+-                          (ins c_reg:$c4,  c_reg:$c5,  c_reg:$c6,  c_reg:$c7));
+-  dag Ins = !con((ins ab_reg:$a0, ab_reg:$a1, ab_reg:$a2, ab_reg:$a3,
+-                      ab_reg:$a4, ab_reg:$a5, ab_reg:$a6, ab_reg:$a7,
+-                      ab_reg:$b0, ab_reg:$b1, ab_reg:$b2, ab_reg:$b3,
+-                      ab_reg:$b4, ab_reg:$b5, ab_reg:$b6, ab_reg:$b7,
+-                      c_reg:$c0,  c_reg:$c1,  c_reg:$c2,  c_reg:$c3),
+-                  InsExtraCArgs);
+-
+-  // Construct the pattern to match corresponding intrinsic call. See the
+-  // details in the comments in WMMA_LOAD_ALSTOS.
++    Requires<FragC.Predicates> {
++  //Intrinsic Intr = int_nvvm_suld_1d_v4i32_zero;
++  Intrinsic Intr = !cast<Intrinsic>(WMMA_NAME_MMA<ALayout, BLayout, FragC, FragD, Satfinite>.record);
++  dag Outs = FragD.Outs;
++  dag Ins = !con(FragA.Ins,
++                 FragB.Ins,
++                 FragC.Ins);
++
++  // Construct the pattern to match corresponding intrinsic call.
++  // mma does not load/store anything, so we don't need complex operand matching here.
+   dag PatOuts = !foreach(tmp, Outs, !subst(outs, set, tmp));
+   dag PatArgs = !foreach(tmp, Ins, !subst(ins, Intr, tmp));
+   let Pattern = [!con(PatOuts, (set PatArgs))];
+@@ -7710,54 +7588,30 @@ class WMMA_MMA_GABDCS<string Geometry, string ALayout, string BLayout,
+   let AsmString = "wmma.mma.sync."
+                   # ALayout
+                   # "." # BLayout
+-                  # "." # Geometry
+-                  # "." # DType
+-                  # "." # CType
+-                  # Satfinite # "\n\t\t"
+-                  # !if(!eq(DType,"f16"),
+-                        "{{$d0, $d1, $d2, $d3}}, \n\t\t",
+-                        "{{$d0, $d1, $d2, $d3, $d4, $d5, $d6, $d7}},\n\t\t")
+-                  # "{{$a0, $a1, $a2, $a3, $a4, $a5, $a6, $a7}},\n\t\t"
+-                  # "{{$b0, $b1, $b2, $b3, $b4, $b5, $b6, $b7}},\n\t\t"
+-                  # !if(!eq(CType,"f16"),
+-                        "{{$c0, $c1, $c2, $c3}};",
+-                        "{{$c0, $c1, $c2, $c3, $c4, $c5, $c6, $c7}};");
+-}
+-
+-multiclass WMMA_MMA_GABDC<string Geometry, string ALayout, string BLayout,
+-                         string DType, NVPTXRegClass d_reg,
+-                         string CType, NVPTXRegClass c_reg> {
+-  def _satfinite: WMMA_MMA_GABDCS<Geometry, ALayout, BLayout,
+-                                 DType, d_reg, CType, c_reg,
+-                                 Float16x2Regs, ".satfinite">;
+-  def NAME:       WMMA_MMA_GABDCS<Geometry, ALayout, BLayout,
+-                                 DType, d_reg, CType, c_reg,
+-                                 Float16x2Regs>;
+-}
+-
+-multiclass WMMA_MMA_GABD<string Geometry, string ALayout, string BLayout,
+-                        string DType, NVPTXRegClass d_reg> {
+-  defm _f16: WMMA_MMA_GABDC<Geometry, ALayout, BLayout, DType, d_reg,
+-                            "f16", Float16x2Regs>;
+-  defm _f32: WMMA_MMA_GABDC<Geometry, ALayout, BLayout, DType, d_reg,
+-                            "f32", Float32Regs>;
+-}
+-
+-multiclass WMMA_MMA_GAB<string Geometry, string ALayout, string BLayout> {
+-  defm _f16: WMMA_MMA_GABD<Geometry, ALayout, BLayout, "f16", Float16x2Regs>;
+-  defm _f32: WMMA_MMA_GABD<Geometry, ALayout, BLayout, "f32", Float32Regs>;
+-}
+-
+-multiclass WMMA_MMA_GA<string Geometry, string ALayout> {
+-  defm _col: WMMA_MMA_GAB<Geometry, ALayout, "col">;
+-  defm _row: WMMA_MMA_GAB<Geometry, ALayout, "row">;
+-}
+-
+-multiclass WMMA_MMA_G<string Geometry> {
+-  defm _col: WMMA_MMA_GA<Geometry, "col">;
+-  defm _row: WMMA_MMA_GA<Geometry, "row">;
++                  # "." # FragA.geom
++                  # "." # FragD.ptx_elt_type
++                  # "." # FragC.ptx_elt_type
++                  # !if(Satfinite, ".satfinite", "") # "\n\t\t"
++                  # FragD.regstring # ",\n\t\t"
++                  # FragA.regstring # ",\n\t\t"
++                  # FragB.regstring # ",\n\t\t"
++                  # FragC.regstring # ";";
+ }
+ 
+-defm INT_WMMA_MMA_m32n8k16 : WMMA_MMA_G<"m32n8k16">;
+-defm INT_WMMA_MMA_m16n16k16 : WMMA_MMA_G<"m16n16k16">;
+-defm INT_WMMA_MMA_m8n32k16 : WMMA_MMA_G<"m8n32k16">;
++foreach geom = ["m16n16k16", "m32n8k16", "m8n32k16" ] in {
++  foreach layout_a = ["row", "col"] in {
++    foreach layout_b = ["row", "col"] in {
++      foreach frag_c = [WMMA_REGINFO<geom, "c", "f16">,
++                        WMMA_REGINFO<geom, "c", "f32">] in {
++        foreach frag_d = [WMMA_REGINFO<geom, "d", "f16">,
++                          WMMA_REGINFO<geom, "d", "f32">] in {
++          foreach satf = [0, 1] in {
++            def : WMMA_MMA<WMMA_REGINFO<geom, "a", "f16">,
++                           WMMA_REGINFO<geom, "b", "f16">,
++                           frag_c, frag_d, layout_a, layout_b, satf>;
++          } // satf
++        } // frag_d
++      } // frag_c
++    } // layout_b
++  } // layout_a
++} // geom
+-- 
+2.17.1
+
diff -pruN 1.3.1+dfsg-1/deps/patches/llvm-8.0-D59393-mma-ptx63-fix.patch 1.4.0+dfsg-1/deps/patches/llvm-8.0-D59393-mma-ptx63-fix.patch
--- 1.3.1+dfsg-1/deps/patches/llvm-8.0-D59393-mma-ptx63-fix.patch	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/patches/llvm-8.0-D59393-mma-ptx63-fix.patch	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1,510 @@
+From be924be7f9e699775fe7690d4b421bebfed73aa9 Mon Sep 17 00:00:00 2001
+From: Artem Belevich <tra@google.com>
+Date: Thu, 25 Apr 2019 22:27:46 +0000
+Subject: [PATCH] [NVPTX] generate correct MMA instruction mnemonics with
+ PTX63+.
+
+PTX 6.3 requires using ".aligned" in the MMA instruction names.
+In order to generate correct name, now we pass current
+PTX version to each instruction as an extra constant operand
+and InstPrinter adjusts its output accordingly.
+
+Differential Revision: https://reviews.llvm.org/D59393
+
+llvm-svn: 359246
+---
+ .../NVPTX/InstPrinter/NVPTXInstPrinter.cpp    |  14 +
+ .../NVPTX/InstPrinter/NVPTXInstPrinter.h      |   2 +
+ lib/Target/NVPTX/NVPTXInstrInfo.td            |   4 +
+ lib/Target/NVPTX/NVPTXIntrinsics.td           | 279 ++++++++++--------
+ test/CodeGen/NVPTX/wmma.py                    |  17 +-
+ 5 files changed, 184 insertions(+), 132 deletions(-)
+
+diff --git a/lib/Target/NVPTX/InstPrinter/NVPTXInstPrinter.cpp b/lib/Target/NVPTX/InstPrinter/NVPTXInstPrinter.cpp
+index b774fe169d7..6fb577d5499 100644
+--- a/lib/Target/NVPTX/InstPrinter/NVPTXInstPrinter.cpp
++++ b/lib/Target/NVPTX/InstPrinter/NVPTXInstPrinter.cpp
+@@ -270,6 +270,20 @@ void NVPTXInstPrinter::printLdStCode(const MCInst *MI, int OpNum,
+     llvm_unreachable("Empty Modifier");
+ }
+ 
++void NVPTXInstPrinter::printMmaCode(const MCInst *MI, int OpNum, raw_ostream &O,
++                                    const char *Modifier) {
++  const MCOperand &MO = MI->getOperand(OpNum);
++  int Imm = (int)MO.getImm();
++  if (Modifier == nullptr || strcmp(Modifier, "version") == 0) {
++    O << Imm; // Just print out PTX version
++  } else if (strcmp(Modifier, "aligned") == 0) {
++    // PTX63 requires '.aligned' in the name of the instruction.
++    if (Imm >= 63)
++      O << ".aligned";
++  } else
++    llvm_unreachable("Unknown Modifier");
++}
++
+ void NVPTXInstPrinter::printMemOperand(const MCInst *MI, int OpNum,
+                                        raw_ostream &O, const char *Modifier) {
+   printOperand(MI, OpNum, O);
+diff --git a/lib/Target/NVPTX/InstPrinter/NVPTXInstPrinter.h b/lib/Target/NVPTX/InstPrinter/NVPTXInstPrinter.h
+index f0f223aa057..588439137f9 100644
+--- a/lib/Target/NVPTX/InstPrinter/NVPTXInstPrinter.h
++++ b/lib/Target/NVPTX/InstPrinter/NVPTXInstPrinter.h
+@@ -41,6 +41,8 @@ public:
+                     const char *Modifier = nullptr);
+   void printLdStCode(const MCInst *MI, int OpNum,
+                      raw_ostream &O, const char *Modifier = nullptr);
++  void printMmaCode(const MCInst *MI, int OpNum, raw_ostream &O,
++                    const char *Modifier = nullptr);
+   void printMemOperand(const MCInst *MI, int OpNum,
+                        raw_ostream &O, const char *Modifier = nullptr);
+   void printProtoIdent(const MCInst *MI, int OpNum,
+diff --git a/lib/Target/NVPTX/NVPTXInstrInfo.td b/lib/Target/NVPTX/NVPTXInstrInfo.td
+index 02a40b9f526..603d3212395 100644
+--- a/lib/Target/NVPTX/NVPTXInstrInfo.td
++++ b/lib/Target/NVPTX/NVPTXInstrInfo.td
+@@ -1549,6 +1549,10 @@ def LdStCode : Operand<i32> {
+   let PrintMethod = "printLdStCode";
+ }
+ 
++def MmaCode : Operand<i32> {
++  let PrintMethod = "printMmaCode";
++}
++
+ def SDTWrapper : SDTypeProfile<1, 1, [SDTCisSameAs<0, 1>, SDTCisPtrTy<0>]>;
+ def Wrapper    : SDNode<"NVPTXISD::Wrapper", SDTWrapper>;
+ 
+diff --git a/lib/Target/NVPTX/NVPTXIntrinsics.td b/lib/Target/NVPTX/NVPTXIntrinsics.td
+index b9a67ba5ed3..5cd534914f7 100644
+--- a/lib/Target/NVPTX/NVPTXIntrinsics.td
++++ b/lib/Target/NVPTX/NVPTXIntrinsics.td
+@@ -39,6 +39,24 @@ def AS_match {
+   }];
+ }
+ 
++// A node that will be replaced with the current PTX version.
++class PTX {
++  SDNodeXForm PTXVerXform = SDNodeXForm<imm, [{
++    return getI32Imm(Subtarget->getPTXVersion(), SDLoc(N));
++  }]>;
++  // (i32 0) will be XForm'ed to the currently used PTX version.
++  dag version = (PTXVerXform (i32 0));
++}
++def ptx : PTX;
++
++// Generates list of n sequential register names.
++// E.g. RegNames<3,"r">.ret -> ["r0", "r1", "r2" ]
++class RegSeq<int n, string prefix> {
++  list<string> ret = !if(n, !listconcat(RegSeq<!add(n,-1), prefix>.ret,
++                                        [prefix # !add(n, -1)]),
++                            []);
++}
++
+ //-----------------------------------
+ // Synchronization and shuffle functions
+ //-----------------------------------
+@@ -7385,14 +7403,6 @@ def INT_PTX_SREG_WARPSIZE :
+     NVPTXInst<(outs Int32Regs:$dst), (ins), "mov.u32 \t$dst, WARP_SZ;",
+               [(set Int32Regs:$dst, (int_nvvm_read_ptx_sreg_warpsize))]>;
+ 
+-class EmptyNVPTXInst : NVPTXInst<(outs), (ins), "?", []>;
+-// Generates list of n sequential register names.
+-class RegSeq<int n, string prefix> {
+-  list<string> ret = !if(n, !listconcat(RegSeq<!add(n,-1), prefix>.ret,
+-                                        [prefix # !add(n, -1)]),
+-                            []);
+-}
+-
+ // Helper class that represents a 'fragment' of an NVPTX *MMA instruction.
+ // In addition to target-independent fields provided by WMMA_REGS, it adds
+ // the fields commonly used to implement specific PTX instruction -- register
+@@ -7409,6 +7419,7 @@ class WMMA_REGINFO<string Geom, string Frag, string PtxEltType>
+ 
+   // List of register names for the fragment -- ["ra0", "ra1",...]
+   list<string> reg_names = RegSeq<!size(ptx_regs), "r"#frag>.ret;
++
+   // Generates "{{$r0, $r1,.... $rN-1}}" for use in asm string construction.
+   string regstring = "{{$" # !head(reg_names)
+                            # !foldl("", !tail(reg_names), a, b,
+@@ -7438,61 +7449,65 @@ class WMMA_REGINFO<string Geom, string Frag, string PtxEltType>
+   dag Ins = !dag(ins, ptx_regs, reg_names);
+ }
+ 
+-class BuildPattern<dag Outs, PatFrag IntrMatcher, dag Ins> {
++// Convert dag of arguments into a dag to match given intrinsic.
++class BuildPatternI<Intrinsic Intr, dag Ins> {
++  // Build a dag pattern that matches the intrinsic call.
++  dag ret = !foreach(tmp, Ins,
++                          !subst(imem, ADDRvar,
++                          !subst(MEMri64, ADDRri64,
++                          !subst(MEMri, ADDRri,
++                          !subst(ins, Intr, tmp)))));
++}
++
++// Same as above, but uses PatFrag instead of an Intrinsic.
++class BuildPatternPF<PatFrag Intr, dag Ins> {
+   // Build a dag pattern that matches the intrinsic call.
+-  // We want a dag that looks like this:
+-  // (set <output args>, (intrinsic <input arguments>)) where input and
+-  // output arguments are named patterns that would match corresponding
+-  // input/output arguments of the instruction.
+-  //
+-  // First we construct (set <output arguments>) from instruction's outs dag by
+-  // replacing dag operator 'outs' with 'set'.
+-  dag PatOuts = !foreach(tmp, Outs, !subst(outs, set, tmp));
+-  // Similarly, construct (intrinsic <input arguments>) sub-dag from
+-  // instruction's input arguments, only now we also need to replace operands
+-  // with patterns that would match them and the operator 'ins' with the
+-  // intrinsic.
+-  dag PatArgs = !foreach(tmp, Ins,
+-                              !subst(imem, ADDRvar,
+-                              !subst(MEMri64, ADDRri64,
+-                              !subst(MEMri, ADDRri,
+-                              !subst(ins, IntrMatcher, tmp)))));
+-  // Finally, consatenate both parts together. !con() requires both dags to have
+-  // the same operator, so we wrap PatArgs in a (set ...) dag.
+-  dag ret = !con(PatOuts, (set PatArgs));
++  dag ret = !foreach(tmp, Ins,
++                          !subst(imem, ADDRvar,
++                          !subst(MEMri64, ADDRri64,
++                          !subst(MEMri, ADDRri,
++                          !subst(ins, Intr, tmp)))));
++}
++
++// Common WMMA-related fields used for building patterns for all MMA instructions.
++class WMMA_INSTR<string _Intr, list<dag> _Args>
++  : NVPTXInst<(outs), (ins), "?", []> {
++  Intrinsic Intr = !cast<Intrinsic>(_Intr);
++  // Concatenate all arguments into a single dag.
++  dag Args = !foldl((ins), _Args, a, b, !con(a,b));
++  // Pre-build the pattern to match (intrinsic arg0, arg1, ...).
++  dag IntrinsicPattern = BuildPatternI<!cast<Intrinsic>(Intr), Args>.ret;
+ }
+ 
+ //
+ // wmma.load.[a|b|c].sync.[row|col].m16n16k16[|.global|.shared].[f16|f32]
+ //
+ 
+-class WMMA_LOAD_INTR_HELPER<WMMA_REGINFO Frag, string Layout, string Space,
+-                            bit WithStride>
+-                           : PatFrag <(ops),(ops)> {
+-  // Intrinsic that matches this instruction.
+-  Intrinsic Intr = !cast<Intrinsic>(WMMA_NAME_LDST<"load", Frag, Layout,
+-                                                   WithStride>.record);
+-  let Operands = !if(WithStride, (ops node:$src, node:$ldm), (ops node:$src));
+-  let Fragments = [!foreach(tmp, Operands, !subst(ops, Intr, tmp))];
+-  let PredicateCode = !cond(!eq(Space, ".shared"): AS_match.shared,
+-                            !eq(Space, ".global"): AS_match.global,
+-                            1: AS_match.generic);
+-}
+-
+ class WMMA_LOAD<WMMA_REGINFO Frag, string Layout, string Space, bit WithStride,
+                 DAGOperand SrcOp>
+-  : EmptyNVPTXInst,
++  : WMMA_INSTR<WMMA_NAME_LDST<"load", Frag, Layout, WithStride>.record,
++                              [!con((ins SrcOp:$src),
++                                    !if(WithStride, (ins Int32Regs:$ldm), (ins)))]>,
+     Requires<Frag.Predicates> {
+-  // Pattern that matches the intrinsic for this instruction variant.
+-  PatFrag IntrMatcher = WMMA_LOAD_INTR_HELPER<Frag, Layout, Space, WithStride>;
+-  dag Ins = !con((ins SrcOp:$src), !if(WithStride, (ins Int32Regs:$ldm), (ins)));
++  // Load/store intrinsics are overloaded on pointer's address space.
++  // To match the right intrinsic, we need to build AS-constrained PatFrag.
++  // Operands is a dag equivalent in shape to Args, but using (ops node:$name, .....).
++  dag PFOperands = !if(WithStride, (ops node:$src, node:$ldm), (ops node:$src));
++  // Build PatFrag that only matches particular address space.
++  PatFrag IntrFrag = PatFrag<PFOperands,
++                             !foreach(tmp, PFOperands, !subst(ops, Intr, tmp)),
++                             !cond(!eq(Space, ".shared"): AS_match.shared,
++                                   !eq(Space, ".global"): AS_match.global,
++                                   1: AS_match.generic)>;
++  // Build AS-constrained pattern.
++  let IntrinsicPattern = BuildPatternPF<IntrFrag, Args>.ret;
+ 
+-  let Pattern = [BuildPattern<Frag.Outs, IntrMatcher, Ins>.ret];
+   let OutOperandList = Frag.Outs;
+-  let InOperandList = Ins;
++  let InOperandList = !con(Args, (ins MmaCode:$ptx));
+   let AsmString = "wmma.load."
+                   # Frag.frag
+                   # ".sync"
++                  # "${ptx:aligned}"
+                   # "." # Layout
+                   # "." # Frag.geom
+                   # Space
+@@ -7506,87 +7521,79 @@ class WMMA_LOAD<WMMA_REGINFO Frag, string Layout, string Space, bit WithStride,
+ //
+ // wmma.store.d.sync.[row|col].m16n16k16[|.global|.shared].[f16|f32]
+ //
+-class WMMA_STORE_INTR_HELPER<WMMA_REGINFO Frag, string Layout, string Space,
+-                             bit WithStride>
+-                            : PatFrag <(ops),(ops)> {
+-  // Intrinsic that matches this instruction.
+-  Intrinsic Intr = !cast<Intrinsic>(WMMA_NAME_LDST<"store", Frag, Layout,
+-                                                   WithStride>.record);
+-  let Operands = !con((ops node:$dst),
+-                      !dag(ops, !foreach(tmp, Frag.regs, node), Frag.reg_names),
+-                      !if(WithStride, (ops node:$ldm), (ops)));
+-  let Fragments = [!foreach(tmp, Operands, !subst(ops, Intr, tmp))];
+-  let PredicateCode = !cond(!eq(Space, ".shared"): AS_match.shared,
+-                            !eq(Space, ".global"): AS_match.global,
+-                            1: AS_match.generic);
+-}
+-
+-class WMMA_STORE<WMMA_REGINFO Frag, string Layout, string Space, bit WithStride,
+-                 DAGOperand DstOp>
+-  : EmptyNVPTXInst,
++class WMMA_STORE_D<WMMA_REGINFO Frag, string Layout, string Space,
++                   bit WithStride, DAGOperand DstOp>
++  : WMMA_INSTR<WMMA_NAME_LDST<"store", Frag, Layout, WithStride>.record,
++               [!con((ins DstOp:$dst),
++                     Frag.Ins,
++                     !if(WithStride, (ins Int32Regs:$ldm), (ins)))]>,
+     Requires<Frag.Predicates> {
+-  PatFrag IntrMatcher = WMMA_STORE_INTR_HELPER<Frag, Layout, Space, WithStride>;
+-  dag Ins = !con((ins DstOp:$src),
+-                 Frag.Ins,
+-                 !if(WithStride, (ins Int32Regs:$ldm), (ins)));
+-  let Pattern = [BuildPattern<(set), IntrMatcher, Ins>.ret];
++
++  // Load/store intrinsics are overloaded on pointer's address space.
++  // To match the right intrinsic, we need to build AS-constrained PatFrag.
++  // Operands is a dag equivalent in shape to Args, but using (ops node:$name, .....).
++  dag PFOperands = !con((ops node:$dst),
++                        !dag(ops, !foreach(tmp, Frag.regs, node), Frag.reg_names),
++                        !if(WithStride, (ops node:$ldm), (ops)));
++  // Build PatFrag that only matches particular address space.
++  PatFrag IntrFrag = PatFrag<PFOperands,
++                             !foreach(tmp, PFOperands, !subst(ops, Intr, tmp)),
++                             !cond(!eq(Space, ".shared"): AS_match.shared,
++                                   !eq(Space, ".global"): AS_match.global,
++                                   1: AS_match.generic)>;
++  // Build AS-constrained pattern.
++  let IntrinsicPattern = BuildPatternPF<IntrFrag, Args>.ret;
++
++  let InOperandList  = !con(Args, (ins MmaCode:$ptx));
+   let OutOperandList = (outs);
+-  let InOperandList = Ins;
+-  let AsmString = "wmma.store.d.sync."
+-                  # Layout
++  let AsmString = "wmma.store.d.sync"
++                  # "${ptx:aligned}"
++                  # "." # Layout
+                   # "." # Frag.geom
+                   # Space
+                   # "." # Frag.ptx_elt_type
+-                  # " \t[$src],"
++                  # " \t[$dst],"
+                   # Frag.regstring
+                   # !if(WithStride, ", $ldm", "")
+                   # ";";
+ }
+ 
+ // Create all load/store variants
+-foreach geom = ["m16n16k16", "m32n8k16", "m8n32k16" ] in {
+-  foreach layout = ["row", "col"] in {
+-    foreach stride = [0, 1] in {
+-      foreach space = [".global", ".shared", ""] in {
+-        foreach addr = [imem, Int32Regs, Int64Regs, MEMri, MEMri64] in {
+-          foreach frag = [WMMA_REGINFO<geom, "a", "f16">,
+-                          WMMA_REGINFO<geom, "b", "f16">,
+-                          WMMA_REGINFO<geom, "c", "f16">,
+-                          WMMA_REGINFO<geom, "c", "f32">] in {
+-              def : WMMA_LOAD<frag, layout, space, stride, addr>;
+-          }
+-          foreach frag = [WMMA_REGINFO<geom, "d", "f16">,
+-                          WMMA_REGINFO<geom, "d", "f32">] in {
+-              def : WMMA_STORE<frag, layout, space, stride, addr>;
+-          }
+-        } // addr
+-      } // space
+-    } // stride
+-  } // layout
+-} // geom
++defset list<WMMA_INSTR> MMA_LDSTs  = {
++  foreach geom = ["m16n16k16", "m32n8k16", "m8n32k16" ] in {
++    foreach layout = ["row", "col"] in {
++      foreach stride = [0, 1] in {
++        foreach space = [".global", ".shared", ""] in {
++          foreach addr = [imem, Int32Regs, Int64Regs, MEMri, MEMri64] in {
++            foreach frag = [WMMA_REGINFO<geom, "a", "f16">,
++                            WMMA_REGINFO<geom, "b", "f16">,
++                            WMMA_REGINFO<geom, "c", "f16">,
++                            WMMA_REGINFO<geom, "c", "f32">] in {
++                def : WMMA_LOAD<frag, layout, space, stride, addr>;
++            }
++            foreach frag = [WMMA_REGINFO<geom, "d", "f16">,
++                            WMMA_REGINFO<geom, "d", "f32">] in {
++                def : WMMA_STORE_D<frag, layout, space, stride, addr>;
++            }
++          } // addr
++        } // space
++      } // stride
++    } // layout
++  } // geom
++} // defset
+ 
+ // WMMA.MMA
+ class WMMA_MMA<WMMA_REGINFO FragA, WMMA_REGINFO FragB,
+                WMMA_REGINFO FragC, WMMA_REGINFO FragD,
+                string ALayout, string BLayout, int Satfinite>
+-  : EmptyNVPTXInst,
++  : WMMA_INSTR<WMMA_NAME_MMA<ALayout, BLayout, FragC, FragD, Satfinite>.record,
++                             [FragA.Ins, FragB.Ins, FragC.Ins]>,
+     Requires<FragC.Predicates> {
+-  //Intrinsic Intr = int_nvvm_suld_1d_v4i32_zero;
+-  Intrinsic Intr = !cast<Intrinsic>(WMMA_NAME_MMA<ALayout, BLayout, FragC, FragD, Satfinite>.record);
+-  dag Outs = FragD.Outs;
+-  dag Ins = !con(FragA.Ins,
+-                 FragB.Ins,
+-                 FragC.Ins);
+-
+-  // Construct the pattern to match corresponding intrinsic call.
+-  // mma does not load/store anything, so we don't need complex operand matching here.
+-  dag PatOuts = !foreach(tmp, Outs, !subst(outs, set, tmp));
+-  dag PatArgs = !foreach(tmp, Ins, !subst(ins, Intr, tmp));
+-  let Pattern = [!con(PatOuts, (set PatArgs))];
+-  let OutOperandList = Outs;
+-  let InOperandList  = Ins;
+-  let AsmString = "wmma.mma.sync."
+-                  # ALayout
++  let OutOperandList = FragD.Outs;
++  let InOperandList  = !con(Args, (ins MmaCode:$ptx));
++  let AsmString = "wmma.mma.sync"
++                  # "${ptx:aligned}"
++                  # "." # ALayout
+                   # "." # BLayout
+                   # "." # FragA.geom
+                   # "." # FragD.ptx_elt_type
+@@ -7598,20 +7605,34 @@ class WMMA_MMA<WMMA_REGINFO FragA, WMMA_REGINFO FragB,
+                   # FragC.regstring # ";";
+ }
+ 
+-foreach geom = ["m16n16k16", "m32n8k16", "m8n32k16" ] in {
+-  foreach layout_a = ["row", "col"] in {
+-    foreach layout_b = ["row", "col"] in {
+-      foreach frag_c = [WMMA_REGINFO<geom, "c", "f16">,
+-                        WMMA_REGINFO<geom, "c", "f32">] in {
+-        foreach frag_d = [WMMA_REGINFO<geom, "d", "f16">,
+-                          WMMA_REGINFO<geom, "d", "f32">] in {
+-          foreach satf = [0, 1] in {
+-            def : WMMA_MMA<WMMA_REGINFO<geom, "a", "f16">,
+-                           WMMA_REGINFO<geom, "b", "f16">,
+-                           frag_c, frag_d, layout_a, layout_b, satf>;
+-          } // satf
+-        } // frag_d
+-      } // frag_c
+-    } // layout_b
+-  } // layout_a
+-} // geom
++defset list<WMMA_INSTR> MMAs  = {
++  foreach geom = ["m16n16k16", "m32n8k16", "m8n32k16" ] in {
++    foreach layout_a = ["row", "col"] in {
++      foreach layout_b = ["row", "col"] in {
++        foreach frag_c = [WMMA_REGINFO<geom, "c", "f16">,
++                          WMMA_REGINFO<geom, "c", "f32">] in {
++          foreach frag_d = [WMMA_REGINFO<geom, "d", "f16">,
++                            WMMA_REGINFO<geom, "d", "f32">] in {
++            foreach satf = [0, 1] in {
++              def : WMMA_MMA<WMMA_REGINFO<geom, "a", "f16">,
++                             WMMA_REGINFO<geom, "b", "f16">,
++                             frag_c, frag_d, layout_a, layout_b, satf>;
++            } // satf
++          } // frag_d
++        } // frag_c
++      } // layout_b
++    } // layout_a
++  } // geom
++} // defset
++
++// Constructing non-flat DAGs is still a pain. I can't !subst a dag node with a
++// dag, so the ptx.version must be appended *after* foreach replaces 'ins' with
++// the instruction record.
++class WMMA_PAT<WMMA_INSTR wi>
++      : Pat<wi.IntrinsicPattern,
++            !con(!foreach(tmp, wi.Args, !subst(ins, wi, tmp)),
++                 (wi ptx.version))>;
++
++// Build intrinsic->instruction patterns for all MMA instructions.
++foreach mma = !listconcat(MMAs, MMA_LDSTs) in
++  def : WMMA_PAT<mma>;
+diff --git a/test/CodeGen/NVPTX/wmma.py b/test/CodeGen/NVPTX/wmma.py
+index 14bbfd7df09..72d189ca050 100644
+--- a/test/CodeGen/NVPTX/wmma.py
++++ b/test/CodeGen/NVPTX/wmma.py
+@@ -3,9 +3,12 @@
+ 
+ # RUN: python %s > %t.ll
+ # RUN: llc < %t.ll -march=nvptx64 -mcpu=sm_70 -mattr=+ptx61 | FileCheck %t.ll
++# RUN: python %s --ptx=63 > %t-ptx63.ll
++# RUN: llc < %t-ptx63.ll -march=nvptx64 -mcpu=sm_70 -mattr=+ptx63 | FileCheck %t-ptx63.ll
+ 
+ from __future__ import print_function
+ 
++import argparse
+ from itertools import product
+ from string import Template
+ 
+@@ -64,7 +67,7 @@ define ${ret_ty} @test_${function}_o(i8 ${as}* %src ${extra_args}) {
+ }
+ """
+   intrinsic_template = "llvm.nvvm.wmma.${geom}.load.${abc}.${layout}${stride}.${itype}.${pspace}"
+-  instruction_template = "wmma.load.${abc}.sync.${layout}.${geom}${space}.${itype}"
++  instruction_template = "wmma.load.${abc}.sync${aligned}.${layout}.${geom}${space}.${itype}"
+ 
+   for geom, abc, layout, space, stride, itype in product(
+       known_geoms,
+@@ -76,6 +79,7 @@ define ${ret_ty} @test_${function}_o(i8 ${as}* %src ${extra_args}) {
+ 
+     params = {
+         "abc" : abc,
++        "aligned" : ".aligned" if ptx_version >= 63 else "",
+         "layout" : layout,
+         "space" : space,
+         "stride" : stride,
+@@ -135,7 +139,7 @@ define void @test_${function}_o(i8 ${as}* %src, ${args}${extra_args}) {
+ }
+ """
+   intrinsic_template = "llvm.nvvm.wmma.${geom}.store.${abc}.${layout}${stride}.${itype}.${pspace}"
+-  instruction_template = "wmma.store.${abc}.sync.${layout}.${geom}${space}.${itype}"
++  instruction_template = "wmma.store.${abc}.sync${aligned}.${layout}.${geom}${space}.${itype}"
+ 
+   for geom, abc, layout, space, stride, itype in product(
+       known_geoms,
+@@ -147,6 +151,7 @@ define void @test_${function}_o(i8 ${as}* %src, ${args}${extra_args}) {
+ 
+     params = {
+         "abc" : abc,
++        "aligned" : ".aligned" if ptx_version >= 63 else "",
+         "layout" : layout,
+         "space" : space,
+         "stride" : stride,
+@@ -191,7 +196,7 @@ define ${ret_ty} @test_${function}(
+ }
+ """
+   intrinsic_template = "llvm.nvvm.wmma.${geom}.mma.${alayout}.${blayout}.${dtype}.${ctype}${satf}"
+-  instruction_template = "wmma.mma.sync.${alayout}.${blayout}.${geom}.${dtype}.${ctype}${satf}"
++  instruction_template = "wmma.mma.sync${aligned}.${alayout}.${blayout}.${geom}.${dtype}.${ctype}${satf}"
+ 
+   for geom, alayout, blayout, ctype, dtype, satf in product(
+       known_geoms,
+@@ -202,6 +207,7 @@ define ${ret_ty} @test_${function}(
+       [".satfinite", ""]):
+ 
+     params = {
++        "aligned" : ".aligned" if ptx_version >= 63 else "",
+         "alayout" : alayout,
+         "blayout" : blayout,
+         "ctype" : ctype,
+@@ -230,4 +236,9 @@ def main():
+   gen_wmma_store_tests()
+   gen_wmma_mma_tests()
+ 
++parser = argparse.ArgumentParser()
++parser.add_argument('--ptx', type=int, default=60)
++args = parser.parse_args()
++ptx_version = args.ptx
++
+ main()
+-- 
+2.17.1
+
diff -pruN 1.3.1+dfsg-1/deps/patches/llvm-8.0-D63688-wasm-isLocal.patch 1.4.0+dfsg-1/deps/patches/llvm-8.0-D63688-wasm-isLocal.patch
--- 1.3.1+dfsg-1/deps/patches/llvm-8.0-D63688-wasm-isLocal.patch	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/patches/llvm-8.0-D63688-wasm-isLocal.patch	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1,39 @@
+From 83d5085a7fcbb4596d964dbe037c5ebf4de02b69 Mon Sep 17 00:00:00 2001
+From: Keno Fischer <keno@alumni.harvard.edu>
+Date: Sun, 23 Jun 2019 00:29:59 +0000
+Subject: [PATCH] [Support] Fix build under Emscripten
+
+Summary:
+Emscripten's libc doesn't define MNT_LOCAL, thus causing a build
+failure in the fallback path. However, to the best of my knowledge,
+it also doesn't support remote file system mounts, so we may simply
+return `true` here (as we do for e.g. Fuchsia). With this fix, the
+core LLVM libraries build correctly under emscripten (though some
+of the tools and utils do not).
+
+Reviewers: kripken
+Differential Revision: https://reviews.llvm.org/D63688
+
+llvm-svn: 364143
+(cherry picked from commit 5f4ae7c45718618c4c571495e7d910d5722f70ad)
+---
+ llvm/lib/Support/Unix/Path.inc | 3 +++
+ 1 file changed, 3 insertions(+)
+
+diff --git a/lib/Support/Unix/Path.inc b/lib/Support/Unix/Path.inc
+index d7cc0d627d0..eb38a71fffb 100644
+--- a/lib/Support/Unix/Path.inc
++++ b/lib/Support/Unix/Path.inc
+@@ -398,6 +398,9 @@ static bool is_local_impl(struct STATVFS &Vfs) {
+ #elif defined(__Fuchsia__)
+   // Fuchsia doesn't yet support remote filesystem mounts.
+   return true;
++#elif defined(__EMSCRIPTEN__)
++  // Emscripten doesn't currently support remote filesystem mounts.
++  return true;
+ #elif defined(__HAIKU__)
+   // Haiku doesn't expose this information.
+   return false;
+-- 
+2.24.0
+
diff -pruN 1.3.1+dfsg-1/deps/patches/llvm-8.0-D66401-mingw-reloc.patch 1.4.0+dfsg-1/deps/patches/llvm-8.0-D66401-mingw-reloc.patch
--- 1.3.1+dfsg-1/deps/patches/llvm-8.0-D66401-mingw-reloc.patch	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/patches/llvm-8.0-D66401-mingw-reloc.patch	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1,69 @@
+diff --git a/test/CodeGen/X86/mingw-refptr.ll b/test/CodeGen/X86/mingw-refptr.ll
+--- a/test/CodeGen/X86/mingw-refptr.ll
++++ b/test/CodeGen/X86/mingw-refptr.ll
+@@ -1,5 +1,6 @@
+ ; RUN: llc < %s -mtriple=x86_64-w64-mingw32 | FileCheck %s -check-prefix=CHECK-X64
+ ; RUN: llc < %s -mtriple=i686-w64-mingw32 | FileCheck %s -check-prefix=CHECK-X86
++; RUN: llc < %s -mtriple=i686-w64-mingw32-none-elf | FileCheck %s -check-prefix=CHECK-X86-ELF
+ 
+ @var = external local_unnamed_addr global i32, align 4
+ @dsolocalvar = external dso_local local_unnamed_addr global i32, align 4
+@@ -16,6 +17,9 @@
+ ; CHECK-X86:    movl .refptr._var, %eax
+ ; CHECK-X86:    movl (%eax), %eax
+ ; CHECK-X86:    retl
++; CHECK-X86-ELF-LABEL: getVar:
++; CHECK-X86-ELF:    movl var, %eax
++; CHECK-X86-ELF:    retl
+ entry:
+   %0 = load i32, i32* @var, align 4
+   ret i32 %0
+@@ -66,6 +70,9 @@
+ ; CHECK-X86:    movl __imp__extvar, %eax
+ ; CHECK-X86:    movl (%eax), %eax
+ ; CHECK-X86:    retl
++; CHECK-X86-ELF-LABEL: getExtVar:
++; CHECK-X86-ELF:    movl extvar, %eax
++; CHECK-X86-ELF:    retl
+ entry:
+   %0 = load i32, i32* @extvar, align 4
+   ret i32 %0
+diff --git a/lib/Target/X86/X86Subtarget.cpp b/lib/Target/X86/X86Subtarget.cpp
+--- a/lib/Target/X86/X86Subtarget.cpp
++++ b/lib/Target/X86/X86Subtarget.cpp
+@@ -146,6 +146,9 @@
+       return X86II::MO_DLLIMPORT;
+     return X86II::MO_COFFSTUB;
+   }
++  // Some JIT users use *-win32-elf triples; these shouldn't use GOT tables.
++  if (isOSWindows())
++    return X86II::MO_NO_FLAG;
+ 
+   if (is64Bit()) {
+     // ELF supports a large, truly PIC code model with non-PC relative GOT
+diff --git a/lib/Target/TargetMachine.cpp b/lib/Target/TargetMachine.cpp
+--- a/lib/Target/TargetMachine.cpp
++++ b/lib/Target/TargetMachine.cpp
+@@ -128,8 +128,8 @@
+   // don't assume the variables to be DSO local unless we actually know
+   // that for sure. This only has to be done for variables; for functions
+   // the linker can insert thunks for calling functions from another DLL.
+-  if (TT.isWindowsGNUEnvironment() && GV && GV->isDeclarationForLinker() &&
+-      isa<GlobalVariable>(GV))
++  if (TT.isWindowsGNUEnvironment() && TT.isOSBinFormatCOFF() && GV &&
++      GV->isDeclarationForLinker() && isa<GlobalVariable>(GV))
+     return false;
+ 
+   // On COFF, don't mark 'extern_weak' symbols as DSO local. If these symbols
+@@ -142,7 +142,9 @@
+   // Make an exception for windows OS in the triple: Some firmware builds use
+   // *-win32-macho triples. This (accidentally?) produced windows relocations
+   // without GOT tables in older clang versions; Keep this behaviour.
+-  if (TT.isOSBinFormatCOFF() || (TT.isOSWindows() && TT.isOSBinFormatMachO()))
++  // Some JIT users use *-win32-elf triples; these shouldn't use GOT tables
++  // either.
++  if (TT.isOSBinFormatCOFF() || TT.isOSWindows())
+     return true;
+ 
+   // Most PIC code sequences that assume that a symbol is local cannot
+
diff -pruN 1.3.1+dfsg-1/deps/patches/llvm-8.0-D66657-codegen-degenerate.patch 1.4.0+dfsg-1/deps/patches/llvm-8.0-D66657-codegen-degenerate.patch
--- 1.3.1+dfsg-1/deps/patches/llvm-8.0-D66657-codegen-degenerate.patch	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/patches/llvm-8.0-D66657-codegen-degenerate.patch	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1,65 @@
+From 4c7e1defbddafcfcfe1211b041d43a36114a8f48 Mon Sep 17 00:00:00 2001
+From: Valentin Churavy <v.churavy@gmail.com>
+Date: Sat, 14 Dec 2019 10:33:30 -0500
+Subject: [PATCH 2/2] [CodegenPrepare] Guard against degenerate branches
+
+Summary:
+Guard against a potential crash observed in https://github.com/JuliaLang/julia/issues/32994#issuecomment-524249628
+If two branches are collapsed we can encounter a degenerate conditional branch `TBB==FBB`.
+The subsequent code assumes that they differ, so we exit out early.
+
+Reviewers: ributzka, spatel
+
+Subscribers: loladiro, dexonsmith, hiraditya, llvm-commits
+
+Tags: #llvm
+
+Differential Revision: https://reviews.llvm.org/D66657
+---
+ llvm/lib/CodeGen/CodeGenPrepare.cpp            |  4 ++++
+ .../CodeGen/X86/codegen-prepare-collapse.ll    | 18 ++++++++++++++++++
+ 2 files changed, 22 insertions(+)
+ create mode 100644 llvm/test/CodeGen/X86/codegen-prepare-collapse.ll
+
+diff --git a/lib/CodeGen/CodeGenPrepare.cpp b/lib/CodeGen/CodeGenPrepare.cpp
+index c35f8666fa3..3647641c594 100644
+--- a/lib/CodeGen/CodeGenPrepare.cpp
++++ b/lib/CodeGen/CodeGenPrepare.cpp
+@@ -6929,6 +6929,10 @@ bool CodeGenPrepare::splitBranchCondition(Function &F) {
+     if (Br1->getMetadata(LLVMContext::MD_unpredictable))
+       continue;
+ 
++    // The merging of mostly empty BB can cause a degenerate branch.
++    if (TBB == FBB)
++      continue;
++
+     unsigned Opc;
+     Value *Cond1, *Cond2;
+     if (match(LogicOp, m_And(m_OneUse(m_Value(Cond1)),
+diff --git a/test/CodeGen/X86/codegen-prepare-collapse.ll b/test/CodeGen/X86/codegen-prepare-collapse.ll
+new file mode 100644
+index 00000000000..18e3ef7afbd
+--- /dev/null
++++ b/test/CodeGen/X86/codegen-prepare-collapse.ll
+@@ -0,0 +1,18 @@
++; RUN: llc -fast-isel=true -O1 -mtriple=x86_64-unkown-linux-gnu -start-before=codegenprepare -stop-after=codegenprepare -o - < %s | FileCheck %s
++
++; CHECK-LABEL: @foo
++define void @foo() {
++top:
++; CHECK: br label %L34
++  br label %L34
++
++L34:                                              ; preds = %L34, %L34, %top
++  %.sroa.075.0 = phi i64 [ undef, %top ], [ undef, %L34 ], [ undef, %L34 ]
++  %0 = icmp sgt i8 undef, -1
++  %cond5896 = icmp eq i8 0, 2
++  %cond58 = and i1 %cond5896, %0
++; During codegenprepare such degenerate branches can occur and should not
++; lead to crashes.
++; CHECK: br label %L34
++  br i1 %cond58, label %L34, label %L34
++}
+-- 
+2.24.1
+
diff -pruN 1.3.1+dfsg-1/deps/patches/llvm-8.0-D71495-vectorize-freduce.patch 1.4.0+dfsg-1/deps/patches/llvm-8.0-D71495-vectorize-freduce.patch
--- 1.3.1+dfsg-1/deps/patches/llvm-8.0-D71495-vectorize-freduce.patch	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/patches/llvm-8.0-D71495-vectorize-freduce.patch	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1,94 @@
+From 7c30e23f115ae285b497ef11af0153703111dff2 Mon Sep 17 00:00:00 2001
+From: Valentin Churavy <v.churavy@gmail.com>
+Date: Sun, 22 Dec 2019 14:25:50 -0500
+Subject: [PATCH 1/2] [SelectionDAG] Copy FP flags when visiting a binary
+ instruction.
+
+Summary:
+We noticed in Julia that the sequence below no longer turned into
+a sequence of FMA instructions in LLVM 7+, but it did in LLVM 6.
+
+```
+    %29 = fmul contract <4 x double> %wide.load, %wide.load16
+    %30 = fmul contract <4 x double> %wide.load13, %wide.load17
+    %31 = fmul contract <4 x double> %wide.load14, %wide.load18
+    %32 = fmul contract <4 x double> %wide.load15, %wide.load19
+    %33 = fadd fast <4 x double> %vec.phi, %29
+    %34 = fadd fast <4 x double> %vec.phi10, %30
+    %35 = fadd fast <4 x double> %vec.phi11, %31
+    %36 = fadd fast <4 x double> %vec.phi12, %32
+```
+
+Unlike Clang, Julia doesn't set the `unsafe-fp-math=true` function
+attribute, but rather emits more local instruction flags.
+
+This partially undoes https://reviews.llvm.org/D46854 and if required I can try to minimize the test further.
+
+Reviewers: spatel, mcberg2017
+
+Reviewed By: spatel
+
+Subscribers: chriselrod, merge_guards_bot, hiraditya, llvm-commits
+
+Tags: #llvm
+
+Differential Revision: https://reviews.llvm.org/D71495
+---
+ .../SelectionDAG/SelectionDAGBuilder.cpp      |  7 +++++
+ llvm/test/CodeGen/X86/fmf-reduction.ll        | 26 +++++++++++++++++++
+ 2 files changed, 33 insertions(+)
+ create mode 100644 llvm/test/CodeGen/X86/fmf-reduction.ll
+
+diff --git a/lib/CodeGen/SelectionDAG/SelectionDAGBuilder.cpp b/lib/CodeGen/SelectionDAG/SelectionDAGBuilder.cpp
+index bfeb3d1bc2b..e6362c19691 100644
+--- a/lib/CodeGen/SelectionDAG/SelectionDAGBuilder.cpp
++++ b/lib/CodeGen/SelectionDAG/SelectionDAGBuilder.cpp
+@@ -2833,6 +2833,13 @@ void SelectionDAGBuilder::visitBinary(const User &I, unsigned Opcode) {
+   if (isVectorReductionOp(&I)) {
+     Flags.setVectorReduction(true);
+     LLVM_DEBUG(dbgs() << "Detected a reduction operation:" << I << "\n");
++
++    // If no flags are set we will propagate the incoming flags, if any flags
++    // are set, we will intersect them with the incoming flag and so we need to
++    // copy the FMF flags here.
++    if (auto *FPOp = dyn_cast<FPMathOperator>(&I)) {
++      Flags.copyFMF(*FPOp);
++    }
+   }
+ 
+   SDValue Op1 = getValue(I.getOperand(0));
+diff --git a/test/CodeGen/X86/fmf-reduction.ll b/test/CodeGen/X86/fmf-reduction.ll
+new file mode 100644
+index 00000000000..1d669d2a924
+--- /dev/null
++++ b/test/CodeGen/X86/fmf-reduction.ll
+@@ -0,0 +1,26 @@
++; NOTE: Assertions have been autogenerated by utils/update_llc_test_checks.py
++; RUN: llc < %s -mtriple=x86_64-- -mattr=fma | FileCheck %s
++
++; Propagation of IR FMF should not drop flags when adding the DAG reduction flag.
++; This should include an FMA instruction, not separate FMUL/FADD.
++
++define double @julia_dotf(<4 x double> %x, <4 x double> %y, <4 x double> %z, i1 %t3) {
++; CHECK-LABEL: julia_dotf:
++; CHECK:       # %bb.0:
++; CHECK-NEXT:    vfmadd213pd {{.*#+}} ymm0 = (ymm1 * ymm0) + ymm2
++; CHECK-NEXT:    vextractf128 $1, %ymm0, %xmm1
++; CHECK-NEXT:    vaddpd %xmm1, %xmm0, %xmm0
++; CHECK-NEXT:    vpermilpd {{.*#+}} xmm1 = xmm0[1,0]
++; CHECK-NEXT:    vaddsd %xmm1, %xmm0, %xmm0
++; CHECK-NEXT:    vzeroupper
++; CHECK-NEXT:    retq
++  %t1 = fmul contract <4 x double> %x, %y
++  %t2 = fadd fast <4 x double> %z, %t1
++  %rdx.shuf = shufflevector <4 x double> %t2, <4 x double> undef, <4 x i32> <i32 2, i32 3, i32 undef, i32 undef>
++  %bin.rdx22 = fadd fast <4 x double> %t2, %rdx.shuf
++  %rdx.shuf23 = shufflevector <4 x double> %bin.rdx22, <4 x double> undef, <4 x i32> <i32 1, i32 undef, i32 undef, i32 undef>
++  %bin.rdx24 = fadd fast <4 x double> %bin.rdx22, %rdx.shuf23
++  %t4 = extractelement <4 x double> %bin.rdx24, i32 0
++  ret double %t4
++}
++
+-- 
+2.24.1
+
diff -pruN 1.3.1+dfsg-1/deps/patches/llvm-exegesis-mingw.patch 1.4.0+dfsg-1/deps/patches/llvm-exegesis-mingw.patch
--- 1.3.1+dfsg-1/deps/patches/llvm-exegesis-mingw.patch	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/patches/llvm-exegesis-mingw.patch	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1,24 @@
+From 9ba86352649a39b03adce98670714c4c8eb5341d Mon Sep 17 00:00:00 2001
+From: Valentin Churavy <v.churavy@gmail.com>
+Date: Wed, 24 Jul 2019 21:19:20 -0400
+Subject: [PATCH] Fix build of llvm-exegis on mingw32
+
+---
+ llvm/tools/llvm-exegesis/CMakeLists.txt | 2 +-
+ 1 file changed, 1 insertion(+), 1 deletion(-)
+
+diff --git a/tools/llvm-exegesis/CMakeLists.txt b/tools/llvm-exegesis/CMakeLists.txt
+index a59e1b74024..7a30e0ea98f 100644
+--- a/tools/llvm-exegesis/CMakeLists.txt
++++ b/tools/llvm-exegesis/CMakeLists.txt
+@@ -4,7 +4,7 @@ set(LLVM_LINK_COMPONENTS
+   native
+   )
+ 
+-add_llvm_tool(llvm-exegesis
++add_llvm_tool(llvm-exegesis DISABLE_LLVM_LINK_LLVM_DYLIB
+   llvm-exegesis.cpp
+   )
+ 
+-- 
+2.22.0
diff -pruN 1.3.1+dfsg-1/deps/patches/llvm-test-plugin-mingw.patch 1.4.0+dfsg-1/deps/patches/llvm-test-plugin-mingw.patch
--- 1.3.1+dfsg-1/deps/patches/llvm-test-plugin-mingw.patch	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/patches/llvm-test-plugin-mingw.patch	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1,24 @@
+From 9bd3774db73533c8df475639805ff1516aea274c Mon Sep 17 00:00:00 2001
+From: Valentin Churavy <v.churavy@gmail.com>
+Date: Wed, 24 Jul 2019 21:45:33 -0400
+Subject: [PATCH] add missing components to TestPlugin
+
+---
+ llvm/unittests/Passes/CMakeLists.txt | 2 +-
+ 1 file changed, 1 insertion(+), 1 deletion(-)
+
+diff --git a/unittests/Passes/CMakeLists.txt b/unittests/Passes/CMakeLists.txt
+index 3e83b527958..4b09f47c234 100644
+--- a/unittests/Passes/CMakeLists.txt
++++ b/unittests/Passes/CMakeLists.txt
+@@ -14,7 +14,7 @@ add_llvm_unittest(PluginsTests
+ export_executable_symbols(PluginsTests)
+ target_link_libraries(PluginsTests PRIVATE LLVMTestingSupport)
+ 
+-set(LLVM_LINK_COMPONENTS)
++set(LLVM_LINK_COMPONENTS Support Passes Core)
+ add_llvm_library(TestPlugin MODULE BUILDTREE_ONLY
+   TestPlugin.cpp
+   )
+-- 
+2.22.0
diff -pruN 1.3.1+dfsg-1/deps/patches/openblas-winexit.patch 1.4.0+dfsg-1/deps/patches/openblas-winexit.patch
--- 1.3.1+dfsg-1/deps/patches/openblas-winexit.patch	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/patches/openblas-winexit.patch	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1,27 @@
+commit 7f4a96a353c06c2fdecb0b2464800bcf8fab6fd7
+Author: Keno Fischer <keno@juliacomputing.com>
+Date:   Sun Dec 29 15:08:13 2019 -0500
+
+    win32: Don't run cleanup if we're about to exit anyway
+    
+    If the process is about to exit, there's no point trying to do
+    a bunch of work to clean up resources. The kernel will release
+    them much more efficiently when the process exits at the end
+    of this function.
+
+diff --git a/exports/dllinit.c b/exports/dllinit.c
+index 02ff092e..56aafa95 100644
+--- a/exports/dllinit.c
++++ b/exports/dllinit.c
+@@ -48,7 +48,10 @@ BOOL APIENTRY DllMain(HINSTANCE hInst, DWORD reason, LPVOID reserved) {
+   }
+ 
+   if (reason == DLL_PROCESS_DETACH) {
+-    gotoblas_quit();
++    // If the process is about to exit, don't bother releasing any resources
++    // The kernel is much better at bulk releasing then.
++    if (!reserved)
++      gotoblas_quit();
+   }
+ 
+   return TRUE;
diff -pruN 1.3.1+dfsg-1/deps/suitesparse.mk 1.4.0+dfsg-1/deps/suitesparse.mk
--- 1.3.1+dfsg-1/deps/suitesparse.mk	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/suitesparse.mk	2020-03-21 16:36:32.000000000 +0000
@@ -138,10 +138,10 @@ install-suitesparse-wrapper: $(build_shl
 
 else # USE_BINARYBUILDER_SUITESPARSE
 
-SUITESPARSE_BB_URL_BASE := https://github.com/JuliaPackaging/Yggdrasil/releases/download/SuiteSparse-v$(SUITESPARSE_VER)-$(SUITESPARSE_BB_REL)
+SUITESPARSE_BB_URL_BASE := https://github.com/JuliaBinaryWrappers/SuiteSparse_jll.jl/releases/download/SuiteSparse-v$(SUITESPARSE_VER)+$(SUITESPARSE_BB_REL)
 SUITESPARSE_BB_NAME := SuiteSparse.v$(SUITESPARSE_VER)
 
-$(eval $(call bb-install,suitesparse,SUITESPARSE,true))
+$(eval $(call bb-install,suitesparse,SUITESPARSE,false))
 get-suitesparse-wrapper: get-suitesparse
 extract-suitesparse-wrapper: extract-suitesparse
 configure-suitesparse-wrapper: configure-suitesparse
diff -pruN 1.3.1+dfsg-1/deps/tools/bb-install.mk 1.4.0+dfsg-1/deps/tools/bb-install.mk
--- 1.3.1+dfsg-1/deps/tools/bb-install.mk	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/tools/bb-install.mk	2020-03-21 16:36:32.000000000 +0000
@@ -1,12 +1,16 @@
+#$(call bb-install, \
+#    1 target, \               # name (lowercase)
+#    2 variable, \             # name (uppercase)
+#    3 gfortran, \             # signifies a GCC ABI (e.g. libgfortran version) dependency
+#    4 cxx11)                  # signifies a cxx11 ABI dependency
+
 # Auto-detect triplet once, create different versions that we use as defaults below for each BB install target
-# This is much more efficient than launching `gcc` and `python` once for each BB install target.
-BB_TRIPLET_GCCABI_CXXABI := $(shell python $(JULIAHOME)/contrib/normalize_triplet.py $(or $(XC_HOST),$(XC_HOST),$(BUILD_MACHINE)) "$(shell $(FC) --version | head -1)" "$(shell echo '\#include <string>' | $(CXX) $(CXXFLAGS) -x c++ -dM -E - | grep _GLIBCXX_USE_CXX11_ABI | awk '{ print $$3 }' )")
+BB_TRIPLET_GCCABI_CXXABI := $(shell $(call invoke_python,$(JULIAHOME)/contrib/normalize_triplet.py) $(or $(XC_HOST),$(XC_HOST),$(BUILD_MACHINE)) "$(shell $(FC) --version | head -1)" "$(or $(shell echo '\#include <string>' | $(CXX) $(CXXFLAGS) -x c++ -dM -E - | grep _GLIBCXX_USE_CXX11_ABI | awk '{ print $$3 }' ),1)")
 BB_TRIPLET_GCCABI := $(subst $(SPACE),-,$(filter-out cxx%,$(subst -,$(SPACE),$(BB_TRIPLET_GCCABI_CXXABI))))
 BB_TRIPLET_CXXABI := $(subst $(SPACE),-,$(filter-out gcc%,$(subst -,$(SPACE),$(BB_TRIPLET_GCCABI_CXXABI))))
 BB_TRIPLET := $(subst $(SPACE),-,$(filter-out cxx%,$(filter-out gcc%,$(subst -,$(SPACE),$(BB_TRIPLET_GCCABI_CXXABI)))))
 
 define bb-install
-# $(3) signifies a GCC ABI (e.g. libgfortran version) dependency, $(4) signifies a cxx11 ABI dependency
 TRIPLET_VAR := BB_TRIPLET
 ifeq ($(3),true)
 TRIPLET_VAR := $$(TRIPLET_VAR)_GCCABI
@@ -26,20 +30,20 @@ $$(SRCCACHE)/$$($(2)_BB_BASENAME): | $$(
 
 stage-$(strip $1): $$(SRCCACHE)/$$($(2)_BB_BASENAME)
 install-$(strip $1): $$(build_prefix)/manifest/$(strip $1)
-uninstall-$(strip $1):
-	-rm $$(build_prefix)/manifest/$(strip $1)
-	-cd $$(build_prefix) && rm -dv -- $$$$($(TAR) -tzf $$(SRCCACHE)/$$($(2)_BB_BASENAME) --exclude './$$$$')
 
 reinstall-$(strip $1):
 	+$$(MAKE) uninstall-$(strip $1)
 	+$$(MAKE) stage-$(strip $1)
 	+$$(MAKE) install-$(strip $1)
 
+UNINSTALL_$(strip $1) := $$($(2)_BB_BASENAME:.tar.gz=) bb-uninstaller
+
 $$(build_prefix)/manifest/$(strip $1): $$(SRCCACHE)/$$($(2)_BB_BASENAME) | $(build_prefix)/manifest
+	-+[ ! -e $$@ ] || $$(MAKE) uninstall-$(strip $1)
 	$$(JLCHECKSUM) $$<
 	mkdir -p $$(build_prefix)
 	$(UNTAR) $$< -C $$(build_prefix)
-	echo $2 > $$@
+	echo '$$(UNINSTALL_$(strip $1))' > $$@
 
 clean-bb-download-$(1):
 	rm -f $$(SRCCACHE)/$$($(2)_BB_BASENAME)
@@ -62,3 +66,9 @@ $$(error Attempting to use gcc4 $(2) tar
 endif
 endif
 endef
+
+define bb-uninstaller
+uninstall-$(strip $1):
+	-cd $$(build_prefix) && rm -fdv -- $$$$($$(TAR) -tzf $$(SRCCACHE)/$2.tar.gz --exclude './$$$$')
+	-rm $$(build_prefix)/manifest/$(strip $1)
+endef
diff -pruN 1.3.1+dfsg-1/deps/tools/common.mk 1.4.0+dfsg-1/deps/tools/common.mk
--- 1.3.1+dfsg-1/deps/tools/common.mk	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/tools/common.mk	2020-03-21 16:36:32.000000000 +0000
@@ -144,9 +144,6 @@ endef
 define staged-install
 stage-$(strip $1): $$(build_staging)/$2.tgz
 install-$(strip $1): $$(build_prefix)/manifest/$(strip $1)
-uninstall-$(strip $1):
-	-rm $$(build_prefix)/manifest/$(strip $1)
-	-cd $$(build_prefix) && rm -dv -- $$$$($(TAR) -tzf $$(build_staging)/$2.tgz --exclude './$$$$')
 
 ifeq (exists, $$(shell [ -e $$(build_staging)/$2.tgz ] && echo exists ))
 # clean depends on uninstall only if the staged file exists
@@ -171,11 +168,20 @@ $$(build_staging)/$2.tgz: $$(BUILDDIR)/$
 	rm -rf $$(build_staging)/$2
 	mv $$@.tmp $$@
 
+UNINSTALL_$(strip $1) := $2 staged-uninstaller
+
 $$(build_prefix)/manifest/$(strip $1): $$(build_staging)/$2.tgz | $(build_prefix)/manifest
+	-+[ ! -e $$@ ] || $$(MAKE) uninstall-$(strip $1)
 	mkdir -p $$(build_prefix)
 	$(UNTAR) $$< -C $$(build_prefix)
 	$6
-	echo $2 > $$@
+	echo '$$(UNINSTALL_$(strip $1))' > $$@
+endef
+
+define staged-uninstaller
+uninstall-$(strip $1):
+	-cd $$(build_prefix) && rm -fdv -- $$$$($$(TAR) -tzf $$(build_staging)/$2.tgz --exclude './$$$$')
+	-rm $$(build_prefix)/manifest/$(strip $1)
 endef
 
 
@@ -189,16 +195,11 @@ define symlink_install # (target-name, r
 clean-$1: uninstall-$1
 install-$1: $$(build_prefix)/manifest/$1
 reinstall-$1: install-$1
-uninstall-$1:
-ifeq ($$(BUILD_OS), WINNT)
-	-cmd //C rmdir $$(call mingw_to_dos,$3/$1,cd $3 &&)
-else
-	-rm -r $3/$1
-endif
-	-rm $$(build_prefix)/manifest/$1
+
+UNINSTALL_$(strip $1) := $2 symlink-uninstaller $3
 
 $$(build_prefix)/manifest/$1: $$(BUILDDIR)/$2/build-compiled | $3 $$(build_prefix)/manifest
-	+[ ! \( -e $3/$1 -o -h $3/$1 \) ] || $$(MAKE) uninstall-$1
+	-+[ ! \( -e $3/$1 -o -h $3/$1 \) ] || $$(MAKE) uninstall-$1
 ifeq ($$(BUILD_OS), WINNT)
 	cmd //C mklink //J $$(call mingw_to_dos,$3/$1,cd $3 &&) $$(call mingw_to_dos,$$(BUILDDIR)/$2,)
 else ifneq (,$$(findstring CYGWIN,$$(BUILD_OS)))
@@ -208,7 +209,17 @@ else ifdef JULIA_VAGRANT_BUILD
 else
 	ln -sf $$(abspath $$(BUILDDIR)/$2) $3/$1
 endif
-	echo $2 > $$@
+	echo '$$(UNINSTALL_$(strip $1))' > $$@
+endef
+
+define symlink-uninstaller
+uninstall-$1:
+ifeq ($$(BUILD_OS), WINNT)
+	-cmd //C rmdir $$(call mingw_to_dos,$3/$1,cd $3 &&)
+else
+	-rm -r $3/$1
+endif
+	-rm $$(build_prefix)/manifest/$1
 endef
 
 
diff -pruN 1.3.1+dfsg-1/deps/tools/find_python2 1.4.0+dfsg-1/deps/tools/find_python2
--- 1.3.1+dfsg-1/deps/tools/find_python2	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/tools/find_python2	1970-01-01 00:00:00.000000000 +0000
@@ -1,16 +0,0 @@
-#!/bin/sh
-#
-# LLVM requires 2.7 <= python2 < 3
-#
-
-valid_python() {
-    $1 -c 'import sys; sys.exit(not (sys.version_info >= (2,7) and sys.version_info < (3,0)))' 2> /dev/null
-}
-
-for python in python python2 python2.7 python27; do
-    if valid_python $python; then
-        echo `which $python`
-        break
-    fi
-done
-
diff -pruN 1.3.1+dfsg-1/deps/tools/git-external.mk 1.4.0+dfsg-1/deps/tools/git-external.mk
--- 1.3.1+dfsg-1/deps/tools/git-external.mk	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/tools/git-external.mk	2020-03-21 16:36:32.000000000 +0000
@@ -22,6 +22,8 @@
 #
 define git-external
 include $$(SRCDIR)/$1.version
+$2_SHA1 := $$(strip $$($2_SHA1))
+$2_BRANCH := $$(strip $$($2_BRANCH))
 
 ifneq (,$$(filter $1 1,$$(DEPS_GIT)))
 $2_SRC_DIR := $1
diff -pruN 1.3.1+dfsg-1/deps/tools/uninstallers.mk 1.4.0+dfsg-1/deps/tools/uninstallers.mk
--- 1.3.1+dfsg-1/deps/tools/uninstallers.mk	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/deps/tools/uninstallers.mk	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1,31 @@
+# include after all other files:
+# defines uninstallers and version-checks
+# based on the contents of the UNINSTALL_* variables and the manifest files
+
+install: version-check
+version-check: $(addprefix version-check-, $(DEP_LIBS_STAGED))
+uninstall: $(addprefix uninstall-, $(DEP_LIBS_STAGED))
+
+## read 'uninstall-*' definition from either the manifest or the current session
+define define-uninstaller
+MANIFEST_$1 := $$(shell [ -e $$(build_prefix)/manifest/$1 ] && cat $$(build_prefix)/manifest/$1)
+ifeq (undefined,$$(flavor $$(word 2,$$(MANIFEST_$1))))
+MANIFEST_$1 := $$(UNINSTALL_$1)
+endif
+UNINST_HOW_$1 := $$(word 2,$$(MANIFEST_$1))
+ifneq ($$(UNINST_HOW_$1),)
+UNINST_WHO_$1 := $$(firstword $$(MANIFEST_$1))
+UNINST_WHERE_$1 := $$(wordlist 3,99,$$(MANIFEST_$1))
+$$(eval $$(call $$(UNINST_HOW_$1),$1,$$(UNINST_WHO_$1),$$(UNINST_WHERE_$1)))
+endif
+endef
+$(foreach dep,$(DEP_LIBS_STAGED),$(eval $(call define-uninstaller,$(dep))))
+
+# for each subproject with a manifest, keep the user aware if something is not the expected version
+$(addprefix version-check-,$(DEP_LIBS_STAGED)) : version-check-% : install-%
+	@if [ ! -e $(build_prefix)/manifest/$* ] || ( \
+			[ "1" != "`wc -w $(build_prefix)/manifest/$* | cut -f 1 -d ' '`" ] && \
+			[ "$(UNINSTALL_$*)" != "`cat $(build_prefix)/manifest/$*`" ]) ; then \
+		echo "WARNING: using mismatched version for $$(cat $(build_prefix)/manifest/$*):" ; \
+		echo "  want $(UNINSTALL_$*)" ; \
+	fi
diff -pruN 1.3.1+dfsg-1/deps/Versions.make 1.4.0+dfsg-1/deps/Versions.make
--- 1.3.1+dfsg-1/deps/Versions.make	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/deps/Versions.make	2020-03-21 16:36:32.000000000 +0000
@@ -1,11 +1,11 @@
-LLVM_VER = 6.0.1
-LLVM_BB_REL = 7+nowasm
+LLVM_VER = 8.0.1
+LLVM_BB_REL = 0
 PCRE_VER = 10.31
 PCRE_BB_REL = 0
 DSFMT_VER = 2.2.3
 DSFMT_BB_REL = 0
 OPENBLAS_VER = 0.3.5
-OPENBLAS_BB_REL = 2
+OPENBLAS_BB_REL = 1
 LAPACK_VER = 3.5.0
 SUITESPARSE_VER = 5.4.0
 SUITESPARSE_BB_REL = 2
@@ -16,18 +16,18 @@ UNWIND_BB_REL = 4
 OSXUNWIND_VER = 0.0.5
 OSXUNWIND_BB_REL = 0
 GMP_VER = 6.1.2
-GMP_BB_REL = 3
+GMP_BB_REL = 4
 MPFR_VER = 4.0.2
-MPFR_BB_REL = 0
+MPFR_BB_REL = 2
 PATCHELF_VER = 0.9
 MBEDTLS_VER = 2.16.0
-MBEDTLS_BB_REL = v0.17.0
+MBEDTLS_BB_REL = 1
 LIBSSH2_VER = 1.9.0
-LIBSSH2_BB_REL = 0
-CURL_VER = 7.61.0
+LIBSSH2_BB_REL = 1
+CURL_VER = 7.66.0
 CURL_BB_REL = 1
 LIBGIT2_VER = 0.28.2
-LIBGIT2_BB_REL = 0
+LIBGIT2_BB_REL = 1
 LIBUV_VER = 1.29.1
 LIBUV_BB_REL = 0
 OBJCONV_VER = 2.49.0
@@ -40,4 +40,4 @@ P7ZIP_BB_REL = 1
 # Specify the version of the Mozilla CA Certificate Store to obtain.
 # The versions of cacert.pem are identified by the date (YYYY-MM-DD) of their changes.
 # See https://curl.haxx.se/docs/caextract.html for more details.
-MOZILLA_CACERT_VERSION := 2019-10-16
+MOZILLA_CACERT_VERSION := 2020-01-01
diff -pruN 1.3.1+dfsg-1/doc/build/build.md 1.4.0+dfsg-1/doc/build/build.md
--- 1.3.1+dfsg-1/doc/build/build.md	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/doc/build/build.md	2020-03-21 16:36:32.000000000 +0000
@@ -257,3 +257,15 @@ Add the following to the `Make.user` fil
     USE_INTEL_MKL = 1
 
 It is highly recommended to start with a fresh clone of the Julia repository.
+
+## Source distributions of releases
+
+Each pre-release and release of Julia has a "full" source distribution and a "light" source
+distribution.
+
+The full source distribution contains the source code for Julia and all dependencies so
+that it can be built from source without an internet connection. The light source
+distribution does not include the source code of dependencies.
+
+For example, `julia-1.0.0.tar.gz` is the light source distribution for the `v1.0.0` release
+of Julia, while `julia-1.0.0-full.tar.gz` is the full source distribution.
diff -pruN 1.3.1+dfsg-1/doc/build/windows.md 1.4.0+dfsg-1/doc/build/windows.md
--- 1.3.1+dfsg-1/doc/build/windows.md	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/doc/build/windows.md	2020-03-21 16:36:32.000000000 +0000
@@ -211,16 +211,17 @@ end
 
 ### Cross-building Julia without Vagrant
 
-If you don't care that the build is potentially incompatible with the WinRPM
-ecosystem (or happen to be on opensuse), use the following steps to
-cross-compile julia:
+Alternatively, if you want to build it on the local system,
+use the following steps to cross-compile julia:
 
 First, you will need to ensure your system has the required dependencies.  We
 need wine (>=1.7.5), a system compiler, and some downloaders.
 
 **On Ubuntu** (on other linux systems, the dependency names are likely to be similar):
 ```sh
-apt-get install wine-stable subversion cvs gcc wget p7zip-full winbind mingw-w64 gfortran-mingw-w64
+apt-get install wine-stable gcc wget p7zip-full winbind mingw-w64 gfortran-mingw-w64
+# switch all of the following to their "-posix" variants (interactively):
+for pkg in i686-w64-mingw32-g++ i686-w64-mingw32-gcc i686-w64-mingw32-gfortran x86_64-w64-mingw32-g++ x86_64-w64-mingw32-gcc x86_64-w64-mingw32-gfortran; do sudo update-alternatives --config $pkg; done
 ```
 
 **On Mac**: Install XCode, XCode command line tools, X11 (now [XQuartz](
diff -pruN 1.3.1+dfsg-1/doc/make.jl 1.4.0+dfsg-1/doc/make.jl
--- 1.3.1+dfsg-1/doc/make.jl	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/doc/make.jl	2020-03-21 16:36:32.000000000 +0000
@@ -172,6 +172,8 @@ else
         canonical = ("deploy" in ARGS) ? "https://docs.julialang.org/en/v1/" : nothing,
         assets = ["assets/julia-manual.css", ],
         analytics = "UA-28835595-6",
+        collapselevel = 1,
+        sidebar_sitename = false,
     )
 end
 
@@ -190,28 +192,23 @@ makedocs(
     pages     = PAGES,
 )
 
-# Only deploy docs from 64bit Linux to avoid committing multiple versions of the same
-# docs from different workers.
-if "deploy" in ARGS && Sys.ARCH === :x86_64 && Sys.KERNEL === :Linux
-
-# Override a few environment variables to deploy to the appropriate repository,
-# encode things like branch, whether it's built on a tag, etc....
-env_mappings = [
-    "TRAVIS_REPO_SLUG" => "JuliaLang/docs.julialang.org",
-    "TRAVIS_BRANCH" => Base.GIT_VERSION_INFO.branch,
-]
-
-if Base.GIT_VERSION_INFO.tagged_commit
-    push!(env_mappings, "TRAVIS_TAG" => "v$(Base.VERSION)")
+# Define our own DeployConfig
+struct BuildBotConfig <: Documenter.DeployConfig end
+function Documenter.deploy_folder(::BuildBotConfig; devurl, kwargs...)
+    haskey(ENV, "DOCUMENTER_KEY") || return nothing
+    if Base.GIT_VERSION_INFO.tagged_commit
+        return "v$(Base.VERSION)"
+    elseif Base.GIT_VERSION_INFO.branch == "master"
+        return devurl
+    end
+    return nothing
 end
 
-withenv(env_mappings...) do
-    deploydocs(
-        repo = "github.com/JuliaLang/docs.julialang.org.git",
-        target = joinpath(buildroot, "doc", "_build", "html", "en"),
-        dirname = "en",
-        devurl = "v1.3-dev",
-        versions = ["v#.#", "v1.3-dev" => "v1.3-dev"]
-    )
-end
-end
+deploydocs(
+    repo = "github.com/JuliaLang/docs.julialang.org.git",
+    deploy_config = BuildBotConfig(),
+    target = joinpath(buildroot, "doc", "_build", "html", "en"),
+    dirname = "en",
+    devurl = "v1.4-dev",
+    versions = ["v#.#", "v1.4-dev" => "v1.4-dev"]
+)
diff -pruN 1.3.1+dfsg-1/doc/Manifest.toml 1.4.0+dfsg-1/doc/Manifest.toml
--- 1.3.1+dfsg-1/doc/Manifest.toml	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/doc/Manifest.toml	2020-03-21 16:36:32.000000000 +0000
@@ -13,15 +13,15 @@ uuid = "8ba89e20-285c-5b6f-9357-94700520
 
 [[DocStringExtensions]]
 deps = ["LibGit2", "Markdown", "Pkg", "Test"]
-git-tree-sha1 = "0513f1a8991e9d83255e0140aace0d0fc4486600"
+git-tree-sha1 = "88bb0edb352b16608036faadcc071adda068582a"
 uuid = "ffbed154-4ef7-542d-bbb7-c09d3a79fcae"
-version = "0.8.0"
+version = "0.8.1"
 
 [[Documenter]]
-deps = ["Base64", "DocStringExtensions", "InteractiveUtils", "JSON", "LibGit2", "Logging", "Markdown", "REPL", "Test", "Unicode"]
-git-tree-sha1 = "1dba3854d6b0e35b3ed77f84419efbaf81f28886"
+deps = ["Base64", "Dates", "DocStringExtensions", "InteractiveUtils", "JSON", "LibGit2", "Logging", "Markdown", "REPL", "Test", "Unicode"]
+git-tree-sha1 = "51f0c7df46abb9c07d80e529718951e634670afb"
 uuid = "e30172f5-a6a5-5a46-863b-614d45cd2de4"
-version = "0.23.1"
+version = "0.24.4"
 
 [[DocumenterLaTeX]]
 deps = ["Documenter", "Test"]
@@ -40,8 +40,12 @@ uuid = "682c06a0-de6a-54ab-a142-c8b1cf79
 version = "0.21.0"
 
 [[LibGit2]]
+deps = ["Printf"]
 uuid = "76f85450-5226-5b5a-8eaa-529ad045b433"
 
+[[Libdl]]
+uuid = "8f399da3-3557-5675-b5ff-fb832c97cbdb"
+
 [[Logging]]
 uuid = "56ddb016-857b-54e1-b83d-db4d58db5568"
 
@@ -54,12 +58,12 @@ uuid = "a63ad114-7e13-5084-954f-fe012c67
 
 [[Parsers]]
 deps = ["Dates", "Test"]
-git-tree-sha1 = "db2b35dedab3c0e46dc15996d170af07a5ab91c9"
+git-tree-sha1 = "0139ba59ce9bc680e2925aec5b7db79065d60556"
 uuid = "69de0a69-1ddd-5017-9359-2bf0b02dc9f0"
-version = "0.3.6"
+version = "0.3.10"
 
 [[Pkg]]
-deps = ["Dates", "LibGit2", "Markdown", "Printf", "REPL", "Random", "SHA", "UUIDs"]
+deps = ["Dates", "LibGit2", "Libdl", "Logging", "Markdown", "Printf", "REPL", "Random", "SHA", "UUIDs"]
 uuid = "44cfe95a-1eb2-52ea-b672-e2afdf69b78f"
 
 [[Printf]]
diff -pruN 1.3.1+dfsg-1/doc/README.md 1.4.0+dfsg-1/doc/README.md
--- 1.3.1+dfsg-1/doc/README.md	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/doc/README.md	2020-03-21 16:36:32.000000000 +0000
@@ -1,6 +1,6 @@
 # Julia Documentation README
 
-Julia's documentation is written in Markdown. A reference of all supported syntax can be found in the [manual](https://docs.julialang.org/en/latest/manual/documentation/#Markdown-syntax-1). All documentation can be found in the Markdown files in `doc/src/` and the docstrings in Julia source files in `base/`.
+Julia's documentation is written in Markdown. A reference of all supported syntax can be found in the [manual](https://docs.julialang.org/en/v1/stdlib/Markdown/). All documentation can be found in the Markdown files in `doc/src/` and the docstrings in Julia source files in `base/` and `stdlib/`.
 
 ## Requirements
 
@@ -27,4 +27,3 @@ $ make -C doc doctest=true
 ```
 
 from the root directory.
-
diff -pruN 1.3.1+dfsg-1/doc/src/assets/logo-dark.svg 1.4.0+dfsg-1/doc/src/assets/logo-dark.svg
--- 1.3.1+dfsg-1/doc/src/assets/logo-dark.svg	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/doc/src/assets/logo-dark.svg	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1,10 @@
+<?xml version="1.0" encoding="UTF-8"?>
+<svg xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink" width="320pt" height="200pt" viewBox="0 0 320 200" version="1.1">
+<g id="surface1">
+<path style=" stroke:none;fill-rule:nonzero;fill:rgb(100%,100%,100%);fill-opacity:1;" d="M 67.871094 164.3125 C 67.871094 171.847656 67.023438 177.933594 65.328125 182.566406 C 63.632812 187.203125 61.222656 190.800781 58.09375 193.363281 C 54.96875 195.925781 51.21875 197.640625 46.847656 198.507812 C 42.476562 199.371094 37.613281 199.804688 32.265625 199.804688 C 25.027344 199.804688 19.488281 198.675781 15.648438 196.414062 C 11.804688 194.152344 9.882812 191.441406 9.882812 188.273438 C 9.882812 185.636719 10.953125 183.414062 13.101562 181.605469 C 15.25 179.796875 18.132812 178.894531 21.75 178.894531 C 24.464844 178.894531 26.632812 179.628906 28.25 181.097656 C 29.871094 182.566406 31.210938 184.019531 32.265625 185.449219 C 33.46875 187.03125 34.488281 188.085938 35.316406 188.613281 C 36.144531 189.140625 36.898438 189.40625 37.578125 189.40625 C 39.007812 189.40625 40.101562 188.558594 40.855469 186.863281 C 41.609375 185.167969 41.984375 181.871094 41.984375 176.972656 L 41.984375 84.050781 L 67.871094 76.929688 L 67.871094 164.3125 M 104.738281 79.414062 L 104.738281 139.214844 C 104.738281 140.875 105.058594 142.4375 105.699219 143.90625 C 106.339844 145.375 107.226562 146.640625 108.355469 147.695312 C 109.488281 148.75 110.804688 149.597656 112.3125 150.238281 C 113.820312 150.878906 115.441406 151.199219 117.175781 151.199219 C 119.132812 151.199219 121.359375 150.101562 124.070312 148.203125 C 128.363281 145.195312 130.964844 143.128906 130.964844 140.683594 C 130.964844 140.097656 130.964844 79.414062 130.964844 79.414062 L 156.738281 79.414062 L 156.738281 164.3125 L 130.964844 164.3125 L 130.964844 156.398438 C 127.574219 159.261719 123.957031 161.558594 120.113281 163.292969 C 116.269531 165.027344 112.539062 165.894531 108.921875 165.894531 C 104.703125 165.894531 100.78125 165.195312 97.164062 163.800781 C 93.546875 162.40625 90.382812 160.503906 87.671875 158.09375 C 84.957031 155.683594 82.828125 152.855469 81.28125 149.613281 C 79.738281 146.375 78.964844 142.90625 78.964844 139.214844 L 78.964844 79.414062 L 104.738281 79.414062 M 192.882812 164.3125 L 167.222656 164.3125 L 167.222656 45.277344 L 192.882812 38.15625 L 192.882812 164.3125 M 203.601562 84.050781 L 229.375 76.929688 L 229.375 164.3125 L 203.601562 164.3125 L 203.601562 84.050781 M 283.226562 120.449219 C 280.738281 121.507812 278.230469 122.730469 275.707031 124.125 C 273.183594 125.519531 270.882812 127.046875 268.8125 128.703125 C 266.738281 130.359375 265.0625 132.132812 263.78125 134.015625 C 262.5 135.898438 261.859375 137.859375 261.859375 139.894531 C 261.859375 141.476562 262.066406 143.003906 262.480469 144.472656 C 262.894531 145.941406 263.480469 147.203125 264.234375 148.257812 C 264.988281 149.3125 265.816406 150.160156 266.722656 150.800781 C 267.625 151.441406 268.605469 151.761719 269.660156 151.761719 C 271.769531 151.761719 273.898438 151.121094 276.046875 149.839844 C 278.195312 148.558594 280.585938 146.941406 283.226562 144.980469 L 283.226562 120.449219 M 309.109375 164.3125 L 283.226562 164.3125 L 283.226562 157.527344 C 281.792969 158.734375 280.398438 159.847656 279.042969 160.863281 C 277.6875 161.878906 276.160156 162.765625 274.464844 163.519531 C 272.769531 164.273438 270.867188 164.855469 268.753906 165.273438 C 266.644531 165.6875 264.15625 165.894531 261.296875 165.894531 C 257.375 165.894531 253.851562 165.328125 250.726562 164.199219 C 247.597656 163.066406 244.941406 161.523438 242.757812 159.5625 C 240.570312 157.605469 238.894531 155.285156 237.726562 152.609375 C 236.558594 149.9375 235.972656 147.015625 235.972656 143.851562 C 235.972656 140.609375 236.59375 137.671875 237.839844 135.03125 C 239.082031 132.394531 240.777344 130.023438 242.925781 127.910156 C 245.074219 125.800781 247.578125 123.917969 250.441406 122.257812 C 253.304688 120.601562 256.378906 119.074219 259.65625 117.679688 C 262.933594 116.285156 266.34375 115.007812 269.886719 113.839844 C 273.425781 112.671875 276.933594 111.558594 280.398438 110.503906 L 283.226562 109.824219 L 283.226562 101.460938 C 283.226562 96.035156 282.1875 92.191406 280.117188 89.929688 C 278.042969 87.667969 275.273438 86.539062 271.808594 86.539062 C 267.738281 86.539062 264.910156 87.519531 263.328125 89.476562 C 261.746094 91.4375 260.953125 93.808594 260.953125 96.597656 C 260.953125 98.179688 260.785156 99.726562 260.445312 101.234375 C 260.109375 102.742188 259.523438 104.058594 258.695312 105.191406 C 257.867188 106.320312 256.679688 107.226562 255.132812 107.902344 C 253.589844 108.582031 251.648438 108.921875 249.3125 108.921875 C 245.695312 108.921875 242.757812 107.882812 240.496094 105.8125 C 238.234375 103.738281 237.105469 101.121094 237.105469 97.953125 C 237.105469 95.015625 238.101562 92.285156 240.097656 89.761719 C 242.097656 87.234375 244.789062 85.066406 248.183594 83.261719 C 251.574219 81.449219 255.492188 80.019531 259.9375 78.964844 C 264.382812 77.910156 269.09375 77.382812 274.066406 77.382812 C 280.171875 77.382812 285.429688 77.929688 289.839844 79.019531 C 294.246094 80.113281 297.882812 81.675781 300.746094 83.710938 C 303.609375 85.746094 305.71875 88.195312 307.074219 91.058594 C 308.433594 93.921875 309.109375 97.128906 309.109375 100.667969 L 309.109375 164.3125 "/>
+<path style=" stroke:none;fill-rule:nonzero;fill:rgb(79.6%,23.5%,20%);fill-opacity:1;" d="M 235.273438 55.089844 C 235.273438 64.757812 227.4375 72.589844 217.773438 72.589844 C 208.105469 72.589844 200.273438 64.757812 200.273438 55.089844 C 200.273438 45.425781 208.105469 37.589844 217.773438 37.589844 C 227.4375 37.589844 235.273438 45.425781 235.273438 55.089844 "/>
+<path style=" stroke:none;fill-rule:nonzero;fill:rgb(25.1%,38.8%,84.7%);fill-opacity:1;" d="M 72.953125 55.089844 C 72.953125 64.757812 65.117188 72.589844 55.453125 72.589844 C 45.789062 72.589844 37.953125 64.757812 37.953125 55.089844 C 37.953125 45.425781 45.789062 37.589844 55.453125 37.589844 C 65.117188 37.589844 72.953125 45.425781 72.953125 55.089844 "/>
+<path style=" stroke:none;fill-rule:nonzero;fill:rgb(58.4%,34.5%,69.8%);fill-opacity:1;" d="M 277.320312 55.089844 C 277.320312 64.757812 269.484375 72.589844 259.820312 72.589844 C 250.15625 72.589844 242.320312 64.757812 242.320312 55.089844 C 242.320312 45.425781 250.15625 37.589844 259.820312 37.589844 C 269.484375 37.589844 277.320312 45.425781 277.320312 55.089844 "/>
+<path style=" stroke:none;fill-rule:nonzero;fill:rgb(22%,59.6%,14.9%);fill-opacity:1;" d="M 256.300781 18.671875 C 256.300781 28.335938 248.464844 36.171875 238.800781 36.171875 C 229.132812 36.171875 221.300781 28.335938 221.300781 18.671875 C 221.300781 9.007812 229.132812 1.171875 238.800781 1.171875 C 248.464844 1.171875 256.300781 9.007812 256.300781 18.671875 "/>
+</g>
+</svg>
Binary files 1.3.1+dfsg-1/doc/src/assets/logo.png and 1.4.0+dfsg-1/doc/src/assets/logo.png differ
diff -pruN 1.3.1+dfsg-1/doc/src/assets/logo.svg 1.4.0+dfsg-1/doc/src/assets/logo.svg
--- 1.3.1+dfsg-1/doc/src/assets/logo.svg	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/doc/src/assets/logo.svg	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1,10 @@
+<?xml version="1.0" encoding="UTF-8"?>
+<svg xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink" width="320pt" height="200pt" viewBox="0 0 320 200" version="1.1">
+<g id="surface61">
+<path style=" stroke:none;fill-rule:nonzero;fill:rgb(0%,0%,0%);fill-opacity:1;" d="M 67.871094 164.3125 C 67.871094 171.847656 67.023438 177.933594 65.328125 182.566406 C 63.632812 187.203125 61.222656 190.800781 58.09375 193.363281 C 54.96875 195.925781 51.21875 197.640625 46.847656 198.507812 C 42.476562 199.371094 37.613281 199.804688 32.265625 199.804688 C 25.027344 199.804688 19.488281 198.675781 15.648438 196.414062 C 11.804688 194.152344 9.882812 191.441406 9.882812 188.273438 C 9.882812 185.636719 10.953125 183.414062 13.101562 181.605469 C 15.25 179.796875 18.132812 178.894531 21.75 178.894531 C 24.464844 178.894531 26.632812 179.628906 28.25 181.097656 C 29.871094 182.566406 31.210938 184.019531 32.265625 185.449219 C 33.46875 187.03125 34.488281 188.085938 35.316406 188.613281 C 36.144531 189.140625 36.898438 189.40625 37.578125 189.40625 C 39.007812 189.40625 40.101562 188.558594 40.855469 186.863281 C 41.609375 185.167969 41.984375 181.871094 41.984375 176.972656 L 41.984375 84.050781 L 67.871094 76.929688 L 67.871094 164.3125 M 104.738281 79.414062 L 104.738281 139.214844 C 104.738281 140.875 105.058594 142.4375 105.699219 143.90625 C 106.339844 145.375 107.226562 146.640625 108.355469 147.695312 C 109.488281 148.75 110.804688 149.597656 112.3125 150.238281 C 113.820312 150.878906 115.441406 151.199219 117.175781 151.199219 C 119.132812 151.199219 121.359375 150.101562 124.070312 148.203125 C 128.363281 145.195312 130.964844 143.128906 130.964844 140.683594 C 130.964844 140.097656 130.964844 79.414062 130.964844 79.414062 L 156.738281 79.414062 L 156.738281 164.3125 L 130.964844 164.3125 L 130.964844 156.398438 C 127.574219 159.261719 123.957031 161.558594 120.113281 163.292969 C 116.269531 165.027344 112.539062 165.894531 108.921875 165.894531 C 104.703125 165.894531 100.78125 165.195312 97.164062 163.800781 C 93.546875 162.40625 90.382812 160.503906 87.671875 158.09375 C 84.957031 155.683594 82.828125 152.855469 81.28125 149.613281 C 79.738281 146.375 78.964844 142.90625 78.964844 139.214844 L 78.964844 79.414062 L 104.738281 79.414062 M 192.882812 164.3125 L 167.222656 164.3125 L 167.222656 45.277344 L 192.882812 38.15625 L 192.882812 164.3125 M 203.601562 84.050781 L 229.375 76.929688 L 229.375 164.3125 L 203.601562 164.3125 L 203.601562 84.050781 M 283.226562 120.449219 C 280.738281 121.507812 278.230469 122.730469 275.707031 124.125 C 273.183594 125.519531 270.882812 127.046875 268.8125 128.703125 C 266.738281 130.359375 265.0625 132.132812 263.78125 134.015625 C 262.5 135.898438 261.859375 137.859375 261.859375 139.894531 C 261.859375 141.476562 262.066406 143.003906 262.480469 144.472656 C 262.894531 145.941406 263.480469 147.203125 264.234375 148.257812 C 264.988281 149.3125 265.816406 150.160156 266.722656 150.800781 C 267.625 151.441406 268.605469 151.761719 269.660156 151.761719 C 271.769531 151.761719 273.898438 151.121094 276.046875 149.839844 C 278.195312 148.558594 280.585938 146.941406 283.226562 144.980469 L 283.226562 120.449219 M 309.109375 164.3125 L 283.226562 164.3125 L 283.226562 157.527344 C 281.792969 158.734375 280.398438 159.847656 279.042969 160.863281 C 277.6875 161.878906 276.160156 162.765625 274.464844 163.519531 C 272.769531 164.273438 270.867188 164.855469 268.753906 165.273438 C 266.644531 165.6875 264.15625 165.894531 261.296875 165.894531 C 257.375 165.894531 253.851562 165.328125 250.726562 164.199219 C 247.597656 163.066406 244.941406 161.523438 242.757812 159.5625 C 240.570312 157.605469 238.894531 155.285156 237.726562 152.609375 C 236.558594 149.9375 235.972656 147.015625 235.972656 143.851562 C 235.972656 140.609375 236.59375 137.671875 237.839844 135.03125 C 239.082031 132.394531 240.777344 130.023438 242.925781 127.910156 C 245.074219 125.800781 247.578125 123.917969 250.441406 122.257812 C 253.304688 120.601562 256.378906 119.074219 259.65625 117.679688 C 262.933594 116.285156 266.34375 115.007812 269.886719 113.839844 C 273.425781 112.671875 276.933594 111.558594 280.398438 110.503906 L 283.226562 109.824219 L 283.226562 101.460938 C 283.226562 96.035156 282.1875 92.191406 280.117188 89.929688 C 278.042969 87.667969 275.273438 86.539062 271.808594 86.539062 C 267.738281 86.539062 264.910156 87.519531 263.328125 89.476562 C 261.746094 91.4375 260.953125 93.808594 260.953125 96.597656 C 260.953125 98.179688 260.785156 99.726562 260.445312 101.234375 C 260.109375 102.742188 259.523438 104.058594 258.695312 105.191406 C 257.867188 106.320312 256.679688 107.226562 255.132812 107.902344 C 253.589844 108.582031 251.648438 108.921875 249.3125 108.921875 C 245.695312 108.921875 242.757812 107.882812 240.496094 105.8125 C 238.234375 103.738281 237.105469 101.121094 237.105469 97.953125 C 237.105469 95.015625 238.101562 92.285156 240.097656 89.761719 C 242.097656 87.234375 244.789062 85.066406 248.183594 83.261719 C 251.574219 81.449219 255.492188 80.019531 259.9375 78.964844 C 264.382812 77.910156 269.09375 77.382812 274.066406 77.382812 C 280.171875 77.382812 285.429688 77.929688 289.839844 79.019531 C 294.246094 80.113281 297.882812 81.675781 300.746094 83.710938 C 303.609375 85.746094 305.71875 88.195312 307.074219 91.058594 C 308.433594 93.921875 309.109375 97.128906 309.109375 100.667969 L 309.109375 164.3125 "/>
+<path style=" stroke:none;fill-rule:nonzero;fill:rgb(79.6%,23.5%,20%);fill-opacity:1;" d="M 235.273438 55.089844 C 235.273438 64.757812 227.4375 72.589844 217.773438 72.589844 C 208.105469 72.589844 200.273438 64.757812 200.273438 55.089844 C 200.273438 45.425781 208.105469 37.589844 217.773438 37.589844 C 227.4375 37.589844 235.273438 45.425781 235.273438 55.089844 "/>
+<path style=" stroke:none;fill-rule:nonzero;fill:rgb(25.1%,38.8%,84.7%);fill-opacity:1;" d="M 72.953125 55.089844 C 72.953125 64.757812 65.117188 72.589844 55.453125 72.589844 C 45.789062 72.589844 37.953125 64.757812 37.953125 55.089844 C 37.953125 45.425781 45.789062 37.589844 55.453125 37.589844 C 65.117188 37.589844 72.953125 45.425781 72.953125 55.089844 "/>
+<path style=" stroke:none;fill-rule:nonzero;fill:rgb(58.4%,34.5%,69.8%);fill-opacity:1;" d="M 277.320312 55.089844 C 277.320312 64.757812 269.484375 72.589844 259.820312 72.589844 C 250.15625 72.589844 242.320312 64.757812 242.320312 55.089844 C 242.320312 45.425781 250.15625 37.589844 259.820312 37.589844 C 269.484375 37.589844 277.320312 45.425781 277.320312 55.089844 "/>
+<path style=" stroke:none;fill-rule:nonzero;fill:rgb(22%,59.6%,14.9%);fill-opacity:1;" d="M 256.300781 18.671875 C 256.300781 28.335938 248.464844 36.171875 238.800781 36.171875 C 229.132812 36.171875 221.300781 28.335938 221.300781 18.671875 C 221.300781 9.007812 229.132812 1.171875 238.800781 1.171875 C 248.464844 1.171875 256.300781 9.007812 256.300781 18.671875 "/>
+</g>
+</svg>
diff -pruN 1.3.1+dfsg-1/doc/src/base/base.md 1.4.0+dfsg-1/doc/src/base/base.md
--- 1.3.1+dfsg-1/doc/src/base/base.md	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/doc/src/base/base.md	2020-03-21 16:36:32.000000000 +0000
@@ -395,6 +395,7 @@ Base.functionloc(::Method)
 Base.GC.gc
 Base.GC.enable
 Base.GC.@preserve
+Base.GC.safepoint
 Meta.lower
 Meta.@lower
 Meta.parse(::AbstractString, ::Int)
diff -pruN 1.3.1+dfsg-1/doc/src/base/c.md 1.4.0+dfsg-1/doc/src/base/c.md
--- 1.3.1+dfsg-1/doc/src/base/c.md	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/doc/src/base/c.md	2020-03-21 16:36:32.000000000 +0000
@@ -19,6 +19,7 @@ Base.unsafe_pointer_to_objref
 Base.disable_sigint
 Base.reenable_sigint
 Base.systemerror
+Base.windowserror
 Core.Ptr
 Core.Ref
 Base.Cchar
diff -pruN 1.3.1+dfsg-1/doc/src/base/io-network.md 1.4.0+dfsg-1/doc/src/base/io-network.md
--- 1.3.1+dfsg-1/doc/src/base/io-network.md	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/doc/src/base/io-network.md	2020-03-21 16:36:32.000000000 +0000
@@ -33,7 +33,6 @@ Base.isreadonly
 Base.iswritable
 Base.isreadable
 Base.isopen
-Base.Grisu.print_shortest
 Base.fd
 Base.redirect_stdout
 Base.redirect_stdout(::Function, ::Any)
diff -pruN 1.3.1+dfsg-1/doc/src/base/iterators.md 1.4.0+dfsg-1/doc/src/base/iterators.md
--- 1.3.1+dfsg-1/doc/src/base/iterators.md	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/doc/src/base/iterators.md	2020-03-21 16:36:32.000000000 +0000
@@ -14,5 +14,8 @@ Base.Iterators.product
 Base.Iterators.flatten
 Base.Iterators.partition
 Base.Iterators.filter
+Base.Iterators.accumulate
 Base.Iterators.reverse
+Base.Iterators.only
+Base.Iterators.peel
 ```
diff -pruN 1.3.1+dfsg-1/doc/src/base/math.md 1.4.0+dfsg-1/doc/src/base/math.md
--- 1.3.1+dfsg-1/doc/src/base/math.md	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/doc/src/base/math.md	2020-03-21 16:36:32.000000000 +0000
@@ -173,6 +173,33 @@ Base.invmod
 Base.powermod
 Base.ndigits
 Base.widemul
+Base.Math.evalpoly
 Base.Math.@evalpoly
 Base.FastMath.@fastmath
 ```
+
+## Customizable binary operators
+
+Some unicode characters can be used to define new binary operators
+that support infix notation.
+For example
+```⊗(x,y) = kron(x,y)```
+defines the `⊗` (otimes) function to be the Kronecker product,
+and one can call it as binary operator using infix syntax:
+```C = A ⊗ B```
+as well as with the usual prefix syntax
+```C = ⊗(A,B)```.
+
+Other characters that support such extensions include
+\odot `⊙`
+and
+\oplus `⊕`
+
+The complete list is in the parser code:
+https://github.com/JuliaLang/julia/blob/master/src/julia-parser.scm
+
+Those that are parsed like `*` (in terms of precedence) include
+`* / ÷ % & ⋅ ∘ × |\\| ∩ ∧ ⊗ ⊘ ⊙ ⊚ ⊛ ⊠ ⊡ ⊓ ∗ ∙ ∤ ⅋ ≀ ⊼ ⋄ ⋆ ⋇ ⋉ ⋊ ⋋ ⋌ ⋏ ⋒ ⟑ ⦸ ⦼ ⦾ ⦿ ⧶ ⧷ ⨇ ⨰ ⨱ ⨲ ⨳ ⨴ ⨵ ⨶ ⨷ ⨸ ⨻ ⨼ ⨽ ⩀ ⩃ ⩄ ⩋ ⩍ ⩎ ⩑ ⩓ ⩕ ⩘ ⩚ ⩜ ⩞ ⩟ ⩠ ⫛ ⊍ ▷ ⨝ ⟕ ⟖ ⟗`
+and those that are parsed like `+` include
+`+ - |\|| ⊕ ⊖ ⊞ ⊟ |++| ∪ ∨ ⊔ ± ∓ ∔ ∸ ≏ ⊎ ⊻ ⊽ ⋎ ⋓ ⧺ ⧻ ⨈ ⨢ ⨣ ⨤ ⨥ ⨦ ⨧ ⨨ ⨩ ⨪ ⨫ ⨬ ⨭ ⨮ ⨹ ⨺ ⩁ ⩂ ⩅ ⩊ ⩌ ⩏ ⩐ ⩒ ⩔ ⩖ ⩗ ⩛ ⩝ ⩡ ⩢ ⩣`
+There are many others that are related to arrows, comparisons, and powers.
diff -pruN 1.3.1+dfsg-1/doc/src/base/punctuation.md 1.4.0+dfsg-1/doc/src/base/punctuation.md
--- 1.3.1+dfsg-1/doc/src/base/punctuation.md	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/doc/src/base/punctuation.md	2020-03-21 16:36:32.000000000 +0000
@@ -4,44 +4,53 @@ Extended documentation for mathematical
 
 | symbol      | meaning                                                                                                                                         |
 |:----------- |:----------------------------------------------------------------------------------------------------------------------------------------------- |
-| `@m`        | invoke macro `m`; followed by space-separated expressions                                   |
-| `!`         | prefix "not" (logical negation) operator                                                    |
-| `a!( )`     | at the end of a function name, `!` is used as a convention to indicate that a function modifies its argument(s) |
-| `#`         | begin single line comment                                                                   |
-| `#=`        | begin multi-line comment (these are nestable)                                               |
-| `=#`        | end multi-line comment                                                                      |
-| `$`         | string and expression interpolation                                                         |
-| `%`         | remainder operator                                                                          |
-| `^`         | exponent operator                                                                           |
-| `&`         | bitwise and                                                                                 |
-| `&&`        | short-circuiting boolean and                                                                |
-| `\|`        | bitwise or                                                                                  |
-| `\|\|`      | short-circuiting boolean or                                                                 |
-| `⊻`         | bitwise xor operator                                                                        |
-| `*`         | multiply, or matrix multiply                                                                |
-| `()`        | the empty tuple                                                                             |
-| `~`         | bitwise not operator                                                                        |
-| `\`         | backslash operator                                                                          |
-| `'`         | complex transpose operator Aᴴ                                                               |
-| `a[]`       | array indexing (calling [`getindex`](@ref) or [`setindex!`](@ref))                          |
-| `[,]`       | vector literal constructor (calling [`vect`](@ref Base.vect))                               |
-| `[;]`       | vertical concatenation (calling [`vcat`](@ref) or [`hvcat`](@ref))                          |
-| `[    ]`    | with space-separated expressions, horizontal concatenation (calling [`hcat`](@ref) or [`hvcat`](@ref)) |
-| `T{ }`      | parametric type instantiation                                                               |
-| `;`         | statement separator                                                                         |
-| `,`         | separate function arguments or tuple components                                             |
-| `?`         | 3-argument conditional operator (used like: `conditional ? if_true : if_false`)             |
-| `""`        | delimit string literals                                                                     |
-| `''`        | delimit character literals                                                                  |
-| ``` ` ` ``` | delimit external process (command) specifications                                           |
-| `...`       | splice arguments into a function call or declare a varargs function                         |
-| `.`         | access named fields in objects/modules (calling [`getproperty`](@ref Base.getproperty) or [`setproperty!`](@ref Base.setproperty!)), also prefixes elementwise function calls (calling [`broadcast`](@ref)) |
-| `a:b`       | range a, a+1, a+2, ..., b                                                                   |
-| `a:s:b`     | range a, a+s, a+2s, ..., b                                                                  |
-| `:`         | index an entire dimension (firstindex:lastindex), see [`Colon`](@ref))                      |
-| `::`        | type annotation or [`typeassert`](@ref), depending on context                               |
+| `@m`        | the at-symbol invokes [macro](@ref man-macros) `m`; followed by space-separated expressions or a function-call-like argument list |
+| [`!`](@ref) | an exclamation mark is a prefix operator for logical negation ("not")                       |
+| `a!`        | function names that end with an exclamation mark modify one or more of their arguments by convention |
+| `#`         | the number sign (or hash or pound) character begins single line comments                    |
+| `#=`        | when followed by an equals sign, it begins a multi-line comment (these are nestable)          |
+| `=#`        | end a multi-line comment by immediately preceding the number sign with an equals sign       |
+| `$`         | the dollar sign is used for [string](@ref string-interpolation) and [expression](@ref man-expression-interpolation) interpolation |
+| [`%`](@ref rem) | the percent symbol is the remainder operator                                            |
+| [`^`](@ref) | the caret is the exponentiation operator.                                                   |
+| [`&`](@ref) | single ampersand is bitwise and                                                             |
+| [`&&`](@ref)| double ampersands is short-circuiting boolean and                                           |
+| [`\|`](@ref)| single pipe character is bitwise or                                                         |
+| [`\|\|`](@ref) | double pipe characters is short-circuiting boolean or                                    |
+| [`⊻`](@ref xor) | the unicode xor character is bitwise exclusive or                                       |
+| [`~`](@ref) | the tilde is an operator for bitwise not                                                    |
+| `'`         | a trailing apostrophe is the [`adjoint`](@ref) (that is, the complex transpose) operator Aᴴ |
+| [`*`](@ref) | the asterisk is used for multiplication, including matrix multiplication and [string concatenation](@ref man-concatenation) |
+| [`/`](@ref) | forward slash divides the argument on its left by the one on its right                      |
+| [`\`](@ref) | backslash operator divides the argument on its right by the one on its left, commonly used to solve matrix equations |
+| `()`        | parentheses with no arguments constructs an empty [`Tuple`](@ref)                           |
+| `(a,...)`   | parentheses with comma-separated arguments constructs a tuple containing its arguments      |
+| `(a=1,...)` | parentheses with comma-separated assignments constructs a [`NamedTuple`](@ref)              |
+| `(x;y)`     | parentheses can also be used to group one or more semicolon separated expressions           |
+| `a[]`       | [array indexing](@ref man-array-indexing) (calling [`getindex`](@ref) or [`setindex!`](@ref)) |
+| `[,]`       | [vector literal constructor](@ref man-array-literals) (calling [`vect`](@ref Base.vect))    |
+| `[;]`       | [vertical concatenation](@ref man-array-concatenation) (calling [`vcat`](@ref) or [`hvcat`](@ref)) |
+| `[    ]`    | with space-separated expressions, [horizontal concatenation](@ref man-concatenation) (calling [`hcat`](@ref) or [`hvcat`](@ref)) |
+| `T{ }`      | curly braces following a type list that type's [parameters](@ref Parametric-Types)      |
+| `{}`        | curly braces can also be used to group multiple [`where`](@ref) expressions in function declarations |
+| `;`         | semicolons separate statements, begin a list of keyword arguments in function declarations or calls, or are used to separate array literals for vertical concatenation |
+| `,`         | commas separate function arguments or tuple or array components                             |
+| `?`         | the question mark delimits the ternary conditional operator (used like: `conditional ? if_true : if_false`) |
+| `" "`       | the single double-quote character delimits [`String`](@ref) literals                        |
+| `""" """`   | three double-quote characters delimits string literals that may contain `"` and ignore leading indentation |
+| `' '`       | the single-quote character delimits [`Char`](@ref) (that is, character) literals            |
+| ``` ` ` ``` | the backtick character delimits [external process](@ref Running-External-Programs) ([`Cmd`](@ref)) literals |
+| `A...`      | triple periods are a postfix operator that "splat" their arguments' contents into many arguments of a function call or declare a varargs function that "slurps" up many arguments into a single tuple |
+| `a.b`       | single periods access named fields in objects/modules (calling [`getproperty`](@ref Base.getproperty) or [`setproperty!`](@ref Base.setproperty!)) |
+| `f.()`      | periods may also prefix parentheses (like `f.(...)`) or infix operators (like `.+`) to perform the function element-wise (calling [`broadcast`](@ref)) |
+| `a:b`       | colons ([`:`](@ref)) used as a binary infix operator construct a range from `a` to `b` (inclusive) with fixed step size `1` |
+| `a:s:b`     | colons ([`:`](@ref)) used as a ternary infix operator construct a range from `a` to `b` (inclusive) with step size `s` |
+| `:`         | when used by themselves, [`Colon`](@ref)s represent all indices within a dimension, frequently combined with [indexing](@ref man-array-indexing) |
+| `::`        | double-colons represent a type annotation or [`typeassert`](@ref), depending on context, frequently used when declaring function arguments |
 | `:( )`      | quoted expression                                                                           |
-| `:a`        | symbol a                                                                                    |
-| `<:`        | [`subtype operator`](@ref <:)                                                               |
-| `>:`        | [`supertype operator`](@ref >:) (reverse of subtype operator)                               |
-| `===`       | [`egal comparison operator`](@ref ===)                                                      |
+| `:a`        | [`Symbol`](@ref) a                                                                          |
+| [`<:`](@ref)| subtype operator                                                                            |
+| [`>:`](@ref)| supertype operator (reverse of subtype operator)                                            |
+| `=`         | single equals sign is [assignment](@ref man-variables)                                      |
+| [`==`](@ref)| double equals sign is value equality comparison                                             |
+| [`===`](@ref) | triple equals sign is programmatically identical equality comparison.                     |
diff -pruN 1.3.1+dfsg-1/doc/src/devdocs/ast.md 1.4.0+dfsg-1/doc/src/devdocs/ast.md
--- 1.3.1+dfsg-1/doc/src/devdocs/ast.md	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/doc/src/devdocs/ast.md	2020-03-21 16:36:32.000000000 +0000
@@ -59,7 +59,7 @@ call. Finally, chains of comparisons hav
 | `a==b`      | `(call == a b)`           |
 | `1<i<=n`    | `(comparison 1 < i <= n)` |
 | `a.b`       | `(. a (quote b))`         |
-| `a.(b)`     | `(. a b)`                 |
+| `a.(b)`     | `(. a (tuple b))`         |
 
 ### Bracketed forms
 
@@ -356,20 +356,20 @@ These symbols appear in the `head` field
 
       * `args[2]`
 
-        A `call` expression that creates `SimpleVector` specifying its parameters
+        A `call` expression that creates a `SimpleVector` specifying its parameters
 
       * `args[3]`
 
-        A `call` expression that creates `SimpleVector` specifying its fieldnames
+        A `call` expression that creates a `SimpleVector` specifying its fieldnames
 
       * `args[4]`
 
-        A `Symbol` or `GlobalRef` specifying the supertype (e.g., `:Integer` or
-        `GlobalRef(Core, :Any)`)
+        A `Symbol`, `GlobalRef`, or `Expr` specifying the supertype (e.g., `:Integer`,
+        `GlobalRef(Core, :Any)`, or `:(Core.apply_type(AbstractArray, T, N))`)
 
       * `args[5]`
 
-        A `call` expression that creates `SimpleVector` specifying its fieldtypes
+        A `call` expression that creates a `SimpleVector` specifying its fieldtypes
 
       * `args[6]`
 
@@ -384,7 +384,7 @@ These symbols appear in the `head` field
   * `abstract_type`
 
     A 3-argument expression that defines a new abstract type. The
-    arguments are the same as the first three arguments of
+    arguments are the same as arguments 1, 2, and 4 of
     `struct_type` expressions.
 
   * `primitive_type`
@@ -503,7 +503,7 @@ These symbols appear in the `head` field
         See [Working with LLVM](@ref Working-with-LLVM) for where these are derived from and how they get handled.
 
 
-### Method
+### [Method](@id ast-lowered-method)
 
 A unique'd container describing the shared metadata for a single method.
 
diff -pruN 1.3.1+dfsg-1/doc/src/devdocs/debuggingtips.md 1.4.0+dfsg-1/doc/src/devdocs/debuggingtips.md
--- 1.3.1+dfsg-1/doc/src/devdocs/debuggingtips.md	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/doc/src/devdocs/debuggingtips.md	2020-03-21 16:36:32.000000000 +0000
@@ -240,3 +240,10 @@ deterministically.  The replayed executi
 are exactly the same in every run.
 
 A recent version of rr (3.1.0 or higher) is required.
+
+### Reproducing concurrency bugs with rr
+
+rr simulates a single-threaded machine by default. In order to debug concurrent
+code you can use `rr record --chaos` which will cause rr to simulate between
+one to eight cores, chosen randomly. You might therefore want to set `JULIA_NUM_THREADS=8`
+and rerun your code under rr until you have caught your bug.
diff -pruN 1.3.1+dfsg-1/doc/src/devdocs/eval.md 1.4.0+dfsg-1/doc/src/devdocs/eval.md
--- 1.3.1+dfsg-1/doc/src/devdocs/eval.md	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/doc/src/devdocs/eval.md	2020-03-21 16:36:32.000000000 +0000
@@ -71,6 +71,14 @@ which handles tokenizing Julia code and
 which handles transforming complex AST representations into simpler, "lowered" AST representations
 which are more suitable for analysis and execution.
 
+If you want to test the parser without re-building Julia in its entirety, you can run the frontend
+on its own as follows:
+
+    $ cd src
+    $ flisp/flisp
+    > (load "jlfrontend.scm")
+    > (jl-parse-file "<filename>")
+
 ## [Macro Expansion](@id dev-macro-expansion)
 
 When [`eval()`](@ref) encounters a macro, it expands that AST node before attempting to evaluate
diff -pruN 1.3.1+dfsg-1/doc/src/devdocs/functions.md 1.4.0+dfsg-1/doc/src/devdocs/functions.md
--- 1.3.1+dfsg-1/doc/src/devdocs/functions.md	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/doc/src/devdocs/functions.md	2020-03-21 16:36:32.000000000 +0000
@@ -210,7 +210,7 @@ This function further unpacks each *elem
 Naturally, a more efficient implementation is available if all splatted arguments are named tuples.
 Notice that the original `circle` function is passed through, to handle closures.
 
-## Compiler efficiency issues
+## [Compiler efficiency issues](@id compiler-efficiency-issues)
 
 Generating a new type for every function has potentially serious consequences for compiler resource
 use when combined with Julia's "specialize on all arguments by default" design. Indeed, the initial
diff -pruN 1.3.1+dfsg-1/doc/src/devdocs/ssair.md 1.4.0+dfsg-1/doc/src/devdocs/ssair.md
--- 1.3.1+dfsg-1/doc/src/devdocs/ssair.md	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/doc/src/devdocs/ssair.md	2020-03-21 16:36:32.000000000 +0000
@@ -28,7 +28,7 @@ struct PhiNode
 end
 ```
 where we ensure that both vectors always have the same length. In the canonical representation (the one
-handles by codegen and the interpreter), the edge values indicate come-from statement numbers (i.e.
+handled by codegen and the interpreter), the edge values indicate come-from statement numbers (i.e.
 if edge has an entry of `15`, there must be a `goto`, `gotoifnot` or implicit fall through from
 statement `15` that targets this phi node). Values are either SSA values or constants. It is also
 possible for a value to be unassigned if the variable was not defined on this path. However, undefinedness
diff -pruN 1.3.1+dfsg-1/doc/src/devdocs/types.md 1.4.0+dfsg-1/doc/src/devdocs/types.md
--- 1.3.1+dfsg-1/doc/src/devdocs/types.md	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/doc/src/devdocs/types.md	2020-03-21 16:36:32.000000000 +0000
@@ -82,7 +82,7 @@ f3(A::Array{T}) where {T<:Any} = 3
 f4(A::Array{Any}) = 4
 ```
 
-The signature - as decribed in [Function calls](@ref) - of `f3` is a `UnionAll` type wrapping a tuple type: `Tuple{typeof(f3), Array{T}} where T`.
+The signature - as described in [Function calls](@ref) - of `f3` is a `UnionAll` type wrapping a tuple type: `Tuple{typeof(f3), Array{T}} where T`.
 All but `f4` can be called with `a = [1,2]`; all but `f2` can be called with `b = Any[1,2]`.
 
 Let's look at these types a little more closely:
@@ -92,12 +92,12 @@ julia> dump(Array)
 UnionAll
   var: TypeVar
     name: Symbol T
-    lb: Core.TypeofBottom Union{}
+    lb: Union{}
     ub: Any
   body: UnionAll
     var: TypeVar
       name: Symbol N
-      lb: Core.TypeofBottom Union{}
+      lb: Union{}
       ub: Any
     body: Array{T,N} <: DenseArray{T,N}
 ```
@@ -178,12 +178,12 @@ TypeName
   wrapper: UnionAll
     var: TypeVar
       name: Symbol T
-      lb: Core.TypeofBottom Union{}
+      lb: Union{}
       ub: Any
     body: UnionAll
       var: TypeVar
         name: Symbol N
-        lb: Core.TypeofBottom Union{}
+        lb: Union{}
         ub: Any
       body: Array{T,N} <: DenseArray{T,N}
   cache: SimpleVector
diff -pruN 1.3.1+dfsg-1/doc/src/manual/arrays.md 1.4.0+dfsg-1/doc/src/manual/arrays.md
--- 1.3.1+dfsg-1/doc/src/manual/arrays.md	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/doc/src/manual/arrays.md	2020-03-21 16:36:32.000000000 +0000
@@ -66,18 +66,14 @@ omitted it will default to [`Float64`](@
 | [`reinterpret(T, A)`](@ref)                    | an array with the same binary data as `A`, but with element type `T`                                                                                                                                                                         |
 | [`rand(T, dims...)`](@ref)                     | an `Array` with random, iid [^1] and uniformly distributed values in the half-open interval ``[0, 1)``                                                                                                                                       |
 | [`randn(T, dims...)`](@ref)                    | an `Array` with random, iid and standard normally distributed values                                                                                                                                                                         |
-| [`Matrix{T}(I, m, n)`](@ref)                   | `m`-by-`n` identity matrix                                                                                                                                                                                                                   |
+| [`Matrix{T}(I, m, n)`](@ref)                   | `m`-by-`n` identity matrix (requires `using LinearAlgebra`)                                                                                                                                                                                                                   |
 | [`range(start, stop=stop, length=n)`](@ref)    | range of `n` linearly spaced elements from `start` to `stop`                                                                                                                                                                                 |
 | [`fill!(A, x)`](@ref)                          | fill the array `A` with the value `x`                                                                                                                                                                                                        |
 | [`fill(x, dims...)`](@ref)                     | an `Array` filled with the value `x`                                                                                                                                                                                                         |
 
 [^1]: *iid*, independently and identically distributed.
 
-The syntax `[A, B, C, ...]` constructs a 1-d array (i.e., a vector) of its arguments. If all
-arguments have a common [promotion type](@ref conversion-and-promotion) then they get
-converted to that type using [`convert`](@ref).
-
-To see the various ways we can pass dimensions to these constructors, consider the following examples:
+To see the various ways we can pass dimensions to these functions, consider the following examples:
 ```jldoctest
 julia> zeros(Int8, 2, 3)
 2×3 Array{Int8,2}:
@@ -94,60 +90,125 @@ julia> zeros((2, 3))
  0.0  0.0  0.0
  0.0  0.0  0.0
 ```
-Here, `(2, 3)` is a [`Tuple`](@ref).
-
-## Concatenation
+Here, `(2, 3)` is a [`Tuple`](@ref) and the first argument — the element type — is optional, defaulting to `Float64`.
 
-Arrays can be constructed and also concatenated using the following functions:
+## [Array literals](@id man-array-literals)
 
-| Function                    | Description                                     |
-|:--------------------------- |:----------------------------------------------- |
-| [`cat(A...; dims=k)`](@ref) | concatenate input arrays along dimension(s) `k` |
-| [`vcat(A...)`](@ref)        | shorthand for `cat(A...; dims=1)`               |
-| [`hcat(A...)`](@ref)        | shorthand for `cat(A...; dims=2)`               |
+Arrays can also be directly constructed with square braces; the syntax `[A, B, C, ...]`
+creates a one dimensional array (i.e., a vector) containing the comma-separated arguments as
+its elements. The element type ([`eltype`](@ref)) of the resulting array is automatically
+determined by the types of the arguments inside the braces. If all the arguments are the
+same type, then that is its `eltype`. If they all have a common
+[promotion type](@ref conversion-and-promotion) then they get converted to that type using
+[`convert`](@ref) and that type is the array's `eltype`. Otherwise, a heterogeneous array
+that can hold anything — a `Vector{Any}` — is constructed; this includes the literal `[]`
+where no arguments are given.
 
-Scalar values passed to these functions are treated as 1-element arrays. For example,
 ```jldoctest
-julia> vcat([1, 2], 3)
+julia> [1,2,3] # An array of `Int`s
 3-element Array{Int64,1}:
  1
  2
  3
 
-julia> hcat([1 2], 3)
-1×3 Array{Int64,2}:
- 1  2  3
+julia> promote(1, 2.3, 4//5) # This combination of Int, Float64 and Rational promotes to Float64
+(1.0, 2.3, 0.8)
+
+julia> [1, 2.3, 4//5] # Thus that's the element type of this Array
+3-element Array{Float64,1}:
+ 1.0
+ 2.3
+ 0.8
+
+julia> []
+0-element Array{Any,1}
 ```
 
-The concatenation functions are used so often that they have special syntax:
+### [Concatenation](@id man-array-concatenation)
 
-| Expression        | Calls             |
-|:----------------- |:----------------- |
-| `[A; B; C; ...]`  | [`vcat`](@ref)  |
-| `[A B C ...]`     | [`hcat`](@ref)  |
-| `[A B; C D; ...]` | [`hvcat`](@ref) |
+If the arguments inside the square brackets are separated by semicolons (`;`) or newlines
+instead of commas, then their contents are _vertically concatenated_ together instead of
+the arguments being used as elements themselves.
 
-[`hvcat`](@ref) concatenates in both dimension 1 (with semicolons) and dimension 2 (with spaces).
-Consider these examples of this syntax:
 ```jldoctest
-julia> [[1; 2]; [3, 4]]
+julia> [1:2, 4:5] # Has a comma, so no concatenation occurs. The ranges are themselves the elements
+2-element Array{UnitRange{Int64},1}:
+ 1:2
+ 4:5
+
+julia> [1:2; 4:5]
 4-element Array{Int64,1}:
  1
  2
- 3
  4
+ 5
 
-julia> [[1 2] [3 4]]
-1×4 Array{Int64,2}:
- 1  2  3  4
+julia> [1:2; 4:5]
+4-element Array{Int64,1}:
+ 1
+ 2
+ 4
+ 5
 
-julia> [[1 2]; [3 4]]
+julia> [1:2
+        4:5
+        6]
+5-element Array{Int64,1}:
+ 1
+ 2
+ 4
+ 5
+ 6
+```
+
+Similarly, if the arguments are separated by tabs or spaces, then their contents are
+_horizontally concatenated_ together.
+
+```jldoctest
+julia> [1:2  4:5  7:8]
+2×3 Array{Int64,2}:
+ 1  4  7
+ 2  5  8
+
+julia> [[1,2]  [4,5]  [7,8]]
+2×3 Array{Int64,2}:
+ 1  4  7
+ 2  5  8
+
+julia> [1 2 3] # Numbers can also be horizontally concatenated
+1×3 Array{Int64,2}:
+ 1  2  3
+```
+
+Using semicolons (or newlines) and spaces (or tabs) can be combined to concatenate
+both horizontally and vertically at the same time.
+
+```jldoctest
+julia> [1 2
+        3 4]
 2×2 Array{Int64,2}:
  1  2
  3  4
-```
 
-## Typed array initializers
+julia> [zeros(Int, 2, 2) [1; 2]
+        [3 4]            5]
+3×3 Array{Int64,2}:
+ 0  0  1
+ 0  0  2
+ 3  4  5
+```
+
+More generally, concatenation can be accomplished through the [`cat`](@ref) function.
+These syntaxes are shorthands for function calls that themselves are convenience functions:
+
+| Syntax            | Function        | Description                                        |
+|:----------------- |:--------------- |:-------------------------------------------------- |
+|                   | [`cat`](@ref)   | concatenate input arrays along dimension(s) `k`    |
+| `[A; B; C; ...]`  | [`vcat`](@ref)  | shorthand for `cat(A...; dims=1)                   |
+| `[A B C ...]`     | [`hcat`](@ref)  | shorthand for `cat(A...; dims=2)                   |
+| `[A B; C D; ...]` | [`hvcat`](@ref) | simultaneous vertical and horizontal concatenation |
+
+### Typed array literals
 
 An array with a specific element type can be constructed using the syntax `T[A, B, C, ...]`. This
 will construct a 1-d array with element type `T`, initialized to contain elements `A`, `B`, `C`,
@@ -166,7 +227,7 @@ julia> Int8[[1 2] [3 4]]
  1  2  3  4
 ```
 
-## Comprehensions
+## [Comprehensions](@id man-comprehensions)
 
 Comprehensions provide a general and powerful way to construct arrays. Comprehension syntax is
 similar to set construction notation in mathematics:
@@ -206,7 +267,7 @@ julia> [ 0.25*x[i-1] + 0.5*x[i] + 0.25*x
  0.656511
 ```
 
-The resulting array type depends on the types of the computed elements. In order to control the
+The resulting array type depends on the types of the computed elements just like [array literals](@ref man-array-literals) do. In order to control the
 type explicitly, a type can be prepended to the comprehension. For example, we could have requested
 the result in single precision by writing:
 
@@ -249,7 +310,7 @@ inner functions used elsewhere in the la
 "captured" in the inner function.  For example, `sum(p[i] - q[i] for i=1:n)`
 captures the three variables `p`, `q` and `n` from the enclosing scope.
 Captured variables can present performance challenges; see
-[performance tips](@ref man-performance-tips).
+[performance tips](@ref man-performance-captured).
 
 
 Ranges in generators and comprehensions can depend on previous ranges by writing multiple `for`
@@ -397,7 +458,7 @@ julia> x[1, [2 3; 4 1]]
  13  1
 ```
 
-## Assignment
+## [Indexed Assignment](@id man-indexed-assignment)
 
 The general syntax for assigning values in an n-dimensional array `A` is:
 
@@ -913,8 +974,8 @@ the length of the tuple returned by [`si
 `AbstractArray` implementations, see the [array interface guide in the interfaces chapter](@ref man-interface-array).
 
 `DenseArray` is an abstract subtype of `AbstractArray` intended to include all arrays where
-elements are stored contiguously in column-major order (see additional notes in
-[Performance Tips](@ref man-performance-tips)). The [`Array`](@ref) type is a specific instance
+elements are stored contiguously in column-major order (see [additional notes in
+Performance Tips](@ref man-performance-column-major)). The [`Array`](@ref) type is a specific instance
 of `DenseArray`;  [`Vector`](@ref) and [`Matrix`](@ref) are aliases for the 1-d and 2-d cases.
 Very few operations are implemented specifically for `Array` beyond those that are required
 for all `AbstractArray`s; much of the array library is implemented in a generic
diff -pruN 1.3.1+dfsg-1/doc/src/manual/calling-c-and-fortran-code.md 1.4.0+dfsg-1/doc/src/manual/calling-c-and-fortran-code.md
--- 1.3.1+dfsg-1/doc/src/manual/calling-c-and-fortran-code.md	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/doc/src/manual/calling-c-and-fortran-code.md	2020-03-21 16:36:32.000000000 +0000
@@ -358,7 +358,7 @@ an `Int` in Julia).
 | C name                                                  | Fortran name             | Standard Julia Alias | Julia Base Type                                                                                                |
 |:------------------------------------------------------- |:------------------------ |:-------------------- |:-------------------------------------------------------------------------------------------------------------- |
 | `unsigned char`                                         | `CHARACTER`              | `Cuchar`             | `UInt8`                                                                                                        |
-| `bool` (only in C++)                                    |                          | `Cuchar`             | `UInt8`                                                                                                        |
+| `bool` (_Bool in C99+)                                  |                          | `Cuchar`             | `UInt8`                                                                                                        |
 | `short`                                                 | `INTEGER*2`, `LOGICAL*2` | `Cshort`             | `Int16`                                                                                                        |
 | `unsigned short`                                        |                          | `Cushort`            | `UInt16`                                                                                                       |
 | `int`, `BOOL` (C, typical)                              | `INTEGER*4`, `LOGICAL*4` | `Cint`               | `Int32`                                                                                                        |
@@ -945,6 +945,10 @@ function qsort(a::Vector{T}, cmp) where
 end
 ```
 
+!!! note
+    Closure [`@cfunction`](@ref) rely on LLVM trampolines, which are not available on all
+    platforms (for example ARM and PowerPC).
+
 
 ## Closing a Library
 
diff -pruN 1.3.1+dfsg-1/doc/src/manual/constructors.md 1.4.0+dfsg-1/doc/src/manual/constructors.md
--- 1.3.1+dfsg-1/doc/src/manual/constructors.md	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/doc/src/manual/constructors.md	2020-03-21 16:36:32.000000000 +0000
@@ -38,7 +38,7 @@ addresses all of these cases and more.
     is used to mean "constructor method" rather than "constructor function", especially as it is often
     used in the sense of singling out a particular method of the constructor from all of the others.
 
-## Outer Constructor Methods
+## [Outer Constructor Methods](@id man-outer-constructor-methods)
 
 A constructor is just like any other function in Julia in that its overall behavior is defined
 by the combined behavior of its methods. Accordingly, you can add functionality to a constructor
@@ -71,7 +71,7 @@ become clear very shortly, additional co
 are called *outer* constructor methods. Outer constructor methods can only ever create a new instance
 by calling another constructor method, such as the automatically provided default ones.
 
-## Inner Constructor Methods
+## [Inner Constructor Methods](@id man-inner-constructor-methods)
 
 While outer constructor methods succeed in addressing the problem of providing additional convenience
 methods for constructing objects, they fail to address the other two use cases mentioned in the
diff -pruN 1.3.1+dfsg-1/doc/src/manual/control-flow.md 1.4.0+dfsg-1/doc/src/manual/control-flow.md
--- 1.3.1+dfsg-1/doc/src/manual/control-flow.md	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/doc/src/manual/control-flow.md	2020-03-21 16:36:32.000000000 +0000
@@ -2,7 +2,7 @@
 
 Julia provides a variety of control flow constructs:
 
-  * [Compound Expressions](@ref man-compound-expressions): `begin` and `(;)`.
+  * [Compound Expressions](@ref man-compound-expressions): `begin` and `;`.
   * [Conditional Evaluation](@ref man-conditional-evaluation): `if`-`elseif`-`else` and `?:` (ternary operator).
   * [Short-Circuit Evaluation](@ref): `&&`, `||` and chained comparisons.
   * [Repeated Evaluation: Loops](@ref man-loops): `while` and `for`.
@@ -19,7 +19,7 @@ direct usage of tasks, but certain probl
 
 Sometimes it is convenient to have a single expression which evaluates several subexpressions
 in order, returning the value of the last subexpression as its value. There are two Julia constructs
-that accomplish this: `begin` blocks and `(;)` chains. The value of both compound expression constructs
+that accomplish this: `begin` blocks and `;` chains. The value of both compound expression constructs
 is that of the last subexpression. Here's an example of a `begin` block:
 
 ```jldoctest
@@ -32,7 +32,7 @@ julia> z = begin
 ```
 
 Since these are fairly small, simple expressions, they could easily be placed onto a single line,
-which is where the `(;)` chain syntax comes in handy:
+which is where the `;` chain syntax comes in handy:
 
 ```jldoctest
 julia> z = (x = 1; y = 2; x + y)
@@ -41,7 +41,7 @@ julia> z = (x = 1; y = 2; x + y)
 
 This syntax is particularly useful with the terse single-line function definition form introduced
 in [Functions](@ref). Although it is typical, there is no requirement that `begin` blocks be multiline
-or that `(;)` chains be single-line:
+or that `;` chains be single-line:
 
 ```jldoctest
 julia> begin x = 1; y = 2; x + y end
diff -pruN 1.3.1+dfsg-1/doc/src/manual/conversion-and-promotion.md 1.4.0+dfsg-1/doc/src/manual/conversion-and-promotion.md
--- 1.3.1+dfsg-1/doc/src/manual/conversion-and-promotion.md	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/doc/src/manual/conversion-and-promotion.md	2020-03-21 16:36:32.000000000 +0000
@@ -83,7 +83,7 @@ julia> convert(Array{Float64}, a)
  4.0  5.0  6.0
 ```
 
-Conversion isn't always possible, in which case a no method error is thrown indicating that `convert`
+Conversion isn't always possible, in which case a [`MethodError`](@ref) is thrown indicating that `convert`
 doesn't know how to perform the requested conversion:
 
 ```jldoctest
diff -pruN 1.3.1+dfsg-1/doc/src/manual/documentation.md 1.4.0+dfsg-1/doc/src/manual/documentation.md
--- 1.3.1+dfsg-1/doc/src/manual/documentation.md	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/doc/src/manual/documentation.md	2020-03-21 16:36:32.000000000 +0000
@@ -21,7 +21,7 @@ other string macros and pass them to the
 !!! note
     Markdown support is implemented in the `Markdown` standard library
     and for a full list of supported syntax see the
-    [documentation](@ref Markdown).
+    [documentation](@ref markdown_stdlib).
 
 Here is a more complex example, still using Markdown:
 
diff -pruN 1.3.1+dfsg-1/doc/src/manual/faq.md 1.4.0+dfsg-1/doc/src/manual/faq.md
--- 1.3.1+dfsg-1/doc/src/manual/faq.md	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/doc/src/manual/faq.md	2020-03-21 16:36:32.000000000 +0000
@@ -67,7 +67,7 @@ When a file is run as the main script us
 functionality like command line argument handling. A way to determine that a file is run in
 this fashion is to check if `abspath(PROGRAM_FILE) == @__FILE__` is `true`.
 
-### How do I catch CTRL-C in a script?
+### [How do I catch CTRL-C in a script?](@id catch-ctrl-c)
 
 Running a Julia script using `julia file.jl` does not throw
 [`InterruptException`](@ref) when you try to terminate it with CTRL-C
@@ -90,8 +90,7 @@ use `exec` to replace the process to `ju
 ```julia
 #!/bin/bash
 #=
-exec julia --color=yes --startup-file=no -e 'include(popfirst!(ARGS))' \
-    "${BASH_SOURCE[0]}" "$@"
+exec julia --color=yes --startup-file=no "${BASH_SOURCE[0]}" "$@"
 =#
 
 @show ARGS  # put any Julia code here
@@ -102,6 +101,19 @@ script.  Julia ignores this part since i
 Julia.  The Julia code after `=#` is ignored by `bash` since it stops
 parsing the file once it reaches to the `exec` statement.
 
+!!! note
+    In order to [catch CTRL-C](@ref catch-ctrl-c) in the script you can use
+    ```julia
+    #!/bin/bash
+    #=
+    exec julia --color=yes --startup-file=no -e 'include(popfirst!(ARGS))' \
+        "${BASH_SOURCE[0]}" "$@"
+    =#
+
+    @show ARGS  # put any Julia code here
+    ```
+    instead. Note that with this strategy [`PROGRAM_FILE`](@ref) will not be set.
+
 ## Functions
 
 ### I passed an argument `x` to a function, modified it inside that function, but on the outside, the variable `x` is still unchanged. Why?
@@ -352,6 +364,45 @@ julia> sqrt(-2.0+0im)
 0.0 + 1.4142135623730951im
 ```
 
+### How can I constrain or compute type parameters?
+
+The parameters of a [parametric type](@ref Parametric-Types) can hold either
+types or bits values, and the type itself chooses how it makes use of these parameters.
+For example, `Array{Float64, 2}` is parameterized by the type `Float64` to express its
+element type and the integer value `2` to express its number of dimensions.  When
+defining your own parametric type, you can use subtype constraints to declare that a
+certain parameter must be a subtype ([`<:`](@ref)) of some abstract type or a previous
+type parameter.  There is not, however, a dedicated syntax to declare that a parameter
+must be a _value_ of a given type — that is, you cannot directly declare that a
+dimensionality-like parameter [`isa`](@ref) `Int` within the `struct` definition, for
+example.  Similarly, you cannot do computations (including simple things like addition
+or subtraction) on type parameters.  Instead, these sorts of constraints and
+relationships may be expressed through additional type parameters that are computed
+and enforced within the type's [constructors](@ref man-constructors).
+
+As an example, consider
+```julia
+struct ConstrainedType{T,N,N+1} # NOTE: INVALID SYNTAX
+    A::Array{T,N}
+    B::Array{T,N+1}
+end
+```
+where the user would like to enforce that the third type parameter is always the second plus one. This can be implemented with an explicit type parameter that is checked by an [inner constructor method](@ref man-inner-constructor-methods) (where it can be combined with other checks):
+```julia
+struct ConstrainedType{T,N,M}
+    A::Array{T,N}
+    B::Array{T,M}
+    function ConstrainedType(A::Array{T,N}, B::Array{T,M}) where {T,N,M}
+        N + 1 == M || throw(ArgumentError("second argument should have one more axis" ))
+        new{T,N,M}(A, B)
+    end
+end
+```
+This check is usually *costless*, as the compiler can elide the check for valid concrete types. If the second argument is also computed, it may be advantageous to provide an [outer constructor method](@ref man-outer-constructor-methods) that performs this calculation:
+```julia
+ConstrainedType(A) = ConstrainedType(A, compute_B(A))
+```
+
 ### [Why does Julia use native machine integer arithmetic?](@id faq-integer-arithmetic)
 
 Julia uses machine arithmetic for integer computations. This means that the range of `Int` values
@@ -576,6 +627,14 @@ have, it ends up having a substantial co
 around the added overflow checks. If this improves in the future, we could consider defaulting
 to checked integer arithmetic in Julia, but for now, we have to live with the possibility of overflow.
 
+In the meantime, overflow-safe integer operations can be achieved through the use of external libraries
+such as [SaferIntegers.jl](https://github.com/JeffreySarnoff/SaferIntegers.jl). Note that, as stated
+previously, the use of these libraries significantly increases the execution time of code using the
+checked integer types. However, for limited usage, this is far less of an issue than if it were used
+for all integer operations. You can follow the status of the discussion
+[here](https://github.com/JuliaLang/julia/issues/855).
+
+
 ### What are the possible causes of an `UndefVarError` during remote execution?
 
 As the error states, an immediate cause of an `UndefVarError` on a remote node is that a binding
diff -pruN 1.3.1+dfsg-1/doc/src/manual/functions.md 1.4.0+dfsg-1/doc/src/manual/functions.md
--- 1.3.1+dfsg-1/doc/src/manual/functions.md	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/doc/src/manual/functions.md	2020-03-21 16:36:32.000000000 +0000
@@ -11,6 +11,9 @@ julia> function f(x,y)
 f (generic function with 1 method)
 ```
 
+This function accepts two arguments `x` and `y` and returns the value
+of the last expression evaluated, which is `x + y`.
+
 There is a second, more terse syntax for defining a function in Julia. The traditional function
 declaration syntax demonstrated above is equivalent to the following compact "assignment form":
 
@@ -64,8 +67,9 @@ Python, Ruby and Perl, among other dynam
 
 The value returned by a function is the value of the last expression evaluated, which, by default,
 is the last expression in the body of the function definition. In the example function, `f`, from
-the previous section this is the value of the expression `x + y`. As in C and most other imperative
-or functional languages, the `return` keyword causes a function to return immediately, providing
+the previous section this is the value of the expression `x + y`.
+As an alternative, as in many other languages,
+the `return` keyword causes a function to return immediately, providing
 an expression whose value is returned:
 
 ```julia
@@ -125,7 +129,9 @@ There are three possible points of retur
 expressions, depending on the values of `x` and `y`. The `return` on the last line could be omitted
 since it is the last expression.
 
-A return type can also be specified in the function declaration using the `::` operator. This converts
+### Return type
+
+A return type can be specified in the function declaration using the `::` operator. This converts
 the return value to the specified type.
 
 ```jldoctest
@@ -140,6 +146,30 @@ Int8
 This function will always return an `Int8` regardless of the types of `x` and `y`.
 See [Type Declarations](@ref) for more on return types.
 
+### Returning nothing
+
+For functions that do not need to return a value (functions used only for some side effects),
+the Julia convention is to return the value [`nothing`](@ref):
+
+```julia
+function printx(x)
+    println("x = $x")
+    return nothing
+end
+```
+
+This is a *convention* in the sense that `nothing` is not a Julia keyword
+but a only singleton object of type `Nothing`.
+Also, you may notice that the `printx` function example above is contrived,
+because `println` already returns `nothing`, so that the `return` line is redundant.
+
+There are two possible shortened forms for the `return nothing` expression.
+On the one hand, the `return` keyword implicitly returns `nothing`, so it can be used alone.
+On the other hand, since functions implicitly return their last expression evaluated,
+`nothing` can be used alone when it's the last expression.
+The preference for the expression `return nothing` as opposed to `return` or `nothing`
+alone is a matter of coding style.
+
 ## Operators Are Functions
 
 In Julia, most operators are just functions with support for special syntax. (The exceptions are
@@ -677,7 +707,7 @@ the arguments of the user function are i
 A `do` block, like any other inner function, can "capture" variables from its
 enclosing scope. For example, the variable `data` in the above example of
 `open...do` is captured from the outer scope. Captured variables
-can create performance challenges as discussed in [performance tips](@ref man-performance-tips).
+can create performance challenges as discussed in [performance tips](@ref man-performance-captured).
 
 ## Function composition and piping
 
@@ -808,8 +838,8 @@ the results (see [Pre-allocating outputs
 is equivalent to `broadcast!(identity, X, ...)` except that, as above, the `broadcast!` loop is
 fused with any nested "dot" calls. For example, `X .= sin.(Y)` is equivalent to `broadcast!(sin, X, Y)`,
 overwriting `X` with `sin.(Y)` in-place. If the left-hand side is an array-indexing expression,
-e.g. `X[2:end] .= sin.(Y)`, then it translates to `broadcast!` on a `view`, e.g.
-`broadcast!(sin, view(X, 2:lastindex(X)), Y)`,
+e.g. `X[begin+1:end] .= sin.(Y)`, then it translates to `broadcast!` on a `view`, e.g.
+`broadcast!(sin, view(X, firstindex(X)+1:lastindex(X)), Y)`,
 so that the left-hand side is updated in-place.
 
 Since adding dots to many operations and function calls in an expression
diff -pruN 1.3.1+dfsg-1/doc/src/manual/integers-and-floating-point-numbers.md 1.4.0+dfsg-1/doc/src/manual/integers-and-floating-point-numbers.md
--- 1.3.1+dfsg-1/doc/src/manual/integers-and-floating-point-numbers.md	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/doc/src/manual/integers-and-floating-point-numbers.md	2020-03-21 16:36:32.000000000 +0000
@@ -216,7 +216,7 @@ UInt128: [0,3402823669209384634633746074
 
 The values returned by [`typemin`](@ref) and [`typemax`](@ref) are always of the given argument
 type. (The above expression uses several features that have yet to be introduced, including [for loops](@ref man-loops),
-[Strings](@ref man-strings), and [Interpolation](@ref), but should be easy enough to understand for users
+[Strings](@ref man-strings), and [Interpolation](@ref string-interpolation), but should be easy enough to understand for users
 with some existing programming experience.)
 
 ### Overflow behavior
@@ -527,7 +527,7 @@ the [GNU Multiple Precision Arithmetic L
 respectively. The [`BigInt`](@ref) and [`BigFloat`](@ref) types are available in Julia for arbitrary
 precision integer and floating point numbers respectively.
 
-Constructors exist to create these types from primitive numerical types, and [`parse`](@ref)
+Constructors exist to create these types from primitive numerical types, and the [string literal](@ref non-standard-string-literals) [`@big_str`](@ref) or [`parse`](@ref)
 can be used to construct them from `AbstractString`s.  Once created, they participate in arithmetic
 with all other numeric types thanks to Julia's [type promotion and conversion mechanism](@ref conversion-and-promotion):
 
@@ -535,9 +535,15 @@ with all other numeric types thanks to J
 julia> BigInt(typemax(Int64)) + 1
 9223372036854775808
 
+julia> big"123456789012345678901234567890" + 1
+123456789012345678901234567891
+
 julia> parse(BigInt, "123456789012345678901234567890") + 1
 123456789012345678901234567891
 
+julia> big"1.23456789012345678901"
+1.234567890123456789010000000000000000000000000000000000000000000000000000000004
+
 julia> parse(BigFloat, "1.23456789012345678901")
 1.234567890123456789010000000000000000000000000000000000000000000000000000000004
 
diff -pruN 1.3.1+dfsg-1/doc/src/manual/interfaces.md 1.4.0+dfsg-1/doc/src/manual/interfaces.md
--- 1.3.1+dfsg-1/doc/src/manual/interfaces.md	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/doc/src/manual/interfaces.md	2020-03-21 16:36:32.000000000 +0000
@@ -164,8 +164,8 @@ julia> collect(Iterators.reverse(Squares
 |:-------------------- |:-------------------------------- |
 | `getindex(X, i)`     | `X[i]`, indexed element access   |
 | `setindex!(X, v, i)` | `X[i] = v`, indexed assignment   |
-| `firstindex(X)`      | The first index                  |
-| `lastindex(X)`        | The last index, used in `X[end]` |
+| `firstindex(X)`         | The first index, used in `X[begin]` |
+| `lastindex(X)`           | The last index, used in `X[end]` |
 
 For the `Squares` iterable above, we can easily compute the `i`th element of the sequence by squaring
 it.  We can expose this as an indexing expression `S[i]`. To opt into this behavior, `Squares`
@@ -181,8 +181,8 @@ julia> Squares(100)[23]
 529
 ```
 
-Additionally, to support the syntax `S[end]`, we must define [`lastindex`](@ref) to specify the last
-valid index. It is recommended to also define [`firstindex`](@ref) to specify the first valid index:
+Additionally, to support the syntax `S[begin]` and `S[end]`, we must define [`firstindex`](@ref) and
+[`lastindex`](@ref) to specify the first and last valid indices, respectively:
 
 ```jldoctest squaretype
 julia> Base.firstindex(S::Squares) = 1
@@ -226,7 +226,7 @@ ourselves, we can officially define it a
 | **Optional methods**                            | **Default definition**                 | **Brief description**                                                                 |
 | `IndexStyle(::Type)`                            | `IndexCartesian()`                     | Returns either `IndexLinear()` or `IndexCartesian()`. See the description below.      |
 | `getindex(A, I...)`                             | defined in terms of scalar `getindex`  | [Multidimensional and nonscalar indexing](@ref man-array-indexing)                    |
-| `setindex!(A, I...)`                            | defined in terms of scalar `setindex!` | [Multidimensional and nonscalar indexed assignment](@ref man-array-indexing)          |
+| `setindex!(A, X, I...)`                            | defined in terms of scalar `setindex!` | [Multidimensional and nonscalar indexed assignment](@ref man-array-indexing)          |
 | `iterate`                                       | defined in terms of scalar `getindex`  | Iteration                                                                             |
 | `length(A)`                                     | `prod(size(A))`                        | Number of elements                                                                    |
 | `similar(A)`                                    | `similar(A, eltype(A), size(A))`       | Return a mutable array with the same shape and element type                           |
@@ -565,10 +565,11 @@ end
 find_aac(bc::Base.Broadcast.Broadcasted) = find_aac(bc.args)
 find_aac(args::Tuple) = find_aac(find_aac(args[1]), Base.tail(args))
 find_aac(x) = x
+find_aac(::Tuple{}) = nothing
 find_aac(a::ArrayAndChar, rest) = a
 find_aac(::Any, rest) = find_aac(rest)
 # output
-find_aac (generic function with 5 methods)
+find_aac (generic function with 6 methods)
 ```
 
 From these definitions, one obtains the following behavior:
diff -pruN 1.3.1+dfsg-1/doc/src/manual/mathematical-operations.md 1.4.0+dfsg-1/doc/src/manual/mathematical-operations.md
--- 1.3.1+dfsg-1/doc/src/manual/mathematical-operations.md	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/doc/src/manual/mathematical-operations.md	2020-03-21 16:36:32.000000000 +0000
@@ -233,7 +233,7 @@ are compared according to the [IEEE 754
   * Finite numbers are ordered in the usual manner.
   * Positive zero is equal but not greater than negative zero.
   * `Inf` is equal to itself and greater than everything else except `NaN`.
-  * `-Inf` is equal to itself and less then everything else except `NaN`.
+  * `-Inf` is equal to itself and less than everything else except `NaN`.
   * `NaN` is not equal to, not less than, and not greater than anything, including itself.
 
 The last point is potentially surprising and thus worth noting:
@@ -386,7 +386,7 @@ You can also find the numerical preceden
 
 ```jldoctest
 julia> Base.operator_precedence(:+), Base.operator_precedence(:*), Base.operator_precedence(:.)
-(11, 13, 17)
+(11, 12, 17)
 
 julia> Base.operator_precedence(:sin), Base.operator_precedence(:+=), Base.operator_precedence(:(=))  # (Note the necessary parens on `:(=)`)
 (0, 1, 1)
diff -pruN 1.3.1+dfsg-1/doc/src/manual/metaprogramming.md 1.4.0+dfsg-1/doc/src/manual/metaprogramming.md
--- 1.3.1+dfsg-1/doc/src/manual/metaprogramming.md	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/doc/src/manual/metaprogramming.md	2020-03-21 16:36:32.000000000 +0000
@@ -199,7 +199,7 @@ julia> typeof(ex)
 Expr
 ```
 
-### Interpolation
+### [Interpolation](@id man-expression-interpolation)
 
 Direct construction of [`Expr`](@ref) objects with value arguments is powerful, but `Expr` constructors
 can be tedious compared to "normal" Julia syntax. As an alternative, Julia allows *interpolation* of
@@ -261,14 +261,14 @@ julia> x = :(1 + 2);
 julia> e = quote quote $x end end
 quote
     #= none:1 =#
-    $(Expr(:quote, quote
-    #= none:1 =#
-    $(Expr(:$, :x))
-end))
+    quote
+        #= none:1 =#
+        $x
+    end
 end
 ```
 
-Notice that the result contains `Expr(:$, :x)`, which means that `x` has not been
+Notice that the result contains `$x`, which means that `x` has not been
 evaluated yet.
 In other words, the `$` expression "belongs to" the inner quote expression, and
 so its argument is only evaluated when the inner quote expression is:
@@ -289,14 +289,14 @@ This is done with multiple `$`s:
 julia> e = quote quote $$x end end
 quote
     #= none:1 =#
-    $(Expr(:quote, quote
-    #= none:1 =#
-    $(Expr(:$, :(1 + 2)))
-end))
+    quote
+        #= none:1 =#
+        $(1 + 2)
+    end
 end
 ```
 
-Notice that `:(1 + 2)` now appears in the result instead of the symbol `:x`.
+Notice that `(1 + 2)` now appears in the result instead of the symbol `x`.
 Evaluating this expression yields an interpolated `3`:
 
 ```jldoctest interp1
@@ -553,7 +553,7 @@ julia> macro twostep(arg)
 @twostep (macro with 1 method)
 
 julia> ex = macroexpand(Main, :(@twostep :(1, 2, 3)) );
-I execute at parse time. The argument is: $(Expr(:quote, :((1, 2, 3))))
+I execute at parse time. The argument is: :((1, 2, 3))
 ```
 
 The first call to [`println`](@ref) is executed when [`macroexpand`](@ref) is called. The
@@ -1295,7 +1295,7 @@ to build some more advanced (and valid)
 
 ### An advanced example
 
-Julia's base library has a an internal `sub2ind` function to calculate a linear index into an n-dimensional
+Julia's base library has an internal `sub2ind` function to calculate a linear index into an n-dimensional
 array, based on a set of n multilinear indices - in other words, to calculate the index `i` that
 can be used to index into an array `A` using `A[i]`, instead of `A[x,y,z,...]`. One possible implementation
 is the following:
diff -pruN 1.3.1+dfsg-1/doc/src/manual/noteworthy-differences.md 1.4.0+dfsg-1/doc/src/manual/noteworthy-differences.md
--- 1.3.1+dfsg-1/doc/src/manual/noteworthy-differences.md	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/doc/src/manual/noteworthy-differences.md	2020-03-21 16:36:32.000000000 +0000
@@ -80,7 +80,8 @@ may trip up Julia users accustomed to MA
     `x[x.>3]` and `x = x[x.>3]`. Using [`filter!`](@ref) reduces the use of temporary arrays.
   * The analogue of extracting (or "dereferencing") all elements of a cell array, e.g. in `vertcat(A{:})`
     in MATLAB, is written using the splat operator in Julia, e.g. as `vcat(A...)`.
-
+  * In Julia, the `adjoint` function performs conjugate transposition; in MATLAB, `adjoint` provides the "adjugate" or
+    classical adjoint, which is the transpose of the matrix of cofactors.
 ## Noteworthy differences from R
 
 One of Julia's goals is to provide an effective language for data analysis and statistical programming.
@@ -209,7 +210,7 @@ For users coming to Julia from R, these
     to continue is to wrap it in parentheses.
   * Julia arrays are column major (Fortran ordered) whereas NumPy arrays are row major (C-ordered)
     by default. To get optimal performance when looping over arrays, the order of the loops should
-    be reversed in Julia relative to NumPy (see relevant section of [Performance Tips](@ref man-performance-tips)).
+    be reversed in Julia relative to NumPy (see [relevant section of Performance Tips](@ref man-performance-column-major)).
   * Julia's updating operators (e.g. `+=`, `-=`, ...) are *not in-place* whereas NumPy's are. This
     means `A = [1, 1]; B = A; B += [3, 3]` doesn't change values in `A`, it rather rebinds the name `B`
     to the result of the right-hand side `B = B + 3`, which is a new array. For in-place operation, use `B .+= 3`
@@ -235,7 +236,7 @@ For users coming to Julia from R, these
     which rebinds the left-hand side to the result of the right-hand side expression.
   * Julia arrays are column major (Fortran ordered) whereas C/C++ arrays are row major ordered by
     default. To get optimal performance when looping over arrays, the order of the loops should be
-    reversed in Julia relative to C/C++ (see relevant section of [Performance Tips](@ref man-performance-tips)).
+    reversed in Julia relative to C/C++ (see [relevant section of Performance Tips](@ref man-performance-column-major)).
   * Julia values are not copied when assigned or passed to a function. If a function modifies an array, the changes
     will be visible in the caller.
   * In Julia, whitespace is significant, unlike C/C++, so care must be taken when adding/removing
diff -pruN 1.3.1+dfsg-1/doc/src/manual/parallel-computing.md 1.4.0+dfsg-1/doc/src/manual/parallel-computing.md
--- 1.3.1+dfsg-1/doc/src/manual/parallel-computing.md	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/doc/src/manual/parallel-computing.md	2020-03-21 16:36:32.000000000 +0000
@@ -218,7 +218,7 @@ too.
 
 # [Multi-Threading (Experimental)](@id man-multithreading)
 
-In addition to tasks Julia forwards natively supports multi-threading.
+In addition to tasks Julia natively supports multi-threading.
 Note that this section is experimental and the interfaces may change in the future.
 
 ## Setup
@@ -234,13 +234,24 @@ julia> Threads.nthreads()
 The number of threads Julia starts up with is controlled by an environment variable called `JULIA_NUM_THREADS`.
 Now, let's start up Julia with 4 threads:
 
+Bash on Linux/OSX:
+
 ```bash
 export JULIA_NUM_THREADS=4
 ```
 
-(The above command works on bourne shells on Linux and OSX. Note that if you're using a C shell
-on these platforms, you should use the keyword `set` instead of `export`. If you're on Windows,
-start up the command line in the location of `julia.exe` and use `set` instead of `export`.)
+C shell on Linux/OSX, CMD on Windows:
+
+```bash
+set JULIA_NUM_THREADS=4
+```
+
+Powershell on Windows:
+
+```powershell
+$env:JULIA_NUM_THREADS=4
+```
+
 
 Let's verify there are 4 threads at our disposal.
 
@@ -383,7 +394,7 @@ julia> acc[]
 When using multi-threading we have to be careful when using functions that are not
 [pure](https://en.wikipedia.org/wiki/Pure_function) as we might get a wrong answer.
 For instance functions that have their
-[name ending with `!`](https://docs.julialang.org/en/latest/manual/style-guide/#Append-!-to-names-of-functions-that-modify-their-arguments-1)
+[name ending with `!`](@ref bang-convention)
 by convention modify their arguments and thus are not pure. However, there are
 functions that have side effects and their name does not end with `!`. For
 instance [`findfirst(regex, str)`](@ref) mutates its `regex` argument or
@@ -758,7 +769,8 @@ It is automatically made available on th
 
 Note that workers do not run a `~/.julia/config/startup.jl` startup script, nor do they synchronize
 their global state (such as global variables, new method definitions, and loaded modules) with any
-of the other running processes.
+of the other running processes. You may use `addprocs(exeflags="--project")` to initialize a worker with
+a particular environment, and then `@everywhere using <modulename>` or `@everywhere include("file.jl")`.
 
 Other types of clusters can be supported by writing your own custom `ClusterManager`, as described
 below in the [ClusterManagers](@ref) section.
@@ -1143,7 +1155,7 @@ sent to the remote node to go ahead and
 Once finalized, a reference becomes invalid and cannot be used in any further calls.
 
 
-## Local invocations(@id man-distributed-local-invocations)
+## Local invocations
 
 Data is necessarily copied over to the remote node for execution. This is the case for both
 remotecalls and when data is stored to a[`RemoteChannel`](@ref) / [`Future`](@ref Distributed.Future) on
@@ -1280,7 +1292,7 @@ julia> addprocs(3)
 
 julia> @everywhere using SharedArrays
 
-julia> S = SharedArray{Int,2}((3,4), init = S -> S[localindices(S)] = myid())
+julia> S = SharedArray{Int,2}((3,4), init = S -> S[localindices(S)] = repeat([myid()], length(localindices(S))))
 3×4 SharedArray{Int64,2}:
  2  2  3  4
  2  3  3  4
@@ -1301,7 +1313,7 @@ convenient for splitting up tasks among
 you wish:
 
 ```julia-repl
-julia> S = SharedArray{Int,2}((3,4), init = S -> S[indexpids(S):length(procs(S)):length(S)] = myid())
+julia> S = SharedArray{Int,2}((3,4), init = S -> S[indexpids(S):length(procs(S)):length(S)] = repeat([myid()], length( indexpids(S):length(procs(S)):length(S))))
 3×4 SharedArray{Int64,2}:
  2  2  2  2
  3  3  3  3
diff -pruN 1.3.1+dfsg-1/doc/src/manual/performance-tips.md 1.4.0+dfsg-1/doc/src/manual/performance-tips.md
--- 1.3.1+dfsg-1/doc/src/manual/performance-tips.md	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/doc/src/manual/performance-tips.md	2020-03-21 16:36:32.000000000 +0000
@@ -142,7 +142,7 @@ the performance of your code:
   * [Profiling](@ref) allows you to measure the performance of your running code and identify lines
     that serve as bottlenecks. For complex projects, the [ProfileView](https://github.com/timholy/ProfileView.jl)
     package can help you visualize your profiling results.
-  * The [Traceur](https://github.com/MikeInnes/Traceur.jl) package can help you find common performance problems in your code.
+  * The [Traceur](https://github.com/JunoLab/Traceur.jl) package can help you find common performance problems in your code.
   * Unexpectedly-large memory allocations--as reported by [`@time`](@ref), [`@allocated`](@ref), or
     the profiler (through calls to the garbage-collection routines)--hint that there might be issues
     with your code. If you don't see another reason for the allocations, suspect a type problem.
@@ -151,7 +151,7 @@ the performance of your code:
   * `@code_warntype` generates a representation of your code that can be helpful in finding expressions
     that result in type uncertainty. See [`@code_warntype`](@ref) below.
 
-## Avoid containers with abstract type parameters
+## [Avoid containers with abstract type parameters](@id man-performance-abstract-container)
 
 When working with parameterized types, including arrays, it is best to avoid parameterizing with
 abstract types where possible.
@@ -481,6 +481,65 @@ c = (b + 1.0f0)::Complex{T}
 does not hinder performance (but does not help either) since the compiler can determine the type of `c`
 at the time `k` is compiled.
 
+### Be aware of when Julia avoids specializing
+
+As a heuristic, Julia avoids automatically specializing on argument type parameters in three
+specific cases: `Type`, `Function`, and `Vararg`. Julia will always specialize when the argument is
+used within the method, but not if the argument is just passed through to another function. This
+usually has no performance impact at runtime and
+[improves compiler performance](@ref compiler-efficiency-issues). If you find it does have a
+performance impact at runtime in your case, you can trigger specialization by adding a type
+parameter to the method declaration. Here are some examples:
+
+This will not specialize:
+
+```julia
+function f_type(t)  # or t::Type
+    x = ones(t, 10)
+    return sum(map(sin, x))
+end
+```
+
+but this will:
+
+```julia
+function g_type(t::Type{T}) where T
+    x = ones(T, 10)
+    return sum(map(sin, x))
+end
+```
+
+These will not specialize:
+
+```julia
+f_func(f, num) = ntuple(f, div(num, 2))
+g_func(g::Function, num) = ntuple(g, div(num, 2))
+```
+
+but this will:
+
+```julia
+h_func(h::H, num) where {H} = ntuple(h, div(num, 2))
+```
+
+This will not specialize:
+
+```julia
+f_vararg(x::Int...) = tuple(x...)
+```
+
+but this will:
+
+```julia
+g_vararg(x::Vararg{Int, N}) where {N} = tuple(x...)
+```
+
+Note that [`@code_typed`](@ref) and friends will always show you specialized code, even if Julia
+would not normally specialize that method call. You need to check the
+[method internals](@ref ast-lowered-method) if you want to see whether specializations are generated
+when argument types are changed, i.e., if `(@which f(...)).specializations` contains specializations
+for the argument in question.
+
 ## Break functions into multiple definitions
 
 Writing a function as many small definitions allows the compiler to directly call the most applicable
@@ -615,7 +674,7 @@ or the [`fill!`](@ref) function, which w
 Functions like `strange_twos` occur when dealing with data of uncertain type, for example data
 loaded from an input file that might contain either integers, floats, strings, or something else.
 
-## Types with values-as-parameters
+## [Types with values-as-parameters](@id man-performance-value-type)
 
 Let's say you want to create an `N`-dimensional array that has size 3 along each axis. Such arrays
 can be created like this:
@@ -752,7 +811,7 @@ or thousands of variants compiled for it
 code, the length of internal lists of methods, etc. Excess enthusiasm for values-as-parameters
 can easily waste enormous resources.
 
-## Access arrays in memory order, along columns
+## [Access arrays in memory order, along columns](@id man-performance-column-major)
 
 Multidimensional arrays in Julia are stored in column-major order. This means that arrays are
 stacked one column at a time. This can be verified using the `vec` function or the syntax `[:]`
@@ -1129,7 +1188,7 @@ Sometimes you can enable better optimiza
 
 The common idiom of using 1:n to index into an AbstractArray is not safe if the Array uses unconventional indexing,
 and may cause a segmentation fault if bounds checking is turned off. Use `LinearIndices(x)` or `eachindex(x)`
-instead (see also [offset-arrays](https://docs.julialang.org/en/latest/devdocs/offset-arrays/)).
+instead (see also [Arrays with custom indices](@ref man-custom-indices)).
 
 !!! note
     While `@simd` needs to be placed directly in front of an innermost `for` loop, both `@inbounds` and `@fastmath`
diff -pruN 1.3.1+dfsg-1/doc/src/manual/running-external-programs.md 1.4.0+dfsg-1/doc/src/manual/running-external-programs.md
--- 1.3.1+dfsg-1/doc/src/manual/running-external-programs.md	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/doc/src/manual/running-external-programs.md	2020-03-21 16:36:32.000000000 +0000
@@ -315,7 +315,7 @@ Another common solution is to separate t
 ```julia
 writer = @async write(process, "data")
 reader = @async do_compute(read(process, String))
-wait(process)
+wait(writer)
 fetch(reader)
 ```
 
diff -pruN 1.3.1+dfsg-1/doc/src/manual/stacktraces.md 1.4.0+dfsg-1/doc/src/manual/stacktraces.md
--- 1.3.1+dfsg-1/doc/src/manual/stacktraces.md	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/doc/src/manual/stacktraces.md	2020-03-21 16:36:32.000000000 +0000
@@ -312,4 +312,3 @@ julia> frame = StackTraces.lookup(pointe
 julia> println("The top frame is from $(frame[1].func)!")
 The top frame is from jl_apply_generic!
 ```
-
diff -pruN 1.3.1+dfsg-1/doc/src/manual/strings.md 1.4.0+dfsg-1/doc/src/manual/strings.md
--- 1.3.1+dfsg-1/doc/src/manual/strings.md	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/doc/src/manual/strings.md	2020-03-21 16:36:32.000000000 +0000
@@ -88,8 +88,8 @@ julia> isvalid(Char, 0x110000)
 false
 ```
 
-As of this writing, the valid Unicode code points are `U+00` through `U+d7ff` and `U+e000` through
-`U+10ffff`. These have not all been assigned intelligible meanings yet, nor are they necessarily
+As of this writing, the valid Unicode code points are `U+0000` through `U+D7FF` and `U+E000` through
+`U+10FFFF`. These have not all been assigned intelligible meanings yet, nor are they necessarily
 interpretable by applications, but all of these values are considered to be valid Unicode characters.
 
 You can input any Unicode character in single quotes using `\u` followed by up to four hexadecimal
@@ -107,7 +107,7 @@ julia> '\u2200'
 '∀': Unicode U+2200 (category Sm: Symbol, math)
 
 julia> '\U10ffff'
-'\U10ffff': Unicode U+10ffff (category Cn: Other, not assigned)
+'\U10ffff': Unicode U+10FFFF (category Cn: Other, not assigned)
 ```
 
 Julia uses your system's locale and language settings to determine which characters can be printed
@@ -169,20 +169,23 @@ julia> """Contains "quote" characters"""
 If you want to extract a character from a string, you index into it:
 
 ```jldoctest helloworldstring
+julia> str[begin]
+'H': ASCII/Unicode U+0048 (category Lu: Letter, uppercase)
+
 julia> str[1]
 'H': ASCII/Unicode U+0048 (category Lu: Letter, uppercase)
 
 julia> str[6]
-',': ASCII/Unicode U+002c (category Po: Punctuation, other)
+',': ASCII/Unicode U+002C (category Po: Punctuation, other)
 
 julia> str[end]
-'\n': ASCII/Unicode U+000a (category Cc: Other, control)
+'\n': ASCII/Unicode U+000A (category Cc: Other, control)
 ```
 
 Many Julia objects, including strings, can be indexed with integers. The index of the first
 element (the first character of a string) is returned by [`firstindex(str)`](@ref), and the index of the last element (character)
-with [`lastindex(str)`](@ref). The keyword `end` can be used inside an indexing
-operation as shorthand for the last index along the given dimension.
+with [`lastindex(str)`](@ref). The keywords `begin` and `end` can be used inside an indexing
+operation as shorthand for the first and last indices, respectively, along the given dimension.
 String indexing, like most indexing in Julia, is 1-based: `firstindex` always returns `1` for any `AbstractString`.
 As we will see below, however, `lastindex(str)` is *not* in general the same as `length(str)` for a string,
 because some Unicode characters can occupy multiple "code units".
@@ -192,16 +195,16 @@ a normal value:
 
 ```jldoctest helloworldstring
 julia> str[end-1]
-'.': ASCII/Unicode U+002e (category Po: Punctuation, other)
+'.': ASCII/Unicode U+002E (category Po: Punctuation, other)
 
 julia> str[end÷2]
 ' ': ASCII/Unicode U+0020 (category Zs: Separator, space)
 ```
 
-Using an index less than 1 or greater than `end` raises an error:
+Using an index less than `begin` (`1`) or greater than `end` raises an error:
 
 ```jldoctest helloworldstring
-julia> str[0]
+julia> str[begin-1]
 ERROR: BoundsError: attempt to access String
   at index [0]
 [...]
@@ -223,7 +226,7 @@ Notice that the expressions `str[k]` and
 
 ```jldoctest helloworldstring
 julia> str[6]
-',': ASCII/Unicode U+002c (category Po: Punctuation, other)
+',': ASCII/Unicode U+002C (category Po: Punctuation, other)
 
 julia> str[6:6]
 ","
@@ -416,7 +419,7 @@ julia> foreach(display, s)
 '\xc0\xa0': [overlong] ASCII/Unicode U+0020 (category Zs: Separator, space)
 '\xe2\x88': Malformed UTF-8 (category Ma: Malformed, bad data)
 '\xe2': Malformed UTF-8 (category Ma: Malformed, bad data)
-'|': ASCII/Unicode U+007c (category Sm: Symbol, math)
+'|': ASCII/Unicode U+007C (category Sm: Symbol, math)
 
 julia> isvalid.(collect(s))
 4-element BitArray{1}:
@@ -429,7 +432,7 @@ julia> s2 = "\xf7\xbf\xbf\xbf"
 "\U1fffff"
 
 julia> foreach(display, s2)
-'\U1fffff': Unicode U+1fffff (category In: Invalid, too high)
+'\U1fffff': Unicode U+1FFFFF (category In: Invalid, too high)
 ```
 
 We can see that the first two code units in the string `s` form an overlong encoding of
diff -pruN 1.3.1+dfsg-1/doc/src/manual/style-guide.md 1.4.0+dfsg-1/doc/src/manual/style-guide.md
--- 1.3.1+dfsg-1/doc/src/manual/style-guide.md	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/doc/src/manual/style-guide.md	2020-03-21 16:36:32.000000000 +0000
@@ -86,7 +86,7 @@ One issue here is that if a function inh
 the caller to decide how non-integers should be converted (e.g. floor or ceiling). Another issue
 is that declaring more specific types leaves more "space" for future method definitions.
 
-## Append `!` to names of functions that modify their arguments
+## [Append `!` to names of functions that modify their arguments](@id bang-convention)
 
 Instead of:
 
@@ -176,7 +176,7 @@ as applicable:
 
 7. **Value**.
    For associative collections, this is the value of the key-value pair(s).
-   In cases like `fill!(x, v)`, this is `v`.
+   In cases like [`fill!(x, v)`](@ref fill!), this is `v`.
 
 8. **Everything else**.
    Any other arguments.
diff -pruN 1.3.1+dfsg-1/doc/src/manual/types.md 1.4.0+dfsg-1/doc/src/manual/types.md
--- 1.3.1+dfsg-1/doc/src/manual/types.md	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/doc/src/manual/types.md	2020-03-21 16:36:32.000000000 +0000
@@ -125,7 +125,7 @@ end
 Returning from this function behaves just like an assignment to a variable with a declared type:
 the value is always converted to `Float64`.
 
-## Abstract Types
+## [Abstract Types](@id man-abstract-types)
 
 Abstract types cannot be instantiated, and serve only as nodes in the type graph, thereby describing
 sets of related concrete types: those concrete types which are their descendants. We begin with
@@ -232,7 +232,7 @@ has full control over whether the defaul
 An important point to note is that there is no loss in performance if the programmer relies on
 a function whose arguments are abstract types, because it is recompiled for each tuple of argument
 concrete types with which it is invoked. (There may be a performance issue, however, in the case
-of function arguments that are containers of abstract types; see [Performance Tips](@ref man-performance-tips).)
+of function arguments that are containers of abstract types; see [Performance Tips](@ref man-performance-abstract-container).)
 
 ## Primitive Types
 
@@ -1408,6 +1408,6 @@ a *type*, i.e., use `foo(Val(:bar))` rat
 It's worth noting that it's extremely easy to mis-use parametric "value" types, including `Val`;
 in unfavorable cases, you can easily end up making the performance of your code much *worse*.
  In particular, you would never want to write actual code as illustrated above.  For more information
-about the proper (and improper) uses of `Val`, please read the more extensive discussion in [the performance tips](@ref man-performance-tips).
+about the proper (and improper) uses of `Val`, please read [the more extensive discussion in the performance tips](@ref man-performance-value-type).
 
 [^1]: "Small" is defined by the `MAX_UNION_SPLITTING` constant, which is currently set to 4.
diff -pruN 1.3.1+dfsg-1/doc/src/manual/variables-and-scoping.md 1.4.0+dfsg-1/doc/src/manual/variables-and-scoping.md
--- 1.3.1+dfsg-1/doc/src/manual/variables-and-scoping.md	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/doc/src/manual/variables-and-scoping.md	2020-03-21 16:36:32.000000000 +0000
@@ -259,8 +259,8 @@ julia> counter()
 See also the closures in the examples in the next two sections. A variable,
 such as `x` in the first example and `state` in the second, that is inherited
 from the enclosing scope by the inner function is sometimes called a
-*captured* variable. Captured variables can present performance challenges
-discussed in [performance tips](@ref man-performance-tips).
+*captured* variable. Captured variables can present [performance challenges
+discussed in performance tips](@ref man-performance-captured).
 
 The distinction between inheriting global scope and nesting local scope
 can lead to some slight differences between functions
@@ -411,7 +411,7 @@ outer local `x`.
 
 ### For Loops and Comprehensions
 
-`for` loops, `while` loops, and [Comprehensions](@ref) have the following behavior: any new variables
+`for` loops, `while` loops, and [comprehensions](@ref man-comprehensions) have the following behavior: any new variables
 introduced in their body scopes are freshly allocated for each loop iteration, as if the loop body
 were surrounded by a `let` block:
 
diff -pruN 1.3.1+dfsg-1/doc/src/manual/variables.md 1.4.0+dfsg-1/doc/src/manual/variables.md
--- 1.3.1+dfsg-1/doc/src/manual/variables.md	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/doc/src/manual/variables.md	2020-03-21 16:36:32.000000000 +0000
@@ -1,4 +1,4 @@
-# Variables
+# [Variables](@id man-variables)
 
 A variable, in Julia, is a name associated (or bound) to a value. It's useful when you want to
 store a value (that you obtained after some math, for example) for later use. For example:
diff -pruN 1.3.1+dfsg-1/.gitattributes 1.4.0+dfsg-1/.gitattributes
--- 1.3.1+dfsg-1/.gitattributes	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/.gitattributes	2020-03-21 16:36:32.000000000 +0000
@@ -1,2 +1,2 @@
-# treat patches as files that should not be modified
-*.patch -text
+# treat all files as files that should not be modified
+* -text
diff -pruN 1.3.1+dfsg-1/.github/CODE_OF_CONDUCT.md 1.4.0+dfsg-1/.github/CODE_OF_CONDUCT.md
--- 1.3.1+dfsg-1/.github/CODE_OF_CONDUCT.md	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/.github/CODE_OF_CONDUCT.md	1970-01-01 00:00:00.000000000 +0000
@@ -1,23 +0,0 @@
-Julia Community Standards
-=========================
-
-The Julia community is committed to maintaining a welcoming, civil and constructive environment. We expect the following standards to be observed and upheld by all participants in any community forum (mailing lists, GitHub, IRC, etc.).
-
-**Be respectful and inclusive.**
-Please do not use overtly sexual language or imagery, and do not attack anyone based on any aspect of personal identity, including gender, sexuality, religion, ethnicity, race, age or ability. Keep in mind that what you write in public forums is read by many people who don't know you personally, so please refrain from making prejudiced or sexual jokes and comments – even ones that you might consider acceptable in private. Ask yourself if a comment or statement might make someone feel unwelcomed or like an outsider.
-
-In particular, do not sexualize the term "Julia" or any other aspects of the project. While "Julia" is a female name in many parts of the world, the programming language is not a person and does not have a gender.
-
-**Give credit.**
-All participants in the Julia community are expected to respect copyright laws and ethical attribution standards. This applies to both code and written materials, such as documentation or blog posts. Materials that violate the law, are plagiaristic, or ethically dubious in some way will be removed from officially-maintained lists of resources.
-
-If you believe one of these standards has been violated, you can either file an issue on an appropriate repository or confidentially contact the [Julia Stewards](https://julialang.org/community/stewards/) at [stewards@julialang.org](mailto:stewards@julialang.org). Keep in mind that most mistakes are due to ignorance rather than malice.
-
-**Be concise.**
-Constructive criticism and suggestions are welcome, but high-traffic forums do not generally have the bandwidth for extensive discourse. Consider writing a blog post if you feel that you have enough to say on a particular subject.
-
-**Get involved.**
-The Julia community is built on a foundation of reciprocity and collaboration. Be aware that most community members contribute on a voluntary basis, so ideas and bug reports are ok, but demands are not. Pull requests are always welcomed – see the [guidelines for contributing](https://github.com/JuliaLang/julia/blob/master/CONTRIBUTING.md) to read about how to get started.
-
-**Any concerns?**
-If you have a conflict or concern that requires resolution, please contact the [Julia Community Stewards](https://julialang.org/community/stewards/).
diff -pruN 1.3.1+dfsg-1/.github/FUNDING.yml 1.4.0+dfsg-1/.github/FUNDING.yml
--- 1.3.1+dfsg-1/.github/FUNDING.yml	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/.github/FUNDING.yml	1970-01-01 00:00:00.000000000 +0000
@@ -1 +0,0 @@
-custom: https://numfocus.org/donate-to-julia
diff -pruN 1.3.1+dfsg-1/.github/ISSUE_TEMPLATE.md 1.4.0+dfsg-1/.github/ISSUE_TEMPLATE.md
--- 1.3.1+dfsg-1/.github/ISSUE_TEMPLATE.md	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/.github/ISSUE_TEMPLATE.md	1970-01-01 00:00:00.000000000 +0000
@@ -1,9 +0,0 @@
-If you have a question please search or post to our Discourse site: https://discourse.julialang.org.
-We use the GitHub issue tracker for bug reports and feature requests only.
-
-If you're submitting a bug report, be sure to include as much relevant information as
-possible, including a minimal reproducible example and the output of `versioninfo()`.
-If you're experiencing a problem with a particular package, open an issue on that
-package's repository instead.
-
-Thanks for contributing to the Julia project!
diff -pruN 1.3.1+dfsg-1/.github/SECURITY.md 1.4.0+dfsg-1/.github/SECURITY.md
--- 1.3.1+dfsg-1/.github/SECURITY.md	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/.github/SECURITY.md	1970-01-01 00:00:00.000000000 +0000
@@ -1,15 +0,0 @@
-# Security Policy
-
-## Supported Versions
-
-The LTS and current stable releases of Julia are the ones supported for security updates.
-
-| Version | Supported          |
-| ------- | ------------------ |
-| LTS     | :white_check_mark: |
-| Stable  | :white_check_mark: |
-| < 1.0   | :x:                |
-
-## Reporting a Vulnerability
-
-Please report security vulnerabilities by emailing security@julialang.org.
diff -pruN 1.3.1+dfsg-1/.github/SUPPORT.md 1.4.0+dfsg-1/.github/SUPPORT.md
--- 1.3.1+dfsg-1/.github/SUPPORT.md	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/.github/SUPPORT.md	1970-01-01 00:00:00.000000000 +0000
@@ -1,12 +0,0 @@
-# Getting support for Julia
-
-We use the GitHub issue tracker for bug reports and feature requests only. If
-what you'd like to do is best described as a bug report or a code contribution
-then you should submit a GitHub issue or pull request as usual. Please see our
-[Notes for Julia
-Contributors](https://github.com/JuliaLang/julia/blob/master/CONTRIBUTING.md)
-for how to file a bug report, our contributor checklist and other helpful
-information. But if you have come here for help, or if you are unsure whether
-the behavior you're experiencing is a bug, then you should see our [Community
-page](https://julialang.org/community/) for a list of other places where you can
-get support first.
diff -pruN 1.3.1+dfsg-1/.gitignore 1.4.0+dfsg-1/.gitignore
--- 1.3.1+dfsg-1/.gitignore	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/.gitignore	2020-03-21 16:36:32.000000000 +0000
@@ -17,6 +17,7 @@
 *.dwo
 *.do
 *.o
+*.o.tmp
 *.obj
 *.so
 *.dylib
@@ -29,3 +30,4 @@
 
 /perf*
 .DS_Store
+.idea/*
diff -pruN 1.3.1+dfsg-1/HISTORY.md 1.4.0+dfsg-1/HISTORY.md
--- 1.3.1+dfsg-1/HISTORY.md	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/HISTORY.md	2020-03-21 16:36:32.000000000 +0000
@@ -1,3 +1,180 @@
+Julia v1.3 Release Notes
+========================
+
+New language features
+---------------------
+
+* Support for Unicode 12.1.0 ([#32002]).
+* Methods can now be added to an abstract type ([#31916]).
+* Support for unicode bold digits and double-struck digits 0 through 9 as valid identifiers ([#32838]).
+* Added the syntax `var"#str#"` for printing and parsing non-standard variable names ([#32408]).
+
+Language changes
+----------------
+
+
+Multi-threading changes
+-----------------------
+
+* New experimental `Threads.@spawn` macro that runs a task on any available thread ([#32600]).
+* All system-level I/O operations (e.g. files and sockets) are now thread-safe.
+  This does not include subtypes of `IO` that are entirely in-memory, such as `IOBuffer`,
+  although it specifically does include `BufferStream`.
+  ([#32309], [#32174], [#31981], [#32421]).
+* The global random number generator (`GLOBAL_RNG`) is now thread-safe (and thread-local) ([#32407]).
+* New `Channel(f::Function, spawn=true)` keyword argument to schedule the created Task on
+  any available thread, matching the behavior of `Threads.@spawn` ([#32872]).
+* Simplified the `Channel` constructor, which is now easier to read and more idiomatic julia.
+  Use of the keyword arguments `csize` and `ctype` is now discouraged ([#30855], [#32818]).
+
+Build system changes
+--------------------
+
+
+New library functions
+---------------------
+
+* `findfirst`, `findlast`, `findnext` and `findprev` now accept a character as first argument
+  to search for that character in a string passed as the second argument ([#31664]).
+* New `findall(pattern, string)` method where `pattern` is a string or regex ([#31834]).
+* `count(pattern, string)` gives the number of things `findall` would match ([#32849]).
+* `istaskfailed` is now documented and exported, like its siblings `istaskdone` and `istaskstarted` ([#32300]).
+* `RefArray` and `RefValue` objects now accept index `CartesianIndex()` in  `getindex` and `setindex!` ([#32653])
+* Added `sincosd(x)` to simultaneously compute the sine and cosine of `x`, where `x` is in degrees ([#30134]).
+* The function `nonmissingtype`, which removes `Missing` from type unions, is now exported ([#31562]).
+
+Standard library changes
+------------------------
+
+* `Pkg` won't clobber pre-compilation files as often when switching environments ([#32651])
+* `Pkg` can now download and install binary artifacts through the `Pkg.Artifacts`
+   submodule and supporting functions. ([#32918])
+* When `wait` (or `@sync`, or `fetch`) is called on a failing `Task`, the exception is propagated as a
+  `TaskFailedException` wrapping the task.
+  This makes it possible to see the location of the original failure inside the task (as well as the
+  location of the `wait` call, as before) ([#32814]).
+* `Regex` can now be multiplied (`*`) and exponentiated (`^`), like strings ([#23422]).
+* `Cmd` interpolation (``` `$(x::Cmd) a b c` ``` where) now propagates `x`'s process flags
+  (environment, flags, working directory, etc) if `x` is the first interpolant and errors
+  otherwise ([#24353]).
+* Zero-dimensional arrays are now consistently preserved in the return values of mathematical
+  functions that operate on the array(s) as a whole (and are not explicitly broadcasted across their elements).
+  Previously, the functions  `+`, `-`, `*`, `/`, `conj`, `real` and `imag` returned the unwrapped element
+  when operating over zero-dimensional arrays ([#32122]).
+* `IPAddr` subtypes now behave like scalars when used in broadcasting ([#32133]).
+* `Pair` is now treated as a scalar for broadcasting ([#32209]).
+* `clamp` can now handle missing values ([#31066]).
+* `empty` now accepts a `NamedTuple` ([#32534]).
+* `mod` now accepts a unit range as the second argument to easily perform offset modular arithmetic to ensure the result is inside the range ([#32628]).
+* `nothing` can now be `print`ed, and interpolated into strings etc. as the string `"nothing"`. It is still not permitted to be interpolated into Cmds (i.e. ``echo `$(nothing)` `` will still error without running anything.) ([#32148])
+* When `open` is called with a function, command, and keyword argument (e.g. ```open(`ls`, read=true) do f ...```)
+  it now correctly throws a `ProcessFailedException` like other similar calls ([#32193]).
+* `mktemp` and `mktempdir` now try, by default, to remove temporary paths they create before the process exits ([#32851]).
+* Added argument `keep` to `unescape_string` ([#27125]).
+
+#### Libdl
+
+* `dlopen()` can now be invoked in `do`-block syntax, similar to `open()`.
+
+#### LinearAlgebra
+
+* The BLAS submodule no longer exports `dot`, which conflicts with that in LinearAlgebra ([#31838]).
+* `diagm` and `spdiagm` now accept optional `m,n` initial arguments to specify a size ([#31654]).
+* `Hessenberg` factorizations `H` now support efficient shifted solves `(H+µI) \ b` and determinants, and use a specialized tridiagonal factorization for Hermitian matrices. There is also a new `UpperHessenberg` matrix type ([#31853]).
+* Added keyword argument `alg` to `svd` and `svd!` that allows one to switch between different SVD algorithms ([#31057]).
+* Five-argument `mul!(C, A, B, α, β)` now implements inplace multiplication fused with addition _C = A B α + C β_ ([#23919]).
+
+#### SparseArrays
+
+* `SparseMatrixCSC(m,n,colptr,rowval,nzval)` perform consistency checks for arguments:
+  `colptr` must be properly populated and lengths of `colptr`, `rowval`, and `nzval`
+  must be compatible with `m`, `n`, and `eltype(colptr)`.
+* `sparse(I, J, V, m, n)` verifies lengths of `I`, `J`, `V` are equal and compatible with
+  `eltype(I)` and `m`, `n`.
+
+#### Dates
+
+* `DateTime` and `Time` formatting/parsing now supports 12-hour clocks with AM/PM via `I` and `p` codes, similar to `strftime` ([#32308]).
+* Fixed `repr` such that it displays `Time` as it would be entered in Julia ([#32103]).
+
+#### Statistics
+
+* `mean` now accepts both a function argument and a `dims` keyword ([#31576]).
+
+#### Sockets
+
+* `Sockets.recvfrom` now returns both host and port as an InetAddr ([#32729]).
+* Added `InetAddr` constructor from `AbstractString`, representing IP address, and `Integer`,
+  representing port number ([#31459]).
+
+#### Miscellaneous
+
+* `foldr` and `mapfoldr` now work on any iterator that supports `Iterators.reverse`, not just arrays ([#31781]).
+
+Deprecated or removed
+---------------------
+
+* `@spawn expr` from the `Distributed` standard library should be replaced with `@spawnat :any expr` ([#32600]).
+* `Threads.Mutex` and `Threads.RecursiveSpinLock` have been removed; use `ReentrantLock` (preferred) or
+  `Threads.SpinLock` instead ([#32875]).
+
+External dependencies
+---------------------
+
+Tooling Improvements
+---------------------
+
+* The `ClangSA.jl` static analysis package has been imported, which makes use of
+  the clang static analyzer to validate GC invariants in Julia's C code. The analysis
+  may be run using `make -C src analyzegc`.
+
+<!--- generated by NEWS-update.jl: -->
+[#23422]: https://github.com/JuliaLang/julia/issues/23422
+[#23919]: https://github.com/JuliaLang/julia/issues/23919
+[#24353]: https://github.com/JuliaLang/julia/issues/24353
+[#27125]: https://github.com/JuliaLang/julia/issues/27125
+[#30134]: https://github.com/JuliaLang/julia/issues/30134
+[#30855]: https://github.com/JuliaLang/julia/issues/30855
+[#31057]: https://github.com/JuliaLang/julia/issues/31057
+[#31066]: https://github.com/JuliaLang/julia/issues/31066
+[#31459]: https://github.com/JuliaLang/julia/issues/31459
+[#31562]: https://github.com/JuliaLang/julia/issues/31562
+[#31576]: https://github.com/JuliaLang/julia/issues/31576
+[#31654]: https://github.com/JuliaLang/julia/issues/31654
+[#31664]: https://github.com/JuliaLang/julia/issues/31664
+[#31781]: https://github.com/JuliaLang/julia/issues/31781
+[#31834]: https://github.com/JuliaLang/julia/issues/31834
+[#31838]: https://github.com/JuliaLang/julia/issues/31838
+[#31853]: https://github.com/JuliaLang/julia/issues/31853
+[#31916]: https://github.com/JuliaLang/julia/issues/31916
+[#31981]: https://github.com/JuliaLang/julia/issues/31981
+[#32002]: https://github.com/JuliaLang/julia/issues/32002
+[#32103]: https://github.com/JuliaLang/julia/issues/32103
+[#32122]: https://github.com/JuliaLang/julia/issues/32122
+[#32133]: https://github.com/JuliaLang/julia/issues/32133
+[#32148]: https://github.com/JuliaLang/julia/issues/32148
+[#32174]: https://github.com/JuliaLang/julia/issues/32174
+[#32193]: https://github.com/JuliaLang/julia/issues/32193
+[#32209]: https://github.com/JuliaLang/julia/issues/32209
+[#32300]: https://github.com/JuliaLang/julia/issues/32300
+[#32308]: https://github.com/JuliaLang/julia/issues/32308
+[#32309]: https://github.com/JuliaLang/julia/issues/32309
+[#32407]: https://github.com/JuliaLang/julia/issues/32407
+[#32408]: https://github.com/JuliaLang/julia/issues/32408
+[#32421]: https://github.com/JuliaLang/julia/issues/32421
+[#32534]: https://github.com/JuliaLang/julia/issues/32534
+[#32600]: https://github.com/JuliaLang/julia/issues/32600
+[#32628]: https://github.com/JuliaLang/julia/issues/32628
+[#32653]: https://github.com/JuliaLang/julia/issues/32653
+[#32729]: https://github.com/JuliaLang/julia/issues/32729
+[#32814]: https://github.com/JuliaLang/julia/issues/32814
+[#32818]: https://github.com/JuliaLang/julia/issues/32818
+[#32838]: https://github.com/JuliaLang/julia/issues/32838
+[#32849]: https://github.com/JuliaLang/julia/issues/32849
+[#32851]: https://github.com/JuliaLang/julia/issues/32851
+[#32872]: https://github.com/JuliaLang/julia/issues/32872
+[#32875]: https://github.com/JuliaLang/julia/issues/32875
+
 Julia v1.2 Release Notes
 ========================
 
diff -pruN 1.3.1+dfsg-1/LICENSE.md 1.4.0+dfsg-1/LICENSE.md
--- 1.3.1+dfsg-1/LICENSE.md	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/LICENSE.md	2020-03-21 16:36:32.000000000 +0000
@@ -35,10 +35,11 @@ Julia includes code from the following p
 - [MUSL](https://git.musl-libc.org/cgit/musl/tree/COPYRIGHT) (for getopt implementation on Windows) [MIT]
 - [MINGW](https://sourceforge.net/p/mingw/mingw-org-wsl/ci/legacy/tree/mingwrt/mingwex/dirname.c) (for dirname implementation on Windows) [MIT]
 - [NetBSD](https://www.netbsd.org/about/redistribution.html) (for setjmp, longjmp, and strptime implementations on Windows) [BSD-3]
-- [Python](https://docs.python.org/2/license.html) (for strtod implementation on Windows) [BSD-3, effectively]
+- [Python](https://docs.python.org/2/license.html) (for strtod and joinpath implementation on Windows) [BSD-3, effectively]
 
 The following components included in Julia `Base` have their own separate licenses:
 
+- base/ryu/* [Boost] (see [ryu](https://github.com/ulfjack/ryu/blob/master/LICENSE-Boost))
 - base/grisu/* [BSD-3] (see [double-conversion](https://github.com/google/double-conversion/blob/master/LICENSE))
 - base/special/{exp,rem_pio2,hyperbolic}.jl [Freely distributable with preserved copyright notice] (see [FDLIBM](https://www.netlib.org/fdlibm))
 
diff -pruN 1.3.1+dfsg-1/Makefile 1.4.0+dfsg-1/Makefile
--- 1.3.1+dfsg-1/Makefile	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/Makefile	2020-03-21 16:36:32.000000000 +0000
@@ -80,6 +80,9 @@ julia-ui-release julia-ui-debug : julia-
 julia-sysimg-ji : julia-stdlib julia-base julia-ui-$(JULIA_BUILD_MODE) | $(build_private_libdir)
 	@$(MAKE) $(QUIET_MAKE) -C $(BUILDROOT) -f sysimage.mk sysimg-ji JULIA_EXECUTABLE='$(JULIA_EXECUTABLE)'
 
+julia-sysimg-bc : julia-stdlib julia-base julia-ui-$(JULIA_BUILD_MODE) | $(build_private_libdir)
+	@$(MAKE) $(QUIET_MAKE) -C $(BUILDROOT) -f sysimage.mk sysimg-bc JULIA_EXECUTABLE='$(JULIA_EXECUTABLE)'
+
 julia-sysimg-release julia-sysimg-debug : julia-sysimg-% : julia-sysimg-ji julia-ui-%
 	@$(MAKE) $(QUIET_MAKE) -C $(BUILDROOT) -f sysimage.mk sysimg-$*
 
@@ -147,7 +150,7 @@ $(build_depsbindir)/stringreplace: $(JUL
 	@$(call PRINT_CC, $(HOSTCC) -o $(build_depsbindir)/stringreplace $(JULIAHOME)/contrib/stringreplace.c)
 
 julia-base-cache: julia-sysimg-$(JULIA_BUILD_MODE) | $(DIRS) $(build_datarootdir)/julia
-	@$(call spawn,JULIA_BINDIR=$(call cygpath_w,$(build_bindir)) $(JULIA_EXECUTABLE) --startup-file=no $(call cygpath_w,$(JULIAHOME)/etc/write_base_cache.jl) \
+	@JULIA_BINDIR=$(call cygpath_w,$(build_bindir)) $(call spawn, $(JULIA_EXECUTABLE) --startup-file=no $(call cygpath_w,$(JULIAHOME)/etc/write_base_cache.jl) \
 		$(call cygpath_w,$(build_datarootdir)/julia/base.cache))
 
 # public libraries, that are installed in $(prefix)/lib
@@ -176,7 +179,7 @@ else
 JL_PRIVATE_LIBS-$(USE_SYSTEM_ZLIB) += libz
 endif
 ifeq ($(USE_LLVM_SHLIB),1)
-JL_PRIVATE_LIBS-$(USE_SYSTEM_LLVM) += libLLVM libLLVM-6
+JL_PRIVATE_LIBS-$(USE_SYSTEM_LLVM) += libLLVM libLLVM-8
 endif
 
 ifeq ($(USE_SYSTEM_LIBM),0)
@@ -219,8 +222,8 @@ ifeq ($(OS),WINNT)
 ifeq ($(XC_HOST),)
 STD_LIB_PATH ?= $(PATH)
 else
-STD_LIB_PATH := $(shell LANG=C $(CC) -print-search-dirs | grep programs | sed -e "s/^programs: =//")
-STD_LIB_PATH += :$(shell LANG=C $(CC) -print-search-dirs | grep libraries | sed -e "s/^libraries: =//")
+STD_LIB_PATH := $(shell LANG=C $(CC) -print-search-dirs | grep '^programs: =' | sed -e "s/^programs: =//")
+STD_LIB_PATH += :$(shell LANG=C $(CC) -print-search-dirs | grep '^libraries: =' | sed -e "s/^libraries: =//")
 ifneq (,$(findstring CYGWIN,$(BUILD_OS))) # the cygwin-mingw32 compiler lies about it search directory paths
 STD_LIB_PATH := $(shell echo '$(STD_LIB_PATH)' | sed -e "s!/lib/!/bin/!g")
 endif
@@ -396,7 +399,7 @@ else ifneq (,$(findstring $(OS),Linux Fr
 endif
 
 	# Overwrite JL_SYSTEM_IMAGE_PATH in julia library
-	if [ $(DARWIN_FRAMEWORK) == 0 ]; then \
+	if [ $(DARWIN_FRAMEWORK) = 0 ]; then \
 		RELEASE_TARGET=$(DESTDIR)$(libdir)/libjulia.$(SHLIB_EXT); \
 		DEBUG_TARGET=$(DESTDIR)$(libdir)/libjulia-debug.$(SHLIB_EXT); \
 	else \
@@ -404,7 +407,7 @@ endif
 		DEBUG_TARGET=$(DESTDIR)$(prefix)/$(framework_dylib)_debug; \
 	fi; \
 	$(call stringreplace,$${RELEASE_TARGET},sys.$(SHLIB_EXT)$$,$(private_libdir_rel)/sys.$(SHLIB_EXT)); \
-	if [ $(BUNDLE_DEBUG_LIBS) == 1 ]; then \
+	if [ $(BUNDLE_DEBUG_LIBS) = 1 ]; then \
 		$(call stringreplace,$${DEBUG_TARGET},sys-debug.$(SHLIB_EXT)$$,$(private_libdir_rel)/sys-debug.$(SHLIB_EXT)); \
 	fi;
 
@@ -431,7 +434,7 @@ ifeq ($(DARWIN_FRAMEWORK),1)
 endif
 
 distclean:
-	-rm -fr $(BUILDROOT)/julia-*.tar.gz $(BUILDROOT)/julia*.exe $(BUILDROOT)/julia-*.7z $(BUILDROOT)/julia-$(JULIA_COMMIT)
+	-rm -fr $(BUILDROOT)/julia-*.tar.gz $(BUILDROOT)/julia*.exe $(BUILDROOT)/julia-$(JULIA_COMMIT)
 
 binary-dist: distclean
 ifeq ($(USE_SYSTEM_BLAS),0)
@@ -466,18 +469,9 @@ endif
 ifeq ($(OS), WINNT)
 	cd $(BUILDROOT)/julia-$(JULIA_COMMIT)/bin && rm -f llvm* llc.exe lli.exe opt.exe LTO.dll bugpoint.exe macho-dump.exe
 
-	# create file listing for uninstall. note: must have Windows path separators and line endings.
-	cd $(BUILDROOT)/julia-$(JULIA_COMMIT) && find * | sed -e 's/\//\\/g' -e 's/$$/\r/g' > etc/uninstall.log
-
-	# build nsis package
-	cd $(BUILDROOT) && $(call spawn,$(JULIAHOME)/dist-extras/nsis/makensis.exe) -NOCD -DVersion=$(JULIA_VERSION) -DArch=$(ARCH) -DCommit=$(JULIA_COMMIT) -DJULIAHOME="$(call cygpath_w,$(JULIAHOME))" $(call cygpath_w,$(JULIAHOME)/contrib/windows/build-installer.nsi) | iconv -f latin1
-
-	# compress nsis installer and combine with 7zip self-extracting header
-	cd $(BUILDROOT) && $(JULIAHOME)/usr/bin/7z a -mx=9 "julia-install-$(JULIA_COMMIT)-$(ARCH).7z" julia-installer.exe
-	cd $(BUILDROOT) && cat $(JULIAHOME)/contrib/windows/7zS.sfx $(JULIAHOME)/contrib/windows/7zSFX-config.txt "julia-install-$(JULIA_COMMIT)-$(ARCH).7z" > "$(JULIA_BINARYDIST_FILENAME).exe"
+	# run Inno Setup to compile installer; /O flag specifies where to place installer and /F flag the installer name
+	$(call spawn,$(JULIAHOME)/dist-extras/inno/iscc.exe /DAppVersion=$(JULIA_VERSION) /DAppSourceFiles="$(call cygpath_w,$(BUILDROOT)/julia-$(JULIA_COMMIT))" /DAppHomeFiles="$(call cygpath_w,$(JULIAHOME))" /F"$(JULIA_BINARYDIST_FILENAME)" /O"$(call cygpath_w,$(BUILDROOT))"  $(call cygpath_w,$(JULIAHOME)/contrib/windows/build-installer.iss))
 	chmod a+x "$(BUILDROOT)/$(JULIA_BINARYDIST_FILENAME).exe"
-	-rm -f $(BUILDROOT)/julia-install-$(JULIA_COMMIT)-$(ARCH).7z
-	-rm -f $(BUILDROOT)/julia-installer.exe
 else
 	cd $(BUILDROOT) && $(TAR) zcvf $(JULIA_BINARYDIST_FILENAME).tar.gz julia-$(JULIA_COMMIT)
 endif
@@ -568,7 +562,8 @@ distcleanall: cleanall
 	julia-debug julia-release julia-stdlib julia-deps julia-deps-libs \
 	julia-ui-release julia-ui-debug julia-src-release julia-src-debug \
 	julia-symlink julia-base julia-sysimg julia-sysimg-ji julia-sysimg-release julia-sysimg-debug \
-	test testall testall1 test clean distcleanall cleanall clean-* \
+	test testall testall1 test test-* test-revise-* \
+	clean distcleanall cleanall clean-* \
 	run-julia run-julia-debug run-julia-release run \
 	install binary-dist light-source-dist.tmp light-source-dist \
 	dist full-source-dist source-dist
@@ -576,8 +571,6 @@ distcleanall: cleanall
 test: check-whitespace $(JULIA_BUILD_MODE)
 	@$(MAKE) $(QUIET_MAKE) -C $(BUILDROOT)/test default JULIA_BUILD_MODE=$(JULIA_BUILD_MODE)
 
-JULIA_SYSIMG=$(build_private_libdir)/sys$(JULIA_LIBSUFFIX).$(SHLIB_EXT)
-
 testall: check-whitespace $(JULIA_BUILD_MODE)
 	cp $(JULIA_SYSIMG) $(BUILDROOT)/local.$(SHLIB_EXT)
 	$(call spawn,$(JULIA_EXECUTABLE) -J $(call cygpath_w,$(BUILDROOT)/local.$(SHLIB_EXT)) -e 'true')
@@ -588,18 +581,22 @@ testall1: check-whitespace $(JULIA_BUILD
 	@env JULIA_CPU_THREADS=1 $(MAKE) $(QUIET_MAKE) -C $(BUILDROOT)/test all JULIA_BUILD_MODE=$(JULIA_BUILD_MODE)
 
 test-%: check-whitespace $(JULIA_BUILD_MODE)
+	@([ $$(( $$(date +%s) - $$(date -r $(build_private_libdir)/sys.$(SHLIB_EXT) +%s) )) -le 100 ] && \
+		printf '\033[93m    HINT The system image was recently rebuilt. Are you aware of the test-revise-* targets? See CONTRIBUTING.md. \033[0m\n') || true
 	@$(MAKE) $(QUIET_MAKE) -C $(BUILDROOT)/test $* JULIA_BUILD_MODE=$(JULIA_BUILD_MODE)
 
+test-revise-%:
+	@$(MAKE) $(QUIET_MAKE) -C $(BUILDROOT)/test revise-$* JULIA_BUILD_MODE=$(JULIA_BUILD_MODE)
+
 # download target for some hardcoded windows dependencies
 .PHONY: win-extras wine_path
 win-extras:
 	@$(MAKE) -C $(BUILDROOT)/deps install-p7zip
 	mkdir -p $(JULIAHOME)/dist-extras
 	cd $(JULIAHOME)/dist-extras && \
-	$(JLDOWNLOAD) https://sourceforge.net/projects/nsis/files/NSIS%203/3.04/nsis-3.04-setup.exe && \
-	$(JLCHECKSUM) nsis-3.04-setup.exe && \
-	$(call spawn,$(JULIAHOME)/usr/bin/7z.exe) x -y -onsis nsis-3.04-setup.exe && \
-	chmod a+x ./nsis/makensis.exe
+	$(JLDOWNLOAD) http://www.jrsoftware.org/download.php/is.exe && \
+	chmod a+x is.exe && \
+	$(call spawn, $(JULIAHOME)/dist-extras/is.exe /DIR="$(call cygpath_w,$(JULIAHOME)/dist-extras/inno)" /PORTABLE=1 /CURRENTUSER /VERYSILENT)
 
 # various statistics about the build that may interest the user
 ifeq ($(USE_SYSTEM_LLVM), 1)
@@ -608,11 +605,11 @@ else
 LLVM_SIZE := $(build_depsbindir)/llvm-size$(EXE)
 endif
 build-stats:
-	@echo $(JULCOLOR)' ==> ./julia binary sizes'$(ENDCOLOR)
+	@printf $(JULCOLOR)' ==> ./julia binary sizes\n'$(ENDCOLOR)
 	$(call spawn,$(LLVM_SIZE) -A $(call cygpath_w,$(build_private_libdir)/sys.$(SHLIB_EXT)) \
 		$(call cygpath_w,$(build_shlibdir)/libjulia.$(SHLIB_EXT)) \
 		$(call cygpath_w,$(build_bindir)/julia$(EXE)))
-	@echo $(JULCOLOR)' ==> ./julia launch speedtest'$(ENDCOLOR)
+	@printf $(JULCOLOR)' ==> ./julia launch speedtest\n'$(ENDCOLOR)
 	@time $(call spawn,$(build_bindir)/julia$(EXE) -e '')
 	@time $(call spawn,$(build_bindir)/julia$(EXE) -e '')
 	@time $(call spawn,$(build_bindir)/julia$(EXE) -e '')
diff -pruN 1.3.1+dfsg-1/Make.inc 1.4.0+dfsg-1/Make.inc
--- 1.3.1+dfsg-1/Make.inc	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/Make.inc	2020-03-21 16:36:32.000000000 +0000
@@ -475,7 +475,7 @@ endif
 ifeq ($(USECLANG),1)
 CC := $(CROSS_COMPILE)clang
 CXX := $(CROSS_COMPILE)clang++
-JCFLAGS := -pipe $(fPIC) -fno-strict-aliasing -D_FILE_OFFSET_BITS=64
+JCFLAGS := -std=gnu99 -pipe $(fPIC) -fno-strict-aliasing -D_FILE_OFFSET_BITS=64
 # AArch64 needs this flag to generate the .eh_frame used by libunwind
 JCPPFLAGS := -fasynchronous-unwind-tables
 JCXXFLAGS := -pipe $(fPIC) -fno-rtti -pedantic
@@ -1010,13 +1010,29 @@ else
   UTF8PROC_INC := $(build_includedir)
 endif
 
+# We need python for things like BB triplet recognition.  We don't really care
+# about version, generally, so just find something that works:
+PYTHON := "$(shell which python 2>/dev/null || which python3 2>/dev/null || which python2 2>/dev/null || echo not found)"
+PYTHON_SYSTEM := $(shell $(PYTHON) -c 'from __future__ import print_function; import platform; print(platform.system())')
+
+# If we're running on Cygwin, but using a native-windows Python, we need to use cygpath -w
+ifneq ($(and $(filter $(PYTHON_SYSTEM),Windows),$(findstring CYGWIN,$(BUILD_OS))),)
+define invoke_python
+$(PYTHON) "$$(cygpath -w "$(1)")"
+endef
+else
+define invoke_python
+$(PYTHON) "$(1)"
+endef
+endif
+
 # BinaryBuilder options.  We default to "on" for all the projects listed in BB_PROJECTS,
 # but only if contrib/normalize_triplet.py works for our requested triplet.
-ifeq ($(shell python $(JULIAHOME)/contrib/normalize_triplet.py $(or $(XC_HOST),$(XC_HOST),$(BUILD_MACHINE)) >/dev/null 2>/dev/null; echo $$?),0)
+ifeq ($(shell $(call invoke_python,$(JULIAHOME)/contrib/normalize_triplet.py) $(or $(XC_HOST),$(XC_HOST),$(BUILD_MACHINE)) >/dev/null 2>/dev/null; echo $$?),0)
 USE_BINARYBUILDER ?= 1
 else
-ifneq ($(shell python $(JULIAHOME)/contrib/normalize_triplet.py x86_64-linux-gnu),x86_64-linux-gnu)
-$(warning python normalize_triplet.py appears to be non-functional, so BinaryBuilder disabled)
+ifneq ($(shell $(call invoke_python,$(JULIAHOME)/contrib/normalize_triplet.py) x86_64-linux-gnu),x86_64-linux-gnu)
+$(warning normalize_triplet.py appears to be non-functional (used python interpreter "$(PYTHON)"), so BinaryBuilder disabled)
 endif
 USE_BINARYBUILDER ?= 0
 endif
@@ -1261,7 +1277,7 @@ ifeq ($(USECLANG),1)
 CXXLDFLAGS += -stdlib=libc++
 else
 ifeq ($(USEGCC),1)
-$(error BUILD_CUSTOM_LIBCXX is currently only supported with Clang. Try setting BUILD_CUSTOM_LIBCXX=0)
+$(error BUILD_CUSTOM_LIBCXX is currently only supported with Clang. Try setting BUILD_CUSTOM_LIBCXX=0 or USECLANG=1)
 endif
 endif # Clang
 CUSTOM_LD_LIBRARY_PATH := LD_LIBRARY_PATH="$(build_libdir)"
@@ -1340,11 +1356,9 @@ endif
 exec = $(shell $(call spawn,$(1)))
 
 JULIA_BUILD_MODE := release
-JULIA_LIBSUFFIX:=
 ifeq (,$(findstring release,$(MAKECMDGOALS)))
 ifneq (,$(findstring debug,$(MAKECMDGOALS)))
 JULIA_BUILD_MODE := debug
-JULIA_LIBSUFFIX:=-debug
 endif
 endif
 
@@ -1352,6 +1366,10 @@ JULIA_EXECUTABLE_debug := $(build_bindir
 JULIA_EXECUTABLE_release := $(build_bindir)/julia$(EXE)
 JULIA_EXECUTABLE := $(JULIA_EXECUTABLE_$(JULIA_BUILD_MODE))
 
+JULIA_SYSIMG_debug := $(build_private_libdir)/sys-debug.$(SHLIB_EXT)
+JULIA_SYSIMG_release := $(build_private_libdir)/sys.$(SHLIB_EXT)
+JULIA_SYSIMG := $(JULIA_SYSIMG_$(JULIA_BUILD_MODE))
+
 # Colors for make
 ifndef VERBOSE
 VERBOSE := 0
diff -pruN 1.3.1+dfsg-1/NEWS.md 1.4.0+dfsg-1/NEWS.md
--- 1.3.1+dfsg-1/NEWS.md	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/NEWS.md	2020-03-21 16:36:32.000000000 +0000
@@ -1,175 +1,130 @@
-Julia v1.3 Release Notes
+Julia v1.4 Release Notes
 ========================
 
 New language features
 ---------------------
 
-* Support for Unicode 12.1.0 ([#32002]).
-* Methods can now be added to an abstract type ([#31916]).
-* Support for unicode bold digits and double-struck digits 0 through 9 as valid identifiers ([#32838]).
-* Added the syntax `var"#str#"` for printing and parsing non-standard variable names ([#32408]).
+* Structs with all isbits and isbitsunion fields are now stored inline in arrays ([#32448]).
+* `import` now allows quoted symbols, e.g. `import Base.:+` ([#33158]).
+* `a[begin]` can now be used to address the first element of an integer-indexed collection `a`.
+  The index is computed by `firstindex(a)` ([#33946]).
 
 Language changes
 ----------------
 
+* The syntax `(;)`, which used to parse as an empty block expression, is deprecated.
+  In the future it will indicate an empty named tuple ([#30115]).
 
 Multi-threading changes
 -----------------------
 
-* New experimental `Threads.@spawn` macro that runs a task on any available thread ([#32600]).
-* All system-level I/O operations (e.g. files and sockets) are now thread-safe.
-  This does not include subtypes of `IO` that are entirely in-memory, such as `IOBuffer`,
-  although it specifically does include `BufferStream`.
-  ([#32309], [#32174], [#31981], [#32421]).
-* The global random number generator (`GLOBAL_RNG`) is now thread-safe (and thread-local) ([#32407]).
-* New `Channel(f::Function, spawn=true)` keyword argument to schedule the created Task on
-  any available thread, matching the behavior of `Threads.@spawn` ([#32872]).
-* Simplified the `Channel` constructor, which is now easier to read and more idiomatic julia.
-  Use of the keyword arguments `csize` and `ctype` is now discouraged ([#30855], [#32818]).
+* Values can now be interpolated into `@async` and `@spawn` via `$`, which copies the value directly into the constructed
+  underlying closure ([#33119]).
 
 Build system changes
 --------------------
 
+* Windows build installer has switched to Inno Setup. Installer command line parameters have thus changed. For example, to extract the installer to a specific directory, the command line parameter is now `/DIR=x:\dirname`. Use `julia-installer.exe /?` to list all new command line parameters.
 
 New library functions
 ---------------------
 
-* `findfirst`, `findlast`, `findnext` and `findprev` now accept a character as first argument
-  to search for that character in a string passed as the second argument ([#31664]).
-* New `findall(pattern, string)` method where `pattern` is a string or regex ([#31834]).
-* `count(pattern, string)` gives the number of things `findall` would match ([#32849]).
-* `istaskfailed` is now documented and exported, like its siblings `istaskdone` and `istaskstarted` ([#32300]).
-* `RefArray` and `RefValue` objects now accept index `CartesianIndex()` in  `getindex` and `setindex!` ([#32653])
-* Added `sincosd(x)` to simultaneously compute the sine and cosine of `x`, where `x` is in degrees ([#30134]).
-* The function `nonmissingtype`, which removes `Missing` from type unions, is now exported ([#31562]).
+* The new `only(x)` function returns the one-and-only element of a collection `x`, and throws an `ArgumentError` if `x` contains zero or multiple elements ([#33129]).
+* `takewhile` and `dropwhile` have been added to the Iterators submodule ([#33437]).
+* `accumulate` has been added to the Iterators submodule ([#34033]).
+* There is a now an `evalpoly` function meant to take the role of the `@evalpoly` macro. The function is just as efficient as the macro while giving added flexibility, so it should be preferred over `@evalpoly`. `evalpoly` takes a list of coefficients as a tuple, so where one might write `@evalpoly(x, p1, p2, p3)` one would instead write `evalpoly(x, (p1, p2, p3))` ([#32753]).
+* `pkgdir(ModuleName)` now provides a simpler way to return the package root directory of a module (or submodule) than the typically used `dirname(dirname(pathof(ModuleName)))` ([#33128]).
 
-Standard library changes
-------------------------
+New library features
+--------------------
 
-* `Pkg` won't clobber pre-compilation files as often when switching environments ([#32651])
-* `Pkg` can now download and install binary artifacts through the `Pkg.Artifacts`
-   submodule and supporting functions. ([#32918])
-* When `wait` (or `@sync`, or `fetch`) is called on a failing `Task`, the exception is propagated as a
-  `TaskFailedException` wrapping the task.
-  This makes it possible to see the location of the original failure inside the task (as well as the
-  location of the `wait` call, as before) ([#32814]).
-* `Regex` can now be multiplied (`*`) and exponentiated (`^`), like strings ([#23422]).
-* `Cmd` interpolation (``` `$(x::Cmd) a b c` ``` where) now propagates `x`'s process flags
-  (environment, flags, working directory, etc) if `x` is the first interpolant and errors
-  otherwise ([#24353]).
-* Zero-dimensional arrays are now consistently preserved in the return values of mathematical
-  functions that operate on the array(s) as a whole (and are not explicitly broadcasted across their elements).
-  Previously, the functions  `+`, `-`, `*`, `/`, `conj`, `real` and `imag` returned the unwrapped element
-  when operating over zero-dimensional arrays ([#32122]).
-* `IPAddr` subtypes now behave like scalars when used in broadcasting ([#32133]).
-* `Pair` is now treated as a scalar for broadcasting ([#32209]).
-* `clamp` can now handle missing values ([#31066]).
-* `empty` now accepts a `NamedTuple` ([#32534]).
-* `mod` now accepts a unit range as the second argument to easily perform offset modular arithmetic to ensure the result is inside the range ([#32628]).
-* `nothing` can now be `print`ed, and interpolated into strings etc. as the string `"nothing"`. It is still not permitted to be interpolated into Cmds (i.e. ``echo `$(nothing)` `` will still error without running anything.) ([#32148])
-* When `open` is called with a function, command, and keyword argument (e.g. ```open(`ls`, read=true) do f ...```)
-  it now correctly throws a `ProcessFailedException` like other similar calls ([#32193]).
-* `mktemp` and `mktempdir` now try, by default, to remove temporary paths they create before the process exits ([#32851]).
-* Added argument `keep` to `unescape_string` ([#27125]).
+* Function composition now supports multiple functions: `∘(f, g, h) = f ∘ g ∘ h`
+  and splatting `∘(fs...)` for composing an iterable collection of functions ([#33568]).
+* Functions `gcd`, `lcm`, and `gcdx` now support `Rational` arguments ([#33910]).
+* The `splitpath` function now accepts any `AbstractString` whereas previously it only accepted paths of type `String` ([#33012]).
+* `filter` can now act on a `Tuple` ([#32968]).
+* The `tempname` function now takes an optional `parent::AbstractString` argument to give it a directory in which to attempt to produce a temporary path name ([#33090]).
+* The `tempname` function now takes a `cleanup::Bool` keyword argument defaulting to `true`, which causes the process to try to ensure that any file or directory at the path returned by `tempname` is deleted upon process exit ([#33090]).
+* The `readdir` function now takes a `join::Bool` keyword argument defaulting to `false`, which when set causes `readdir` to join its directory argument with each listed name ([#33113]).
+* `div` now accepts a rounding mode as the third argument, consistent with the corresponding argument to `rem`. Support for rounding division, by passing one of the RoundNearest modes to this function, was added. For future compatibility, library authors should now extend this function, rather than extending the two-argument `fld`/`cld`/`div` directly ([#33040]).
+* `methods` now accepts a module (or a list thereof) to filter methods defined in it ([#33403]).
 
-#### Libdl
+Standard library changes
+------------------------
 
-* `dlopen()` can now be invoked in `do`-block syntax, similar to `open()`.
+* Calling `show` or `repr` on an `undef`/`UndefInitializer()` array initializer now shows valid Julia code ([#33211]).
+* Calling `show` or `repr` on a 0-dimensional `AbstractArray` now shows valid code for creating an equivalent 0-dimensional array, instead of only showing the contained value ([#33206]).
+* `readdir` output is now guaranteed to be sorted. The `sort` keyword allows opting out of sorting to get names in OS-native order ([#33542]).
+* The methods of `mktemp` and `mktempdir` that take a function to pass temporary paths to no longer throw errors if the path is already deleted when the function returns ([#33091]).
+* Verbose `display` of `Char` (`text/plain` output) now shows the codepoint value in standard-conforming `"U+XXXX"` format ([#33291]).
+* `Iterators.partition` now uses views (or smartly re-computed ranges) for partitions of all `AbstractArray`s ([#33533]).
+* Sets are now displayed less compactly in the REPL, as a column of elements, like vectors
+  and dictionaries ([#33300]).
+* `delete!` on `WeakKeyDict`s now returns the `WeakKeyDict` itself instead of the underlying `Dict` used for implementation
 
 #### LinearAlgebra
 
-* The BLAS submodule no longer exports `dot`, which conflicts with that in LinearAlgebra ([#31838]).
-* `diagm` and `spdiagm` now accept optional `m,n` initial arguments to specify a size ([#31654]).
-* `Hessenberg` factorizations `H` now support efficient shifted solves `(H+µI) \ b` and determinants, and use a specialized tridiagonal factorization for Hermitian matrices. There is also a new `UpperHessenberg` matrix type ([#31853]).
-* Added keyword argument `alg` to `svd` and `svd!` that allows one to switch between different SVD algorithms ([#31057]).
-* Five-argument `mul!(C, A, B, α, β)` now implements inplace multiplication fused with addition _C = A B α + C β_ ([#23919]).
-
-#### SparseArrays
-
-* `SparseMatrixCSC(m,n,colptr,rowval,nzval)` perform consistency checks for arguments:
-  `colptr` must be properly populated and lengths of `colptr`, `rowval`, and `nzval`
-  must be compatible with `m`, `n`, and `eltype(colptr)`.
-* `sparse(I, J, V, m, n)` verifies lengths of `I`, `J`, `V` are equal and compatible with
-  `eltype(I)` and `m`, `n`.
-
-#### Dates
+* `qr` and `qr!` functions support `blocksize` keyword argument ([#33053]).
+* `dot` now admits a 3-argument method `dot(x, A, y)` to compute generalized dot products `dot(x, A*y)`, but without computing and storing the intermediate result `A*y` ([#32739]).
+* `ldlt` and non-pivoted `lu` now throw a new `ZeroPivotException` type ([#33372]).
+* `cond(A, p)` with `p=1` or `p=Inf` now computes the exact condition number instead of an estimate ([#33547]).
+* `UniformScaling` objects may now be exponentiated such that `(a*I)^x = a^x * I`.
 
-* `DateTime` and `Time` formatting/parsing now supports 12-hour clocks with AM/PM via `I` and `p` codes, similar to `strftime` ([#32308]).
+#### Markdown
 
-#### Statistics
+* Tables now have the `align` attribute set when `show`n as HTML ([#33849]).
 
-* `mean` now accepts both a function argument and a `dims` keyword ([#31576]).
+#### Random
 
-#### Sockets
+* `AbstractRNG`s now behave like scalars when used in broadcasting ([#33213]).
+* The performance of `rand(::Tuple)` is improved in some cases ([#32208]). As a consequence, the
+  stream of generated values produced for a given seed has changed.
 
-* `Sockets.recvfrom` now returns both host and port as an InetAddr ([#32729]).
-* Added `InetAddr` constructor from `AbstractString`, representing IP address, and `Integer`,
-  representing port number ([#31459]).
+#### REPL
 
-#### Miscellaneous
+* The attributes of the implicit `IOContext` used by the REPL to display objects can be
+  modified by the user (experimental feature) ([#29249]).
 
-* `foldr` and `mapfoldr` now work on any iterator that supports `Iterators.reverse`, not just arrays ([#31781]).
-
-Deprecated or removed
----------------------
-
-* `@spawn expr` from the `Distributed` standard library should be replaced with `@spawnat :any expr` ([#32600]).
-* `Threads.Mutex` and `Threads.RecursiveSpinLock` have been removed; use `ReentrantLock` (preferred) or
-  `Threads.SpinLock` instead ([#32875]).
-
-External dependencies
----------------------
-
-Tooling Improvements
----------------------
+#### SparseArrays
 
-* The `ClangSA.jl` static analysis package has been imported, which makes use of
-  the clang static analyzer to validate GC invariants in Julia's C code. The analysis
-  may be run using `make -C src analyzegc`.
+* The return value of `zero(x::AbstractSparseArray)` has no stored zeros anymore ([#31835]).
+  Previously, it would have stored zeros wherever `x` had them. This makes the operation
+  constant time instead of `O(<number of stored values>)`.
+* Products involving sparse arrays now allow more general sparse `eltype`s, such as `StaticArrays` ([#33205])
 
 <!--- generated by NEWS-update.jl: -->
-[#23422]: https://github.com/JuliaLang/julia/issues/23422
-[#23919]: https://github.com/JuliaLang/julia/issues/23919
-[#24353]: https://github.com/JuliaLang/julia/issues/24353
-[#27125]: https://github.com/JuliaLang/julia/issues/27125
-[#30134]: https://github.com/JuliaLang/julia/issues/30134
-[#30855]: https://github.com/JuliaLang/julia/issues/30855
-[#31057]: https://github.com/JuliaLang/julia/issues/31057
-[#31066]: https://github.com/JuliaLang/julia/issues/31066
-[#31459]: https://github.com/JuliaLang/julia/issues/31459
-[#31562]: https://github.com/JuliaLang/julia/issues/31562
-[#31576]: https://github.com/JuliaLang/julia/issues/31576
-[#31654]: https://github.com/JuliaLang/julia/issues/31654
-[#31664]: https://github.com/JuliaLang/julia/issues/31664
-[#31781]: https://github.com/JuliaLang/julia/issues/31781
-[#31834]: https://github.com/JuliaLang/julia/issues/31834
-[#31838]: https://github.com/JuliaLang/julia/issues/31838
-[#31853]: https://github.com/JuliaLang/julia/issues/31853
-[#31916]: https://github.com/JuliaLang/julia/issues/31916
-[#31981]: https://github.com/JuliaLang/julia/issues/31981
-[#32002]: https://github.com/JuliaLang/julia/issues/32002
-[#32122]: https://github.com/JuliaLang/julia/issues/32122
-[#32133]: https://github.com/JuliaLang/julia/issues/32133
-[#32148]: https://github.com/JuliaLang/julia/issues/32148
-[#32174]: https://github.com/JuliaLang/julia/issues/32174
-[#32193]: https://github.com/JuliaLang/julia/issues/32193
-[#32209]: https://github.com/JuliaLang/julia/issues/32209
-[#32300]: https://github.com/JuliaLang/julia/issues/32300
-[#32308]: https://github.com/JuliaLang/julia/issues/32308
-[#32309]: https://github.com/JuliaLang/julia/issues/32309
-[#32407]: https://github.com/JuliaLang/julia/issues/32407
-[#32408]: https://github.com/JuliaLang/julia/issues/32408
-[#32421]: https://github.com/JuliaLang/julia/issues/32421
-[#32534]: https://github.com/JuliaLang/julia/issues/32534
-[#32600]: https://github.com/JuliaLang/julia/issues/32600
-[#32628]: https://github.com/JuliaLang/julia/issues/32628
-[#32653]: https://github.com/JuliaLang/julia/issues/32653
-[#32729]: https://github.com/JuliaLang/julia/issues/32729
-[#32814]: https://github.com/JuliaLang/julia/issues/32814
-[#32818]: https://github.com/JuliaLang/julia/issues/32818
-[#32838]: https://github.com/JuliaLang/julia/issues/32838
-[#32849]: https://github.com/JuliaLang/julia/issues/32849
-[#32851]: https://github.com/JuliaLang/julia/issues/32851
-[#32872]: https://github.com/JuliaLang/julia/issues/32872
-[#32875]: https://github.com/JuliaLang/julia/issues/32875
-[#32918]: https://github.com/JuliaLang/julia/issues/32918
+[#29249]: https://github.com/JuliaLang/julia/issues/29249
+[#30115]: https://github.com/JuliaLang/julia/issues/30115
+[#31835]: https://github.com/JuliaLang/julia/issues/31835
+[#32208]: https://github.com/JuliaLang/julia/issues/32208
+[#32448]: https://github.com/JuliaLang/julia/issues/32448
+[#32739]: https://github.com/JuliaLang/julia/issues/32739
+[#32753]: https://github.com/JuliaLang/julia/issues/32753
+[#33128]: https://github.com/JuliaLang/julia/issues/33128
+[#32968]: https://github.com/JuliaLang/julia/issues/32968
+[#33012]: https://github.com/JuliaLang/julia/issues/33012
+[#33040]: https://github.com/JuliaLang/julia/issues/33040
+[#33053]: https://github.com/JuliaLang/julia/issues/33053
+[#33090]: https://github.com/JuliaLang/julia/issues/33090
+[#33091]: https://github.com/JuliaLang/julia/issues/33091
+[#33113]: https://github.com/JuliaLang/julia/issues/33113
+[#33119]: https://github.com/JuliaLang/julia/issues/33119
+[#33129]: https://github.com/JuliaLang/julia/issues/33129
+[#33158]: https://github.com/JuliaLang/julia/issues/33158
+[#33205]: https://github.com/JuliaLang/julia/issues/33205
+[#33206]: https://github.com/JuliaLang/julia/issues/33206
+[#33211]: https://github.com/JuliaLang/julia/issues/33211
+[#33213]: https://github.com/JuliaLang/julia/issues/33213
+[#33291]: https://github.com/JuliaLang/julia/issues/33291
+[#33300]: https://github.com/JuliaLang/julia/issues/33300
+[#33372]: https://github.com/JuliaLang/julia/issues/33372
+[#33403]: https://github.com/JuliaLang/julia/issues/33403
+[#33437]: https://github.com/JuliaLang/julia/issues/33437
+[#33533]: https://github.com/JuliaLang/julia/issues/33533
+[#33542]: https://github.com/JuliaLang/julia/issues/33542
+[#33547]: https://github.com/JuliaLang/julia/issues/33547
+[#33568]: https://github.com/JuliaLang/julia/issues/33568
+[#33849]: https://github.com/JuliaLang/julia/issues/33849
+[#33910]: https://github.com/JuliaLang/julia/issues/33910
+[#33946]: https://github.com/JuliaLang/julia/issues/33946
+[#34033]: https://github.com/JuliaLang/julia/issues/34033
diff -pruN 1.3.1+dfsg-1/README.md 1.4.0+dfsg-1/README.md
--- 1.3.1+dfsg-1/README.md	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/README.md	2020-03-21 16:36:32.000000000 +0000
@@ -5,18 +5,18 @@
 </a>
 </div>
 
-Build status:
-[![travis][travis-img]](https://travis-ci.org/JuliaLang/julia)
-[![appveyor][appveyor-img]](https://ci.appveyor.com/project/JuliaLang/julia/branch/master)
-
 Code coverage:
 [![coveralls][coveralls-img]](https://coveralls.io/r/JuliaLang/julia?branch=master)
 [![codecov][codecov-img]](https://codecov.io/github/JuliaLang/julia?branch=master)
 
+Documentation:
+[![version 1][docs-img]](https://docs.julialang.org)
+
 [travis-img]: https://img.shields.io/travis/JuliaLang/julia/master.svg?label=Linux+/+macOS
 [appveyor-img]: https://img.shields.io/appveyor/ci/JuliaLang/julia/master.svg?label=Windows
 [coveralls-img]: https://img.shields.io/coveralls/github/JuliaLang/julia/master.svg?label=coveralls
 [codecov-img]: https://img.shields.io/codecov/c/github/JuliaLang/julia/master.svg?label=codecov
+[docs-img]: https://img.shields.io/badge/docs-v1-blue.svg
 
 ## The Julia Language
 
@@ -80,7 +80,7 @@ Julia. However, most users should use th
 of Julia. You can get this version by changing to the Julia directory
 and running:
 
-    git checkout v1.1.1
+    git checkout v1.3.0
 
 Now run `make` to build the `julia` executable.
 
@@ -130,7 +130,7 @@ The Julia source code is organized as fo
 ## Terminal, Editors and IDEs
 
 The Julia REPL is quite powerful.  See the section in the manual on
-[the Julia REPL](https://docs.julialang.org/en/latest/stdlib/REPL/)
+[the Julia REPL](https://docs.julialang.org/en/v1/stdlib/REPL/)
 for more details.
 
 Support for editing Julia is available for many
diff -pruN 1.3.1+dfsg-1/src/array.c 1.4.0+dfsg-1/src/array.c
--- 1.3.1+dfsg-1/src/array.c	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/src/array.c	2020-03-21 16:36:32.000000000 +0000
@@ -27,12 +27,6 @@ char *jl_array_typetagdata(jl_array_t *a
     return ((char*)jl_array_data(a)) + ((jl_array_ndims(a) == 1 ? (a->maxsize - a->offset) : jl_array_len(a)) * a->elsize) + a->offset;
 }
 
-JL_DLLEXPORT int jl_array_store_unboxed(jl_value_t *eltype) JL_NOTSAFEPOINT
-{
-    size_t fsz = 0, al = 0;
-    return jl_islayout_inline(eltype, &fsz, &al);
-}
-
 STATIC_INLINE jl_value_t *jl_array_owner(jl_array_t *a JL_PROPAGATES_ROOT) JL_NOTSAFEPOINT
 {
     if (a->flags.how == 3) {
@@ -53,7 +47,7 @@ size_t jl_arr_xtralloc_limit = 0;
 #define MAXINTVAL (((size_t)-1)>>1)
 
 static jl_array_t *_new_array_(jl_value_t *atype, uint32_t ndims, size_t *dims,
-                               int isunboxed, int isunion, int elsz)
+                               int isunboxed, int hasptr, int isunion, int elsz)
 {
     jl_ptls_t ptls = jl_get_ptls_states();
     size_t i, tot, nel=1;
@@ -101,7 +95,7 @@ static jl_array_t *_new_array_(jl_value_
         // No allocation or safepoint allowed after this
         a->flags.how = 0;
         data = (char*)a + doffs;
-        if ((tot > 0 && !isunboxed) || isunion)
+        if (tot > 0 && (!isunboxed || hasptr || isunion)) // TODO: check for zeroinit
             memset(data, 0, tot);
     }
     else {
@@ -113,7 +107,7 @@ static jl_array_t *_new_array_(jl_value_
         // No allocation or safepoint allowed after this
         a->flags.how = 2;
         jl_gc_track_malloced_array(ptls, a);
-        if (!isunboxed || isunion)
+        if (tot > 0 && (!isunboxed || hasptr || isunion)) // TODO: check for zeroinit
             // need to zero out isbits union array selector bytes to ensure a valid type index
             memset(data, 0, tot);
     }
@@ -127,6 +121,7 @@ static jl_array_t *_new_array_(jl_value_
 #endif
     a->flags.ndims = ndims;
     a->flags.ptrarray = !isunboxed;
+    a->flags.hasptr = hasptr;
     a->elsize = elsz;
     a->flags.isshared = 0;
     a->flags.isaligned = 1;
@@ -135,9 +130,12 @@ static jl_array_t *_new_array_(jl_value_
         a->nrows = nel;
         a->maxsize = nel;
     }
+    else if (a->flags.ndims != ndims) {
+        jl_exceptionf(jl_argumenterror_type, "invalid Array dimensions");
+    }
     else {
         size_t *adims = &a->nrows;
-        for(i=0; i < ndims; i++)
+        for (i = 0; i < ndims; i++)
             adims[i] = dims[i];
     }
 
@@ -152,6 +150,7 @@ static inline jl_array_t *_new_array(jl_
         jl_type_error_rt("Array", "element type", (jl_value_t*)jl_type_type, eltype);
     int isunboxed = jl_islayout_inline(eltype, &elsz, &al);
     int isunion = jl_is_uniontype(eltype);
+    int hasptr = isunboxed && (jl_is_datatype(eltype) && ((jl_datatype_t*)eltype)->layout->npointers > 0);
     if (!isunboxed) {
         elsz = sizeof(void*);
         al = elsz;
@@ -160,13 +159,13 @@ static inline jl_array_t *_new_array(jl_
         elsz = LLT_ALIGN(elsz, al);
     }
 
-    return _new_array_(atype, ndims, dims, isunboxed, isunion, elsz);
+    return _new_array_(atype, ndims, dims, isunboxed, hasptr, isunion, elsz);
 }
 
 jl_array_t *jl_new_array_for_deserialization(jl_value_t *atype, uint32_t ndims, size_t *dims,
-                                             int isunboxed, int isunion, int elsz)
+                                             int isunboxed, int hasptr, int isunion, int elsz)
 {
-    return _new_array_(atype, ndims, dims, isunboxed, isunion, elsz);
+    return _new_array_(atype, ndims, dims, isunboxed, hasptr, isunion, elsz);
 }
 
 #ifndef JL_NDEBUG
@@ -224,10 +223,12 @@ JL_DLLEXPORT jl_array_t *jl_reshape_arra
                           "reinterpret from alignment %d bytes to alignment %d bytes not allowed",
                           (int) oldalign, (int) align);
         a->flags.ptrarray = 0;
+        a->flags.hasptr = data->flags.hasptr;
     }
     else {
         a->elsize = sizeof(void*);
         a->flags.ptrarray = 1;
+        a->flags.hasptr = 0;
     }
 
     // if data is itself a shared wrapper,
@@ -247,6 +248,9 @@ JL_DLLEXPORT jl_array_t *jl_reshape_arra
         a->nrows = l;
         a->maxsize = l;
     }
+    else if (a->flags.ndims != ndims) {
+        jl_exceptionf(jl_argumenterror_type, "invalid Array dimensions");
+    }
     else {
         size_t *adims = &a->nrows;
         size_t l = 1;
@@ -281,6 +285,7 @@ JL_DLLEXPORT jl_array_t *jl_string_to_ar
     a->flags.isaligned = 0;
     a->elsize = 1;
     a->flags.ptrarray = 0;
+    a->flags.hasptr = 0;
     jl_array_data_owner(a) = str;
     a->flags.how = 3;
     a->flags.isshared = 1;
@@ -300,12 +305,12 @@ JL_DLLEXPORT jl_array_t *jl_ptr_to_array
     jl_array_t *a;
     jl_value_t *eltype = jl_tparam0(atype);
 
-    int isunboxed = jl_array_store_unboxed(eltype);
-    size_t elsz;
-    unsigned align;
+    int isunboxed = jl_stored_inline(eltype);
     if (isunboxed && jl_is_uniontype(eltype))
         jl_exceptionf(jl_argumenterror_type,
                       "unsafe_wrap: unspecified layout for union element type");
+    size_t elsz;
+    unsigned align;
     if (isunboxed) {
         elsz = jl_datatype_size(eltype);
         align = jl_datatype_align(eltype);
@@ -313,7 +318,7 @@ JL_DLLEXPORT jl_array_t *jl_ptr_to_array
     else {
         align = elsz = sizeof(void*);
     }
-    if (((uintptr_t)data) & (align - 1))
+    if (((uintptr_t)data) & ((align > JL_HEAP_ALIGNMENT ? JL_HEAP_ALIGNMENT : align) - 1))
         jl_exceptionf(jl_argumenterror_type,
                       "unsafe_wrap: pointer %p is not properly aligned to %u bytes", data, align);
 
@@ -328,6 +333,7 @@ JL_DLLEXPORT jl_array_t *jl_ptr_to_array
 #endif
     a->elsize = LLT_ALIGN(elsz, align);
     a->flags.ptrarray = !isunboxed;
+    a->flags.hasptr = isunboxed && (jl_is_datatype(eltype) && ((jl_datatype_t*)eltype)->layout->npointers > 0);
     a->flags.ndims = 1;
     a->flags.isshared = 1;
     a->flags.isaligned = 0;  // TODO: allow passing memalign'd buffers
@@ -366,12 +372,12 @@ JL_DLLEXPORT jl_array_t *jl_ptr_to_array
         return jl_ptr_to_array_1d(atype, data, nel, own_buffer);
     jl_value_t *eltype = jl_tparam0(atype);
 
-    int isunboxed = jl_array_store_unboxed(eltype);
-    size_t elsz;
-    unsigned align;
+    int isunboxed = jl_stored_inline(eltype);
     if (isunboxed && jl_is_uniontype(eltype))
         jl_exceptionf(jl_argumenterror_type,
                       "unsafe_wrap: unspecified layout for union element type");
+    size_t elsz;
+    unsigned align;
     if (isunboxed) {
         elsz = jl_datatype_size(eltype);
         align = jl_datatype_align(eltype);
@@ -379,7 +385,7 @@ JL_DLLEXPORT jl_array_t *jl_ptr_to_array
     else {
         align = elsz = sizeof(void*);
     }
-    if (((uintptr_t)data) & (align - 1))
+    if (((uintptr_t)data) & ((align > JL_HEAP_ALIGNMENT ? JL_HEAP_ALIGNMENT : align) - 1))
         jl_exceptionf(jl_argumenterror_type,
                       "unsafe_wrap: pointer %p is not properly aligned to %u bytes", data, align);
 
@@ -394,6 +400,7 @@ JL_DLLEXPORT jl_array_t *jl_ptr_to_array
 #endif
     a->elsize = LLT_ALIGN(elsz, align);
     a->flags.ptrarray = !isunboxed;
+    a->flags.hasptr = isunboxed && (jl_is_datatype(eltype) && ((jl_datatype_t*)eltype)->layout->npointers > 0);
     a->flags.ndims = ndims;
     a->offset = 0;
     a->flags.isshared = 1;
@@ -408,6 +415,8 @@ JL_DLLEXPORT jl_array_t *jl_ptr_to_array
     }
 
     assert(ndims != 1); // handled above
+    if (a->flags.ndims != ndims)
+        jl_exceptionf(jl_argumenterror_type, "invalid Array dimensions");
     memcpy(&a->nrows, dims, ndims * sizeof(size_t));
     return a;
 }
@@ -554,13 +563,20 @@ JL_DLLEXPORT jl_value_t *jl_arrayref(jl_
         if (jl_is_datatype_singleton((jl_datatype_t*)eltype))
             return ((jl_datatype_t*)eltype)->instance;
     }
-    return jl_new_bits(eltype, &((char*)a->data)[i * a->elsize]);
+    return undefref_check((jl_datatype_t*)eltype, jl_new_bits(eltype, &((char*)a->data)[i * a->elsize]));
 }
 
 JL_DLLEXPORT int jl_array_isassigned(jl_array_t *a, size_t i)
 {
-    if (a->flags.ptrarray)
+    if (a->flags.ptrarray) {
         return ((jl_value_t**)jl_array_data(a))[i] != NULL;
+    }
+    else if (a->flags.hasptr) {
+         jl_datatype_t *eltype = (jl_datatype_t*)jl_tparam0(jl_typeof(a));
+         assert(eltype->layout->first_ptr >= 0);
+         jl_value_t **elem = (jl_value_t**)((char*)a->data + i * a->elsize);
+         return elem[eltype->layout->first_ptr] != NULL;
+    }
     return 1;
 }
 
@@ -585,6 +601,8 @@ JL_DLLEXPORT void jl_arrayset(jl_array_t
                 return;
         }
         jl_assign_bits(&((char*)a->data)[i * a->elsize], rhs);
+        if (a->flags.hasptr)
+            jl_gc_multi_wb(jl_array_owner(a), rhs);
     }
     else {
         ((jl_value_t**)a->data)[i] = rhs;
@@ -598,9 +616,15 @@ JL_DLLEXPORT void jl_arrayunset(jl_array
         jl_bounds_error_int((jl_value_t*)a, i + 1);
     if (a->flags.ptrarray)
         ((jl_value_t**)a->data)[i] = NULL;
+    else if (a->flags.hasptr) {
+        size_t elsize = a->elsize;
+        jl_assume(elsize >= sizeof(void*) && elsize % sizeof(void*) == 0);
+        memset((char*)a->data + elsize * i, 0, elsize);
+    }
 }
 
-// at this size and bigger, allocate resized array data with malloc
+// at this size and bigger, allocate resized array data with malloc directly
+// instead of managing them separately as gc objects
 #define MALLOC_THRESH 1048576
 
 // Resize the buffer to a max size of `newlen`
@@ -652,13 +676,7 @@ static int NOINLINE array_resize_buffer(
     }
     else {
         newbuf = 1;
-        if (
-#ifdef _P64
-            nbytes >= MALLOC_THRESH
-#else
-            elsz > 4
-#endif
-            ) {
+        if (nbytes >= MALLOC_THRESH) {
             a->data = jl_gc_managed_malloc(nbytes);
             jl_gc_track_malloced_array(ptls, a);
             a->flags.how = 2;
@@ -814,7 +832,7 @@ STATIC_INLINE void jl_array_grow_at_beg(
 #endif
     a->nrows = newnrows;
     a->data = newdata;
-    if (a->flags.ptrarray) {
+    if (a->flags.ptrarray || a->flags.hasptr) { // TODO: check for zeroinit
         memset(newdata + idx * elsz, 0, nbinc);
     }
     else if (isbitsunion) {
@@ -895,7 +913,7 @@ STATIC_INLINE void jl_array_grow_at_end(
     a->length = newnrows;
 #endif
     a->nrows = newnrows;
-    if (a->flags.ptrarray) {
+    if (a->flags.ptrarray || a->flags.hasptr) { // TODO: check for zeroinit
         memset(data + idx * elsz, 0, inc * elsz);
     }
 }
@@ -954,12 +972,12 @@ STATIC_INLINE void jl_array_shrink(jl_ar
         char *typetagdata;
         char *newtypetagdata;
         if (isbitsunion) {
-            typetagdata = (char*)malloc(a->nrows);
+            typetagdata = (char*)malloc_s(a->nrows);
             memcpy(typetagdata, jl_array_typetagdata(a), a->nrows);
         }
         size_t oldoffsnb = a->offset * elsz;
-        a->data = ((char*) jl_gc_managed_realloc(originalptr, newbytes, oldnbytes,
-                                        a->flags.isaligned, (jl_value_t*) a)) + oldoffsnb;
+        a->data = ((char*)jl_gc_managed_realloc(originalptr, newbytes, oldnbytes,
+                a->flags.isaligned, (jl_value_t*) a)) + oldoffsnb;
         a->maxsize -= dec;
         if (isbitsunion) {
             newtypetagdata = jl_array_typetagdata(a);
@@ -1134,7 +1152,7 @@ JL_DLLEXPORT jl_array_t *jl_array_copy(j
     int isunion = jl_is_uniontype(jl_tparam0(jl_typeof(ary)));
     jl_array_t *new_ary = _new_array_(jl_typeof(ary), jl_array_ndims(ary),
                                       &ary->nrows, !ary->flags.ptrarray,
-                                      isunion, elsz);
+                                      ary->flags.hasptr, isunion, elsz);
     memcpy(new_ary->data, ary->data, len * elsz);
     // ensure isbits union arrays copy their selector bytes correctly
     if (jl_array_isbitsunion(ary))
diff -pruN 1.3.1+dfsg-1/src/ast.c 1.4.0+dfsg-1/src/ast.c
--- 1.3.1+dfsg-1/src/ast.c	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/src/ast.c	2020-03-21 16:36:32.000000000 +0000
@@ -478,13 +478,8 @@ static jl_value_t *scm_to_julia_(fl_cont
             return (jl_value_t*)jl_box_int32((int32_t)i64);
 #endif
     }
-    if (issymbol(e)) {
-        if (e == jl_ast_ctx(fl_ctx)->true_sym)
-            return jl_true;
-        else if (e == jl_ast_ctx(fl_ctx)->false_sym)
-            return jl_false;
+    if (issymbol(e))
         return (jl_value_t*)scmsym_to_julia(fl_ctx, e);
-    }
     if (fl_isstring(fl_ctx, e))
         return jl_pchar_to_string((char*)cvalue_data(e), cvalue_len(e));
     if (iscons(e) || e == fl_ctx->NIL) {
@@ -501,6 +496,10 @@ static jl_value_t *scm_to_julia_(fl_cont
                 return jl_box_slotnumber(numval(car_(cdr_(e))));
             else if (hd == jl_ast_ctx(fl_ctx)->null_sym && llength(e) == 1)
                 return jl_nothing;
+            else if (hd == jl_ast_ctx(fl_ctx)->true_sym && llength(e) == 1)
+                return jl_true;
+            else if (hd == jl_ast_ctx(fl_ctx)->false_sym && llength(e) == 1)
+                return jl_false;
         }
         if (issymbol(hd))
             sym = scmsym_to_julia(fl_ctx, hd);
@@ -643,9 +642,9 @@ static int julia_to_scm_noalloc1(fl_cont
     else if (jl_is_symbol(v))
         *retval = symbol(fl_ctx, jl_symbol_name((jl_sym_t*)v));
     else if (v == jl_true)
-        *retval = jl_ast_ctx(fl_ctx)->true_sym;
+        *retval = fl_cons(fl_ctx, jl_ast_ctx(fl_ctx)->true_sym, fl_ctx->NIL);
     else if (v == jl_false)
-        *retval = jl_ast_ctx(fl_ctx)->false_sym;
+        *retval = fl_cons(fl_ctx, jl_ast_ctx(fl_ctx)->false_sym, fl_ctx->NIL);
     else if (v == jl_nothing)
         *retval = fl_cons(fl_ctx, jl_ast_ctx(fl_ctx)->null_sym, fl_ctx->NIL);
     else
@@ -1183,6 +1182,7 @@ JL_DLLEXPORT jl_value_t *jl_expand_with_
     return expr;
 }
 
+// Lower an expression tree into Julia's intermediate-representation.
 JL_DLLEXPORT jl_value_t *jl_expand(jl_value_t *expr, jl_module_t *inmodule)
 {
     return jl_expand_with_loc(expr, inmodule, "none", 0);
diff -pruN 1.3.1+dfsg-1/src/ast.scm 1.4.0+dfsg-1/src/ast.scm
--- 1.3.1+dfsg-1/src/ast.scm	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/src/ast.scm	2020-03-21 16:36:32.000000000 +0000
@@ -49,8 +49,6 @@
 (define (deparse e (ilvl 0))
   (cond ((or (symbol? e) (number? e)) (string e))
         ((string? e) (print-to-string e))
-        ((eq? e #t) "true")
-        ((eq? e #f) "false")
         ((eq? (typeof e) 'julia_value)
          (let ((s (string e)))
            (if (string.find s "#<julia: ")
@@ -75,6 +73,9 @@
              (string (deparse (cadr e)) " " (car e) " " (deparse (caddr e)))))
         (else
          (case (car e)
+           ((null)  "nothing")
+           ((true)  "true")
+           ((false) "false")
            ;; calls and operators
            ((call)
             (cond ((and (eq? (cadr e) ':) (or (length= e 4) (length= e 5)))
@@ -86,7 +87,7 @@
                    (string #\( (deparse (caddr e)) " " (cadr e) " " (deparse (cadddr e)) #\) ))
                   (else
                    (deparse-prefix-call (cadr e) (cddr e) #\( #\)))))
-           (($ &)          (if (and (pair? (cadr e)) (not (eq? (caadr e) 'outerref)))
+           (($ &)          (if (and (pair? (cadr e)) (not (memq (caadr e) '(outerref null true false))))
                                (string (car e) "(" (deparse (cadr e)) ")")
                                (string (car e) (deparse (cadr e)))))
            ((|::|)         (if (length= e 2)
@@ -170,7 +171,7 @@
                     (indented-block (cdr (cadr e)) ilvl)
                     (if (and (pair? (cadddr e)) (eq? (car (cadddr e)) 'block))
                         (string (string.rep "    " ilvl) "catch"
-                                (if (eq? (caddr e) 'false)
+                                (if (equal? (caddr e) '(false))
                                     ""
                                     (string " " (caddr e)))
                                 "\n"
@@ -192,7 +193,7 @@
 				     (deparse-arglist args))
 			     (cdr body) ilvl)))
            ((struct)
-            (string (if (eq? (cadr e) 'true) "mutable " "")
+            (string (if (equal? (cadr e) '(true)) "mutable " "")
                     "struct "
                     (deparse-block (deparse (caddr e)) (cdr (cadddr e)) ilvl)))
            ((abstract)
@@ -200,7 +201,7 @@
            ((primitive)
             (string "primitive type " (deparse (cadr e)) " " (deparse (caddr e)) " end"))
            ((module)
-            (string (if (eq? (cadr e) 'true) "module " "baremodule ")
+            (string (if (equal? (cadr e) '(true)) "module " "baremodule ")
                     (caddr e) "\n"
                     (string.join (map deparse (cdr (cadddr e))) "\n") "\n"
                     "end"))
@@ -272,8 +273,13 @@
 
 ;; predicates and accessors
 
-(define (quoted? e) (memq (car e) '(quote top core globalref outerref line break inert meta)))
+(define (quoted? e)
+  (memq (car e) '(quote top core globalref outerref line break inert meta inbounds loopinfo)))
 (define (quotify e) `',e)
+(define (unquote e)
+  (if (and (pair? e) (memq (car e) '(quote inert)))
+      (cadr e)
+      e))
 
 (define (lam:args x) (cadr x))
 (define (lam:vars x) (llist-vars (lam:args x)))
@@ -285,7 +291,7 @@
   (error (string #\" (deparse v) #\" " is not a valid function argument name")))
 
 (define (valid-name? s)
-  (not (memq s '(true false ccall cglobal))))
+  (not (memq s '(ccall cglobal))))
 
 (define (arg-name v)
   (cond ((and (symbol? v) (valid-name? v))
@@ -347,17 +353,16 @@
   (and (pair? e) (eq? (car e) 'globalref)))
 
 (define (symbol-like? e)
-  (or (and (symbol? e) (not (eq? e 'true)) (not (eq? e 'false)))
-      (ssavalue? e)))
+  (or (symbol? e) (ssavalue? e)))
 
 (define (simple-atom? x)
-  (or (number? x) (string? x) (char? x) (eq? x 'true) (eq? x 'false)
-      (and (pair? x) (memq (car x) '(ssavalue null)))
+  (or (number? x) (string? x) (char? x)
+      (and (pair? x) (memq (car x) '(ssavalue null true false)))
       (eq? (typeof x) 'julia_value)))
 
 ;; identify some expressions that are safe to repeat
 (define (effect-free? e)
-  (or (not (pair? e)) (ssavalue? e) (sym-dot? e) (quoted? e) (equal? e '(null))))
+  (or (not (pair? e)) (ssavalue? e) (sym-dot? e) (quoted? e) (memq (car e) '(null true false))))
 
 ;; get the variable name part of a declaration, x::int => x
 (define (decl-var v)
diff -pruN 1.3.1+dfsg-1/src/builtin_proto.h 1.4.0+dfsg-1/src/builtin_proto.h
--- 1.3.1+dfsg-1/src/builtin_proto.h	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/src/builtin_proto.h	2020-03-21 16:36:32.000000000 +0000
@@ -23,7 +23,7 @@ DECLARE_BUILTIN(throw);      DECLARE_BUI
 DECLARE_BUILTIN(typeof);     DECLARE_BUILTIN(sizeof);
 DECLARE_BUILTIN(issubtype);  DECLARE_BUILTIN(isa);
 DECLARE_BUILTIN(_apply);     DECLARE_BUILTIN(_apply_pure);
-DECLARE_BUILTIN(_apply_latest);
+DECLARE_BUILTIN(_apply_latest); DECLARE_BUILTIN(_apply_iterate);
 DECLARE_BUILTIN(isdefined);  DECLARE_BUILTIN(nfields);
 DECLARE_BUILTIN(tuple);      DECLARE_BUILTIN(svec);
 DECLARE_BUILTIN(getfield);   DECLARE_BUILTIN(setfield);
diff -pruN 1.3.1+dfsg-1/src/builtins.c 1.4.0+dfsg-1/src/builtins.c
--- 1.3.1+dfsg-1/src/builtins.c	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/src/builtins.c	2020-03-21 16:36:32.000000000 +0000
@@ -81,8 +81,8 @@ static int NOINLINE compare_fields(jl_va
     size_t f, nf = jl_datatype_nfields(dt);
     for (f = 0; f < nf; f++) {
         size_t offs = jl_field_offset(dt, f);
-        char *ao = (char*)jl_data_ptr(a) + offs;
-        char *bo = (char*)jl_data_ptr(b) + offs;
+        char *ao = (char*)a + offs;
+        char *bo = (char*)b + offs;
         if (jl_field_isptr(dt, f)) {
             jl_value_t *af = *(jl_value_t**)ao;
             jl_value_t *bf = *(jl_value_t**)bo;
@@ -190,8 +190,8 @@ JL_DLLEXPORT int jl_egal(jl_value_t *a J
     if (sz == 0)
         return 1;
     size_t nf = jl_datatype_nfields(dt);
-    if (nf == 0)
-        return bits_equal(jl_data_ptr(a), jl_data_ptr(b), sz);
+    if (nf == 0 || !dt->layout->haspadding)
+        return bits_equal(a, b, sz);
     if (dt == jl_unionall_type)
         return egal_types(a, b, NULL);
     return compare_fields(a, b, dt);
@@ -277,6 +277,44 @@ static uintptr_t type_object_id_(jl_valu
     return jl_object_id_((jl_value_t*)tv, v);
 }
 
+static uintptr_t immut_id_(jl_datatype_t *dt, jl_value_t *v, uintptr_t h) JL_NOTSAFEPOINT
+{
+    size_t sz = jl_datatype_size(dt);
+    if (sz == 0)
+        return ~h;
+    size_t f, nf = jl_datatype_nfields(dt);
+    if (nf == 0 || (!dt->layout->haspadding && dt->layout->npointers == 0)) {
+        // operate element-wise if there are unused bits inside,
+        // otherwise just take the whole data block at once
+        // a few select pointers (notably symbol) also have special hash values
+        // which may affect the stability of the objectid hash, even though
+        // they don't affect egal comparison
+        return bits_hash(v, sz) ^ h;
+    }
+    if (dt == jl_unionall_type)
+        return type_object_id_(v, NULL);
+    for (f = 0; f < nf; f++) {
+        size_t offs = jl_field_offset(dt, f);
+        char *vo = (char*)v + offs;
+        uintptr_t u;
+        if (jl_field_isptr(dt, f)) {
+            jl_value_t *f = *(jl_value_t**)vo;
+            u = (f == NULL) ? 0 : jl_object_id(f);
+        }
+        else {
+            jl_datatype_t *fieldtype = (jl_datatype_t*)jl_field_type_concrete(dt, f);
+            if (jl_is_uniontype(fieldtype)) {
+                uint8_t sel = ((uint8_t*)vo)[jl_field_size(dt, f) - 1];
+                fieldtype = (jl_datatype_t*)jl_nth_union_component((jl_value_t*)fieldtype, sel);
+            }
+            assert(jl_is_datatype(fieldtype) && !fieldtype->abstract && !fieldtype->mutabl);
+            u = immut_id_(fieldtype, (jl_value_t*)vo, 0);
+        }
+        h = bitmix(h, u);
+    }
+    return h;
+}
+
 JL_DLLEXPORT uintptr_t jl_object_id_(jl_value_t *tv, jl_value_t *v) JL_NOTSAFEPOINT
 {
     if (tv == (jl_value_t*)jl_symbol_type)
@@ -303,38 +341,7 @@ JL_DLLEXPORT uintptr_t jl_object_id_(jl_
     }
     if (dt->mutabl)
         return inthash((uintptr_t)v);
-    size_t sz = jl_datatype_size(tv);
-    uintptr_t h = jl_object_id(tv);
-    if (sz == 0)
-        return ~h;
-    size_t f, nf = jl_datatype_nfields(dt);
-    if (nf == 0)
-        return bits_hash(jl_data_ptr(v), sz) ^ h;
-    if (dt == jl_unionall_type)
-        return type_object_id_(v, NULL);
-    for (f = 0; f < nf; f++) {
-        size_t offs = jl_field_offset(dt, f);
-        char *vo = (char*)jl_data_ptr(v) + offs;
-        uintptr_t u;
-        if (jl_field_isptr(dt, f)) {
-            jl_value_t *f = *(jl_value_t**)vo;
-            u = (f == NULL) ? 0 : jl_object_id(f);
-        }
-        else {
-            jl_datatype_t *fieldtype = (jl_datatype_t*)jl_field_type_concrete(dt, f);
-            if (jl_is_uniontype(fieldtype)) {
-                uint8_t sel = ((uint8_t*)vo)[jl_field_size(dt, f) - 1];
-                fieldtype = (jl_datatype_t*)jl_nth_union_component((jl_value_t*)fieldtype, sel);
-            }
-            assert(jl_is_datatype(fieldtype) && !fieldtype->abstract && !fieldtype->mutabl);
-            if (fieldtype->layout->haspadding)
-                u = jl_object_id_((jl_value_t*)fieldtype, (jl_value_t*)vo);
-            else
-                u = bits_hash(vo, fieldtype->size);
-        }
-        h = bitmix(h, u);
-    }
-    return h;
+    return immut_id_(dt, v, jl_object_id(tv));
 }
 
 JL_DLLEXPORT uintptr_t jl_object_id(jl_value_t *v) JL_NOTSAFEPOINT
@@ -474,9 +481,8 @@ void STATIC_INLINE _grow_to(jl_value_t *
 
 static jl_function_t *jl_iterate_func JL_GLOBALLY_ROOTED;
 
-JL_CALLABLE(jl_f__apply)
+static jl_value_t *do_apply(jl_value_t *F, jl_value_t **args, uint32_t nargs, jl_value_t *iterate)
 {
-    JL_NARGSV(apply, 1);
     jl_function_t *f = args[0];
     if (nargs == 2) {
         // some common simple cases
@@ -516,10 +522,13 @@ JL_CALLABLE(jl_f__apply)
             extra += 1;
         }
     }
-    if (extra && jl_iterate_func == NULL) {
-        jl_iterate_func = jl_get_function(jl_top_module, "iterate");
-        if (jl_iterate_func == NULL)
-            jl_undefined_var_error(jl_symbol("iterate"));
+    if (extra && iterate == NULL) {
+        if (jl_iterate_func == NULL) {
+            jl_iterate_func = jl_get_function(jl_top_module, "iterate");
+            if (jl_iterate_func == NULL)
+                jl_undefined_var_error(jl_symbol("iterate"));
+        }
+        iterate = jl_iterate_func;
     }
     // allocate space for the argument array and gc roots for it
     // based on our previous estimates
@@ -531,7 +540,7 @@ JL_CALLABLE(jl_f__apply)
     size_t n_alloc;
     jl_value_t **roots;
     JL_GC_PUSHARGS(roots, stackalloc + (extra ? 2 : 0));
-    jl_value_t **newargs = NULL;
+    jl_value_t **newargs;
     jl_svec_t *arg_heap = NULL;
     if (onstack) {
         newargs = roots;
@@ -539,7 +548,9 @@ JL_CALLABLE(jl_f__apply)
     }
     else {
         // put arguments on the heap if there are too many
+        newargs = NULL;
         n_alloc = 0;
+        assert(precount > 0); // let optimizer know this won't overflow
         _grow_to(&roots[0], &newargs, &arg_heap, &n_alloc, precount, extra);
     }
     newargs[0] = f;
@@ -552,6 +563,7 @@ JL_CALLABLE(jl_f__apply)
             size_t j, al = jl_svec_len(t);
             precount = (precount > al) ? precount - al : 0;
             _grow_to(&roots[0], &newargs, &arg_heap, &n_alloc, n + precount + al, extra);
+            assert(newargs != NULL); // inform GCChecker that we didn't write a NULL here
             for (j = 0; j < al; j++) {
                 newargs[n++] = jl_svecref(t, j);
                 // GC Note: here we assume that the return value of `jl_svecref`
@@ -564,6 +576,7 @@ JL_CALLABLE(jl_f__apply)
             size_t j, al = jl_nfields(ai);
             precount = (precount > al) ? precount - al : 0;
             _grow_to(&roots[0], &newargs, &arg_heap, &n_alloc, n + precount + al, extra);
+            assert(newargs != NULL); // inform GCChecker that we didn't write a NULL here
             for (j = 0; j < al; j++) {
                 // jl_fieldref may allocate.
                 newargs[n++] = jl_fieldref(ai, j);
@@ -576,6 +589,7 @@ JL_CALLABLE(jl_f__apply)
             size_t j, al = jl_array_len(aai);
             precount = (precount > al) ? precount - al : 0;
             _grow_to(&roots[0], &newargs, &arg_heap, &n_alloc, n + precount + al, extra);
+            assert(newargs != NULL); // inform GCChecker that we didn't write a NULL here
             if (aai->flags.ptrarray) {
                 for (j = 0; j < al; j++) {
                     jl_value_t *arg = jl_array_ptr_ref(aai, j);
@@ -599,12 +613,12 @@ JL_CALLABLE(jl_f__apply)
             assert(extra > 0);
             jl_value_t *args[2];
             args[0] = ai;
-            jl_value_t *next = jl_apply_generic(jl_iterate_func, args, 1);
+            jl_value_t *next = jl_apply_generic(iterate, args, 1);
             while (next != jl_nothing) {
                 roots[stackalloc] = next;
-                jl_value_t *value = jl_fieldref(next, 0);
+                jl_value_t *value = jl_get_nth_field_checked(next, 0);
                 roots[stackalloc + 1] = value;
-                jl_value_t *state = jl_fieldref(next, 1);
+                jl_value_t *state = jl_get_nth_field_checked(next, 1);
                 roots[stackalloc] = state;
                 _grow_to(&roots[0], &newargs, &arg_heap, &n_alloc, n + precount + 1, extra);
                 JL_GC_ASSERT_LIVE(value);
@@ -614,7 +628,7 @@ JL_CALLABLE(jl_f__apply)
                 roots[stackalloc + 1] = NULL;
                 JL_GC_ASSERT_LIVE(state);
                 args[1] = state;
-                next = jl_apply_generic(jl_iterate_func, args, 2);
+                next = jl_apply_generic(iterate, args, 2);
             }
             roots[stackalloc] = NULL;
             extra -= 1;
@@ -622,13 +636,27 @@ JL_CALLABLE(jl_f__apply)
     }
     if (arg_heap) {
         // optimization: keep only the first root, free the others
-        ((void**)roots)[-2] = (void*)(((size_t)1) << 1);
+#ifndef __clang_analyzer__
+        ((void**)roots)[-2] = (void*)JL_GC_ENCODE_PUSHARGS(1);
+#endif
     }
     jl_value_t *result = jl_apply(newargs, n);
     JL_GC_POP();
     return result;
 }
 
+JL_CALLABLE(jl_f__apply_iterate)
+{
+    JL_NARGSV(_apply_iterate, 2);
+    return do_apply(F, args+1, nargs-1, args[0]);
+}
+
+JL_CALLABLE(jl_f__apply)
+{
+    JL_NARGSV(_apply, 1);
+    return do_apply(F, args, nargs, NULL);
+}
+
 // this is like `_apply`, but with quasi-exact checks to make sure it is pure
 JL_CALLABLE(jl_f__apply_pure)
 {
@@ -689,15 +717,22 @@ JL_CALLABLE(jl_f_tuple)
         tt = jl_inst_concrete_tupletype(types);
         JL_GC_POP();
     }
-    return jl_new_structv(tt, args, nargs);
+    if (tt->instance != NULL)
+        return tt->instance;
+    jl_ptls_t ptls = jl_get_ptls_states();
+    jl_value_t *jv = jl_gc_alloc(ptls, jl_datatype_size(tt), tt);
+    for (i = 0; i < nargs; i++)
+        set_nth_field(tt, (void*)jv, i, args[i]);
+    return jv;
 }
 
 JL_CALLABLE(jl_f_svec)
 {
     size_t i;
-    if (nargs == 0) return (jl_value_t*)jl_emptysvec;
+    if (nargs == 0)
+        return (jl_value_t*)jl_emptysvec;
     jl_svec_t *t = jl_alloc_svec_uninit(nargs);
-    for(i=0; i < nargs; i++) {
+    for (i = 0; i < nargs; i++) {
         jl_svecset(t, i, args[i]);
     }
     return (jl_value_t*)t;
@@ -732,10 +767,7 @@ JL_CALLABLE(jl_f_getfield)
         jl_sym_t *fld = (jl_sym_t*)args[1];
         idx = jl_field_index(st, fld, 1);
     }
-    jl_value_t *fval = jl_get_nth_field(v, idx);
-    if (fval == NULL)
-        jl_throw(jl_undefref_exception);
-    return fval;
+    return jl_get_nth_field_checked(v, idx);
 }
 
 JL_CALLABLE(jl_f_setfield)
@@ -760,11 +792,11 @@ JL_CALLABLE(jl_f_setfield)
         JL_TYPECHK(setfield!, symbol, args[1]);
         idx = jl_field_index(st, (jl_sym_t*)args[1], 1);
     }
-    jl_value_t *ft = jl_field_type(st,idx);
+    jl_value_t *ft = jl_field_type(st, idx);
     if (!jl_isa(args[2], ft)) {
         jl_type_error("setfield!", ft, args[2]);
     }
-    jl_set_nth_field(v, idx, args[2]);
+    set_nth_field(st, (void*)v, idx, args[2]);
     return args[2];
 }
 
@@ -1293,7 +1325,7 @@ void jl_init_primitives(void) JL_GC_DISA
     jl_builtin_applicable = add_builtin_func("applicable", jl_f_applicable);
     jl_builtin_invoke = add_builtin_func("invoke", jl_f_invoke);
     jl_typename_t *itn = ((jl_datatype_t*)jl_typeof(jl_builtin_invoke))->name;
-    jl_value_t *ikws = jl_new_generic_function_with_supertype(itn->name, jl_core_module, jl_builtin_type, 1);
+    jl_value_t *ikws = jl_new_generic_function_with_supertype(itn->name, jl_core_module, jl_builtin_type);
     itn->mt->kwsorter = ikws;
     jl_gc_wb(itn->mt, ikws);
     jl_mk_builtin_func((jl_datatype_t*)jl_typeof(ikws), jl_symbol_name(jl_gf_name(ikws)), jl_f_invoke_kwsorter);
@@ -1301,6 +1333,7 @@ void jl_init_primitives(void) JL_GC_DISA
     // internal functions
     jl_builtin_apply_type = add_builtin_func("apply_type", jl_f_apply_type);
     jl_builtin__apply = add_builtin_func("_apply", jl_f__apply);
+    jl_builtin__apply_iterate = add_builtin_func("_apply_iterate", jl_f__apply_iterate);
     jl_builtin__expr = add_builtin_func("_expr", jl_f__expr);
     jl_builtin_svec = add_builtin_func("svec", jl_f_svec);
     add_builtin_func("_apply_pure", jl_f__apply_pure);
diff -pruN 1.3.1+dfsg-1/src/ccall.cpp 1.4.0+dfsg-1/src/ccall.cpp
--- 1.3.1+dfsg-1/src/ccall.cpp	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/src/ccall.cpp	2020-03-21 16:36:32.000000000 +0000
@@ -1,6 +1,7 @@
 // This file is a part of Julia. License is MIT: https://julialang.org/license
 
 // --- the ccall, cglobal, and llvm intrinsics ---
+#include "llvm/Support/Path.h" // for llvm::sys::path
 
 // Map from symbol name (in a certain library) to its GV in sysimg and the
 // DL handle address in the current session.
@@ -68,7 +69,8 @@ static bool runtime_sym_gvs(const char *
     }
     else {
         std::string name = "ccalllib_";
-        name += f_lib;
+        name += llvm::sys::path::filename(f_lib);
+        name += std::to_string(globalUnique++);
         runtime_lib = true;
         auto &libgv = libMapGV[f_lib];
         if (libgv.first == NULL) {
@@ -418,6 +420,7 @@ static Value *llvm_type_rewrite(
         from = emit_static_alloca(ctx, from_type);
         to = emit_bitcast(ctx, from, target_type->getPointerTo());
     }
+    // XXX: deal with possible alignment issues
     ctx.builder.CreateStore(v, from);
     return ctx.builder.CreateLoad(to);
 }
@@ -514,7 +517,7 @@ static Value *julia_to_native(
         tbaa_decorate(jvinfo.tbaa, ctx.builder.CreateStore(emit_unbox(ctx, to, jvinfo, jlto), slot));
     }
     else {
-        emit_memcpy(ctx, slot, jvinfo.tbaa, jvinfo, jl_datatype_size(jlto), jl_datatype_align(jlto));
+        emit_memcpy(ctx, slot, jvinfo.tbaa, jvinfo, jl_datatype_size(jlto), julia_alignment(jlto));
     }
     return slot;
 }
@@ -643,7 +646,8 @@ static jl_cgval_t emit_cglobal(jl_codect
     else {
         rt = (jl_value_t*)jl_voidpointer_type;
     }
-    Type *lrt = julia_type_to_llvm(rt);
+    Type *lrt = T_size;
+    assert(lrt == julia_type_to_llvm(rt));
 
     interpret_symbol_arg(ctx, sym, args[1], "cglobal", false);
 
@@ -662,22 +666,18 @@ static jl_cgval_t emit_cglobal(jl_codect
         }
         else {
             void *symaddr;
-            if (!jl_dlsym(jl_get_library(sym.f_lib), sym.f_name, &symaddr, 0)) {
-                std::stringstream msg;
-                msg << "cglobal: could not find symbol ";
-                msg << sym.f_name;
-                if (sym.f_lib != NULL) {
-#ifdef _OS_WINDOWS_
-                    assert(sym.f_lib != JL_EXE_LIBNAME && sym.f_lib != JL_DL_LIBNAME);
-#endif
-                    msg << " in library ";
-                    msg << sym.f_lib;
-                }
-                emit_error(ctx, msg.str());
+
+            void* libsym = jl_get_library_(sym.f_lib, 0);
+            if (!libsym || !jl_dlsym(libsym, sym.f_name, &symaddr, 0)) {
+                // Error mode, either the library or the symbol couldn't be find during compiletime.
+                // Fallback to a runtime symbol lookup.
+                res = runtime_sym_lookup(ctx, cast<PointerType>(T_pint8), sym.f_lib, sym.f_name, ctx.f);
+                res = ctx.builder.CreatePtrToInt(res, lrt);
+            } else {
+                // since we aren't saving this code, there's no sense in
+                // putting anything complicated here: just JIT the address of the cglobal
+                res = ConstantInt::get(lrt, (uint64_t)symaddr);
             }
-            // since we aren't saving this code, there's no sense in
-            // putting anything complicated here: just JIT the address of the cglobal
-            res = ConstantInt::get(lrt, (uint64_t)symaddr);
         }
     }
 
@@ -888,10 +888,7 @@ static jl_cgval_t emit_llvmcall(jl_codec
         jl_value_t *tti = jl_svecref(tt,i);
         bool toboxed;
         Type *t = julia_type_to_llvm(tti, &toboxed);
-        if (toboxed)
-            argtypes.push_back(T_prjlvalue);
-        else
-            argtypes.push_back(t);
+        argtypes.push_back(t);
         if (4 + i > nargs) {
             jl_error("Missing arguments to llvmcall!");
         }
@@ -906,8 +903,6 @@ static jl_cgval_t emit_llvmcall(jl_codec
     Function *f;
     bool retboxed;
     Type *rettype = julia_type_to_llvm(rtt, &retboxed);
-    if (retboxed)
-        rettype = T_prjlvalue;
     if (isString) {
         // Make sure to find a unique name
         std::string ir_name;
@@ -1164,9 +1159,7 @@ std::string generate_func_sig(const char
                 }
             }
 
-            t = julia_struct_to_llvm(tti, unionall_env, &isboxed);
-            if (isboxed)
-                t = T_prjlvalue;
+            t = julia_struct_to_llvm(tti, unionall_env, &isboxed, llvmcall);
             if (t == NULL || t == T_void) {
                 return make_errmsg(fname, i + 1, " doesn't correspond to a C type");
             }
@@ -1297,7 +1290,7 @@ static bool verify_ref_type(jl_codectx_t
 
 static const std::string verify_ccall_sig(jl_value_t *&rt, jl_value_t *at,
                                           jl_unionall_t *unionall_env, jl_svec_t *sparam_vals,
-                                          Type *&lrt, bool &retboxed, bool &static_rt)
+                                          Type *&lrt, bool &retboxed, bool &static_rt, bool llvmcall=false)
 {
     JL_TYPECHK(ccall, type, rt);
     JL_TYPECHK(ccall, simplevector, at);
@@ -1307,11 +1300,9 @@ static const std::string verify_ccall_si
         rt = (jl_value_t*)jl_any_type;
     }
 
-    lrt = julia_struct_to_llvm(rt, unionall_env, &retboxed);
+    lrt = julia_struct_to_llvm(rt, unionall_env, &retboxed, llvmcall);
     if (lrt == NULL)
         return "return type doesn't correspond to a C type";
-    else if (retboxed)
-        lrt = T_prjlvalue;
 
     // is return type fully statically known?
     if (unionall_env == NULL) {
@@ -1404,9 +1395,9 @@ static jl_cgval_t emit_ccall(jl_codectx_
         if (jl_is_long(argi_root))
             continue;
         jl_cgval_t arg_root = emit_expr(ctx, argi_root);
-        if (arg_root.Vboxed || arg_root.V) {
-            gc_uses.push_back(arg_root.Vboxed ? arg_root.Vboxed : arg_root.V);
-        }
+        Value *gc_root = get_gc_root_for(arg_root);
+        if (gc_root)
+            gc_uses.push_back(gc_root);
     }
 
     jl_unionall_t *unionall = (jl_is_method(ctx.linfo->def.method) && jl_is_unionall(ctx.linfo->def.method->sig))
@@ -1430,7 +1421,9 @@ static jl_cgval_t emit_ccall(jl_codectx_
       rt, at, unionall,
       ctx.spvals_ptr == NULL ? ctx.linfo->sparam_vals : NULL,
       /* outputs: */
-      lrt, retboxed, static_rt);
+      lrt, retboxed, static_rt,
+      /* optional arguments */
+      llvmcall);
     if (err.empty()) {
         // some extra checks for ccall
         if (!retboxed && static_rt) {
@@ -1487,7 +1480,7 @@ static jl_cgval_t emit_ccall(jl_codectx_
             isboxed = false;
         }
         else {
-            largty = julia_struct_to_llvm(tti, unionall, &isboxed);
+            largty = julia_struct_to_llvm(tti, unionall, &isboxed, llvmcall);
         }
         if (isboxed) {
             ary = boxed(ctx, argv[0]);
@@ -1499,8 +1492,9 @@ static jl_cgval_t emit_ccall(jl_codectx_
         if (!retboxed) {
             return mark_or_box_ccall_result(
                     ctx,
-                    emit_pointer_from_objref(ctx,
-                        emit_bitcast(ctx, ary, T_prjlvalue)),
+                    ctx.builder.CreatePtrToInt(
+                        emit_pointer_from_objref(ctx, emit_bitcast(ctx, ary, T_prjlvalue)),
+                        T_size),
                     retboxed, rt, unionall, static_rt);
         }
         else {
@@ -1508,7 +1502,7 @@ static jl_cgval_t emit_ccall(jl_codectx_
                     ctx,
                     ctx.builder.CreateAddrSpaceCast(
                         ctx.builder.CreateIntToPtr(ary, T_pjlvalue),
-                        T_prjlvalue), // TODO: this addrspace cast is invalid (implies that the value is rooted elsewhere)
+                        T_prjlvalue), // WARNING: this addrspace cast necessarily implies that the value is rooted elsewhere!
                     retboxed, rt, unionall, static_rt);
         }
     }
@@ -1631,7 +1625,8 @@ static jl_cgval_t emit_ccall(jl_codectx_
         jl_datatype_t *arydt = (jl_datatype_t*)jl_unwrap_unionall(aryv.typ);
         if (jl_is_array_type(arydt)) {
             jl_value_t *ety = jl_tparam0(arydt);
-            if (jl_array_store_unboxed(ety)) {
+            bool ptrarray = !jl_stored_inline(ety);
+            if (!ptrarray && !jl_type_hasptr(ety)) {
                 JL_GC_POP();
                 return mark_or_box_ccall_result(ctx, ConstantInt::get(T_int32, 1),
                                                 false, rt, unionall, static_rt);
@@ -1639,6 +1634,14 @@ static jl_cgval_t emit_ccall(jl_codectx_
             else if (!jl_has_free_typevars(ety)) {
                 Value *idx = emit_unbox(ctx, T_size, idxv, (jl_value_t*)jl_ulong_type);
                 Value *arrayptr = emit_bitcast(ctx, emit_arrayptr(ctx, aryv, aryex), T_pprjlvalue);
+                if (!ptrarray) {
+                    size_t elsz = jl_datatype_size(ety);
+                    unsigned align = jl_datatype_align(ety);
+                    size_t stride = LLT_ALIGN(elsz, align) / sizeof(jl_value_t*);
+                    if (stride != 1)
+                        idx = ctx.builder.CreateMul(idx, ConstantInt::get(T_size, stride));
+                    idx = ctx.builder.CreateAdd(idx, ConstantInt::get(T_size, ((jl_datatype_t*)ety)->layout->first_ptr));
+                }
                 Value *slot_addr = ctx.builder.CreateInBoundsGEP(T_prjlvalue, arrayptr, idx);
                 Value *load = tbaa_decorate(tbaa_ptrarraybuf, ctx.builder.CreateLoad(T_prjlvalue, slot_addr));
                 Value *res = ctx.builder.CreateZExt(ctx.builder.CreateICmpNE(load, Constant::getNullValue(T_prjlvalue)), T_int32);
@@ -1650,7 +1653,7 @@ static jl_cgval_t emit_ccall(jl_codectx_
     else if (is_libjulia_func(jl_string_ptr)) {
         assert(lrt == T_size);
         assert(!isVa && !llvmcall && nccallargs == 1);
-        Value *obj = emit_pointer_from_objref(ctx, boxed(ctx, argv[0]));
+        Value *obj = ctx.builder.CreatePtrToInt(emit_pointer_from_objref(ctx, boxed(ctx, argv[0])), T_size);
         Value *strp = ctx.builder.CreateAdd(obj, ConstantInt::get(T_size, sizeof(void*)));
         JL_GC_POP();
         return mark_or_box_ccall_result(ctx, strp, retboxed, rt, unionall, static_rt);
@@ -1666,7 +1669,8 @@ static jl_cgval_t emit_ccall(jl_codectx_
                 ctx.builder.CreateIntToPtr(destp, T_pint8),
                 1,
                 ctx.builder.CreateIntToPtr(
-                    emit_unbox(ctx, T_size, src, (jl_value_t*)jl_voidpointer_type), T_pint8),
+                    emit_unbox(ctx, T_size, src, (jl_value_t*)jl_voidpointer_type),
+                    T_pint8),
                 0,
                 emit_unbox(ctx, T_size, n, (jl_value_t*)jl_ulong_type),
                 false);
@@ -1788,18 +1792,20 @@ jl_cgval_t function_sig_t::emit_a_ccall(
     bool sretboxed = false;
     if (sret) {
         assert(!retboxed && jl_is_datatype(rt) && "sret return type invalid");
-        if (jl_justbits(rt)) {
+        if (jl_is_pointerfree(rt)) {
             result = emit_static_alloca(ctx, lrt);
             argvals[0] = ctx.builder.CreateBitCast(result, fargt_sig.at(0));
         }
         else {
             // XXX: result needs to be zero'd and given a GC root here
+            // and has incorrect write barriers.
+            // instead this code path should behave like `unsafe_load`
             assert(jl_datatype_size(rt) > 0 && "sret shouldn't be a singleton instance");
             result = emit_allocobj(ctx, jl_datatype_size(rt),
                                    literal_pointer_val(ctx, (jl_value_t*)rt));
             sretboxed = true;
             gc_uses.push_back(result);
-            argvals[0] = ctx.builder.CreateIntToPtr(emit_pointer_from_objref(ctx, result), fargt_sig.at(0));
+            argvals[0] = ctx.builder.CreateBitCast(emit_pointer_from_objref(ctx, result), fargt_sig.at(0));
         }
     }
 
@@ -1872,23 +1878,17 @@ jl_cgval_t function_sig_t::emit_a_ccall(
         }
         else {
             void *symaddr;
-            if (!jl_dlsym(jl_get_library(symarg.f_lib), symarg.f_name, &symaddr, 0)) {
-                std::stringstream msg;
-                msg << "ccall: could not find function ";
-                msg << symarg.f_name;
-                if (symarg.f_lib != NULL) {
-#ifdef _OS_WINDOWS_
-                    assert(symarg.f_lib != JL_EXE_LIBNAME && symarg.f_lib != JL_DL_LIBNAME);
-#endif
-                    msg << " in library ";
-                    msg << symarg.f_lib;
-                }
-                emit_error(ctx, msg.str());
-                return jl_cgval_t();
+
+            void* libsym = jl_get_library_(symarg.f_lib, 0);
+            if (!libsym || !jl_dlsym(libsym, symarg.f_name, &symaddr, 0)) {
+                // either the library or the symbol could not be found, place a runtime
+                // lookup here instead.
+                llvmf = runtime_sym_lookup(ctx, funcptype, symarg.f_lib, symarg.f_name, ctx.f);
+            } else {
+                // since we aren't saving this code, there's no sense in
+                // putting anything complicated here: just JIT the function address
+                llvmf = literal_static_pointer_val(ctx, symaddr, funcptype);
             }
-            // since we aren't saving this code, there's no sense in
-            // putting anything complicated here: just JIT the function address
-            llvmf = literal_static_pointer_val(ctx, symaddr, funcptype);
         }
     }
 
@@ -1936,9 +1936,6 @@ jl_cgval_t function_sig_t::emit_a_ccall(
     }
     else {
         Type *jlrt = julia_type_to_llvm(rt, &jlretboxed); // compute the real "julian" return type and compute whether it is boxed
-        if (jlretboxed) {
-            jlrt = T_prjlvalue;
-        }
         if (type_is_ghost(jlrt)) {
             return ghostValue(rt);
         }
@@ -1953,7 +1950,7 @@ jl_cgval_t function_sig_t::emit_a_ccall(
                 assert(rtsz > 0);
                 Value *strct = emit_allocobj(ctx, rtsz, runtime_bt);
                 MDNode *tbaa = jl_is_mutable(rt) ? tbaa_mutab : tbaa_immut;
-                int boxalign = jl_datatype_align(rt);
+                int boxalign = julia_alignment(rt);
                 // copy the data from the return value to the new struct
                 const DataLayout &DL = jl_data_layout;
                 auto resultTy = result->getType();
@@ -1961,7 +1958,7 @@ jl_cgval_t function_sig_t::emit_a_ccall(
                     // ARM and AArch64 can use a LLVM type larger than the julia type.
                     // When this happens, cast through memory.
                     auto slot = emit_static_alloca(ctx, resultTy);
-                    slot->setAlignment(boxalign);
+                    slot->setAlignment(Align(boxalign));
                     ctx.builder.CreateAlignedStore(result, slot, boxalign);
                     emit_memcpy(ctx, strct, tbaa, slot, tbaa, rtsz, boxalign, tbaa);
                 }
diff -pruN 1.3.1+dfsg-1/src/ccalltest.c 1.4.0+dfsg-1/src/ccalltest.c
--- 1.3.1+dfsg-1/src/ccalltest.c	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/src/ccalltest.c	2020-03-21 16:36:32.000000000 +0000
@@ -91,7 +91,7 @@ JL_DLLEXPORT complex_t *cptest(complex_t
 
 JL_DLLEXPORT complex_t *cptest_static(complex_t *a) {
     if (verbose) fprintf(stderr,"%" PRIjint " + %" PRIjint " i\n", a->real, a->imag);
-    complex_t *b = (complex_t*)malloc(sizeof(complex_t));
+    complex_t *b = (complex_t*)malloc_s(sizeof(complex_t));
     b->real = a->real;
     b->imag = a->imag;
     return b;
diff -pruN 1.3.1+dfsg-1/src/cgutils.cpp 1.4.0+dfsg-1/src/cgutils.cpp
--- 1.3.1+dfsg-1/src/cgutils.cpp	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/src/cgutils.cpp	2020-03-21 16:36:32.000000000 +0000
@@ -253,24 +253,34 @@ static DIType *julia_type_to_di(jl_value
     return (llvm::DIType*)jdt->ditype;
 }
 
-static Value *emit_pointer_from_objref_internal(jl_codectx_t &ctx, Value *V)
+static Value *emit_pointer_from_objref(jl_codectx_t &ctx, Value *V)
 {
+    unsigned AS = cast<PointerType>(V->getType())->getAddressSpace();
+    if (AS != AddressSpace::Tracked && AS != AddressSpace::Derived)
+        return V;
+    V = decay_derived(V);
+    Type *T = PointerType::get(T_jlvalue, AddressSpace::Derived);
+    if (V->getType() != T)
+        V = ctx.builder.CreateBitCast(V, T);
     CallInst *Call = ctx.builder.CreateCall(prepare_call(pointer_from_objref_func), V);
-    Call->addAttribute(AttributeList::FunctionIndex, Attribute::ReadNone);
+    Call->setAttributes(pointer_from_objref_func->getAttributes());
     return Call;
 }
 
-static Value *emit_pointer_from_objref(jl_codectx_t &ctx, Value *V)
+static Value *get_gc_root_for(const jl_cgval_t &x)
 {
-    unsigned AS = cast<PointerType>(V->getType())->getAddressSpace();
-    if (AS != AddressSpace::Tracked && AS != AddressSpace::Derived)
-        return ctx.builder.CreatePtrToInt(V, T_size);
-    V = ctx.builder.CreateBitCast(decay_derived(V),
-            PointerType::get(T_jlvalue, AddressSpace::Derived));
-
-    return ctx.builder.CreatePtrToInt(
-        emit_pointer_from_objref_internal(ctx, V),
-        T_size);
+    if (x.Vboxed)
+        return x.Vboxed;
+    if (x.ispointer() && !x.constant) {
+        assert(x.V);
+        if (PointerType *T = dyn_cast<PointerType>(x.V->getType())) {
+            if (T->getAddressSpace() == AddressSpace::Tracked ||
+                T->getAddressSpace() == AddressSpace::Derived) {
+                return x.V;
+            }
+        }
+    }
+    return nullptr;
 }
 
 // --- emitting pointers directly into code ---
@@ -386,8 +396,8 @@ static unsigned julia_alignment(jl_value
     }
     assert(jl_is_datatype(jt) && ((jl_datatype_t*)jt)->layout);
     unsigned alignment = jl_datatype_align(jt);
-    assert(alignment <= JL_HEAP_ALIGNMENT);
-    assert(JL_HEAP_ALIGNMENT % alignment == 0);
+    if (alignment > JL_HEAP_ALIGNMENT)
+        return JL_HEAP_ALIGNMENT;
     return alignment;
 }
 
@@ -504,13 +514,15 @@ static Value *julia_binding_gv(jl_codect
 
 // --- mapping between julia and llvm types ---
 
-static Type *julia_struct_to_llvm(jl_value_t *jt, jl_unionall_t *ua_env, bool *isboxed);
+static Type *julia_struct_to_llvm(jl_value_t *jt, jl_unionall_t *ua_env, bool *isboxed, bool llvmcall=false);
 
 static unsigned convert_struct_offset(Type *lty, unsigned byte_offset)
 {
     const DataLayout &DL = jl_data_layout;
     const StructLayout *SL = DL.getStructLayout(cast<StructType>(lty));
-    return SL->getElementContainingOffset(byte_offset);
+    unsigned idx = SL->getElementContainingOffset(byte_offset);
+    assert(SL->getElementOffset(idx) == byte_offset);
+    return idx;
 }
 
 static unsigned convert_struct_offset(jl_codectx_t &ctx, Type *lty, unsigned byte_offset)
@@ -531,7 +543,7 @@ JL_DLLEXPORT Type *julia_type_to_llvm(jl
     if (isboxed) *isboxed = false;
     if (jt == (jl_value_t*)jl_bottom_type)
         return T_void;
-    if (jl_justbits(jt)) {
+    if (jl_is_concrete_immutable(jt)) {
         if (jl_datatype_nbits(jt) == 0)
             return T_void;
         Type *t = julia_struct_to_llvm(jt, NULL, isboxed);
@@ -539,12 +551,12 @@ JL_DLLEXPORT Type *julia_type_to_llvm(jl
         return t;
     }
     if (isboxed) *isboxed = true;
-    return T_pjlvalue;
+    return T_prjlvalue;
 }
 }
 
 // converts a julia bitstype into the equivalent LLVM bitstype
-static Type *bitstype_to_llvm(jl_value_t *bt)
+static Type *bitstype_to_llvm(jl_value_t *bt, bool llvmcall = false)
 {
     assert(jl_is_primitivetype(bt));
     if (bt == (jl_value_t*)jl_bool_type)
@@ -553,6 +565,8 @@ static Type *bitstype_to_llvm(jl_value_t
         return T_int32;
     if (bt == (jl_value_t*)jl_int64_type)
         return T_int64;
+    if (llvmcall && (bt == (jl_value_t*)jl_float16_type))
+        return T_float16;
     if (bt == (jl_value_t*)jl_float32_type)
         return T_float32;
     if (bt == (jl_value_t*)jl_float64_type)
@@ -561,12 +575,17 @@ static Type *bitstype_to_llvm(jl_value_t
     return Type::getIntNTy(jl_LLVMContext, nb * 8);
 }
 
+static bool jl_type_hasptr(jl_value_t* typ)
+{ // assumes that jl_stored_inline(typ) is true
+    return jl_is_datatype(typ) && ((jl_datatype_t*)typ)->layout->npointers > 0;
+}
+
 // compute whether all concrete subtypes of this type have the same layout
 // (which is conservatively approximated here by asking whether the types of any of the
 // fields depend on any of the parameters of the containing type)
 static bool julia_struct_has_layout(jl_datatype_t *dt, jl_unionall_t *ua)
 {
-    if (dt->layout || dt->struct_decl || jl_justbits((jl_value_t*)dt))
+    if (dt->layout || dt->struct_decl)
         return true;
     if (ua) {
         jl_svec_t *types = jl_get_fieldtypes(dt);
@@ -585,10 +604,10 @@ static unsigned jl_field_align(jl_dataty
     unsigned al = jl_field_offset(dt, i);
     al |= 16;
     al &= -al;
-    return std::min(al, jl_datatype_align(dt));
+    return std::min({al, (unsigned)jl_datatype_align(dt), (unsigned)JL_HEAP_ALIGNMENT});
 }
 
-static Type *julia_struct_to_llvm(jl_value_t *jt, jl_unionall_t *ua, bool *isboxed)
+static Type *julia_struct_to_llvm(jl_value_t *jt, jl_unionall_t *ua, bool *isboxed, bool llvmcall)
 {
     // this function converts a Julia Type into the equivalent LLVM struct
     // use this where C-compatible (unboxed) structs are desired
@@ -597,11 +616,12 @@ static Type *julia_struct_to_llvm(jl_val
     if (jt == (jl_value_t*)jl_bottom_type)
         return T_void;
     if (jl_is_primitivetype(jt))
-        return bitstype_to_llvm(jt);
+        return bitstype_to_llvm(jt, llvmcall);
     if (jl_is_structtype(jt)) {
         jl_datatype_t *jst = (jl_datatype_t*)jt;
         bool isTuple = jl_is_tuple_type(jt);
-        if (jst->struct_decl != NULL)
+        // don't use pre-filled struct_decl for llvmcall
+        if (!llvmcall && (jst->struct_decl != NULL))
             return (Type*)jst->struct_decl;
         if (jl_is_structtype(jt) && !(jst->layout && jl_is_layout_opaque(jst->layout))) {
             jl_svec_t *ftypes = jl_get_fieldtypes(jst);
@@ -621,24 +641,33 @@ static Type *julia_struct_to_llvm(jl_val
                 if (jlasttype != NULL && ty != jlasttype)
                     isvector = false;
                 jlasttype = ty;
-                bool isptr;
                 size_t fsz = 0, al = 0;
-                isptr = !jl_islayout_inline(ty, &fsz, &al);
-                if (!isptr && jl_is_uniontype(ty))
-                    fsz += 1;
+                bool isptr = !jl_islayout_inline(ty, &fsz, &al);
+                if (jst->layout) {
+                    assert(isptr == jl_field_isptr(jst, i));
+                    assert((isptr ? sizeof(void*) : fsz + jl_is_uniontype(ty)) == jl_field_size(jst, i));
+                }
                 Type *lty;
                 if (isptr) {
-                    lty = T_pjlvalue;
+                    lty = T_prjlvalue;
+                    isvector = false;
                 }
                 else if (ty == (jl_value_t*)jl_bool_type) {
                     lty = T_int8;
                 }
                 else if (jl_is_uniontype(ty)) {
-                    // pick an Integer type size such that alignment will be correct
-                    // and always end with an Int8 (selector byte)
+                    // pick an Integer type size such that alignment will generally be correct,
+                    // and always end with an Int8 (selector byte).
+                    // We may need to insert padding first to get to the right offset
+                    if (al > MAX_ALIGN) {
+                        Type *AlignmentType = ArrayType::get(VectorType::get(T_int8, al), 0);
+                        latypes.push_back(AlignmentType);
+                        al = MAX_ALIGN;
+                    }
+                    assert(al <= jl_field_align(jst, i));
                     Type *AlignmentType = IntegerType::get(jl_LLVMContext, 8 * al);
-                    unsigned NumATy = (fsz - 1) / al;
-                    unsigned remainder = (fsz - 1) % al;
+                    unsigned NumATy = fsz / al;
+                    unsigned remainder = fsz % al;
                     while (NumATy--)
                         latypes.push_back(AlignmentType);
                     while (remainder--)
@@ -649,7 +678,8 @@ static Type *julia_struct_to_llvm(jl_val
                     continue;
                 }
                 else {
-                    lty = julia_type_to_llvm(ty);
+                    lty = julia_struct_to_llvm(ty, NULL, &isptr, llvmcall);
+                    assert(!isptr);
                 }
                 if (lasttype != NULL && lasttype != lty)
                     isarray = false;
@@ -664,12 +694,12 @@ static Type *julia_struct_to_llvm(jl_val
                 assert(jst->layout == NULL); // otherwise should have been caught above
                 decl = T_void;
             }
-            else if (jl_is_vecelement_type(jt)) {
-                // VecElement type is unwrapped in LLVM
+            else if (jl_is_vecelement_type(jt) && !jl_is_uniontype(jl_svecref(ftypes, 0))) {
+                // VecElement type is unwrapped in LLVM (when possible)
                 decl = latypes[0];
             }
-            else if (isTuple && isarray && lasttype != T_int1 && !type_is_ghost(lasttype)) {
-                if (isvector && jl_special_vector_alignment(ntypes, jlasttype) != 0)
+            else if (isarray && !type_is_ghost(lasttype)) {
+                if (isTuple && isvector && jl_special_vector_alignment(ntypes, jlasttype) != 0)
                     decl = VectorType::get(lasttype, ntypes);
                 else
                     decl = ArrayType::get(lasttype, ntypes);
@@ -684,7 +714,9 @@ static Type *julia_struct_to_llvm(jl_val
 #endif
                 decl = StructType::get(jl_LLVMContext, latypes);
             }
-            jst->struct_decl = decl;
+            // don't use struct_decl cache for llvmcall
+            if (!llvmcall)
+                jst->struct_decl = decl;
             return decl;
         }
     }
@@ -692,17 +724,17 @@ static Type *julia_struct_to_llvm(jl_val
     // if (jl_is_uniontype(jt)) {
     //  // pick an Integer type size such that alignment will be correct
     //  // and always end with an Int8 (selector byte)
-    //  lty = ArrayType::get(IntegerType::get(jl_LLVMContext, 8 * al), (fsz - 1) / al);
+    //  lty = ArrayType::get(IntegerType::get(jl_LLVMContext, 8 * al), fsz / al);
     //  std::vector<Type*> Elements(2);
     //  Elements[0] = lty;
     //  Elements[1] = T_int8;
-    //  unsigned remainder = (fsz - 1) % al;
+    //  unsigned remainder = fsz % al;
     //  while (remainder--)
     //      Elements.push_back(T_int8);
     //  lty = StructType::get(jl_LLVMContext, makeArrayRef(Elements));
     // }
     if (isboxed) *isboxed = true;
-    return T_pjlvalue;
+    return T_prjlvalue;
 }
 
 static bool is_datatype_all_pointers(jl_datatype_t *dt)
@@ -740,12 +772,6 @@ static bool is_tupletype_homogeneous(jl_
     return true;
 }
 
-static bool deserves_sret(jl_value_t *dt, Type *T)
-{
-    assert(jl_is_datatype(dt));
-    return (size_t)jl_datatype_size(dt) > sizeof(void*) && !T->isFloatingPointTy() && !T->isVectorTy();
-}
-
 static bool for_each_uniontype_small(
         std::function<void(unsigned, jl_datatype_t*)> f,
         jl_value_t *ty,
@@ -758,7 +784,7 @@ static bool for_each_uniontype_small(
         allunbox &= for_each_uniontype_small(f, ((jl_uniontype_t*)ty)->b, counter);
         return allunbox;
     }
-    else if (jl_justbits(ty)) {
+    else if (jl_is_pointerfree(ty)) {
         f(++counter, (jl_datatype_t*)ty);
         return true;
     }
@@ -1202,7 +1228,7 @@ static Value *emit_isconcrete(jl_codectx
 {
     Value *isconcrete;
     isconcrete = ctx.builder.CreateConstInBoundsGEP1_32(T_int8, emit_bitcast(ctx, decay_derived(typ), T_pint8), offsetof(jl_datatype_t, isconcretetype));
-    isconcrete = ctx.builder.CreateLoad(isconcrete, tbaa_const);
+    isconcrete = ctx.builder.CreateLoad(T_int8, isconcrete, tbaa_const);
     isconcrete = ctx.builder.CreateTrunc(isconcrete, T_int1);
     return isconcrete;
 }
@@ -1270,6 +1296,38 @@ static Value *emit_bounds_check(jl_codec
 }
 
 static Value *emit_unbox(jl_codectx_t &ctx, Type *to, const jl_cgval_t &x, jl_value_t *jt, Value* dest = NULL, MDNode *tbaa_dest = nullptr, bool isVolatile = false);
+static void emit_write_barrier(jl_codectx_t&, Value*, ArrayRef<Value*>);
+static void emit_write_barrier(jl_codectx_t&, Value*, Value*);
+static void emit_write_multibarrier(jl_codectx_t&, Value*, Value*);
+
+std::vector<unsigned> first_ptr(Type *T)
+{
+    if (isa<CompositeType>(T)) {
+        if (!isa<StructType>(T) && cast<SequentialType>(T)->getNumElements() == 0)
+            return {};
+        unsigned i = 0;
+        for (Type *ElTy : T->subtypes()) {
+            if (isa<PointerType>(ElTy) && ElTy->getPointerAddressSpace() == AddressSpace::Tracked) {
+                return std::vector<unsigned>{i};
+            }
+            auto path = first_ptr(ElTy);
+            if (!path.empty()) {
+                path.push_back(i);
+                return path;
+            }
+            i++;
+        }
+    }
+    return {};
+}
+Value *extract_first_ptr(jl_codectx_t &ctx, Value *V)
+{
+    auto path = first_ptr(V->getType());
+    if (path.empty())
+        return NULL;
+    std::reverse(std::begin(path), std::end(path));
+    return ctx.builder.CreateExtractValue(V, path);
+}
 
 static jl_cgval_t typed_load(jl_codectx_t &ctx, Value *ptr, Value *idx_0based, jl_value_t *jltype,
                              MDNode *tbaa, MDNode *aliasscope,
@@ -1279,8 +1337,6 @@ static jl_cgval_t typed_load(jl_codectx_
     Type *elty = julia_type_to_llvm(jltype, &isboxed);
     if (type_is_ghost(elty))
         return ghostValue(jltype);
-    if (isboxed)
-        elty = T_prjlvalue;
     Type *ptrty = PointerType::get(elty, ptr->getType()->getPointerAddressSpace());
     Value *data;
     if (ptr->getType() != ptrty)
@@ -1296,7 +1352,7 @@ static jl_cgval_t typed_load(jl_codectx_
     //}
     //else {
         load = ctx.builder.CreateAlignedLoad(data,
-            isboxed || alignment ?  alignment : julia_alignment(jltype),
+            isboxed || alignment ? alignment : julia_alignment(jltype),
             false);
         if (aliasscope)
             load->setMetadata("alias.scope", aliasscope);
@@ -1304,8 +1360,11 @@ static jl_cgval_t typed_load(jl_codectx_
             load = maybe_mark_load_dereferenceable(load, true, jltype);
         if (tbaa)
             load = tbaa_decorate(tbaa, load);
-        if (maybe_null_if_boxed && isboxed)
-            null_pointer_check(ctx, load);
+        if (maybe_null_if_boxed) {
+            Value *first_ptr = isboxed ? load : extract_first_ptr(ctx, load);
+            if (first_ptr)
+                null_pointer_check(ctx, first_ptr);
+        }
     //}
     if (jltype == (jl_value_t*)jl_bool_type) { // "freeze" undef memory to a valid value
         // NOTE: if we zero-initialize arrays, this optimization should become valid
@@ -1330,26 +1389,20 @@ static void typed_store(jl_codectx_t &ct
     Value *r;
     if (!isboxed) {
         r = emit_unbox(ctx, elty, rhs, jltype);
+        if (parent != NULL)
+            emit_write_multibarrier(ctx, parent, r);
     }
     else {
         r = maybe_decay_untracked(boxed(ctx, rhs));
         if (parent != NULL)
             emit_write_barrier(ctx, parent, r);
     }
-    Value *data;
     Type *ptrty = PointerType::get(elty, ptr->getType()->getPointerAddressSpace());
-    if (ptr->getType() != ptrty) {
-        if (isboxed) {
-            data = emit_bitcast(ctx, ptr, T_pprjlvalue);
-        } else {
-            data = emit_bitcast(ctx, ptr, ptrty);
-        }
-    } else {
-        data = ptr;
-    }
+    if (ptr->getType() != ptrty)
+        ptr = ctx.builder.CreateBitCast(ptr, ptrty);
     if (idx_0based)
-        data = ctx.builder.CreateInBoundsGEP(r->getType(), data, idx_0based);
-    Instruction *store = ctx.builder.CreateAlignedStore(r, data, isboxed || alignment ? alignment : julia_alignment(jltype));
+        ptr = ctx.builder.CreateInBoundsGEP(r->getType(), ptr, idx_0based);
+    Instruction *store = ctx.builder.CreateAlignedStore(r, ptr, isboxed || alignment ? alignment : julia_alignment(jltype));
     if (aliasscope)
         store->setMetadata("noalias", aliasscope);
     if (tbaa)
@@ -1468,15 +1521,84 @@ static void emit_memcpy(jl_codectx_t &ct
 
 
 
+static jl_cgval_t emit_getfield_knownidx(jl_codectx_t &ctx, const jl_cgval_t &strct, unsigned idx, jl_datatype_t *jt);
+
 static bool emit_getfield_unknownidx(jl_codectx_t &ctx,
-        jl_cgval_t *ret, const jl_cgval_t &strct,
+        jl_cgval_t *ret, jl_cgval_t strct,
         Value *idx, jl_datatype_t *stt, jl_value_t *inbounds)
 {
     size_t nfields = jl_datatype_nfields(stt);
     bool maybe_null = (unsigned)stt->ninitialized != nfields;
+    auto idx0 = [&]() {
+        return emit_bounds_check(ctx, strct, (jl_value_t*)stt, idx, ConstantInt::get(T_size, nfields), inbounds);
+    };
+    if (nfields == 0) {
+        (void)idx0();
+        *ret = jl_cgval_t();
+        return true;
+    }
+    if (nfields == 1) {
+        (void)idx0();
+        *ret = emit_getfield_knownidx(ctx, strct, 0, stt);
+        return true;
+    }
+    assert(!jl_is_vecelement_type((jl_value_t*)stt));
+
+    if (!strct.ispointer()) { // unboxed
+        assert(jl_is_concrete_immutable((jl_value_t*)stt));
+        bool isboxed = is_datatype_all_pointers(stt);
+        bool issame = is_tupletype_homogeneous(stt->types);
+        if (issame) {
+            jl_value_t *jft = jl_svecref(stt->types, 0);
+            if (strct.isghost) {
+                (void)idx0();
+                *ret = ghostValue(jft);
+                return true;
+            }
+            if (isa<VectorType>(strct.V->getType())) {
+                assert(stt->layout->npointers == 0); // we could, but don't emit this
+                idx = idx0();
+                if (sizeof(void*) != sizeof(int))
+                    idx = ctx.builder.CreateTrunc(idx, T_int32); // llvm3.3 requires this, harmless elsewhere
+                Value *fld = ctx.builder.CreateExtractElement(strct.V, idx);
+                *ret = mark_julia_type(ctx, fld, isboxed, jft);
+                return true;
+            }
+            else if (isa<ArrayType>(strct.V->getType())) {
+                if (!isboxed && nfields > 3) {
+                    // For small objects and tracked pointers, emit a set of Select statements,
+                    // otherwise emit as a stack load. This keeps LLVM from becoming unhappy
+                    // about seeing loads of tracked pointers.
+                    strct = value_to_pointer(ctx, strct);
+                    assert(strct.ispointer());
+                }
+                // fall-through to next branch, where we'll handle it
+            }
+            else {
+                llvm_unreachable("homogeneous struct should have had a homogeneous type");
+            }
+        }
+        if (isboxed || (issame && isa<ArrayType>(strct.V->getType()))) {
+            assert((cast<ArrayType>(strct.V->getType())->getElementType() == T_prjlvalue) == isboxed);
+            Value *idx = idx0();
+            unsigned i = 0;
+            Value *fld = ctx.builder.CreateExtractValue(strct.V, makeArrayRef(i));
+            for (i = 1; i < nfields; i++) {
+                fld = ctx.builder.CreateSelect(
+                        ctx.builder.CreateICmpEQ(idx, ConstantInt::get(idx->getType(), i)),
+                        ctx.builder.CreateExtractValue(strct.V, makeArrayRef(i)),
+                        fld);
+            }
+            jl_value_t *jft = issame ? jl_svecref(stt->types, 0) : (jl_value_t*)jl_any_type;
+            if (isboxed && maybe_null)
+                null_pointer_check(ctx, fld);
+            *ret = mark_julia_type(ctx, fld, isboxed, jft);
+            return true;
+        }
+    }
+
     if (strct.ispointer()) { // boxed or stack
         if (is_datatype_all_pointers(stt)) {
-            idx = emit_bounds_check(ctx, strct, (jl_value_t*)stt, idx, ConstantInt::get(T_size, nfields), inbounds);
             size_t minimum_field_size = std::numeric_limits<size_t>::max();
             size_t minimum_align = JL_HEAP_ALIGNMENT;
             for (size_t i = 0; i < nfields; ++i) {
@@ -1493,7 +1615,7 @@ static bool emit_getfield_unknownidx(jl_
             Value *fldptr = ctx.builder.CreateInBoundsGEP(
                     T_prjlvalue,
                     maybe_decay_tracked(emit_bitcast(ctx, data_pointer(ctx, strct), T_pprjlvalue)),
-                    idx);
+                    idx0());
             Value *fld = tbaa_decorate(strct.tbaa,
                 maybe_mark_load_dereferenceable(
                     ctx.builder.CreateLoad(T_prjlvalue, fldptr),
@@ -1505,17 +1627,17 @@ static bool emit_getfield_unknownidx(jl_
         }
         else if (is_tupletype_homogeneous(stt->types)) {
             assert(nfields > 0); // nf == 0 trapped by all_pointers case
-            jl_value_t *jt = jl_svecref(stt->types, 0);
-            idx = emit_bounds_check(ctx, strct, (jl_value_t*)stt, idx, ConstantInt::get(T_size, nfields), inbounds);
+            jl_value_t *jft = jl_svecref(stt->types, 0);
+            idx = idx0();
             Value *ptr = maybe_decay_tracked(data_pointer(ctx, strct));
-            if (!stt->mutabl && !(maybe_null && jt == (jl_value_t*)jl_bool_type)) {
+            if (!stt->mutabl && !(maybe_null && jft == (jl_value_t*)jl_bool_type)) {
                 // just compute the pointer and let user load it when necessary
-                Type *fty = julia_type_to_llvm(jt);
+                Type *fty = julia_type_to_llvm(jft);
                 Value *addr = ctx.builder.CreateInBoundsGEP(fty, emit_bitcast(ctx, ptr, PointerType::get(fty, 0)), idx);
-                *ret = mark_julia_slot(addr, jt, NULL, strct.tbaa);
+                *ret = mark_julia_slot(addr, jft, NULL, strct.tbaa);
                 return true;
             }
-            *ret = typed_load(ctx, ptr, idx, jt, strct.tbaa, nullptr, false);
+            *ret = typed_load(ctx, ptr, idx, jft, strct.tbaa, nullptr, false);
             return true;
         }
         else if (strct.isboxed) {
@@ -1525,49 +1647,24 @@ static bool emit_getfield_unknownidx(jl_
             return true;
         }
     }
-    else if (is_tupletype_homogeneous(stt->types)) {
-        assert(jl_justbits((jl_value_t*)stt));
-        if (nfields == 0) {
-            idx = emit_bounds_check(
-                    ctx, ghostValue(stt), (jl_value_t*)stt,
-                    idx, ConstantInt::get(T_size, nfields), inbounds);
-            *ret = jl_cgval_t();
-            return true;
-        }
-        assert(!jl_field_isptr(stt, 0));
-        jl_value_t *jt = jl_svecref(stt->types, 0);
-        Value *idx0 = emit_bounds_check(ctx, strct, (jl_value_t*)stt, idx, ConstantInt::get(T_size, nfields), inbounds);
-        if (strct.isghost) {
-            *ret = ghostValue(jt);
-            return true;
-        }
-        // llvm::VectorType
-        if (sizeof(void*) != sizeof(int))
-            idx0 = ctx.builder.CreateTrunc(idx0, T_int32); // llvm3.3 requires this, harmless elsewhere
-        Value *fld = ctx.builder.CreateExtractElement(strct.V, idx0);
-        *ret = mark_julia_type(ctx, fld, false, jt);
-        return true;
-    }
     return false;
 }
 
 static jl_cgval_t emit_getfield_knownidx(jl_codectx_t &ctx, const jl_cgval_t &strct, unsigned idx, jl_datatype_t *jt)
 {
     jl_value_t *jfty = jl_field_type(jt, idx);
-    Type *elty = julia_type_to_llvm(jfty);
     if (jfty == jl_bottom_type) {
         raise_exception(ctx, literal_pointer_val(ctx, jl_undefref_exception));
         return jl_cgval_t(); // unreachable
     }
-    if (type_is_ghost(elty))
+    if (type_is_ghost(julia_type_to_llvm(jfty)))
         return ghostValue(jfty);
-    Value *fldv = NULL;
     bool maybe_null = idx >= (unsigned)jt->ninitialized;
+    size_t byte_offset = jl_field_offset(jt, idx);
     if (strct.ispointer()) {
         Value *staddr = maybe_decay_tracked(data_pointer(ctx, strct));
         bool isboxed;
         Type *lt = julia_type_to_llvm((jl_value_t*)jt, &isboxed);
-        size_t byte_offset = jl_field_offset(jt, idx);
         Value *addr;
         if (isboxed) {
             // byte_offset == 0 is an important special case here, e.g.
@@ -1584,29 +1681,17 @@ static jl_cgval_t emit_getfield_knownidx
             }
         }
         else {
-            if (VectorType *vlt = dyn_cast<VectorType>(lt)) {
-                // doesn't have the struct wrapper, so this must have been a VecElement
-                // cast to the element type so that it can be addressed with GEP
-                lt = vlt->getElementType();
-                staddr = emit_bitcast(ctx, staddr, lt->getPointerTo());
-                Value *llvm_idx = ConstantInt::get(T_size, idx);
-                addr = ctx.builder.CreateInBoundsGEP(lt, staddr, llvm_idx);
-            }
-            else if (lt->isSingleValueType()) {
-                addr = emit_bitcast(ctx, staddr, lt->getPointerTo());
-            }
-            else {
-                staddr = emit_bitcast(ctx, staddr, lt->getPointerTo());
-                if (isa<StructType>(lt))
-                    addr = emit_struct_gep(ctx, lt, staddr, byte_offset);
-                else
-                    addr = ctx.builder.CreateConstGEP2_32(lt, staddr, 0, idx);
-            }
+            staddr = maybe_bitcast(ctx, staddr, lt->getPointerTo());
+            if (jl_is_vecelement_type((jl_value_t*)jt))
+                addr = staddr; // VecElement types are unwrapped in LLVM.
+            else if (isa<StructType>(lt))
+                addr = emit_struct_gep(ctx, lt, staddr, byte_offset);
+            else
+                addr = ctx.builder.CreateConstInBoundsGEP2_32(lt, staddr, 0, idx);
         }
-        unsigned align = jl_field_align(jt, idx);
         if (jl_field_isptr(jt, idx)) {
             Instruction *Load = maybe_mark_load_dereferenceable(
-                    ctx.builder.CreateLoad(T_prjlvalue, emit_bitcast(ctx, addr, T_pprjlvalue)),
+                    ctx.builder.CreateLoad(T_prjlvalue, maybe_bitcast(ctx, addr, T_pprjlvalue)),
                     maybe_null, jl_field_type(jt, idx));
             Value *fldv = tbaa_decorate(strct.tbaa, Load);
             if (maybe_null)
@@ -1614,13 +1699,17 @@ static jl_cgval_t emit_getfield_knownidx
             return mark_julia_type(ctx, fldv, true, jfty);
         }
         else if (jl_is_uniontype(jfty)) {
-            int fsz = jl_field_size(jt, idx);
+            size_t fsz = 0, al = 0;
+            bool isptr = !jl_islayout_inline(jfty, &fsz, &al);
+            assert(!isptr && fsz == jl_field_size(jt, idx) - 1); (void)isptr;
             Value *ptindex;
-            if (isa<StructType>(lt))
-                ptindex = emit_struct_gep(ctx, lt, staddr, byte_offset + fsz - 1);
-            else
+            if (isboxed) {
                 ptindex = ctx.builder.CreateConstInBoundsGEP1_32(
-                    T_int8, emit_bitcast(ctx, staddr, T_pint8), byte_offset + fsz - 1);
+                    T_int8, emit_bitcast(ctx, staddr, T_pint8), byte_offset + fsz);
+            }
+            else {
+                ptindex = emit_struct_gep(ctx, cast<StructType>(lt), staddr, byte_offset + fsz);
+            }
             Instruction *tindex0 = tbaa_decorate(tbaa_unionselbyte, ctx.builder.CreateLoad(T_int8, ptindex));
             //tindex0->setMetadata(LLVMContext::MD_range, MDNode::get(jl_LLVMContext, {
             //    ConstantAsMetadata::get(ConstantInt::get(T_int8, 0)),
@@ -1628,11 +1717,10 @@ static jl_cgval_t emit_getfield_knownidx
             Value *tindex = ctx.builder.CreateNUWAdd(ConstantInt::get(T_int8, 1), tindex0);
             if (jt->mutabl) {
                 // move value to an immutable stack slot (excluding tindex)
-                Type *AT = ArrayType::get(IntegerType::get(jl_LLVMContext, 8 * align), (fsz + align - 2) / align);
-                AllocaInst *lv = emit_static_alloca(ctx, AT);
-                if (align > 1)
-                    lv->setAlignment(align);
-                emit_memcpy(ctx, lv, strct.tbaa, addr, strct.tbaa, fsz - 1, align);
+                Type *ET = IntegerType::get(jl_LLVMContext, 8 * al);
+                AllocaInst *lv = emit_static_alloca(ctx, ET);
+                lv->setOperand(0, ConstantInt::get(T_int32, (fsz + al - 1) / al));
+                emit_memcpy(ctx, lv, strct.tbaa, addr, strct.tbaa, fsz, al);
                 addr = lv;
             }
             return mark_julia_slot(addr, jfty, tindex, strct.tbaa);
@@ -1641,22 +1729,72 @@ static jl_cgval_t emit_getfield_knownidx
             // just compute the pointer and let user load it when necessary
             return mark_julia_slot(addr, jfty, NULL, strct.tbaa);
         }
+        unsigned align = jl_field_align(jt, idx);
         return typed_load(ctx, addr, NULL, jfty, strct.tbaa, nullptr, true, align);
     }
     else if (isa<UndefValue>(strct.V)) {
         return jl_cgval_t();
     }
     else {
-        if (strct.V->getType()->isVectorTy()) {
-            fldv = ctx.builder.CreateExtractElement(strct.V, ConstantInt::get(T_int32, idx));
+        Value *obj = strct.V; // aka emit_unbox
+        Type *T = obj->getType();
+        Value *fldv;
+        if (jl_is_vecelement_type((jl_value_t*)jt)) {
+            // VecElement types are unwrapped in LLVM.
+            fldv = obj;
+        }
+        else if (isa<VectorType>(T)) {
+            fldv = ctx.builder.CreateExtractElement(obj, ConstantInt::get(T_int32, idx));
+        }
+        else if (!jl_field_isptr(jt, idx) && jl_is_uniontype(jfty)) {
+            int fsz = jl_field_size(jt, idx) - 1;
+            unsigned ptindex = convert_struct_offset(ctx, T, byte_offset + fsz);
+            AllocaInst *lv = NULL;
+            if (fsz > 0) {
+                unsigned st_idx = convert_struct_offset(ctx, T, byte_offset);
+                IntegerType *ET = cast<IntegerType>(T->getStructElementType(st_idx));
+                unsigned align = (ET->getBitWidth() + 7) / 8;
+                lv = emit_static_alloca(ctx, ET);
+                lv->setOperand(0, ConstantInt::get(T_int32, (fsz + align - 1) / align));
+                // emit all of the align-sized words
+                unsigned i = 0;
+                for (; i < fsz / align; i++) {
+                    unsigned fld = st_idx + i;
+                    Value *fldv = ctx.builder.CreateExtractValue(obj, makeArrayRef(fld));
+                    Value *fldp = ctx.builder.CreateConstInBoundsGEP1_32(ET, lv, i);
+                    ctx.builder.CreateStore(fldv, fldp);
+                }
+                // emit remaining bytes up to tindex
+                if (i < ptindex - st_idx) {
+                    Value *staddr = ctx.builder.CreateConstInBoundsGEP1_32(ET, lv, i);
+                    staddr = ctx.builder.CreateBitCast(staddr, T_pint8);
+                    for (; i < ptindex - st_idx; i++) {
+                        Value *fldv = ctx.builder.CreateExtractValue(obj, makeArrayRef(st_idx + i));
+                        Value *fldp = ctx.builder.CreateConstInBoundsGEP1_32(T_int8, staddr, i);
+                        ctx.builder.CreateStore(fldv, fldp);
+                    }
+                }
+            }
+            Value *tindex0 = ctx.builder.CreateExtractValue(obj, makeArrayRef(ptindex));
+            Value *tindex = ctx.builder.CreateNUWAdd(ConstantInt::get(T_int8, 1), tindex0);
+            return mark_julia_slot(lv, jfty, tindex, tbaa_stack);
         }
         else {
-            // VecElement types are unwrapped in LLVM.
-            assert( strct.V->getType()->isSingleValueType() );
-            fldv = strct.V;
+            unsigned st_idx;
+            if (isa<ArrayType>(T))
+                st_idx = idx;
+            else if (isa<StructType>(T))
+                st_idx = convert_struct_offset(ctx, T, byte_offset);
+            else
+                llvm_unreachable("encountered incompatible type for a struct");
+            fldv = ctx.builder.CreateExtractValue(obj, makeArrayRef(st_idx));
         }
-        assert(!jl_field_isptr(jt, idx));
-        return mark_julia_type(ctx, fldv, false, jfty);
+        if (maybe_null) {
+            Value *first_ptr = jl_field_isptr(jt, idx) ? fldv : extract_first_ptr(ctx, fldv);
+            if (first_ptr)
+                null_pointer_check(ctx, first_ptr);
+        }
+        return mark_julia_type(ctx, fldv, jl_field_isptr(jt, idx), jfty);
     }
 }
 
@@ -1776,7 +1914,7 @@ static Value *emit_arrayptr(jl_codectx_t
 static Value *emit_unsafe_arrayptr(jl_codectx_t &ctx, const jl_cgval_t &tinfo, bool isboxed = false)
 {
     Value *t = boxed(ctx, tinfo);
-    t = emit_pointer_from_objref_internal(ctx, decay_derived(t));
+    t = emit_pointer_from_objref(ctx, decay_derived(t));
     return emit_arrayptr_internal(ctx, tinfo, t, 0, isboxed);
 }
 
@@ -1810,7 +1948,7 @@ static Value *emit_arrayndims(jl_codectx
     Value *flags = emit_arrayflags(ctx, ary);
     cast<LoadInst>(flags)->setMetadata(LLVMContext::MD_invariant_load, MDNode::get(jl_LLVMContext, None));
     flags = ctx.builder.CreateLShr(flags, 2);
-    flags = ctx.builder.CreateAnd(flags, 0x3FF); // (1<<10) - 1
+    flags = ctx.builder.CreateAnd(flags, 0x1FF); // (1<<9) - 1
     return flags;
 }
 
@@ -1972,66 +2110,75 @@ static void init_bits_cgval(jl_codectx_t
 
 static jl_value_t *static_constant_instance(Constant *constant, jl_value_t *jt)
 {
-    assert(constant != NULL);
+    assert(constant != NULL && jl_is_concrete_type(jt));
+    jl_datatype_t *jst = (jl_datatype_t*)jt;
 
     if (isa<UndefValue>(constant))
         return NULL;
 
-    ConstantInt *cint = dyn_cast<ConstantInt>(constant);
-    if (cint != NULL) {
-        assert(jl_is_datatype(jt));
-        if (jt == (jl_value_t*)jl_bool_type)
+    if (ConstantInt *cint = dyn_cast<ConstantInt>(constant)) {
+        if (jst == jl_bool_type)
             return cint->isZero() ? jl_false : jl_true;
         return jl_new_bits(jt,
             const_cast<uint64_t *>(cint->getValue().getRawData()));
     }
 
-    ConstantFP *cfp = dyn_cast<ConstantFP>(constant);
-    if (cfp != NULL) {
-        assert(jl_is_datatype(jt));
+    if (ConstantFP *cfp = dyn_cast<ConstantFP>(constant)) {
         return jl_new_bits(jt,
             const_cast<uint64_t *>(cfp->getValueAPF().bitcastToAPInt().getRawData()));
     }
 
-    ConstantPointerNull *cpn = dyn_cast<ConstantPointerNull>(constant);
-    if (cpn != NULL) {
-        assert(jl_is_cpointer_type(jt));
+    if (isa<ConstantPointerNull>(constant)) {
         uint64_t val = 0;
         return jl_new_bits(jt, &val);
     }
 
     // issue #8464
-    ConstantExpr *ce = dyn_cast<ConstantExpr>(constant);
-    if (ce != NULL) {
-        if (ce->isCast()) {
-            return static_constant_instance(dyn_cast<Constant>(ce->getOperand(0)), jt);
+    if (ConstantExpr *ce = dyn_cast<ConstantExpr>(constant)) {
+        unsigned OpCode = ce->getOpcode();
+        if (OpCode == Instruction::BitCast || OpCode == Instruction::PtrToInt || OpCode == Instruction::IntToPtr) {
+            return static_constant_instance(ce->getOperand(0), jt);
         }
+        return NULL;
     }
 
-    size_t nargs = 0;
-    if (ConstantStruct *cst = dyn_cast<ConstantStruct>(constant))
-        nargs = cst->getType()->getNumElements();
-    else if (ConstantVector *cvec = dyn_cast<ConstantVector>(constant))
-        nargs = cvec->getType()->getNumElements();
-    else if (ConstantArray *carr = dyn_cast<ConstantArray>(constant))
-        nargs = carr->getType()->getNumElements();
-    else if (ConstantDataVector *cdv = dyn_cast<ConstantDataVector>(constant))
-        nargs = cdv->getType()->getNumElements();
-    else if (isa<Function>(constant))
+    if (isa<GlobalValue>(constant))
         return NULL;
-    else
-        assert(false && "Cannot process this type of constant");
 
-    assert(jl_is_tuple_type(jt));
+    size_t nargs;
+    if (const auto *CC = dyn_cast<ConstantAggregate>(constant))
+        nargs = CC->getNumOperands();
+    else if (const auto *CAZ = dyn_cast<ConstantAggregateZero>(constant))
+        nargs = CAZ->getNumElements();
+    else if (const auto *CDS = dyn_cast<ConstantDataSequential>(constant))
+        nargs = CDS->getNumElements();
+    else
+        return NULL;
+    assert(nargs > 0 && jst->instance == NULL);
+    if (nargs != jl_datatype_nfields(jst))
+        return NULL;
 
-    jl_value_t **tupleargs;
-    JL_GC_PUSHARGS(tupleargs, nargs);
+    jl_value_t **flds;
+    JL_GC_PUSHARGS(flds, nargs);
     for (size_t i = 0; i < nargs; i++) {
-        tupleargs[i] = static_constant_instance(constant->getAggregateElement(i), jl_tparam(jt, i));
+        jl_value_t *ft = jl_field_type(jst, i);
+        if (jl_field_isptr(jst, i) || jl_is_uniontype(ft)) {
+            JL_GC_POP();
+            return NULL; // TODO: handle this?
+        }
+        unsigned llvm_idx = i;
+        if (i > 0 && isa<StructType>(constant->getType()))
+            llvm_idx = convert_struct_offset(constant->getType(), jl_field_offset(jst, i));
+        Constant *fld = constant->getAggregateElement(llvm_idx);
+        flds[i] = static_constant_instance(fld, ft);
+        if (flds[i] == NULL) {
+            JL_GC_POP();
+            return NULL; // must have been unreachable
+        }
     }
-    jl_value_t *tpl = jl_f_tuple(NULL, tupleargs, nargs);
+    jl_value_t *obj = jl_new_structv(jst, flds, nargs);
     JL_GC_POP();
-    return tpl;
+    return obj;
 }
 
 static Value *call_with_attrs(jl_codectx_t &ctx, Function *func, Value *v)
@@ -2175,7 +2322,7 @@ static AllocaInst *try_emit_union_alloca
         Type *AT = ArrayType::get(IntegerType::get(jl_LLVMContext, 8 * min_align), (nbytes + min_align - 1) / min_align);
         AllocaInst *lv = emit_static_alloca(ctx, AT);
         if (align > 1)
-            lv->setAlignment(align);
+            lv->setAlignment(Align(align));
         return lv;
     }
     return NULL;
@@ -2284,7 +2431,7 @@ static Value *boxed(jl_codectx_t &ctx, c
     }
     else {
         assert(vinfo.V && "Missing data for unboxed value.");
-        assert(jl_justbits(jt) && "This type shouldn't have been unboxed.");
+        assert(jl_is_concrete_immutable(jt) && "This type shouldn't have been unboxed.");
         Type *t = julia_type_to_llvm(jt);
         assert(!type_is_ghost(t)); // ghost values should have been handled by vinfo.constant above!
         box = _boxed_special(ctx, vinfo, t);
@@ -2303,12 +2450,13 @@ static Value *boxed(jl_codectx_t &ctx, c
 static void emit_unionmove(jl_codectx_t &ctx, Value *dest, MDNode *tbaa_dst, const jl_cgval_t &src, Value *skip, bool isVolatile=false)
 {
     if (AllocaInst *ai = dyn_cast<AllocaInst>(dest))
-        ctx.builder.CreateStore(UndefValue::get(ai->getAllocatedType()), ai);
+        // TODO: make this a lifetime_end & dereferencable annotation?
+        ctx.builder.CreateAlignedStore(UndefValue::get(ai->getAllocatedType()), ai, ai->getAlignment());
     if (jl_is_concrete_type(src.typ) || src.constant) {
         jl_value_t *typ = src.constant ? jl_typeof(src.constant) : src.typ;
         Type *store_ty = julia_type_to_llvm(typ);
-        assert(skip || jl_justbits(typ));
-        if (jl_justbits(typ)) {
+        assert(skip || jl_is_pointerfree(typ));
+        if (jl_is_pointerfree(typ)) {
             if (!src.ispointer() || src.constant) {
                 emit_unbox(ctx, store_ty, src, typ, dest, tbaa_dst, isVolatile);
             }
@@ -2431,11 +2579,26 @@ static Value *emit_new_bits(jl_codectx_t
 // if ptr is NULL this emits a write barrier _back_
 static void emit_write_barrier(jl_codectx_t &ctx, Value *parent, Value *ptr)
 {
-    parent = maybe_decay_untracked(emit_bitcast(ctx, parent, T_prjlvalue));
-    ptr = maybe_decay_untracked(emit_bitcast(ctx, ptr, T_prjlvalue));
-    ctx.builder.CreateCall(prepare_call(jl_write_barrier_func), {parent, ptr});
+    emit_write_barrier(ctx, parent, makeArrayRef(ptr));
+}
+
+static void emit_write_barrier(jl_codectx_t &ctx, Value *parent, ArrayRef<Value*> ptrs)
+{
+    SmallVector<Value*, 8> decay_ptrs;
+    decay_ptrs.push_back(maybe_decay_untracked(emit_bitcast(ctx, parent, T_prjlvalue)));
+    for (auto ptr : ptrs) {
+        decay_ptrs.push_back(maybe_decay_untracked(emit_bitcast(ctx, ptr, T_prjlvalue)));
+    }
+    ctx.builder.CreateCall(prepare_call(jl_write_barrier_func), decay_ptrs);
+}
+
+static void emit_write_multibarrier(jl_codectx_t &ctx, Value *parent, Value *agg)
+{
+    auto ptrs = ExtractTrackedValues(agg, agg->getType(), false, ctx.builder);
+    emit_write_barrier(ctx, parent, ptrs);
 }
 
+
 static void emit_setfield(jl_codectx_t &ctx,
         jl_datatype_t *sty, const jl_cgval_t &strct, size_t idx0,
         const jl_cgval_t &rhs, bool checked, bool wb)
@@ -2459,14 +2622,14 @@ static void emit_setfield(jl_codectx_t &
                 emit_write_barrier(ctx, boxed(ctx, strct), r);
         }
         else if (jl_is_uniontype(jfty)) {
-            int fsz = jl_field_size(sty, idx0);
+            int fsz = jl_field_size(sty, idx0) - 1;
             // compute tindex from rhs
             jl_cgval_t rhs_union = convert_julia_type(ctx, rhs, jfty);
             if (rhs_union.typ == jl_bottom_type)
                 return;
             Value *tindex = compute_tindex_unboxed(ctx, rhs_union, jfty);
             tindex = ctx.builder.CreateNUWSub(tindex, ConstantInt::get(T_int8, 1));
-            Value *ptindex = ctx.builder.CreateInBoundsGEP(T_int8, emit_bitcast(ctx, maybe_decay_tracked(addr), T_pint8), ConstantInt::get(T_size, fsz - 1));
+            Value *ptindex = ctx.builder.CreateInBoundsGEP(T_int8, emit_bitcast(ctx, maybe_decay_tracked(addr), T_pint8), ConstantInt::get(T_size, fsz));
             tbaa_decorate(tbaa_unionselbyte, ctx.builder.CreateStore(tindex, ptindex));
             // copy data
             if (!rhs.isghost) {
@@ -2495,30 +2658,42 @@ static jl_cgval_t emit_new_struct(jl_cod
     jl_datatype_t *sty = (jl_datatype_t*)ty;
     size_t nf = jl_datatype_nfields(sty);
     if (nf > 0 || sty->mutabl) {
-        if (jl_justbits(ty)) {
+        if (deserves_stack(ty)) {
             Type *lt = julia_type_to_llvm(ty);
             unsigned na = nargs < nf ? nargs : nf;
 
             // whether we should perform the initialization with the struct as a IR value
             // or instead initialize the stack buffer with stores
+            auto tracked = CountTrackedPointers(lt);
             bool init_as_value = false;
-            if (lt->isVectorTy() ||
-                    jl_is_vecelement_type(ty)) { // maybe also check the size ?
+            if (lt->isVectorTy() || jl_is_vecelement_type(ty)) { // maybe also check the size ?
+                init_as_value = true;
+            }
+            else if (tracked.count) {
                 init_as_value = true;
             }
 
             Value *strct;
-            if (type_is_ghost(lt))
+            if (type_is_ghost(lt)) {
                 strct = NULL;
-            else if (init_as_value)
-                strct = UndefValue::get(lt);
-            else
+            }
+            else if (init_as_value) {
+                if (tracked.count)
+                    strct = Constant::getNullValue(lt);
+                else
+                    strct = UndefValue::get(lt);
+            }
+            else {
                 strct = emit_static_alloca(ctx, lt);
+                if (tracked.count)
+                    undef_derived_strct(ctx.builder, strct, sty, tbaa_stack);
+            }
 
             for (unsigned i = 0; i < na; i++) {
                 jl_value_t *jtype = jl_svecref(sty->types, i);
-                const jl_cgval_t &fval_info = argv[i];
+                jl_cgval_t fval_info = argv[i];
                 emit_typecheck(ctx, fval_info, jtype, "new");
+                fval_info = update_julia_type(ctx, fval_info, jtype);
                 if (type_is_ghost(lt))
                     continue;
                 Type *fty = julia_type_to_llvm(jtype);
@@ -2533,47 +2708,89 @@ static jl_cgval_t emit_new_struct(jl_cod
                     dest = ctx.builder.CreateConstInBoundsGEP2_32(lt, strct, 0, llvm_idx);
                 }
                 Value *fval = NULL;
-                if (jl_is_uniontype(jtype)) {
-                    assert(!init_as_value && "unimplemented");
+                if (jl_field_isptr(sty, i)) {
+                    fval = boxed(ctx, fval_info);
+                    if (!init_as_value)
+                        tbaa_decorate(tbaa_stack, ctx.builder.CreateAlignedStore(fval, dest, jl_field_align(sty, i)));
+                }
+                else if (jl_is_uniontype(jtype)) {
                     // compute tindex from rhs
                     jl_cgval_t rhs_union = convert_julia_type(ctx, fval_info, jtype);
                     if (rhs_union.typ == jl_bottom_type)
                         return jl_cgval_t();
                     Value *tindex = compute_tindex_unboxed(ctx, rhs_union, jtype);
                     tindex = ctx.builder.CreateNUWSub(tindex, ConstantInt::get(T_int8, 1));
-                    int fsz = jl_field_size(sty, i);
-                    Value *ptindex = emit_struct_gep(ctx, lt, strct, offs + fsz - 1);
-                    tbaa_decorate(tbaa_unionselbyte, ctx.builder.CreateStore(tindex, ptindex));
-                    if (!rhs_union.isghost)
-                        emit_unionmove(ctx, dest, tbaa_stack, fval_info, nullptr);
-                    // If you wanted to implement init_as_value,
-                    // would need to emit the union-move into temporary memory,
-                    // then load it and combine with the tindex.
-                    // But more efficient to just store it directly.
+                    size_t fsz = 0, al = 0;
+                    bool isptr = !jl_islayout_inline(jtype, &fsz, &al);
+                    assert(!isptr && fsz == jl_field_size(sty, i) - 1); (void)isptr;
+                    if (init_as_value) {
+                        // If you wanted to implement init_as_value,
+                        // would need to emit the union-move into temporary memory,
+                        // then load it and combine with the tindex.
+                        // But more efficient to just store it directly.
+                        unsigned ptindex = convert_struct_offset(ctx, lt, offs + fsz);
+                        if (fsz > 0 && !fval_info.isghost) {
+                            Type *ET = IntegerType::get(jl_LLVMContext, 8 * al);
+                            assert(lt->getStructElementType(llvm_idx) == ET);
+                            AllocaInst *lv = emit_static_alloca(ctx, ET);
+                            lv->setOperand(0, ConstantInt::get(T_int32, (fsz + al - 1) / al));
+                            emit_unionmove(ctx, lv, tbaa_stack, fval_info, nullptr);
+                            // emit all of the align-sized words
+                            unsigned i = 0;
+                            for (; i < fsz / al; i++) {
+                                Value *fldp = ctx.builder.CreateConstInBoundsGEP1_32(ET, lv, i);
+                                Value *fldv = tbaa_decorate(tbaa_stack, ctx.builder.CreateLoad(ET, fldp));
+                                strct = ctx.builder.CreateInsertValue(strct, fldv, makeArrayRef(llvm_idx + i));
+                            }
+                            // emit remaining bytes up to tindex
+                            if (i < ptindex - llvm_idx) {
+                                Value *staddr = ctx.builder.CreateConstInBoundsGEP1_32(ET, lv, i);
+                                staddr = ctx.builder.CreateBitCast(staddr, T_pint8);
+                                for (; i < ptindex - llvm_idx; i++) {
+                                    Value *fldp = ctx.builder.CreateConstInBoundsGEP1_32(T_int8, staddr, i);
+                                    Value *fldv = tbaa_decorate(tbaa_stack, ctx.builder.CreateLoad(T_int8, fldp));
+                                    strct = ctx.builder.CreateInsertValue(strct, fldv, makeArrayRef(llvm_idx + i));
+                                }
+                            }
+                        }
+                        llvm_idx = ptindex;
+                        fval = tindex;
+                        if (jl_is_vecelement_type(ty))
+                            fval = ctx.builder.CreateInsertValue(strct, fval, makeArrayRef(llvm_idx));
+                    }
+                    else {
+                        Value *ptindex = emit_struct_gep(ctx, lt, strct, offs + fsz);
+                        tbaa_decorate(tbaa_unionselbyte, ctx.builder.CreateStore(tindex, ptindex));
+                        if (!rhs_union.isghost)
+                            emit_unionmove(ctx, dest, tbaa_stack, fval_info, nullptr);
+                    }
                 }
                 else {
                     fval = emit_unbox(ctx, fty, fval_info, jtype, dest, tbaa_stack);
                 }
                 if (init_as_value) {
                     assert(fval);
-                    if (lt->isVectorTy())
-                        strct = ctx.builder.CreateInsertElement(strct, fval, ConstantInt::get(T_int32, llvm_idx));
-                    else if (jl_is_vecelement_type(ty))
+                    if (jl_is_vecelement_type(ty))
                         strct = fval;  // VecElement type comes unwrapped in LLVM.
+                    else if (lt->isVectorTy())
+                        strct = ctx.builder.CreateInsertElement(strct, fval, ConstantInt::get(T_int32, llvm_idx));
                     else if (lt->isAggregateType())
-                        strct = ctx.builder.CreateInsertValue(strct, fval, ArrayRef<unsigned>(&i, 1));
+                        strct = ctx.builder.CreateInsertValue(strct, fval, makeArrayRef(llvm_idx));
                     else
                         assert(false);
                 }
             }
             for (size_t i = nargs; i < nf; i++) {
                 if (!jl_field_isptr(sty, i) && jl_is_uniontype(jl_field_type(sty, i))) {
-                    tbaa_decorate(tbaa_unionselbyte, ctx.builder.CreateStore(
-                            ConstantInt::get(T_int8, 0),
-                            ctx.builder.CreateInBoundsGEP(
-                                T_int8,
-                                emit_bitcast(ctx, strct, T_pint8),
-                                ConstantInt::get(T_size, jl_field_offset(sty, i) + jl_field_size(sty, i) - 1))));
+                    unsigned offs = jl_field_offset(sty, i);
+                    int fsz = jl_field_size(sty, i) - 1;
+                    unsigned llvm_idx = convert_struct_offset(ctx, cast<StructType>(lt), offs + fsz);
+                    if (init_as_value)
+                        strct = ctx.builder.CreateInsertValue(strct, ConstantInt::get(T_int8, 0), makeArrayRef(llvm_idx));
+                    else
+                        tbaa_decorate(tbaa_unionselbyte, ctx.builder.CreateStore(
+                                ConstantInt::get(T_int8, 0),
+                                ctx.builder.CreateConstInBoundsGEP2_32(lt, strct, 0, llvm_idx)));
                 }
             }
             if (type_is_ghost(lt))
@@ -2587,14 +2804,7 @@ static jl_cgval_t emit_new_struct(jl_cod
                                      literal_pointer_val(ctx, (jl_value_t*)ty));
         jl_cgval_t strctinfo = mark_julia_type(ctx, strct, true, ty);
         strct = decay_derived(strct);
-        for (size_t i = 0; i < nf; i++) {
-            if (jl_field_isptr(sty, i)) {
-                tbaa_decorate(strctinfo.tbaa, ctx.builder.CreateStore(
-                        ConstantPointerNull::get(cast<PointerType>(T_prjlvalue)),
-                        ctx.builder.CreateInBoundsGEP(T_prjlvalue, emit_bitcast(ctx, strct, T_pprjlvalue),
-                                ConstantInt::get(T_size, jl_field_offset(sty, i) / sizeof(void*)))));
-            }
-        }
+        undef_derived_strct(ctx.builder, strct, sty, strctinfo.tbaa);
         for (size_t i = nargs; i < nf; i++) {
             if (!jl_field_isptr(sty, i) && jl_is_uniontype(jl_field_type(sty, i))) {
                 tbaa_decorate(tbaa_unionselbyte, ctx.builder.CreateStore(
@@ -2603,12 +2813,14 @@ static jl_cgval_t emit_new_struct(jl_cod
                                 ConstantInt::get(T_size, jl_field_offset(sty, i) + jl_field_size(sty, i) - 1))));
             }
         }
-        bool need_wb = false;
         // TODO: verify that nargs <= nf (currently handled by front-end)
         for (size_t i = 0; i < nargs; i++) {
             const jl_cgval_t &rhs = argv[i];
-            if (jl_field_isptr(sty, i) && !rhs.isboxed)
-                need_wb = true;
+            bool need_wb; // set to true if the store might cause the allocation of a box newer than the struct
+            if (jl_field_isptr(sty, i))
+                need_wb = !rhs.isboxed;
+            else
+                need_wb = false;
             emit_typecheck(ctx, rhs, jl_svecref(sty->types, i), "new");
             emit_setfield(ctx, sty, strctinfo, i, rhs, false, need_wb);
         }
diff -pruN 1.3.1+dfsg-1/src/clangsa/GCChecker.cpp 1.4.0+dfsg-1/src/clangsa/GCChecker.cpp
--- 1.3.1+dfsg-1/src/clangsa/GCChecker.cpp	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/src/clangsa/GCChecker.cpp	2020-03-21 16:36:32.000000000 +0000
@@ -12,19 +12,36 @@
 #include "clang/StaticAnalyzer/Core/BugReporter/CommonBugCategories.h"
 #include "clang/StaticAnalyzer/Frontend/AnalysisConsumer.h"
 #include "clang/StaticAnalyzer/Checkers/SValExplainer.h"
-#if LLVM_VERSION_MAJOR >= 9
+#if LLVM_VERSION_MAJOR >= 8
 #include "clang/StaticAnalyzer/Frontend/CheckerRegistry.h"
 #else
 #include "clang/StaticAnalyzer/Core/CheckerRegistry.h"
 #endif
+
 #include <iostream>
+#include <memory>
+
+#if defined(__GNUC__)
+#  define USED_FUNC __attribute__((used))
+#elif defined(_COMPILER_MICROSOFT_)
+// Does MSVC have this?
+#  define USED_FUNC
+#else
+#  define USED_FUNC
+#endif
+
+#if LLVM_VERSION_MAJOR >= 10
+using std::make_unique;
+#else
+using llvm::make_unique;
+#endif
 
 namespace {
     using namespace clang;
     using namespace ento;
 
     #define PDP std::shared_ptr<PathDiagnosticPiece>
-    #define MakePDP llvm::make_unique<PathDiagnosticEventPiece>
+    #define MakePDP make_unique<PathDiagnosticEventPiece>
 
     class GCChecker : public Checker<eval::Call,
                                             check::BeginFunction,
@@ -164,7 +181,6 @@ namespace {
 
         static bool isGCTrackedType(QualType Type);
         bool isGloballyRootedType(QualType Type) const;
-        bool isBundleOfGCValues(QualType QT) const;
         static void dumpState(const ProgramStateRef &State);
         static bool declHasAnnotation(const clang::Decl *D, const char *which);
         static bool isFDAnnotatedNotSafepoint(const clang::FunctionDecl *FD);
@@ -211,7 +227,7 @@ namespace {
           }
 
           PDP VisitNode(const ExplodedNode *N,
-#if LLVM_VERSION_MAJOR <= 8
+#if LLVM_VERSION_MAJOR < 8
                         const ExplodedNode *PrevN,
 #endif
                         BugReporterContext &BRC,
@@ -242,7 +258,7 @@ namespace {
               const ExplodedNode *N, PathDiagnosticLocation Pos, BugReporterContext &BRC, BugReport &BR);
 
           PDP VisitNode(const ExplodedNode *N,
-#if LLVM_VERSION_MAJOR <= 8
+#if LLVM_VERSION_MAJOR < 8
                                                          const ExplodedNode *PrevN,
 #endif
                                                          BugReporterContext &BRC,
@@ -287,12 +303,6 @@ SymbolRef GCChecker::walkToRoot(callback
 
 
 namespace Helpers {
-  static SymbolRef trySuperRegion(SValExplainer &Ex, ProgramStateRef State, SVal Val) {
-      const MemRegion *R = Val.getAsRegion();
-      const SubRegion *SR = R->getAs<SubRegion>();
-      return SR ? State->getSVal(SR->getSuperRegion()).getAsSymbol() : nullptr;
-  }
-
   static const VarRegion *walk_back_to_global_VR(const MemRegion *Region) {
     if (!Region)
         return nullptr;
@@ -326,7 +336,7 @@ namespace Helpers {
 
 PDP GCChecker::GCBugVisitor::VisitNode(
   const ExplodedNode *N,
-#if LLVM_VERSION_MAJOR <= 8
+#if LLVM_VERSION_MAJOR < 8
   const ExplodedNode *,
 #endif
   BugReporterContext &BRC, BugReport &BR) {
@@ -385,13 +395,13 @@ PDP GCChecker::GCValueBugVisitor::Explai
     const ValueState *ValS = N->getState()->get<GCValueMap>(Parent);
     assert(ValS);
     if (ValS->isPotentiallyFreed()) {
-        BR.addVisitor(llvm::make_unique<GCValueBugVisitor>(Parent));
+        BR.addVisitor(make_unique<GCValueBugVisitor>(Parent));
         return MakePDP(Pos, "Root not propagated because it may have been freed. Tracking.");
     } else if (ValS->isRooted()) {
-        BR.addVisitor(llvm::make_unique<GCValueBugVisitor>(Parent));
+        BR.addVisitor(make_unique<GCValueBugVisitor>(Parent));
         return MakePDP(Pos, "Root was not propagated due to a bug. Tracking base value.");
     } else {
-        BR.addVisitor(llvm::make_unique<GCValueBugVisitor>(Parent));
+        BR.addVisitor(make_unique<GCValueBugVisitor>(Parent));
         return MakePDP(Pos, "No Root to propagate. Tracking.");
     }
 }
@@ -425,7 +435,7 @@ PDP GCChecker::GCValueBugVisitor::Explai
 
 PDP GCChecker::GCValueBugVisitor::VisitNode(
   const ExplodedNode *N,
-#if LLVM_VERSION_MAJOR <= 8
+#if LLVM_VERSION_MAJOR < 8
   const ExplodedNode *,
 #endif
   BugReporterContext &BRC, BugReport &BR) {
@@ -451,7 +461,7 @@ PDP GCChecker::GCValueBugVisitor::VisitN
             if (NewValueState->FD) {
                 bool isFunctionSafepoint = !isFDAnnotatedNotSafepoint(NewValueState->FD);
                 bool maybeUnrooted = declHasAnnotation(NewValueState->PVD, "julia_maybe_unrooted");
-                assert(isFunctionSafepoint || maybeUnrooted);
+                assert(isFunctionSafepoint || maybeUnrooted); (void)maybeUnrooted;
                 Pos = PathDiagnosticLocation{NewValueState->PVD,
                                              BRC.getSourceManager()};
                 if (!isFunctionSafepoint)
@@ -504,8 +514,8 @@ void GCChecker::report_error(callback f,
     if (!BT)
         BT.reset(new BugType(this, "Invalid GC thingy",
                            categories::LogicError));
-    auto Report = llvm::make_unique<BugReport>(*BT, message, N);
-    Report->addVisitor(llvm::make_unique<GCBugVisitor>());
+    auto Report = make_unique<BugReport>(*BT, message, N);
+    Report->addVisitor(make_unique<GCBugVisitor>());
     f(Report.get());
     C.emitReport(std::move(Report));
 }
@@ -520,10 +530,10 @@ void GCChecker::report_value_error(Check
     if (!BT)
         BT.reset(new BugType(this, "Invalid GC thingy",
                            categories::LogicError));
-    auto Report = llvm::make_unique<BugReport>(*BT, message, N);
-    Report->addVisitor(llvm::make_unique<GCValueBugVisitor>(Sym));
-    Report->addVisitor(llvm::make_unique<GCBugVisitor>());
-    Report->addVisitor(llvm::make_unique<ConditionBRVisitor>());
+    auto Report = make_unique<BugReport>(*BT, message, N);
+    Report->addVisitor(make_unique<GCValueBugVisitor>(Sym));
+    Report->addVisitor(make_unique<GCBugVisitor>());
+    Report->addVisitor(make_unique<ConditionBRVisitor>());
     if (!range.isInvalid()) {
         Report->addRange(range);
     }
@@ -684,14 +694,6 @@ bool GCChecker::isFDAnnotatedNotSafepoin
     return declHasAnnotation(FD, "julia_not_safepoint");
 }
 
-bool GCChecker::isBundleOfGCValues(QualType QT) const {
-    return isJuliaType([](StringRef Name) {
-      if (Name.endswith_lower("typemap_intersection_env"))
-          return true;
-      return false;
-    }, QT);
-}
-
 bool GCChecker::isGCTrackedType(QualType QT) {
     return isValueCollection(QT) || isJuliaType([](StringRef Name) {
         if (Name.endswith_lower("jl_value_t") ||
@@ -749,23 +751,8 @@ bool GCChecker::isGloballyRootedType(Qua
 bool GCChecker::isSafepoint(const CallEvent &Call) const
 {
   bool isCalleeSafepoint = true;
-  if (Call.isGlobalCFunction("malloc") ||
-      Call.isGlobalCFunction("memcpy") ||
-      Call.isGlobalCFunction("memset") ||
-      Call.isGlobalCFunction("memcmp") ||
-      Call.isGlobalCFunction("mmap") ||
-      Call.isGlobalCFunction("munmap") ||
-      Call.isGlobalCFunction("mprotect") ||
-      Call.isGlobalCFunction("madvise") ||
-      Call.isGlobalCFunction("write") ||
-      Call.isGlobalCFunction("vasprintf") ||
-      Call.isGlobalCFunction("strrchr") ||
-      Call.isGlobalCFunction("free") ||
-      Call.isGlobalCFunction("__assert_fail") ||
-      Call.isGlobalCFunction("fflush") ||
-      Call.isGlobalCFunction("__isnan") ||
-      Call.isGlobalCFunction("__isnanf"))
-  {
+  if (Call.isInSystemHeader()) {
+      // defined by -isystem per https://clang.llvm.org/docs/UsersManual.html#controlling-diagnostics-in-system-headers
       isCalleeSafepoint = false;
   } else {
     auto *Decl = Call.getDecl();
@@ -783,14 +770,22 @@ bool GCChecker::isSafepoint(const CallEv
       if (const TypedefType *TDT = dyn_cast<TypedefType>(Callee->getType())) {
         isCalleeSafepoint = !declHasAnnotation(TDT->getDecl(), "julia_not_safepoint");
       }
+      else if (const CXXPseudoDestructorExpr *PDE = dyn_cast<CXXPseudoDestructorExpr>(Callee)) {
+        // A pseudo-destructor is an expression that looks like a member
+        // access to a destructor of a scalar type. A pseudo-destructor
+        // expression has no run-time semantics beyond evaluating the base
+        // expression (which would have it's own CallEvent, if applicable).
+        isCalleeSafepoint = false;
+      }
     } else if (FD) {
-      if (FD->getBuiltinID() != 0)
+      if (FD->getBuiltinID() != 0 || FD->isTrivial())
         isCalleeSafepoint = false;
-      else if ((FD->getName().startswith_lower("uv_") ||
+      else if (FD->getDeclName().isIdentifier() &&
+               (FD->getName().startswith_lower("uv_") ||
                 FD->getName().startswith_lower("unw_") ||
                 FD->getName().startswith("_U")) &&
                FD->getName() != "uv_run")
-          isCalleeSafepoint = false;
+        isCalleeSafepoint = false;
       else
         isCalleeSafepoint = !isFDAnnotatedNotSafepoint(FD);
     }
@@ -1149,7 +1144,7 @@ void GCChecker::checkPostStmt(const Unar
     }
 }
 
-void GCChecker::dumpState(const ProgramStateRef &State) {
+USED_FUNC void GCChecker::dumpState(const ProgramStateRef &State) {
     GCValueMapTy AMap = State->get<GCValueMap>();
     llvm::raw_ostream &Out = llvm::outs();
     Out << "State: " << "\n";
diff -pruN 1.3.1+dfsg-1/src/codegen.cpp 1.4.0+dfsg-1/src/codegen.cpp
--- 1.3.1+dfsg-1/src/codegen.cpp	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/src/codegen.cpp	2020-03-21 16:36:32.000000000 +0000
@@ -210,6 +210,7 @@ static MDNode *tbaa_gcframe;    // GC fr
 // LLVM should have enough info for alias analysis of non-gcframe stack slot
 // this is mainly a place holder for `jl_cgval_t::tbaa`
 static MDNode *tbaa_stack;      // stack slot
+static MDNode *tbaa_unionselbyte;   // a selector byte in isbits Union struct fields
 static MDNode *tbaa_data;       // Any user data that `pointerset/ref` are allowed to alias
 static MDNode *tbaa_binding;        // jl_binding_t::value
 static MDNode *tbaa_value;          // jl_value_t, that is not jl_array_t
@@ -217,7 +218,6 @@ static MDNode *tbaa_mutab;
 static MDNode *tbaa_immut;              // immutable type
 static MDNode *tbaa_ptrarraybuf;    // Data in an array of boxed values
 static MDNode *tbaa_arraybuf;       // Data in an array of POD
-static MDNode *tbaa_unionselbyte;   // a selector byte in isbits Union struct fields
 static MDNode *tbaa_array;      // jl_array_t
 static MDNode *tbaa_arrayptr;       // The pointer inside a jl_array_t
 static MDNode *tbaa_arraysize;      // A size in a jl_array_t
@@ -296,7 +296,7 @@ static Function *jlsubtype_func;
 static Function *jlapplytype_func;
 static Function *jl_object_id__func;
 static Function *setjmp_func;
-static Function *memcmp_derived_func;
+static Function *memcmp_func;
 static Function *box_int8_func;
 static Function *box_uint8_func;
 static Function *box_int16_func;
@@ -338,7 +338,13 @@ static std::map<jl_fptr_args_t, Function
 extern "C" {
     int globalUnique = 0;
     int jl_default_debug_info_kind = (int) DICompileUnit::DebugEmissionKind::FullDebug;
-    jl_cgparams_t jl_default_cgparams = {1, 1, 1, 1, 0, 1, jl_default_debug_info_kind, NULL, NULL, NULL, NULL, NULL};
+    jl_cgparams_t jl_default_cgparams = {1, 1, 1, 1, 0,
+#ifdef _OS_WINDOWS_
+        0,
+#else
+        1,
+#endif
+        jl_default_debug_info_kind, NULL, NULL, NULL, NULL, NULL};
 }
 
 template<typename T>
@@ -359,12 +365,43 @@ static MDNode *best_tbaa(jl_value_t *jt)
 }
 
 // tracks whether codegen is currently able to simply stack-allocate this type
-// note that this is guaranteed to include jl_isbits
-static bool jl_justbits(jl_value_t* t)
+// note that this includes jl_isbits, although codegen should work regardless
+static bool jl_is_concrete_immutable(jl_value_t* t)
+{
+    return jl_is_immutable_datatype(t) && ((jl_datatype_t*)t)->layout;
+}
+
+static bool jl_is_pointerfree(jl_value_t* t)
+{
+    if (!jl_is_immutable_datatype(t))
+        return 0;
+    const jl_datatype_layout_t *layout = ((jl_datatype_t*)t)->layout;
+    return layout && layout->npointers == 0;
+}
+
+// these queries are usually related, but we split them out here
+// for convenience and clarity (and because it changes the calling convention)
+static bool deserves_stack(jl_value_t* t, bool pointerfree=false)
+{
+    if (!jl_is_concrete_immutable(t))
+        return false;
+    return ((jl_datatype_t*)t)->isinlinealloc;
+}
+static bool deserves_argbox(jl_value_t* t)
+{
+    return !deserves_stack(t);
+}
+static bool deserves_retbox(jl_value_t* t)
+{
+    return deserves_argbox(t);
+}
+static bool deserves_sret(jl_value_t *dt, Type *T)
 {
-    return jl_is_immutable_datatype(t) && ((jl_datatype_t*)t)->layout && ((jl_datatype_t*)t)->layout->npointers == 0;
+    assert(jl_is_datatype(dt));
+    return (size_t)jl_datatype_size(dt) > sizeof(void*) && !T->isFloatingPointTy() && !T->isVectorTy();
 }
 
+
 // metadata tracking for a llvm Value* during codegen
 struct jl_cgval_t {
     Value *V; // may be of type T* or T, or set to NULL if ghost (or if the value has not been initialized yet, for a variable definition)
@@ -486,6 +523,7 @@ struct jl_returninfo_t {
     size_t union_bytes;
     size_t union_align;
     size_t union_minalign;
+    unsigned return_roots;
 };
 
 static jl_returninfo_t get_specsig_function(Module *M, const std::string &name, jl_value_t *sig, jl_value_t *jlrettype);
@@ -517,7 +555,6 @@ public:
     MDNode *aliasscope = NULL;
     std::string funcName;
     int vaSlot = -1;        // name of vararg argument
-    bool has_sret = false;
     int nReqArgs = 0;
     int nargs = 0;
     int nvargs = -1;
@@ -551,6 +588,7 @@ static CallInst *emit_jlcall(jl_codectx_
 static Value *literal_pointer_val(jl_codectx_t &ctx, jl_value_t *p);
 static GlobalVariable *prepare_global_in(Module *M, GlobalVariable *G);
 #define prepare_global(G) prepare_global_in(jl_Module, (G))
+static Instruction *tbaa_decorate(MDNode *md, Instruction *load_or_store);
 
 // --- convenience functions for tagging llvm values with julia types ---
 
@@ -567,13 +605,26 @@ static GlobalVariable *get_pointer_to_co
     return gv;
 }
 
-static AllocaInst *emit_static_alloca(jl_codectx_t &ctx, Type *lty, int arraysize=1)
+static AllocaInst *emit_static_alloca(jl_codectx_t &ctx, Type *lty)
 {
-    return new AllocaInst(lty,
-            0,
-            ConstantInt::get(T_int32, arraysize), "", /*InsertBefore=*/ctx.ptlsStates);
+    return new AllocaInst(lty, 0, "", /*InsertBefore=*/ctx.ptlsStates);
 }
 
+static void undef_derived_strct(IRBuilder<> &irbuilder, Value *ptr, jl_datatype_t *sty, MDNode *tbaa)
+{
+    assert(ptr->getType()->getPointerAddressSpace() != AddressSpace::Tracked);
+    size_t i, np = sty->layout->npointers;
+    if (np == 0)
+        return;
+    ptr = irbuilder.CreateBitCast(ptr, T_prjlvalue->getPointerTo(ptr->getType()->getPointerAddressSpace()));
+    Value *V_null = ConstantPointerNull::get(cast<PointerType>(T_prjlvalue));
+    for (i = 0; i < np; i++) {
+        Value *fld = irbuilder.CreateConstInBoundsGEP1_32(T_prjlvalue, ptr, jl_ptr_offset(sty, i));
+        tbaa_decorate(tbaa, irbuilder.CreateStore(V_null, fld));
+    }
+}
+
+
 static inline jl_cgval_t ghostValue(jl_value_t *typ)
 {
     if (typ == jl_bottom_type)
@@ -622,11 +673,25 @@ static inline jl_cgval_t mark_julia_slot
     return tagval;
 }
 
+static bool valid_as_globalinit(const Value *v) {
+    if (isa<ConstantExpr>(v)) {
+        // llvm can't handle all the things that could be inside a ConstantExpr
+        // (such as addrspacecast), and we don't really mind losing this optimization
+        return false;
+    }
+    if (const auto *CC = dyn_cast<ConstantAggregate>(v)) {
+        for (const Value *elem : CC->operand_values())
+            if (!valid_as_globalinit(elem))
+                return false;
+    }
+    return isa<Constant>(v);
+}
+
 static inline jl_cgval_t value_to_pointer(jl_codectx_t &ctx, Value *v, jl_value_t *typ, Value *tindex)
 {
     Value *loc;
-    if (Constant *cv = dyn_cast<Constant>(v)) {
-        loc = get_pointer_to_constant(cv, "", *jl_Module);
+    if (valid_as_globalinit(v)) { // llvm can't handle all the things that could be inside a ConstantExpr
+        loc = get_pointer_to_constant(cast<Constant>(v), "", *jl_Module);
     }
     else {
         loc = emit_static_alloca(ctx, v->getType());
@@ -658,7 +723,7 @@ static inline jl_cgval_t mark_julia_type
     if (type_is_ghost(T)) {
         return ghostValue(typ);
     }
-    if (v && !isboxed && v->getType()->isAggregateType()) {
+    if (v && !isboxed && v->getType()->isAggregateType() && !jl_is_vecelement_type(typ) && CountTrackedPointers(v->getType()).count == 0) {
         // eagerly put this back onto the stack
         // llvm mem2reg pass will remove this if unneeded
         return value_to_pointer(ctx, v, typ, NULL);
@@ -689,7 +754,7 @@ static inline jl_cgval_t update_julia_ty
         if (jl_is_datatype(utyp)) {
             bool alwaysboxed;
             if (jl_is_concrete_type(utyp))
-                alwaysboxed = !jl_justbits(utyp);
+                alwaysboxed = !jl_is_pointerfree(utyp);
             else
                 alwaysboxed = !((jl_datatype_t*)utyp)->abstract && ((jl_datatype_t*)utyp)->mutabl;
             if (alwaysboxed) {
@@ -772,8 +837,6 @@ static void CreateConditionalAbort(IRBui
 #endif
 #endif
 
-static void emit_write_barrier(jl_codectx_t&, Value*, Value*);
-
 #include "cgutils.cpp"
 
 static void jl_rethrow_with_add(const char *fmt, ...)
@@ -950,7 +1013,7 @@ static jl_cgval_t convert_julia_type(jl_
         return ghostValue(typ);
     Value *new_tindex = NULL;
     if (jl_is_concrete_type(typ)) {
-        if (v.TIndex && !jl_justbits(typ)) {
+        if (v.TIndex && !jl_is_pointerfree(typ)) {
             // discovered that this union-split type must actually be isboxed
             if (v.Vboxed) {
                 return jl_cgval_t(v.Vboxed, nullptr, true, typ, NULL);
@@ -1622,7 +1685,7 @@ void *jl_get_llvmf_decl(jl_method_instan
         // internal error
         return NULL;
 
-    const jl_llvm_functions_t &decls = codeinst->functionObjectsDecls;
+    jl_llvm_functions_t decls = codeinst->functionObjectsDecls;
     if (decls.functionObject == NULL && codeinst->invoke == jl_fptr_const_return && jl_is_method(mi->def.method)) {
         // normally we don't generate native code for these functions, so need an exception here
         // This leaks a bit of memory to cache native code that we'll never actually need
@@ -1636,6 +1699,7 @@ void *jl_get_llvmf_decl(jl_method_instan
             if (codeinst == NULL)
                 // internal error
                 return NULL;
+            decls = codeinst->functionObjectsDecls;
         }
         JL_UNLOCK(&codegen_lock);
     }
@@ -2214,7 +2278,29 @@ static jl_cgval_t emit_getfield(jl_codec
     return mark_julia_type(ctx, result, true, jl_any_type);
 }
 
-static Value *emit_bits_compare(jl_codectx_t &ctx, const jl_cgval_t &arg1, const jl_cgval_t &arg2);
+static Value *emit_box_compare(jl_codectx_t &ctx, const jl_cgval_t &arg1, const jl_cgval_t &arg2)
+{
+    if (jl_pointer_egal(arg1.typ) || jl_pointer_egal(arg2.typ)) {
+        Value *varg1 = arg1.constant ? literal_pointer_val(ctx, arg1.constant) : arg1.V;
+        Value *varg2 = arg2.constant ? literal_pointer_val(ctx, arg2.constant) : arg2.V;
+        assert(varg1 && varg2 && (arg1.isboxed || arg1.TIndex) && (arg2.isboxed || arg2.TIndex) &&
+                "Only boxed types are valid for pointer comparison.");
+        varg1 = maybe_decay_tracked(varg1);
+        varg2 = maybe_decay_tracked(varg2);
+        if (cast<PointerType>(varg1->getType())->getAddressSpace() != cast<PointerType>(varg2->getType())->getAddressSpace()) {
+            varg1 = decay_derived(varg1);
+            varg2 = decay_derived(varg2);
+        }
+        return ctx.builder.CreateICmpEQ(emit_bitcast(ctx, varg1, T_pint8),
+                                        emit_bitcast(ctx, varg2, T_pint8));
+    }
+
+    Value *varg1 = mark_callee_rooted(boxed(ctx, arg1));
+    Value *varg2 = mark_callee_rooted(boxed(ctx, arg2));
+    return ctx.builder.CreateTrunc(ctx.builder.CreateCall(prepare_call(jlegal_func), {varg1, varg2}), T_int1);
+}
+
+static Value *emit_bits_compare(jl_codectx_t &ctx, jl_cgval_t arg1, jl_cgval_t arg2);
 
 static Value *emit_bitsunion_compare(jl_codectx_t &ctx, const jl_cgval_t &arg1, const jl_cgval_t &arg2)
 {
@@ -2248,7 +2334,7 @@ static Value *emit_bitsunion_compare(jl_
     return ctx.builder.CreateAnd(phi, ctx.builder.CreateICmpEQ(arg1.TIndex, arg2.TIndex));
 }
 
-static Value *emit_bits_compare(jl_codectx_t &ctx, const jl_cgval_t &arg1, const jl_cgval_t &arg2)
+static Value *emit_bits_compare(jl_codectx_t &ctx, jl_cgval_t arg1, jl_cgval_t arg2)
 {
     bool isboxed;
     Type *at = julia_type_to_llvm(arg1.typ, &isboxed);
@@ -2283,62 +2369,92 @@ static Value *emit_bits_compare(jl_codec
     }
 
     if (at->isAggregateType()) { // Struct or Array
-        assert(arg1.ispointer() && arg2.ispointer());
         jl_datatype_t *sty = (jl_datatype_t*)arg1.typ;
         size_t sz = jl_datatype_size(sty);
-        Value *varg1 = maybe_decay_tracked(data_pointer(ctx, arg1));
-        Value *varg2 = maybe_decay_tracked(data_pointer(ctx, arg2));
+        Value *varg1 = arg1.ispointer() ? maybe_decay_tracked(data_pointer(ctx, arg1)) : arg1.V;
+        Value *varg2 = arg2.ispointer() ? maybe_decay_tracked(data_pointer(ctx, arg2)) : arg2.V;
         if (sz > 512 && !sty->layout->haspadding) {
-            varg1 = decay_derived(varg1);
-            varg2 = decay_derived(varg2);
-            Value *answer = ctx.builder.CreateCall(prepare_call(memcmp_derived_func), {
-                        maybe_bitcast(ctx, varg1, T_pint8),
-                        maybe_bitcast(ctx, varg2, T_pint8),
-                        ConstantInt::get(T_size, sz)
-                    });
+            if (!arg1.ispointer())
+                varg1 = value_to_pointer(ctx, arg1).V;
+            if (!arg2.ispointer())
+                varg2 = value_to_pointer(ctx, arg2).V;
+            varg1 = emit_pointer_from_objref(ctx, varg1);
+            varg2 = emit_pointer_from_objref(ctx, varg2);
+            Value *gc_uses[2];
+            int nroots = 0;
+            if ((gc_uses[nroots] = get_gc_root_for(arg1)))
+                nroots++;
+            if ((gc_uses[nroots] = get_gc_root_for(arg2)))
+                nroots++;
+            OperandBundleDef OpBundle("jl_roots", gc_uses);
+            Value *answer = ctx.builder.CreateCall(prepare_call(memcmp_func), {
+                        ctx.builder.CreateBitCast(varg1, T_pint8),
+                        ctx.builder.CreateBitCast(varg2, T_pint8),
+                        ConstantInt::get(T_size, sz) },
+                    ArrayRef<OperandBundleDef>(&OpBundle, nroots ? 1 : 0));
             return ctx.builder.CreateICmpEQ(answer, ConstantInt::get(T_int32, 0));
         }
         else {
             Type *atp = at->getPointerTo();
-            if (cast<PointerType>(varg1->getType())->getAddressSpace() != cast<PointerType>(varg2->getType())->getAddressSpace()) {
-                varg1 = decay_derived(varg1);
-                varg2 = decay_derived(varg2);
-            }
-            varg1 = maybe_bitcast(ctx, varg1, atp);
-            varg2 = maybe_bitcast(ctx, varg2, atp);
+            if (arg1.ispointer())
+                varg1 = maybe_bitcast(ctx, varg1, atp);
+            if (arg2.ispointer())
+                varg2 = maybe_bitcast(ctx, varg2, atp);
             jl_svec_t *types = sty->types;
             Value *answer = ConstantInt::get(T_int1, 1);
             for (size_t i = 0, l = jl_svec_len(types); i < l; i++) {
+                // TODO: should we replace this with `subAns = emit_f_is(emit_getfield_knownidx(ctx, arg1, i, arg1.typ), emit_getfield_knownidx(ctx, arg2, i, arg2.typ))`
+                // or is there any value in all this extra effort??
                 jl_value_t *fldty = jl_svecref(types, i);
                 if (type_is_ghost(julia_type_to_llvm(fldty)))
                     continue;
                 unsigned byte_offset = jl_field_offset(sty, i);
                 Value *subAns, *fld1, *fld2;
-                if (isa<StructType>(at)) {
-                    fld1 = emit_struct_gep(ctx, at, varg1, byte_offset);
-                    fld2 = emit_struct_gep(ctx, at, varg2, byte_offset);
-                }
-                else {
-                    fld1 = ctx.builder.CreateConstInBoundsGEP2_32(at, varg1, 0, i);
-                    fld2 = ctx.builder.CreateConstInBoundsGEP2_32(at, varg2, 0, i);
+                unsigned llvm_idx = (i > 0 && isa<StructType>(at)) ? convert_struct_offset(ctx, at, byte_offset) : i;
+                if (arg1.ispointer())
+                    fld1 = ctx.builder.CreateConstInBoundsGEP2_32(at, varg1, 0, llvm_idx);
+                else
+                    fld1 = ctx.builder.CreateExtractValue(varg1, llvm_idx);
+                if (arg2.ispointer())
+                    fld2 = ctx.builder.CreateConstInBoundsGEP2_32(at, varg2, 0, llvm_idx);
+                else
+                    fld2 = ctx.builder.CreateExtractValue(varg2, llvm_idx);
+                if (jl_field_isptr(sty, i)) {
+                    if (arg1.ispointer())
+                        fld1 = ctx.builder.CreateLoad(T_prjlvalue, fld1);
+                    if (arg2.ispointer())
+                        fld2 = ctx.builder.CreateLoad(T_prjlvalue, fld2);
+                    subAns = emit_box_compare(ctx,
+                            mark_julia_type(ctx, fld1, true, fldty),
+                            mark_julia_type(ctx, fld2, true, fldty));
                 }
-                if (jl_is_uniontype(fldty)) {
+                else if (jl_is_uniontype(fldty)) {
                     unsigned tindex_offset = byte_offset + jl_field_size(sty, i) - 1;
-                    Value *ptindex1 = emit_struct_gep(ctx, at, varg1, tindex_offset);
-                    Value *ptindex2 = emit_struct_gep(ctx, at, varg2, tindex_offset);
-                    Value *tindex1 = ctx.builder.CreateNUWAdd(ConstantInt::get(T_int8, 1),
-                            ctx.builder.CreateLoad(T_int8, ptindex1));
-                    Value *tindex2 = ctx.builder.CreateNUWAdd(ConstantInt::get(T_int8, 1),
-                            ctx.builder.CreateLoad(T_int8, ptindex2));
-                    subAns = emit_bitsunion_compare(ctx,
-                            mark_julia_slot(fld1, fldty, tindex1, arg1.tbaa),
-                            mark_julia_slot(fld2, fldty, tindex2, arg2.tbaa));
+                    jl_cgval_t fld1_info;
+                    jl_cgval_t fld2_info;
+                    if (arg1.ispointer()) {
+                        Value *tindex1 = ctx.builder.CreateNUWAdd(ConstantInt::get(T_int8, 1),
+                                ctx.builder.CreateLoad(T_int8, emit_struct_gep(ctx, at, varg1, tindex_offset)));
+                        fld1_info = mark_julia_slot(fld1, fldty, tindex1, arg1.tbaa);
+                    }
+                    else {
+                        fld1_info = emit_getfield_knownidx(ctx, arg1, i, sty);
+                    }
+                    if (arg2.ispointer()) {
+                        Value *tindex2 = ctx.builder.CreateNUWAdd(ConstantInt::get(T_int8, 1),
+                                ctx.builder.CreateLoad(T_int8, emit_struct_gep(ctx, at, varg2, tindex_offset)));
+                        fld2_info = mark_julia_slot(fld2, fldty, tindex2, arg2.tbaa);
+                    }
+                    else {
+                        fld2_info = emit_getfield_knownidx(ctx, arg2, i, sty);
+                    }
+                    subAns = emit_bitsunion_compare(ctx, fld1_info, fld2_info);
                 }
                 else {
                     assert(jl_is_concrete_type(fldty));
-                    subAns = emit_bits_compare(ctx,
-                            mark_julia_slot(fld1, fldty, NULL, arg1.tbaa),
-                            mark_julia_slot(fld2, fldty, NULL, arg2.tbaa));
+                    jl_cgval_t fld1_info = arg1.ispointer() ? mark_julia_slot(fld1, fldty, NULL, arg1.tbaa) : mark_julia_type(ctx, fld1, false, fldty);
+                    jl_cgval_t fld2_info = arg2.ispointer() ? mark_julia_slot(fld2, fldty, NULL, arg2.tbaa) : mark_julia_type(ctx, fld2, false, fldty);
+                    subAns = emit_bits_compare(ctx, fld1_info, fld2_info);
                 }
                 answer = ctx.builder.CreateAnd(answer, subAns);
             }
@@ -2377,8 +2493,8 @@ static Value *emit_f_is(jl_codectx_t &ct
     if (jl_type_intersection(rt1, rt2) == (jl_value_t*)jl_bottom_type) // types are disjoint (exhaustive test)
         return ConstantInt::get(T_int1, 0);
 
-    bool justbits1 = jl_justbits(rt1);
-    bool justbits2 = jl_justbits(rt2);
+    bool justbits1 = jl_is_concrete_immutable(rt1);
+    bool justbits2 = jl_is_concrete_immutable(rt2);
     if (justbits1 || justbits2) { // whether this type is unique'd by value
         jl_value_t *typ = justbits1 ? rt1 : rt2;
         if (rt1 == rt2)
@@ -2403,45 +2519,7 @@ static Value *emit_f_is(jl_codectx_t &ct
     // if (arg1.tindex || arg2.tindex)
     //   TODO: handle with emit_bitsunion_compare
 
-    int ptr_comparable = 0; // whether this type is unique'd by pointer
-    if (rt1 == (jl_value_t*)jl_symbol_type || rt2 == (jl_value_t*)jl_symbol_type)
-        ptr_comparable = 1;
-    if (jl_is_mutable_datatype(rt1) && // excludes abstract types
-        rt1 != (jl_value_t*)jl_string_type && // technically mutable, but compared by contents
-        rt1 != (jl_value_t*)jl_simplevector_type)
-        ptr_comparable = 1;
-    if (jl_is_mutable_datatype(rt2) && // excludes abstract types
-        rt2 != (jl_value_t*)jl_string_type && // technically mutable, but compared by contents
-        rt2 != (jl_value_t*)jl_simplevector_type)
-        ptr_comparable = 1;
-    if (jl_subtype(rt1, (jl_value_t*)jl_type_type) ||
-        jl_subtype(rt2, (jl_value_t*)jl_type_type)) {
-        // need to use typeseq for most types
-        ptr_comparable = 0;
-        if ((jl_is_type_type(rt1) && jl_is_concrete_type(jl_tparam0(rt1))) ||
-            (jl_is_type_type(rt2) && jl_is_concrete_type(jl_tparam0(rt2)))) {
-            // but can compare some types by pointer
-            ptr_comparable = 1;
-        }
-    }
-    if (ptr_comparable) {
-        Value *varg1 = arg1.constant ? literal_pointer_val(ctx, arg1.constant) : arg1.V;
-        Value *varg2 = arg2.constant ? literal_pointer_val(ctx, arg2.constant) : arg2.V;
-        assert(varg1 && varg2 && (arg1.isboxed || arg1.TIndex) && (arg2.isboxed || arg2.TIndex) &&
-                "Only boxed types are valid for pointer comparison.");
-        varg1 = maybe_decay_tracked(varg1);
-        varg2 = maybe_decay_tracked(varg2);
-        if (cast<PointerType>(varg1->getType())->getAddressSpace() != cast<PointerType>(varg2->getType())->getAddressSpace()) {
-            varg1 = decay_derived(varg1);
-            varg2 = decay_derived(varg2);
-        }
-        return ctx.builder.CreateICmpEQ(emit_bitcast(ctx, varg1, T_pint8),
-                                        emit_bitcast(ctx, varg2, T_pint8));
-    }
-
-    Value *varg1 = mark_callee_rooted(boxed(ctx, arg1));
-    Value *varg2 = mark_callee_rooted(boxed(ctx, arg2));
-    return ctx.builder.CreateTrunc(ctx.builder.CreateCall(prepare_call(jlegal_func), {varg1, varg2}), T_int1);
+    return emit_box_compare(ctx, arg1, arg2);
 }
 
 static bool emit_builtin_call(jl_codectx_t &ctx, jl_cgval_t *ret, jl_value_t *f,
@@ -2513,16 +2591,18 @@ static bool emit_builtin_call(jl_codectx
         }
     }
 
-    else if (f == jl_builtin__apply && nargs == 2 && ctx.vaSlot > 0) {
+    else if (((f == jl_builtin__apply && nargs == 2) ||
+              (f == jl_builtin__apply_iterate && nargs == 3)) && ctx.vaSlot > 0) {
+        int arg_start = f == jl_builtin__apply ? 2 : 3;
         // turn Core._apply(f, Tuple) ==> f(Tuple...) using the jlcall calling convention if Tuple is the va allocation
-        if (LoadInst *load = dyn_cast_or_null<LoadInst>(argv[2].V)) {
+        if (LoadInst *load = dyn_cast_or_null<LoadInst>(argv[arg_start].V)) {
             if (load->getPointerOperand() == ctx.slots[ctx.vaSlot].boxroot && ctx.argArray) {
-                Value *theF = maybe_decay_untracked(boxed(ctx, argv[1]));
+                Value *theF = maybe_decay_untracked(boxed(ctx, argv[arg_start-1]));
                 Value *nva = emit_n_varargs(ctx);
 #ifdef _P64
                 nva = ctx.builder.CreateTrunc(nva, T_int32);
 #endif
-                Value *theArgs = ctx.builder.CreateInBoundsGEP(ctx.argArray, ConstantInt::get(T_size, ctx.nReqArgs));
+                Value *theArgs = ctx.builder.CreateInBoundsGEP(T_prjlvalue, ctx.argArray, ConstantInt::get(T_size, ctx.nReqArgs));
                 Value *r = ctx.builder.CreateCall(prepare_call(jlapplygeneric_func), { theF, theArgs, nva });
                 *ret = mark_julia_type(ctx, r, true, jl_any_type);
                 return true;
@@ -2644,7 +2724,7 @@ static bool emit_builtin_call(jl_codectx
                         ConstantAsMetadata::get(ConstantInt::get(T_int8, union_max)) }));
                     AllocaInst *lv = emit_static_alloca(ctx, AT);
                     if (al > 1)
-                        lv->setAlignment(al);
+                        lv->setAlignment(Align(al));
                     emit_memcpy(ctx, lv, tbaa_arraybuf, ctx.builder.CreateInBoundsGEP(AT, data, idx), tbaa_arraybuf, elsz, al, false);
                     *ret = mark_julia_slot(lv, ety, ctx.builder.CreateNUWAdd(ConstantInt::get(T_int8, 1), tindex), tbaa_arraybuf);
                 }
@@ -2690,8 +2770,7 @@ static bool emit_builtin_call(jl_codectx
                     }
                     else {
                         PHINode *data_owner = NULL; // owner object against which the write barrier must check
-                        if (isboxed) { // if not boxed we don't need a write barrier
-                            assert(ary.isboxed);
+                        if (isboxed || (jl_is_datatype(ety) && ((jl_datatype_t*)ety)->layout->npointers > 0)) { // if elements are just bits, don't need a write barrier
                             Value *aryv = maybe_decay_untracked(boxed(ctx, ary));
                             Value *flags = emit_arrayflags(ctx, ary);
                             // the owner of the data is ary itself except if ary->how == 3
@@ -2779,13 +2858,13 @@ static bool emit_builtin_call(jl_codectx
                     if (load->getPointerOperand() == ctx.slots[ctx.vaSlot].boxroot && ctx.argArray) {
                         Value *valen = emit_n_varargs(ctx);
                         jl_cgval_t va_ary( // fake instantiation of a cgval, in order to call emit_bounds_check
-                                ctx.builder.CreateInBoundsGEP(ctx.argArray, ConstantInt::get(T_size, ctx.nReqArgs)),
+                                ctx.builder.CreateInBoundsGEP(T_prjlvalue, ctx.argArray, ConstantInt::get(T_size, ctx.nReqArgs)),
                                 NULL, false, NULL, NULL);
                         Value *idx = emit_unbox(ctx, T_size, fld, (jl_value_t*)jl_long_type);
                         jl_value_t *boundscheck = (nargs == 3 ? argv[3].constant : jl_true);
                         idx = emit_bounds_check(ctx, va_ary, NULL, idx, valen, boundscheck);
                         idx = ctx.builder.CreateAdd(idx, ConstantInt::get(T_size, ctx.nReqArgs));
-                        Instruction *v = ctx.builder.CreateLoad(ctx.builder.CreateInBoundsGEP(ctx.argArray, idx));
+                        Instruction *v = ctx.builder.CreateLoad(T_prjlvalue, ctx.builder.CreateInBoundsGEP(ctx.argArray, idx));
                         // if we know the result type of this load, we will mark that information here too
                         tbaa_decorate(tbaa_value, maybe_mark_load_dereferenceable(v, false, rt));
                         *ret = mark_julia_type(ctx, v, /*boxed*/ true, rt);
@@ -2836,8 +2915,11 @@ static bool emit_builtin_call(jl_codectx
                                 emit_datatype_nfields(ctx, emit_typeof_boxed(ctx, obj)),
                                 jl_true);
                         }
+                        bool isboxed = !jl_datatype_isinlinealloc(jt);
                         Value *ptr = maybe_decay_tracked(data_pointer(ctx, obj));
-                        *ret = typed_load(ctx, ptr, vidx, jt, obj.tbaa, nullptr, false);
+                        *ret = typed_load(ctx, ptr, vidx,
+                                isboxed ? (jl_value_t*)jl_any_type : jt,
+                                obj.tbaa, nullptr, false);
                         return true;
                     }
                 }
@@ -2924,8 +3006,8 @@ static bool emit_builtin_call(jl_codectx
                 Value *idx = emit_unbox(ctx, T_size, fld, (jl_value_t*)jl_long_type);
                 jl_value_t *boundscheck = (nargs == 3 ? argv[3].constant : jl_true);
                 emit_bounds_check(ctx, typ, (jl_value_t*)jl_datatype_type, idx, types_len, boundscheck);
-                Value *fieldtyp_p = ctx.builder.CreateInBoundsGEP(decay_derived(emit_bitcast(ctx, types_svec, T_pprjlvalue)), idx);
-                Value *fieldtyp = tbaa_decorate(tbaa_const, ctx.builder.CreateLoad(fieldtyp_p));
+                Value *fieldtyp_p = ctx.builder.CreateInBoundsGEP(T_prjlvalue, decay_derived(emit_bitcast(ctx, types_svec, T_pprjlvalue)), idx);
+                Value *fieldtyp = tbaa_decorate(tbaa_const, ctx.builder.CreateLoad(T_prjlvalue, fieldtyp_p));
                 *ret = mark_julia_type(ctx, fieldtyp, true, (jl_value_t*)jl_type_type);
                 return true;
             }
@@ -2939,7 +3021,7 @@ static bool emit_builtin_call(jl_codectx
         if (sty == jl_string_type || sty == jl_simplevector_type) {
             // String and SimpleVector's length fields have the same layout
             auto ptr = emit_bitcast(ctx, boxed(ctx, obj), T_psize);
-            Value *len = tbaa_decorate(tbaa_mutab, ctx.builder.CreateLoad(ptr));
+            Value *len = tbaa_decorate(tbaa_mutab, ctx.builder.CreateLoad(T_size, ptr));
             if (sty == jl_simplevector_type) {
                 len = ctx.builder.CreateMul(len, ConstantInt::get(T_size, sizeof(void*)));
                 len = ctx.builder.CreateAdd(len, ConstantInt::get(T_size, sizeof(void*)));
@@ -3030,20 +3112,34 @@ static bool emit_builtin_call(jl_codectx
         if (fieldidx < 0 || fieldidx >= jl_datatype_nfields(stt)) {
             *ret = mark_julia_const(jl_false);
         }
-        else if (!jl_field_isptr(stt, fieldidx) || fieldidx < stt->ninitialized) {
+        else if (fieldidx < stt->ninitialized) {
             *ret = mark_julia_const(jl_true);
         }
-        else {
-            size_t offs = jl_field_offset(stt, fieldidx);
-            Value *ptr = emit_bitcast(ctx, maybe_decay_tracked(data_pointer(ctx, obj)), T_pprjlvalue);
-            Value *llvm_idx = ConstantInt::get(T_size, offs / sizeof(void*));
-            Value *addr = ctx.builder.CreateInBoundsGEP(ptr, llvm_idx);
-            // emit this using the same type as emit_getfield_knownidx
-            // so that LLVM may be able to load-load forward them and fold the result
-            Value *fldv = tbaa_decorate(obj.tbaa, ctx.builder.CreateLoad(T_prjlvalue, addr));
+        else if (jl_field_isptr(stt, fieldidx) || jl_type_hasptr(jl_field_type(stt, fieldidx))) {
+            Value *fldv;
+            size_t offs = jl_field_offset(stt, fieldidx) / sizeof(jl_value_t*);
+            if (obj.ispointer()) {
+                if (!jl_field_isptr(stt, fieldidx))
+                    offs += ((jl_datatype_t*)jl_field_type(stt, fieldidx))->layout->first_ptr;
+                Value *ptr = emit_bitcast(ctx, maybe_decay_tracked(data_pointer(ctx, obj)), T_pprjlvalue);
+                Value *addr = ctx.builder.CreateConstInBoundsGEP1_32(T_prjlvalue, ptr, offs);
+                // emit this using the same type as emit_getfield_knownidx
+                // so that LLVM may be able to load-load forward them and fold the result
+                fldv = tbaa_decorate(obj.tbaa, ctx.builder.CreateLoad(T_prjlvalue, addr));
+            }
+            else {
+                fldv = ctx.builder.CreateExtractValue(obj.V, offs);
+                if (!jl_field_isptr(stt, fieldidx)) {
+                    fldv = extract_first_ptr(ctx, fldv);
+                    assert(fldv);
+                }
+            }
             Value *isdef = ctx.builder.CreateIsNotNull(fldv);
             *ret = mark_julia_type(ctx, isdef, false, jl_bool_type);
         }
+        else {
+            *ret = mark_julia_const(jl_true);
+        }
         return true;
     }
     return false;
@@ -3092,42 +3188,44 @@ static jl_cgval_t emit_call_specfun_othe
     case jl_returninfo_t::Ghosts:
         break;
     case jl_returninfo_t::SRet:
-        result = emit_static_alloca(ctx, cft->getParamType(0)->getContainedType(0));
+        result = emit_static_alloca(ctx, cft->getParamType(0)->getPointerElementType());
         argvals[idx] = result;
         idx++;
         break;
     case jl_returninfo_t::Union:
         result = emit_static_alloca(ctx, ArrayType::get(T_int8, returninfo.union_bytes));
         if (returninfo.union_align > 1)
-            result->setAlignment(returninfo.union_align);
+            result->setAlignment(Align(returninfo.union_align));
         argvals[idx] = result;
         idx++;
         break;
     }
 
+    if (returninfo.return_roots) {
+        AllocaInst *return_roots = emit_static_alloca(ctx, T_prjlvalue);
+        return_roots->setOperand(0, ConstantInt::get(T_int32, returninfo.return_roots));
+        argvals[idx] = return_roots;
+        idx++;
+    }
+
     for (size_t i = 0; i < nargs; i++) {
         jl_value_t *jt = jl_nth_slot_type(codeinst->def->specTypes, i);
-        bool isboxed;
-        Type *et = julia_type_to_llvm(jt, &isboxed);
+        bool isboxed = deserves_argbox(jt);
+        Type *et = isboxed ?  T_prjlvalue : julia_type_to_llvm(jt);
         if (type_is_ghost(et))
             continue;
         assert(idx < nfargs);
         Type *at = cft->getParamType(idx);
-        const jl_cgval_t &arg = argv[i];
+        jl_cgval_t arg = argv[i];
         if (isboxed) {
-            assert(at == T_prjlvalue && (et == T_pjlvalue || et == T_prjlvalue));
+            assert(at == T_prjlvalue && et == T_prjlvalue);
             argvals[idx] = maybe_decay_untracked(boxed(ctx, arg));
         }
         else if (et->isAggregateType()) {
-            if (!arg.ispointer()) {
-                // This can happen in dead code if there's a type mismatch
-                // Exit early
-                CreateTrap(ctx.builder);
-                return jl_cgval_t();
-            }
+            if (!arg.ispointer())
+                arg = value_to_pointer(ctx, arg);
             // can lazy load on demand, no copy needed
             assert(at == PointerType::get(et, AddressSpace::Derived));
-            assert(arg.ispointer());
             argvals[idx] = decay_derived(maybe_bitcast(ctx,
                 data_pointer(ctx, arg), at));
         }
@@ -3338,7 +3436,7 @@ static Value *global_binding_pointer(jl_
             GlobalVariable *bindinggv = new GlobalVariable(*ctx.f->getParent(), T_pjlvalue,
                     false, GlobalVariable::InternalLinkage,
                     initnul, name.str());
-            Value *cachedval = ctx.builder.CreateLoad(bindinggv);
+            Value *cachedval = ctx.builder.CreateLoad(T_pjlvalue, bindinggv);
             BasicBlock *have_val = BasicBlock::Create(jl_LLVMContext, "found"),
                 *not_found = BasicBlock::Create(jl_LLVMContext, "notfound");
             BasicBlock *currentbb = ctx.builder.GetInsertBlock();
@@ -3390,7 +3488,7 @@ static jl_cgval_t emit_sparam(jl_codectx
             T_prjlvalue,
             ctx.spvals_ptr,
             i + sizeof(jl_svec_t) / sizeof(jl_value_t*));
-    Value *sp = tbaa_decorate(tbaa_const, ctx.builder.CreateLoad(bp));
+    Value *sp = tbaa_decorate(tbaa_const, ctx.builder.CreateLoad(T_prjlvalue, bp));
     Value *isnull = ctx.builder.CreateICmpNE(emit_typeof(ctx, sp),
             maybe_decay_untracked(literal_pointer_val(ctx, (jl_value_t*)jl_tvar_type)));
     jl_unionall_t *sparam = (jl_unionall_t*)ctx.linfo->def.method->sig;
@@ -3413,7 +3511,7 @@ static jl_cgval_t emit_global(jl_codectx
         // double-check that a global variable is actually defined. this
         // can be a problem in parallel when a definition is missing on
         // one machine.
-        return mark_julia_type(ctx, tbaa_decorate(tbaa_binding, ctx.builder.CreateLoad(bp)), true, jl_any_type);
+        return mark_julia_type(ctx, tbaa_decorate(tbaa_binding, ctx.builder.CreateLoad(T_prjlvalue, bp)), true, jl_any_type);
     }
     return emit_checked_var(ctx, bp, sym, false, tbaa_binding);
 }
@@ -3428,15 +3526,15 @@ static jl_cgval_t emit_isdefined(jl_code
             return mark_julia_const(jl_true);
         if (vi.boxroot == NULL || vi.pTIndex != NULL) {
             assert(vi.defFlag);
-            isnull = ctx.builder.CreateLoad(vi.defFlag, vi.isVolatile);
+            isnull = ctx.builder.CreateLoad(T_int1, vi.defFlag, vi.isVolatile);
         }
         if (vi.boxroot != NULL) {
-            Value *boxed = ctx.builder.CreateLoad(vi.boxroot, vi.isVolatile);
+            Value *boxed = ctx.builder.CreateLoad(T_prjlvalue, vi.boxroot, vi.isVolatile);
             Value *box_isnull = ctx.builder.CreateICmpNE(boxed, maybe_decay_untracked(V_null));
             if (vi.pTIndex) {
                 // value is either boxed in the stack slot, or unboxed in value
                 // as indicated by testing (pTIndex & 0x80)
-                Value *tindex = ctx.builder.CreateLoad(vi.pTIndex, vi.isVolatile);
+                Value *tindex = ctx.builder.CreateLoad(T_int8, vi.pTIndex, vi.isVolatile);
                 Value *load_unbox = ctx.builder.CreateICmpEQ(
                             ctx.builder.CreateAnd(tindex, ConstantInt::get(T_int8, 0x80)),
                             ConstantInt::get(T_int8, 0));
@@ -3461,7 +3559,7 @@ static jl_cgval_t emit_isdefined(jl_code
                 T_prjlvalue,
                 ctx.spvals_ptr,
                 i + sizeof(jl_svec_t) / sizeof(jl_value_t*));
-        Value *sp = tbaa_decorate(tbaa_const, ctx.builder.CreateLoad(bp));
+        Value *sp = tbaa_decorate(tbaa_const, ctx.builder.CreateLoad(T_prjlvalue, bp));
         isnull = ctx.builder.CreateICmpNE(emit_typeof(ctx, sp),
             maybe_decay_untracked(literal_pointer_val(ctx, (jl_value_t*)jl_tvar_type)));
     }
@@ -3512,33 +3610,31 @@ static jl_cgval_t emit_varinfo(jl_codect
             AllocaInst *varslot = cast<AllocaInst>(vi.value.V);
             Type *T = varslot->getAllocatedType();
             assert(!varslot->isArrayAllocation() && "variables not expected to be VLA");
-            AllocaInst *ssaslot = emit_static_alloca(ctx, T);
-            unsigned al = varslot->getAlignment();
-            if (al)
-                ssaslot->setAlignment(al);
+            AllocaInst *ssaslot = cast<AllocaInst>(varslot->clone());
+            ssaslot->insertAfter(varslot);
             if (vi.isVolatile) {
-                Value *unbox = ctx.builder.CreateLoad(vi.value.V, true);
-                ctx.builder.CreateStore(unbox, ssaslot);
+                Value *unbox = ctx.builder.CreateAlignedLoad(ssaslot->getAllocatedType(), varslot, varslot->getAlignment(), true);
+                ctx.builder.CreateAlignedStore(unbox, ssaslot, ssaslot->getAlignment());
             }
             else {
                 const DataLayout &DL = jl_data_layout;
                 uint64_t sz = DL.getTypeStoreSize(T);
-                emit_memcpy(ctx, ssaslot, tbaa_stack, vi.value, sz, al);
+                emit_memcpy(ctx, ssaslot, tbaa_stack, vi.value, sz, ssaslot->getAlignment());
             }
             Value *tindex = NULL;
             if (vi.pTIndex)
-                tindex = ctx.builder.CreateLoad(vi.pTIndex, vi.isVolatile);
+                tindex = ctx.builder.CreateLoad(T_int8, vi.pTIndex, vi.isVolatile);
             v = mark_julia_slot(ssaslot, vi.value.typ, tindex, tbaa_stack);
         }
         if (vi.boxroot == NULL)
             v = update_julia_type(ctx, v, typ);
         if (vi.usedUndef) {
             assert(vi.defFlag);
-            isnull = ctx.builder.CreateLoad(vi.defFlag, vi.isVolatile);
+            isnull = ctx.builder.CreateLoad(T_int1, vi.defFlag, vi.isVolatile);
         }
     }
     if (vi.boxroot != NULL) {
-        Instruction *boxed = ctx.builder.CreateLoad(vi.boxroot, vi.isVolatile);
+        Instruction *boxed = ctx.builder.CreateLoad(T_prjlvalue, vi.boxroot, vi.isVolatile);
         Value *box_isnull;
         if (vi.usedUndef)
             box_isnull = ctx.builder.CreateICmpNE(boxed, maybe_decay_untracked(V_null));
@@ -3630,7 +3726,7 @@ static void emit_vi_assignment_unboxed(j
                 if (vi.value.V != rval_info.V) {
                     Value *copy_bytes = ConstantInt::get(T_int32, jl_datatype_size(vi.value.typ));
                     emit_memcpy(ctx, vi.value.V, tbaa_stack, rval_info, copy_bytes,
-                                jl_datatype_align(rval_info.typ), vi.isVolatile);
+                                julia_alignment(rval_info.typ), vi.isVolatile);
                 }
             }
             else {
@@ -3664,9 +3760,9 @@ static void emit_phinode_assign(jl_codec
         bool allunbox;
         size_t min_align, nbytes;
         dest = try_emit_union_alloca(ctx, ((jl_uniontype_t*)phiType), allunbox, min_align, nbytes);
-        Value *phi = try_emit_union_alloca(ctx, ((jl_uniontype_t*)phiType), allunbox, min_align, nbytes);
-        Value *ptr = NULL;
         if (dest) {
+            Instruction *phi = dest->clone();
+            phi->insertAfter(dest);
             PHINode *Tindex_phi = PHINode::Create(T_int8, jl_array_len(edges), "tindex_phi");
             BB->getInstList().insert(InsertPt, Tindex_phi);
             PHINode *ptr_phi = PHINode::Create(T_prjlvalue, jl_array_len(edges), "ptr_phi");
@@ -3680,7 +3776,7 @@ static void emit_phinode_assign(jl_codec
             ctx.builder.CreateMemCpy(phi, dest, nbytes, min_align, false);
 #endif
             ctx.builder.CreateLifetimeEnd(dest);
-            ptr = ctx.builder.CreateSelect(isboxed,
+            Value *ptr = ctx.builder.CreateSelect(isboxed,
                 maybe_bitcast(ctx, decay_derived(ptr_phi), T_pint8),
                 maybe_bitcast(ctx, decay_derived(phi), T_pint8));
             jl_cgval_t val = mark_julia_slot(ptr, phiType, Tindex_phi, tbaa_stack); // XXX: this TBAA is wrong for ptr_phi
@@ -3700,10 +3796,8 @@ static void emit_phinode_assign(jl_codec
             return;
         }
     }
-    bool isboxed;
-    Type *vtype = julia_type_to_llvm(phiType, &isboxed);
-    if (isboxed)
-        vtype = T_prjlvalue;
+    bool isboxed = !deserves_stack(phiType);
+    Type *vtype = isboxed ? T_prjlvalue : julia_type_to_llvm(phiType);
     // The frontend should really not emit this, but we allow it
     // for convenience.
     if (type_is_ghost(vtype)) {
@@ -3715,16 +3809,18 @@ static void emit_phinode_assign(jl_codec
     }
     jl_cgval_t slot;
     PHINode *value_phi = NULL;
-    if (vtype->isAggregateType()) {
+    if (vtype->isAggregateType() && CountTrackedPointers(vtype).count == 0) {
+        // the value will be moved into dest in the predecessor critical block.
+        // here it's moved into phi in the successor (from dest)
         dest = emit_static_alloca(ctx, vtype);
         Value *phi = emit_static_alloca(ctx, vtype);
 #if JL_LLVM_VERSION >= 70000
-        ctx.builder.CreateMemCpy(phi, jl_datatype_align(phiType),
+        ctx.builder.CreateMemCpy(phi, julia_alignment(phiType),
              dest, 0,
              jl_datatype_size(phiType), false);
 #else
         ctx.builder.CreateMemCpy(phi, dest, jl_datatype_size(phiType),
-             jl_datatype_align(phiType), false);
+             julia_alignment(phiType), false);
 #endif
         ctx.builder.CreateLifetimeEnd(dest);
         slot = mark_julia_slot(phi, phiType, NULL, tbaa_stack);
@@ -3769,7 +3865,8 @@ static void emit_ssaval_assign(jl_codect
     ctx.ssavalue_assigned.at(idx) = true;
 }
 
-static void emit_varinfo_assign(jl_codectx_t &ctx, jl_varinfo_t &vi, jl_cgval_t rval_info, jl_value_t *l=NULL) {
+static void emit_varinfo_assign(jl_codectx_t &ctx, jl_varinfo_t &vi, jl_cgval_t rval_info, jl_value_t *l=NULL)
+{
     if (!vi.used)
         return;
 
@@ -4029,7 +4126,8 @@ static jl_cgval_t emit_expr(jl_codectx_t
         if (var == getfield_undefref_sym) {
             raise_exception_unless(ctx, cond,
                 literal_pointer_val(ctx, jl_undefref_exception));
-        } else {
+        }
+        else {
             undef_var_error_ifnot(ctx, cond, var);
         }
         return ghostValue(jl_void_type);
@@ -4307,7 +4405,7 @@ static void emit_last_age_field(jl_codec
 }
 
 static void emit_cfunc_invalidate(
-        Function *gf_thunk, jl_returninfo_t::CallingConv cc,
+        Function *gf_thunk, jl_returninfo_t::CallingConv cc, unsigned return_roots,
         jl_code_instance_t *codeinst, size_t nargs, size_t world)
 {
     jl_method_instance_t *lam = codeinst->def;
@@ -4326,10 +4424,12 @@ static void emit_cfunc_invalidate(
     jl_cgval_t *myargs = (jl_cgval_t*)alloca(sizeof(jl_cgval_t) * nargs);
     if (cc == jl_returninfo_t::SRet || cc == jl_returninfo_t::Union)
         ++AI;
+    if (return_roots)
+        ++AI;
     for (size_t i = 0; i < nargs; i++) {
         jl_value_t *jt = jl_nth_slot_type(lam->specTypes, i);
-        bool isboxed;
-        Type *et = julia_type_to_llvm(jt, &isboxed);
+        bool isboxed = deserves_argbox(jt);
+        Type *et = isboxed ?  T_prjlvalue : julia_type_to_llvm(jt);
         if (type_is_ghost(et)) {
             assert(jl_is_datatype(jt) && ((jl_datatype_t*)jt)->instance);
             myargs[i] = mark_julia_const(((jl_datatype_t*)jt)->instance);
@@ -4338,16 +4438,12 @@ static void emit_cfunc_invalidate(
             Value *arg_v = &*AI;
             ++AI;
             Type *at = arg_v->getType();
-            if (isboxed) {
-                assert(at == T_prjlvalue && et == T_pjlvalue);
-                myargs[i] = mark_julia_type(ctx, arg_v, true, jt);
-            }
-            else if (et->isAggregateType()) {
+            if (!isboxed && et->isAggregateType()) {
                 myargs[i] = mark_julia_slot(arg_v, jt, NULL, tbaa_const);
             }
             else {
                 assert(at == et);
-                myargs[i] = mark_julia_type(ctx, arg_v, false, jt);
+                myargs[i] = mark_julia_type(ctx, arg_v, isboxed, jt);
             }
             (void)at;
         }
@@ -4376,6 +4472,8 @@ static void emit_cfunc_invalidate(
         break;
     }
     case jl_returninfo_t::SRet: {
+        if (return_roots)
+            ctx.builder.CreateStore(gf_ret, gf_thunk->arg_begin() + 1);
         emit_memcpy(ctx, &*gf_thunk->arg_begin(), nullptr, gf_ret, nullptr, jl_datatype_size(astrt), julia_alignment(astrt));
         ctx.builder.CreateRetVoid();
         break;
@@ -4577,10 +4675,10 @@ static Function* gen_cfun_wrapper(
         if (aref) {
             if (jargty == (jl_value_t*)jl_any_type) {
                 inputarg = mark_julia_type(ctx,
-                        ctx.builder.CreateLoad(emit_bitcast(ctx, val, T_pprjlvalue)),
+                        ctx.builder.CreateLoad(T_prjlvalue, emit_bitcast(ctx, val, T_pprjlvalue)),
                         true, jl_any_type);
             }
-            else if (static_at && jl_justbits(jargty)) { // anything that can be stored unboxed
+            else if (static_at && jl_is_concrete_immutable(jargty)) { // anything that could be stored unboxed
                 bool isboxed;
                 Type *T = julia_type_to_llvm(jargty, &isboxed);
                 assert(!isboxed);
@@ -4749,19 +4847,26 @@ static Function* gen_cfun_wrapper(
         Value *result;
         if (jlfunc_sret || returninfo.cc == jl_returninfo_t::Union) {
             // fuse the two sret together, or emit an alloca to hold it
-            if (sig.sret && jlfunc_sret)
+            if (sig.sret && jlfunc_sret) {
                 result = emit_bitcast(ctx, sretPtr, cft->getParamType(0));
-            else
-                result = emit_static_alloca(ctx, cft->getParamType(0)->getContainedType(0));
+            }
+            else {
+                result = emit_static_alloca(ctx, cft->getParamType(0)->getPointerElementType());
+            }
             args.push_back(result);
         }
+        if (returninfo.return_roots) {
+            AllocaInst *return_roots = emit_static_alloca(ctx, T_prjlvalue);
+            return_roots->setOperand(0, ConstantInt::get(T_int32, returninfo.return_roots));
+            args.push_back(return_roots);
+        }
         for (size_t i = 0; i < nargs + 1; i++) {
             // figure out how to repack the arguments
-            const jl_cgval_t &inputarg = inputargs[i];
+            jl_cgval_t &inputarg = inputargs[i];
             Value *arg;
             jl_value_t *spect = jl_nth_slot_type(lam->specTypes, i);
-            bool isboxed;
-            Type *T = julia_type_to_llvm(spect, &isboxed);
+            bool isboxed = deserves_argbox(spect);
+            Type *T = isboxed ? T_prjlvalue : julia_type_to_llvm(spect);
             if (isboxed) {
                 arg = boxed(ctx, inputarg);
             }
@@ -4770,6 +4875,8 @@ static Function* gen_cfun_wrapper(
             }
             else if (T->isAggregateType()) {
                 // aggregate types are passed by pointer
+                if (!inputarg.ispointer())
+                    inputarg = value_to_pointer(ctx, inputarg);
                 arg = maybe_bitcast(ctx, decay_derived(data_pointer(ctx, inputarg)),
                     T->getPointerTo());
             }
@@ -4792,7 +4899,7 @@ static Function* gen_cfun_wrapper(
             // build a  specsig -> jl_apply_generic converter thunk
             // this builds a method that calls jl_apply_generic (as a closure over a singleton function pointer),
             // but which has the signature of a specsig
-            emit_cfunc_invalidate(gf_thunk, returninfo.cc, codeinst, nargs + 1, world);
+            emit_cfunc_invalidate(gf_thunk, returninfo.cc, returninfo.return_roots, codeinst, nargs + 1, world);
             theFptr = ctx.builder.CreateSelect(age_ok, theFptr, gf_thunk);
         }
         CallInst *call = ctx.builder.CreateCall(theFptr, ArrayRef<Value*>(args));
@@ -4980,6 +5087,12 @@ static jl_cgval_t emit_cfunction(jl_code
     }
 
     bool nest = (!fexpr_rt.constant || unionall_env);
+#if defined(_CPU_AARCH64_) || defined(_CPU_ARM_) || defined(_CPU_PPC64_)
+    if (nest) {
+        emit_error(ctx, "cfunction: closures are not supported on this platform");
+        return jl_cgval_t();
+    }
+#endif
     Value *F = gen_cfun_wrapper(
             jl_Module,
             sig, fexpr_rt.constant,
@@ -5156,7 +5269,7 @@ static Function *jl_cfunction_object(jl_
 }
 
 // generate a julia-callable function that calls f (AKA lam)
-static Function *gen_invoke_wrapper(jl_method_instance_t *lam, jl_value_t *jlretty, const jl_returninfo_t &f, StringRef funcName, Module *M)
+static Function *gen_invoke_wrapper(jl_method_instance_t *lam, jl_value_t *jlretty, const jl_returninfo_t &f, int retarg, StringRef funcName, Module *M)
 {
     Function *w = Function::Create(jl_func_sig, GlobalVariable::ExternalLinkage, funcName, M);
     add_return_attr(w, Attribute::NonNull);
@@ -5181,9 +5294,10 @@ static Function *gen_invoke_wrapper(jl_m
     ctx.builder.SetCurrentDebugLocation(noDbg);
     allocate_gc_frame(ctx, b0);
 
+    // TODO: replace this with emit_call_specfun_other?
     FunctionType *ftype = f.decl->getFunctionType();
     size_t nfargs = ftype->getNumParams();
-    Value **args = (Value**) alloca(nfargs*sizeof(Value*));
+    Value **args = (Value**) alloca(nfargs * sizeof(Value*));
     unsigned idx = 0;
     AllocaInst *result;
     switch (f.cc) {
@@ -5192,31 +5306,38 @@ static Function *gen_invoke_wrapper(jl_m
     case jl_returninfo_t::Ghosts:
         break;
     case jl_returninfo_t::SRet:
-        result = ctx.builder.CreateAlloca(ftype->getParamType(0)->getContainedType(0));
+        result = ctx.builder.CreateAlloca(ftype->getParamType(0)->getPointerElementType());
         args[idx] = result;
         idx++;
         break;
     case jl_returninfo_t::Union:
         result = ctx.builder.CreateAlloca(ArrayType::get(T_int8, f.union_bytes));
         if (f.union_align > 1)
-            result->setAlignment(f.union_align);
+            result->setAlignment(Align(f.union_align));
         args[idx] = result;
         idx++;
         break;
     }
+    if (f.return_roots) {
+        AllocaInst *return_roots = emit_static_alloca(ctx, T_prjlvalue);
+        return_roots->setOperand(0, ConstantInt::get(T_int32, f.return_roots));
+        args[idx] = return_roots;
+        idx++;
+    }
+
     for (size_t i = 0; i < jl_nparams(lam->specTypes) && idx < nfargs; ++i) {
         jl_value_t *ty = jl_nth_slot_type(lam->specTypes, i);
-        bool isboxed;
-        Type *lty = julia_type_to_llvm(ty, &isboxed);
-        if (lty != NULL && type_is_ghost(lty))
+        bool isboxed = deserves_argbox(ty);
+        Type *lty = isboxed ?  T_prjlvalue : julia_type_to_llvm(ty);
+        if (type_is_ghost(lty))
             continue;
         Value *theArg;
         if (i == 0) {
             theArg = funcArg;
         }
         else {
-            Value *argPtr = ctx.builder.CreateInBoundsGEP(argArray, ConstantInt::get(T_size, i - 1));
-            theArg = maybe_mark_load_dereferenceable(ctx.builder.CreateLoad(argPtr), false, ty);
+            Value *argPtr = ctx.builder.CreateConstInBoundsGEP1_32(T_prjlvalue, argArray, i - 1);
+            theArg = maybe_mark_load_dereferenceable(ctx.builder.CreateLoad(T_prjlvalue, argPtr), false, ty);
         }
         if (!isboxed) {
             theArg = decay_derived(emit_bitcast(ctx, theArg, PointerType::get(lty, 0)));
@@ -5231,28 +5352,38 @@ static Function *gen_invoke_wrapper(jl_m
     call->setAttributes(f.decl->getAttributes());
 
     jl_cgval_t retval;
-    switch (f.cc) {
-    case jl_returninfo_t::Boxed:
-        retval = mark_julia_type(ctx, call, true, jlretty);
-        break;
-    case jl_returninfo_t::Register:
-        retval = mark_julia_type(ctx, call, false, jlretty);
-        break;
-    case jl_returninfo_t::SRet:
-        retval = mark_julia_slot(result, jlretty, NULL, tbaa_stack);
-        break;
-    case jl_returninfo_t::Union:
-        // result is technically not right here, but `boxed` will only look at it
-        // for the unboxed values, so it's ok.
-        retval = mark_julia_slot(result,
-                                 jlretty,
-                                 ctx.builder.CreateExtractValue(call, 1),
-                                 tbaa_stack);
-        retval.Vboxed = ctx.builder.CreateExtractValue(call, 0);
-        break;
-    case jl_returninfo_t::Ghosts:
-        retval = mark_julia_slot(NULL, jlretty, call, tbaa_stack);
-        break;
+    if (retarg != -1) {
+        Value *theArg;
+        if (retarg == 0)
+            theArg = funcArg;
+        else
+            theArg = ctx.builder.CreateLoad(T_prjlvalue, ctx.builder.CreateConstInBoundsGEP1_32(T_prjlvalue, argArray, retarg - 1));
+        retval = mark_julia_type(ctx, theArg, true, jl_any_type);
+    }
+    else {
+        switch (f.cc) {
+        case jl_returninfo_t::Boxed:
+            retval = mark_julia_type(ctx, call, true, jlretty);
+            break;
+        case jl_returninfo_t::Register:
+            retval = mark_julia_type(ctx, call, false, jlretty);
+            break;
+        case jl_returninfo_t::SRet:
+            retval = mark_julia_slot(result, jlretty, NULL, tbaa_stack);
+            break;
+        case jl_returninfo_t::Union:
+            // result is technically not right here, but `boxed` will only look at it
+            // for the unboxed values, so it's ok.
+            retval = mark_julia_slot(result,
+                                     jlretty,
+                                     ctx.builder.CreateExtractValue(call, 1),
+                                     tbaa_stack);
+            retval.Vboxed = ctx.builder.CreateExtractValue(call, 0);
+            break;
+        case jl_returninfo_t::Ghosts:
+            retval = mark_julia_slot(NULL, jlretty, call, tbaa_stack);
+            break;
+        }
     }
     ctx.builder.CreateRet(boxed(ctx, retval));
     assert(!ctx.roots);
@@ -5278,7 +5409,7 @@ static bool uses_specsig(jl_value_t *sig
     // not invalid, consider if specialized signature is worthwhile
     if (prefer_specsig)
         return true;
-    if (jl_justbits(rettype) && !jl_is_datatype_singleton((jl_datatype_t*)rettype))
+    if (!deserves_retbox(rettype) && !jl_is_datatype_singleton((jl_datatype_t*)rettype))
         return true;
     if (jl_is_uniontype(rettype)) {
         bool allunbox;
@@ -5290,9 +5421,9 @@ static bool uses_specsig(jl_value_t *sig
     bool allSingleton = true;
     for (size_t i = 0; i < jl_nparams(sig); i++) {
         jl_value_t *sigt = jl_tparam(sig, i);
-        bool issing = jl_is_datatype_singleton((jl_datatype_t*)sigt);
+        bool issing = jl_is_datatype(sigt) && jl_is_datatype_singleton((jl_datatype_t*)sigt);
         allSingleton &= issing;
-        if (jl_justbits(sigt) && !issing) {
+        if (!deserves_argbox(sigt) && !issing) {
             return true;
         }
     }
@@ -5328,36 +5459,50 @@ static jl_returninfo_t get_specsig_funct
             rt = T_prjlvalue;
         }
     }
-    else {
+    else if (!deserves_retbox(jlrettype)) {
         bool retboxed;
         rt = julia_type_to_llvm(jlrettype, &retboxed);
-        if (!retboxed) {
-            if (rt != T_void && deserves_sret(jlrettype, rt)) {
-                props.cc = jl_returninfo_t::SRet;
-                fsig.push_back(rt->getPointerTo());
-                rt = T_void;
-            }
-            else {
-                props.cc = jl_returninfo_t::Register;
-            }
-        } else {
-            rt = T_prjlvalue;
+        assert(!retboxed);
+        if (rt != T_void && deserves_sret(jlrettype, rt)) {
+            auto tracked = CountTrackedPointers(rt);
+            assert(!tracked.derived);
+            if (tracked.count && !tracked.all)
+                props.return_roots = tracked.count;
+            props.cc = jl_returninfo_t::SRet;
+            fsig.push_back(rt->getPointerTo());
+            rt = T_void;
         }
+        else {
+            props.cc = jl_returninfo_t::Register;
+        }
+    }
+    else {
+        rt = T_prjlvalue;
     }
+
     AttributeList attributes; // function declaration attributes
     if (props.cc == jl_returninfo_t::SRet) {
-        attributes = attributes.addAttribute(jl_LLVMContext, 1, Attribute::StructRet);
-        attributes = attributes.addAttribute(jl_LLVMContext, 1, Attribute::NoAlias);
-        attributes = attributes.addAttribute(jl_LLVMContext, 1, Attribute::NoCapture);
+        unsigned argno = 1;
+        attributes = attributes.addAttribute(jl_LLVMContext, argno, Attribute::StructRet);
+        attributes = attributes.addAttribute(jl_LLVMContext, argno, Attribute::NoAlias);
+        attributes = attributes.addAttribute(jl_LLVMContext, argno, Attribute::NoCapture);
     }
     if (props.cc == jl_returninfo_t::Union) {
-        attributes = attributes.addAttribute(jl_LLVMContext, 1, Attribute::NoAlias);
-        attributes = attributes.addAttribute(jl_LLVMContext, 1, Attribute::NoCapture);
+        unsigned argno = 1;
+        attributes = attributes.addAttribute(jl_LLVMContext, argno, Attribute::NoAlias);
+        attributes = attributes.addAttribute(jl_LLVMContext, argno, Attribute::NoCapture);
+    }
+
+    if (props.return_roots) {
+        fsig.push_back(T_pprjlvalue);
+        unsigned argno = fsig.size();
+        attributes = attributes.addAttribute(jl_LLVMContext, argno, Attribute::NoAlias);
+        attributes = attributes.addAttribute(jl_LLVMContext, argno, Attribute::NoCapture);
     }
+
     for (size_t i = 0; i < jl_nparams(sig); i++) {
         jl_value_t *jt = jl_tparam(sig, i);
-        bool isboxed;
-        Type *ty = julia_type_to_llvm(jt, &isboxed);
+        Type *ty = deserves_argbox(jt) ? T_prjlvalue : julia_type_to_llvm(jt);
         if (type_is_ghost(ty))
             continue;
         unsigned argno = fsig.size();
@@ -5366,10 +5511,9 @@ static jl_returninfo_t get_specsig_funct
             attributes = attributes.addParamAttribute(jl_LLVMContext, argno, Attribute::ReadOnly);
             ty = PointerType::get(ty, AddressSpace::Derived);
         }
-        if (isboxed)
-            ty = PointerType::get(cast<PointerType>(ty)->getElementType(), AddressSpace::Tracked);
         fsig.push_back(ty);
     }
+
     FunctionType *ftype = FunctionType::get(rt, fsig, false);
     Function *f = M ? cast_or_null<Function>(M->getNamedValue(name)) : NULL;
     if (f == NULL) {
@@ -5385,20 +5529,23 @@ static jl_returninfo_t get_specsig_funct
     return props;
 }
 
+static void emit_sret_roots(jl_codectx_t &ctx, bool isptr, Value *Src, Type *T, Value *Shadow, unsigned count)
+{
+    if (isptr)
+        Src = maybe_decay_tracked(Src);
+    if (isptr && Src->getType()->getPointerElementType() != T)
+        Src = ctx.builder.CreateBitCast(Src, T->getPointerTo(Src->getType()->getPointerAddressSpace()));
+    unsigned emitted = TrackWithShadow(Src, T, isptr, Shadow, ctx.builder);
+    assert(emitted == count); (void)emitted; (void)count;
+}
+
 static DISubroutineType *
 get_specsig_di(jl_value_t *rt, jl_value_t *sig, DIFile *topfile, DIBuilder &dbuilder)
 {
     std::vector<Metadata*> ditypes(0);
-    Type *ty = julia_type_to_llvm(rt);
-    if (type_is_ghost(ty))
-        ditypes.push_back(nullptr);
-    else
-        ditypes.push_back(julia_type_to_di(rt, &dbuilder, false));
+    ditypes.push_back(julia_type_to_di(rt, &dbuilder, false));
     for (size_t i = 0; i < jl_nparams(sig); i++) {
         jl_value_t *jt = jl_tparam(sig, i);
-        Type *ty = julia_type_to_llvm(jt);
-        if (type_is_ghost(ty))
-            continue;
         ditypes.push_back(julia_type_to_di(jt, &dbuilder, false));
     }
     return dbuilder.createSubroutineType(dbuilder.getOrCreateTypeArray(ditypes));
@@ -5578,15 +5725,38 @@ static std::unique_ptr<Module> emit_func
     jl_setup_module(M, params);
     jl_returninfo_t returninfo = {};
     Function *f = NULL;
+    bool has_sret = false;
     if (specsig) { // assumes !va and !needsparams
         returninfo = get_specsig_function(M, funcName.str(), lam->specTypes, jlrettype);
         f = returninfo.decl;
-        ctx.has_sret = (returninfo.cc == jl_returninfo_t::SRet || returninfo.cc == jl_returninfo_t::Union);
+        has_sret = (returninfo.cc == jl_returninfo_t::SRet || returninfo.cc == jl_returninfo_t::Union);
         jl_init_function(f);
 
+        // common pattern: see if all return statements are an argument in that
+        // case the apply-generic call can re-use the original box for the return
+        int retarg = [stmts, nreq]() {
+            int retarg = -1;
+            for (size_t i = 0; i < jl_array_len(stmts); ++i) {
+                jl_value_t *stmt = jl_array_ptr_ref(stmts, i);
+                if (jl_is_expr(stmt) && ((jl_expr_t*)stmt)->head == return_sym) {
+                    stmt = jl_exprarg(stmt, 0);
+                    if (!jl_is_slot(stmt))
+                        return -1;
+                    unsigned sl = jl_slot_number(stmt) - 1;
+                    if (sl >= nreq)
+                        return -1;
+                    if (retarg == -1)
+                        retarg = sl;
+                    else if ((unsigned)retarg != sl)
+                        return -1;
+                }
+            }
+            return retarg;
+        }();
+
         std::stringstream wrapName;
         wrapName << "jfptr_" << unadorned_name << "_" << globalUnique;
-        Function *fwrap = gen_invoke_wrapper(lam, jlrettype, returninfo, wrapName.str(), M);
+        Function *fwrap = gen_invoke_wrapper(lam, jlrettype, returninfo, retarg, wrapName.str(), M);
         declarations->functionObject = strdup(fwrap->getName().str().c_str());
     }
     else {
@@ -5619,7 +5789,7 @@ static std::unique_ptr<Module> emit_func
 
     if (returninfo.cc == jl_returninfo_t::Union) {
         f->addAttribute(1, Attribute::getWithDereferenceableBytes(jl_LLVMContext, returninfo.union_bytes));
-        f->addAttribute(1, Attribute::getWithAlignment(jl_LLVMContext, returninfo.union_align));
+        f->addAttribute(1, Attribute::getWithAlignment(jl_LLVMContext, Align(returninfo.union_align)));
     }
 
 #ifdef JL_DEBUG_BUILD
@@ -5708,7 +5878,7 @@ static std::unique_ptr<Module> emit_func
                 varinfo.dinfo = dbuilder.createParameterVariable(
                     SP,                                 // Scope (current function will be fill in later)
                     jl_symbol_name(argname),            // Variable name
-                    ctx.has_sret + i + 1,               // Argument number (1-based)
+                    has_sret + i + 1,                   // Argument number (1-based)
                     topfile,                            // File
                     toplineno == -1 ? 0 : toplineno,    // Line
                     // Variable type
@@ -5720,7 +5890,7 @@ static std::unique_ptr<Module> emit_func
                 ctx.slots[ctx.vaSlot].dinfo = dbuilder.createParameterVariable(
                     SP,                                 // Scope (current function will be fill in later)
                     std::string(jl_symbol_name(slot_symbol(ctx, ctx.vaSlot))) + "...",  // Variable name
-                    ctx.has_sret + nreq + 1,            // Argument number (1-based)
+                    has_sret + nreq + 1,                // Argument number (1-based)
                     topfile,                            // File
                     toplineno == -1 ? 0 : toplineno,    // Line (for now, use lineno of the function)
                     julia_type_to_di(ctx.slots[ctx.vaSlot].value.typ, &dbuilder, false),
@@ -5734,7 +5904,7 @@ static std::unique_ptr<Module> emit_func
                     continue;
                 // LLVM 4.0: Assume the variable has default alignment
                 varinfo.dinfo = dbuilder.createAutoVariable(
-                    SP,                     // Scope (current function will be fill in later)
+                    SP,                      // Scope (current function will be fill in later)
                     jl_symbol_name(s),       // Variable name
                     topfile,                 // File
                     toplineno == -1 ? 0 : toplineno, // Line (for now, use lineno of the function)
@@ -5801,7 +5971,7 @@ static std::unique_ptr<Module> emit_func
         }
         else if (varinfo.isArgument && !(specsig && i == (size_t)ctx.vaSlot)) {
             // if we can unbox it, just use the input pointer
-            if (i != (size_t)ctx.vaSlot && jl_justbits(jt))
+            if (i != (size_t)ctx.vaSlot && jl_is_concrete_immutable(jt))
                 return;
         }
         else if (jl_is_uniontype(jt)) {
@@ -5826,7 +5996,7 @@ static std::unique_ptr<Module> emit_func
             if (allunbox)
                 return;
         }
-        else if (jl_justbits(jt)) {
+        else if (deserves_stack(jt, true)) {
             bool isboxed;
             Type *vtype = julia_type_to_llvm(jt, &isboxed);
             assert(!isboxed);
@@ -5931,13 +6101,15 @@ static std::unique_ptr<Module> emit_func
         return theArg;
     };
 
-    if (ctx.has_sret)
+    if (has_sret)
         AI++; // skip sret slot
+    if (returninfo.return_roots)
+        AI++; // skip return_roots slot
     for (i = 0; i < nreq; i++) {
         jl_sym_t *s = (jl_sym_t*)jl_array_ptr_ref(src->slotnames, i);
         jl_value_t *argType = jl_nth_slot_type(lam->specTypes, i);
-        bool isboxed;
-        Type *llvmArgType = julia_type_to_llvm(argType, &isboxed);
+        bool isboxed = deserves_argbox(argType);
+        Type *llvmArgType = isboxed ? T_prjlvalue : julia_type_to_llvm(argType);
         if (s == unused_sym) {
             if (specsig && !type_is_ghost(llvmArgType))
                 ++AI;
@@ -5960,8 +6132,8 @@ static std::unique_ptr<Module> emit_func
                     theArg = mark_julia_type(ctx, fArg, true, vi.value.typ);
                 }
                 else {
-                    Value *argPtr = ctx.builder.CreateInBoundsGEP(argArray, ConstantInt::get(T_size, i-1));
-                    auto load = maybe_mark_load_dereferenceable(ctx.builder.CreateLoad(argPtr),
+                    Value *argPtr = ctx.builder.CreateInBoundsGEP(T_prjlvalue, argArray, ConstantInt::get(T_size, i-1));
+                    auto load = maybe_mark_load_dereferenceable(ctx.builder.CreateLoad(T_prjlvalue, argPtr),
                                                                 false, vi.value.typ);
                     theArg = mark_julia_type(ctx, load, true, vi.value.typ);
                     if (ctx.debug_enabled && vi.dinfo && !vi.boxroot && !vi.value.V) {
@@ -6018,8 +6190,8 @@ static std::unique_ptr<Module> emit_func
             jl_cgval_t *vargs = (jl_cgval_t*)alloca(sizeof(jl_cgval_t) * ctx.nvargs);
             for (size_t i = nreq; i < jl_nparams(lam->specTypes); ++i) {
                 jl_value_t *argType = jl_nth_slot_type(lam->specTypes, i);
-                bool isboxed;
-                Type *llvmArgType = julia_type_to_llvm(argType, &isboxed);
+                bool isboxed = deserves_argbox(argType);
+                Type *llvmArgType = isboxed ?  T_prjlvalue : julia_type_to_llvm(argType);
                 vargs[i - nreq] = get_specsig_arg(argType, llvmArgType, isboxed);
             }
             if (jl_is_concrete_type(vi.value.typ)) {
@@ -6038,7 +6210,7 @@ static std::unique_ptr<Module> emit_func
             restTuple =
                 ctx.builder.CreateCall(prepare_call(jltuple_func),
                         { maybe_decay_untracked(V_null),
-                          ctx.builder.CreateInBoundsGEP(argArray,
+                          ctx.builder.CreateInBoundsGEP(T_prjlvalue, argArray,
                                   ConstantInt::get(T_size, nreq - 1)),
                           ctx.builder.CreateSub(argCount,
                                   ConstantInt::get(T_int32, nreq - 1)) });
@@ -6142,7 +6314,7 @@ static std::unique_ptr<Module> emit_func
     std::vector<Metadata*> scope_stack;
     std::vector<MDNode*> scope_list_stack;
     {
-        size_t nstmts = jl_array_len(src->code);
+        size_t nstmts = jl_array_len(stmts);
         aliasscopes.resize(nstmts + 1, nullptr);
         MDBuilder mbuilder(jl_LLVMContext);
         MDNode *alias_domain = mbuilder.createAliasScopeDomain(ctx.name);
@@ -6334,7 +6506,7 @@ static std::unique_ptr<Module> emit_func
 
             Value *isboxed_union = NULL;
             Value *retval;
-            Value *sret = ctx.has_sret ? &*f->arg_begin() : NULL;
+            Value *sret = has_sret ? f->arg_begin() : NULL;
             Type *retty = f->getReturnType();
             switch (returninfo.cc) {
             case jl_returninfo_t::Boxed:
@@ -6389,6 +6561,10 @@ static std::unique_ptr<Module> emit_func
             }
             if (sret) {
                 if (retvalinfo.ispointer()) {
+                    if (returninfo.return_roots) {
+                        Type *store_ty = julia_type_to_llvm(retvalinfo.typ);
+                        emit_sret_roots(ctx, true, data_pointer(ctx, retvalinfo), store_ty, f->arg_begin() + 1, returninfo.return_roots);
+                    }
                     if (returninfo.cc == jl_returninfo_t::SRet) {
                         assert(jl_is_concrete_type(jlrettype));
                         emit_memcpy(ctx, sret, nullptr, retvalinfo, jl_datatype_size(jlrettype),
@@ -6399,11 +6575,17 @@ static std::unique_ptr<Module> emit_func
                     }
                 }
                 else {
-                    Type *store_ty = julia_type_to_llvm(retvalinfo.typ);
+                    Type *store_ty = retvalinfo.V->getType();
                     Type *dest_ty = store_ty->getPointerTo();
+                    Value *Val = retvalinfo.V;
+                    if (returninfo.return_roots) {
+                        assert(julia_type_to_llvm(retvalinfo.typ) == store_ty);
+                        emit_sret_roots(ctx, false, Val, store_ty, f->arg_begin() + 1, returninfo.return_roots);
+                    }
                     if (dest_ty != sret->getType())
                         sret = emit_bitcast(ctx, sret, dest_ty);
-                    ctx.builder.CreateStore(emit_unbox(ctx, store_ty, retvalinfo, retvalinfo.typ), sret);
+                    ctx.builder.CreateAlignedStore(Val, sret, julia_alignment(retvalinfo.typ));
+                    assert(retvalinfo.TIndex == NULL && "unreachable"); // unimplemented representation
                 }
             }
 
@@ -6501,18 +6683,19 @@ static std::unique_ptr<Module> emit_func
     ctx.builder.SetCurrentDebugLocation(noDbg);
     ctx.builder.ClearInsertionPoint();
 
-    auto undef_value_for_type = [&](jl_value_t *phiType, Type *UndefType) {
-        Value *VNUndef;
-        if (UndefType == T_prjlvalue) {
-            VNUndef =  (llvm::Value*)ConstantPointerNull::get(cast<PointerType>(T_prjlvalue));
-        } else {
-            VNUndef = (llvm::Value*)UndefValue::get(UndefType);
-        }
-        return VNUndef;
+    auto undef_value_for_type = [&](Type *T) {
+        auto tracked = CountTrackedPointers(T);
+        Value *undef;
+        if (tracked.count)
+            // make sure gc pointers (including ptr_phi of union-split) are initialized to NULL
+            undef = Constant::getNullValue(T);
+        else
+            undef = UndefValue::get(T);
+        return undef;
     };
 
     // Codegen Phi nodes
-    std::map<std::pair<BasicBlock *, BasicBlock*>, BasicBlock*> BB_rewrite_map;
+    std::map<std::pair<BasicBlock*, BasicBlock*>, BasicBlock*> BB_rewrite_map;
     std::vector<llvm::PHINode*> ToDelete;
     for (auto &tup : ctx.PhiNodes) {
         jl_cgval_t phi_result;
@@ -6525,119 +6708,72 @@ static std::unique_ptr<Module> emit_func
         jl_array_t *edges = (jl_array_t*)jl_fieldref_noalloc(r, 0);
         jl_array_t *values = (jl_array_t*)jl_fieldref_noalloc(r, 1);
         PHINode *TindexN = cast_or_null<PHINode>(phi_result.TIndex);
+        DenseSet<BasicBlock*> preds;
         for (size_t i = 0; i < jl_array_len(edges); ++i) {
             size_t edge = jl_unbox_long(jl_array_ptr_ref(edges, i));
             jl_value_t *value = jl_array_ptr_ref(values, i);
-            Value *V = NULL;
-            BasicBlock *IncomingBB = come_from_bb[edge];
-            BasicBlock *FromBB = IncomingBB;
-            std::pair<BasicBlock *, BasicBlock*> LookupKey(IncomingBB, PhiBB);
-            if (BB_rewrite_map.count(LookupKey)) {
-                FromBB = BB_rewrite_map[LookupKey];
-            }
+            // This edge value is undef, handle it the same as if the edge wasn't listed at all
+            if (!value)
+                continue;
+            BasicBlock *FromBB = come_from_bb[edge];
             // This edge was statically unreachable. Don't codegen it.
             if (!FromBB)
                 continue;
-            // We folded this branch to an unconditional branch, only codegen it once
-            if (cast<BranchInst>(FromBB->getTerminator())->isUnconditional()) {
-                bool found = false;
+            // see if this edge has already been rewritten
+            // (we'll continue appending blocks to the current end)
+            std::pair<BasicBlock*, BasicBlock*> LookupKey(FromBB, PhiBB);
+            if (BB_rewrite_map.count(LookupKey)) {
+                FromBB = BB_rewrite_map[LookupKey];
+            }
+            if (!preds.insert(FromBB).second) {
+                // Only codegen this branch once for each PHI (the expression must be the same on all branches)
+#ifndef NDEBUG
                 for (size_t j = 0; j < i; ++j) {
                     size_t j_edge = jl_unbox_long(jl_array_ptr_ref(edges, j));
                     if (j_edge == edge) {
-                        found = true;
                         assert(jl_egal(value, jl_array_ptr_ref(values, j)));
                     }
                 }
-                if (found)
-                    continue;
-            }
-#ifndef JL_NDEBUG
-            if (FromBB) {
-                bool found_pred = false;
-                for (BasicBlock *pred : predecessors(PhiBB)) {
-                    found_pred = pred == FromBB;
-                    if (found_pred)
-                        break;
-                }
-                assert(found_pred);
-            }
 #endif
-            ctx.builder.SetInsertPoint(FromBB->getTerminator());
-            if (dest)
-                ctx.builder.CreateLifetimeStart(dest);
-            jl_cgval_t val;
-            if (!value || jl_is_ssavalue(value)) {
-                ssize_t idx = value ? ((jl_ssavalue_t*)value)->id : 0;
-                idx -= 1;
-                if (!value || !ctx.ssavalue_assigned.at(idx)) {
-                    Value *RTindex = TindexN ? UndefValue::get(T_int8) : NULL;
-                    if (VN) { // otherwise, it's all-unboxed
-                        Value *undef;
-                        if (isa<PointerType>(VN->getType())) {
-                            bool isboxed;
-                            Type *lphity = julia_type_to_llvm(phiType, &isboxed);
-                            if (!isboxed) {
-                                // the emit_phinode_assign emitted a memcpy in this case,
-                                // so this needs to ensure the pointer is valid, while the contents are undef
-                                undef = decay_derived(emit_static_alloca(ctx, lphity));
-                            }
-                            else {
-                                // but make sure gc pointers (including ptr_phi of union-split) are NULL
-                                undef = ConstantPointerNull::get(cast<PointerType>(VN->getType()));
-                                if (TindexN) // let the runtime / optimizer know this is unknown / boxed / null, so that it won't try to union_move / copy it later
-                                    RTindex = ConstantInt::get(T_int8, 0x80);
-                            }
-                        }
-                        else {
-                            undef = undef_value_for_type(phiType, VN->getType());
-                        }
-                        VN->addIncoming(undef, FromBB);
-                    }
-                    if (TindexN)
-                        TindexN->addIncoming(RTindex, FromBB);
-                    continue;
-                }
-                val = ctx.SAvalues.at(idx);
-            }
-            else {
-                val = emit_expr(ctx, value);
+                continue;
             }
-            if (val.constant)
-                val = mark_julia_const(val.constant); // be over-conservative at making sure `.typ` is set concretely, not tindex
+            assert(find(pred_begin(PhiBB), pred_end(PhiBB), FromBB) != pred_end(PhiBB)); // consistency check
             TerminatorInst *terminator = FromBB->getTerminator();
-            if (!isa<BranchInst>(terminator) ||
-                (cast<BranchInst>(terminator)->isConditional() &&
-                 !(terminator->getSuccessor(0) == terminator->getSuccessor(1)))) {
-                bool found = false;
-                for (size_t i = 0; i < terminator->getNumSuccessors(); ++i) {
-                    if (terminator->getSuccessor(i) == PhiBB) {
-                        // Can't use `llvm::SplitCriticalEdge` here because
-                        // we may have invalid phi nodes in the destination.
-                        BasicBlock *NewBB = BasicBlock::Create(terminator->getContext(),
-                           FromBB->getName() + "." + PhiBB->getName() + "_crit_edge");
-                        terminator->setSuccessor(i, NewBB);
-                        Function::iterator FBBI = FromBB->getIterator();
-                        ctx.f->getBasicBlockList().insert(++FBBI, NewBB);
-                        ctx.builder.SetInsertPoint(NewBB);
-                        terminator = BranchInst::Create(PhiBB);
-                        found = true;
-                        break;
-                    }
+            if (!terminator->getParent()->getUniqueSuccessor()) {
+                // Can't use `llvm::SplitCriticalEdge` here because
+                // we may have invalid phi nodes in the destination.
+                BasicBlock *NewBB = BasicBlock::Create(terminator->getContext(),
+                   FromBB->getName() + "." + PhiBB->getName() + "_crit_edge");
+                Function::iterator FBBI = FromBB->getIterator();
+                ctx.f->getBasicBlockList().insert(++FBBI, NewBB); // insert after existing block
+#if JL_LLVM_VERSION >= 90000
+                terminator->replaceSuccessorWith(PhiBB, NewBB);
+#else
+                for (unsigned Idx = 0, NumSuccessors = terminator->getNumSuccessors(); Idx != NumSuccessors; ++Idx) {
+                    if (terminator->getSuccessor(Idx) == PhiBB)
+                      terminator->setSuccessor(Idx, NewBB);
                 }
-                assert(found);
-                (void)found;
+#endif
+                DebugLoc Loc = terminator->getDebugLoc();
+                terminator = BranchInst::Create(PhiBB);
+                terminator->setDebugLoc(Loc);
+                ctx.builder.SetInsertPoint(NewBB);
             }
             else {
                 terminator->removeFromParent();
                 ctx.builder.SetInsertPoint(FromBB);
             }
+            if (dest)
+                ctx.builder.CreateLifetimeStart(dest);
+            jl_cgval_t val = emit_expr(ctx, value);
+            if (val.constant)
+                val = mark_julia_const(val.constant); // be over-conservative at making sure `.typ` is set concretely, not tindex
             if (!jl_is_uniontype(phiType) || !TindexN) {
+                Type *lty = julia_type_to_llvm(phiType);
                 if (VN) {
-                    // XXX: this code assumes that `val` is of type `phiType` statically,
-                    // that must be true dynamically, but we have not propagated that information here,
-                    // and thus this might generate invalid code
+                    Value *V;
                     if (val.typ == (jl_value_t*)jl_bottom_type) {
-                        V = undef_value_for_type(phiType, VN->getType());
+                        V = undef_value_for_type(VN->getType());
                     }
                     else if (VN && VN->getType() == T_prjlvalue) {
                         // Includes the jl_is_uniontype(phiType) && !TindexN case
@@ -6648,27 +6784,17 @@ static std::unique_ptr<Module> emit_func
                     }
                     VN->addIncoming(V, ctx.builder.GetInsertBlock());
                     assert(!TindexN);
-                } else if (dest && val.typ != (jl_value_t*)jl_bottom_type) {
-#if JL_LLVM_VERSION >= 70000
-                    ctx.builder.CreateMemCpy(maybe_decay_tracked(dest),
-                        jl_datatype_align(phiType),
-                        maybe_decay_tracked(data_pointer(ctx, val)),
-                        0,
-                        jl_datatype_size(phiType),
-                        false);
-#else
-                     ctx.builder.CreateMemCpy(maybe_decay_tracked(dest),
-                        maybe_decay_tracked(data_pointer(ctx, val)),
-                        jl_datatype_size(phiType),
-                        jl_datatype_align(phiType),
-                        false);
-#endif
+                }
+                else if (dest && val.typ != (jl_value_t*)jl_bottom_type) {
+                    assert(lty != T_prjlvalue);
+                    (void)emit_unbox(ctx, lty, val, phiType, maybe_decay_tracked(dest));
                 }
             }
             else {
-                Value *RTindex = NULL;
+                Value *RTindex;
+                Value *V;
                 if (val.typ == (jl_value_t*)jl_bottom_type) {
-                    V = undef_value_for_type(phiType, VN->getType());
+                    V = undef_value_for_type(VN->getType());
                     RTindex = UndefValue::get(T_int8);
                 }
                 else if (jl_is_concrete_type(val.typ) || val.constant) {
@@ -6713,24 +6839,32 @@ static std::unique_ptr<Module> emit_func
                 if (TindexN)
                     TindexN->addIncoming(RTindex, ctx.builder.GetInsertBlock());
             }
+            // put the branch back at the end of our current basic block
             ctx.builder.Insert(terminator);
-            // Check any phi nodes in the Phi block to see if by splitting the edges,
-            // we made things inconsistent
-            if (FromBB != ctx.builder.GetInsertBlock()) {
-                BB_rewrite_map[LookupKey] = ctx.builder.GetInsertBlock();
+            // Record the current tail of this Phi edge in the rewrite map and
+            // check any phi nodes in the Phi block to see if by emitting on the edges
+            // we made things inconsistent.
+            BasicBlock *NewBB = ctx.builder.GetInsertBlock();
+            if (FromBB != NewBB) {
+                BB_rewrite_map[LookupKey] = NewBB;
+                preds.insert(NewBB);
+#if JL_LLVM_VERSION >= 90000
+                PhiBB->replacePhiUsesWith(FromBB, NewBB);
+#else
                 for (BasicBlock::iterator I = PhiBB->begin(); isa<PHINode>(I); ++I) {
                     PHINode *PN = cast<PHINode>(I);
                     ssize_t BBIdx = PN->getBasicBlockIndex(FromBB);
                     if (BBIdx == -1)
                         continue;
-                    PN->setIncomingBlock(BBIdx, ctx.builder.GetInsertBlock());
+                    PN->setIncomingBlock(BBIdx, NewBB);
                 }
+#endif
             }
+            ctx.builder.ClearInsertionPoint();
         }
         // In LLVM IR it is illegal to have phi nodes without incoming values, even if
-        // there are no operands, so delete any such phi nodes
-        if (pred_begin(PhiBB) == pred_end(PhiBB))
-        {
+        // there are no operands (no incoming branches), so delete any such phi nodes
+        if (pred_empty(PhiBB)) {
             if (VN)
                 ToDelete.push_back(VN);
             if (TindexN)
@@ -6738,28 +6872,26 @@ static std::unique_ptr<Module> emit_func
             continue;
         }
         // Julia PHINodes may be incomplete with respect to predecessors, LLVM's may not
-        Value *VNUndef = nullptr;
-        if (VN || TindexN) {
-            for (auto *pred : predecessors(PhiBB)) {
-                PHINode *PhiN = VN ? VN : TindexN;
-                bool found = false;
-                for (size_t i = 0; i < PhiN->getNumIncomingValues(); ++i) {
-                    found = pred == PhiN->getIncomingBlock(i);
-                    if (found)
-                        break;
-                }
-                if (!found) {
-                    if (VN) {
-                        if (!VNUndef) {
-                            VNUndef = undef_value_for_type(phiType, VN->getType());
-                        }
-                        VN->addIncoming(VNUndef, pred);
-                    }
-                    if (TindexN) {
-                        TindexN->addIncoming(UndefValue::get(TindexN->getType()), pred);
-                    }
-                }
+        for (auto *FromBB : predecessors(PhiBB)) {
+            if (preds.count(FromBB))
+                continue;
+            ctx.builder.SetInsertPoint(FromBB->getTerminator());
+            // PHI is undef on this branch. But still may need to put a valid pointer in place.
+            Value *RTindex = TindexN ? UndefValue::get(T_int8) : NULL;
+            if (VN) {
+                Value *undef = undef_value_for_type(VN->getType());
+                VN->addIncoming(undef, FromBB);
+                if (TindexN) // let the runtime / optimizer know this is unknown / boxed / null, so that it won't try to union_move / copy it later
+                    RTindex = ConstantInt::get(T_int8, 0x80);
+            }
+            if (TindexN)
+                TindexN->addIncoming(RTindex, FromBB);
+            if (dest) {
+                ctx.builder.CreateLifetimeStart(dest);
+                if (CountTrackedPointers(dest->getAllocatedType()).count)
+                    ctx.builder.CreateStore(Constant::getNullValue(dest->getAllocatedType()), dest);
             }
+            ctx.builder.ClearInsertionPoint();
         }
     }
 
@@ -6940,7 +7072,9 @@ extern "C" void jl_fptr_to_llvm(void *fp
 static void init_julia_llvm_meta(void)
 {
     tbaa_gcframe = tbaa_make_child("jtbaa_gcframe").first;
-    tbaa_stack = tbaa_make_child("jtbaa_stack").first;
+    MDNode *tbaa_stack_scalar;
+    std::tie(tbaa_stack, tbaa_stack_scalar) = tbaa_make_child("jtbaa_stack");
+    tbaa_unionselbyte = tbaa_make_child("jtbaa_unionselbyte", tbaa_stack_scalar).first;
     MDNode *tbaa_data_scalar;
     std::tie(tbaa_data, tbaa_data_scalar) = tbaa_make_child("jtbaa_data");
     tbaa_binding = tbaa_make_child("jtbaa_binding", tbaa_data_scalar).first;
@@ -6960,7 +7094,6 @@ static void init_julia_llvm_meta(void)
     tbaa_arrayoffset = tbaa_make_child("jtbaa_arrayoffset", tbaa_array_scalar).first;
     tbaa_const = tbaa_make_child("jtbaa_const", nullptr, true).first;
     tbaa_arrayselbyte = tbaa_make_child("jtbaa_arrayselbyte", tbaa_array_scalar).first;
-    tbaa_unionselbyte = tbaa_make_child("jtbaa_unionselbyte", tbaa_data_scalar).first;
 
     Thunk = Attribute::get(jl_LLVMContext, "thunk");
 }
@@ -7214,16 +7347,17 @@ static void init_julia_llvm_env(Module *
     add_named_global(setjmp_func, &jl_setjmp_f);
 
     std::vector<Type*> args_memcmp(0);
-    args_memcmp.push_back(T_pint8_derived);
-    args_memcmp.push_back(T_pint8_derived);
+    args_memcmp.push_back(T_pint8);
+    args_memcmp.push_back(T_pint8);
     args_memcmp.push_back(T_size);
-    memcmp_derived_func =
+    memcmp_func =
         Function::Create(FunctionType::get(T_int32, args_memcmp, false),
                          Function::ExternalLinkage, "memcmp", m);
-    memcmp_derived_func->addFnAttr(Attribute::ReadOnly);
-    memcmp_derived_func->addFnAttr(Attribute::NoUnwind);
-    memcmp_derived_func->addFnAttr(Attribute::ArgMemOnly);
-    add_named_global(memcmp_derived_func, &memcmp);
+    memcmp_func->addFnAttr(Attribute::ReadOnly);
+    memcmp_func->addFnAttr(Attribute::NoUnwind);
+    memcmp_func->addFnAttr(Attribute::ArgMemOnly);
+    add_named_global(memcmp_func, &memcmp);
+    // TODO: inferLibFuncAttributes(*memcmp_func, TLI);
 
     std::vector<Type*> te_args(0);
     te_args.push_back(T_pint8);
@@ -7276,6 +7410,7 @@ static void init_julia_llvm_env(Module *
     builtin_func_map[jl_f_typeassert] = jlcall_func_to_llvm("jl_f_typeassert", &jl_f_typeassert, m);
     builtin_func_map[jl_f_ifelse] = jlcall_func_to_llvm("jl_f_ifelse", &jl_f_ifelse, m);
     builtin_func_map[jl_f__apply] = jlcall_func_to_llvm("jl_f__apply", &jl_f__apply, m);
+    builtin_func_map[jl_f__apply_iterate] = jlcall_func_to_llvm("jl_f__apply_iterate", &jl_f__apply_iterate, m);
     builtin_func_map[jl_f__apply_pure] = jlcall_func_to_llvm("jl_f__apply_pure", &jl_f__apply_pure, m);
     builtin_func_map[jl_f__apply_latest] = jlcall_func_to_llvm("jl_f__apply_latest", &jl_f__apply_latest, m);
     builtin_func_map[jl_f_throw] = jlcall_func_to_llvm("jl_f_throw", &jl_f_throw, m);
@@ -7526,8 +7661,7 @@ static void init_julia_llvm_env(Module *
     add_return_attr(jl_typeof_func, Attribute::NonNull);
     add_named_global(jl_typeof_func, (void*)NULL, /*dllimport*/false);
 
-    jl_write_barrier_func = Function::Create(FunctionType::get(T_void,
-                                                               {T_prjlvalue, T_prjlvalue}, false),
+    jl_write_barrier_func = Function::Create(FunctionType::get(T_void, {T_prjlvalue,}, true),
                                              Function::ExternalLinkage,
                                              "julia.write_barrier");
     jl_write_barrier_func->addFnAttr(Attribute::InaccessibleMemOnly);
diff -pruN 1.3.1+dfsg-1/src/codegen_shared.h 1.4.0+dfsg-1/src/codegen_shared.h
--- 1.3.1+dfsg-1/src/codegen_shared.h	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/src/codegen_shared.h	2020-03-21 16:36:32.000000000 +0000
@@ -1,7 +1,9 @@
 // This file is a part of Julia. License is MIT: https://julialang.org/license
 
+#include <utility>
 #include <llvm/Support/Debug.h>
 #include <llvm/IR/DebugLoc.h>
+#include <llvm/IR/IRBuilder.h>
 
 enum AddressSpace {
     Generic = 0,
@@ -17,6 +19,17 @@ enum AddressSpace {
 #define JLCALL_F_CC (CallingConv::ID)37     // (jl_value_t *arg0, jl_value_t **argv, uint32_t nargv)
 #define JLCALL_F2_CC (CallingConv::ID)38    // (jl_value_t *arg0, jl_value_t **argv, uint32_t nargv, jl_value_t *extra)
 
+// return how many Tracked pointers are in T (count > 0),
+// and if there is anything else in T (all == false)
+struct CountTrackedPointers {
+    unsigned count = 0;
+    bool all = true;
+    bool derived = false;
+    CountTrackedPointers(llvm::Type *T);
+};
+unsigned TrackWithShadow(llvm::Value *Src, llvm::Type *T, bool isptr, llvm::Value *Dst, llvm::IRBuilder<> irbuilder);
+std::vector<llvm::Value*> ExtractTrackedValues(llvm::Value *Src, llvm::Type *STy, bool isptr, llvm::IRBuilder<> irbuilder);
+
 static inline void llvm_dump(llvm::Value *v)
 {
     v->print(llvm::dbgs(), true);
diff -pruN 1.3.1+dfsg-1/src/datatype.c 1.4.0+dfsg-1/src/datatype.c
--- 1.3.1+dfsg-1/src/datatype.c	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/src/datatype.c	2020-03-21 16:36:32.000000000 +0000
@@ -99,29 +99,24 @@ jl_datatype_t *jl_new_uninitialized_data
 }
 
 static jl_datatype_layout_t *jl_get_layout(uint32_t nfields,
+                                           uint32_t npointers,
                                            uint32_t alignment,
                                            int haspadding,
-                                           jl_fielddesc32_t desc[]) JL_NOTSAFEPOINT
+                                           jl_fielddesc32_t desc[],
+                                           uint32_t pointers[]) JL_NOTSAFEPOINT
 {
+    assert(alignment); // should have been verified by caller
+
     // compute the smallest fielddesc type that can hold the layout description
     int fielddesc_type = 0;
-    uint32_t npointers = 0;
-    // First pointer field
-    uint32_t first_ptr = (uint32_t)-1;
-    // Last pointer field
-    uint32_t last_ptr = 0;
     if (nfields > 0) {
         uint32_t max_size = 0;
         uint32_t max_offset = desc[nfields - 1].offset;
+        if (npointers > 0 && pointers[npointers - 1] > max_offset)
+            max_offset = pointers[npointers - 1];
         for (size_t i = 0; i < nfields; i++) {
             if (desc[i].size > max_size)
                 max_size = desc[i].size;
-            if (desc[i].isptr) {
-                npointers++;
-                if (first_ptr == (uint32_t)-1)
-                    first_ptr = i;
-                last_ptr = i;
-            }
         }
         jl_fielddesc8_t maxdesc8 = { 0, max_size, max_offset };
         jl_fielddesc16_t maxdesc16 = { 0, max_size, max_offset };
@@ -138,25 +133,17 @@ static jl_datatype_layout_t *jl_get_layo
     }
 
     // allocate a new descriptor
+    // TODO: lots of these are the same--take advantage of the fact these are immutable to combine them
     uint32_t fielddesc_size = jl_fielddesc_size(fielddesc_type);
-    int has_padding = nfields && npointers;
-    jl_datatype_layout_t *flddesc =
-        (jl_datatype_layout_t*)jl_gc_perm_alloc(sizeof(jl_datatype_layout_t) +
-                                                nfields * fielddesc_size +
-                                                (has_padding ? sizeof(uint32_t) : 0), 0, 4, 0);
-    if (has_padding) {
-        if (first_ptr > UINT16_MAX)
-            first_ptr = UINT16_MAX;
-        last_ptr = nfields - last_ptr - 1;
-        if (last_ptr > UINT16_MAX)
-            last_ptr = UINT16_MAX;
-        flddesc = (jl_datatype_layout_t*)(((char*)flddesc) + sizeof(uint32_t));
-        jl_datatype_layout_n_nonptr(flddesc) = (first_ptr << 16) | last_ptr;
-    }
+    jl_datatype_layout_t *flddesc = (jl_datatype_layout_t*)jl_gc_perm_alloc(
+                sizeof(jl_datatype_layout_t) + nfields * fielddesc_size + (npointers << fielddesc_type),
+                0, 4, 0);
     flddesc->nfields = nfields;
     flddesc->alignment = alignment;
     flddesc->haspadding = haspadding;
     flddesc->fielddesc_type = fielddesc_type;
+    flddesc->npointers = npointers;
+    flddesc->first_ptr = (npointers > 0 ? pointers[0] : -1);
 
     // fill out the fields of the new descriptor
     jl_fielddesc8_t* desc8 = (jl_fielddesc8_t*)jl_dt_layout_fields(flddesc);
@@ -179,12 +166,20 @@ static jl_datatype_layout_t *jl_get_layo
             desc32[i].isptr = desc[i].isptr;
         }
     }
-    uint32_t nexp = 0;
-    while (npointers >= 0x10000) {
-        nexp++;
-        npointers = npointers >> 1;
+    uint8_t* ptrs8 = (uint8_t*)jl_dt_layout_ptrs(flddesc);
+    uint16_t* ptrs16 = (uint16_t*)jl_dt_layout_ptrs(flddesc);
+    uint32_t* ptrs32 = (uint32_t*)jl_dt_layout_ptrs(flddesc);
+    for (size_t i = 0; i < npointers; i++) {
+        if (fielddesc_type == 0) {
+            ptrs8[i] = pointers[i];
+        }
+        else if (fielddesc_type == 1) {
+            ptrs16[i] = pointers[i];
+        }
+        else {
+            ptrs32[i] = pointers[i];
+        }
     }
-    flddesc->npointers = npointers | (nexp << 16);
     return flddesc;
 }
 
@@ -198,19 +193,7 @@ unsigned jl_special_vector_alignment(siz
 {
     if (!jl_is_vecelement_type(t))
         return 0;
-    // LLVM 3.7 and 3.8 either crash or generate wrong code for many
-    // SIMD vector sizes N. It seems the rule is that N can have at
-    // most 2 non-zero bits. (This is true at least for N<=100.) See
-    // also <https://llvm.org/bugs/show_bug.cgi?id=27708>.
-    size_t mask = nfields;
-    // See e.g.
-    // <https://graphics.stanford.edu/%7Eseander/bithacks.html> for an
-    // explanation of this bit-counting algorithm.
-    mask &= mask-1;             // clear least-significant 1 if present
-    mask &= mask-1;             // clear another 1
-    if (mask)
-        return 0;               // nfields has more than two 1s
-    assert(jl_datatype_nfields(t)==1);
+    assert(jl_datatype_nfields(t) == 1);
     jl_value_t *ty = jl_field_type((jl_datatype_t*)t, 0);
     if (!jl_is_primitivetype(ty))
         // LLVM requires that a vector element be a primitive type.
@@ -218,16 +201,12 @@ unsigned jl_special_vector_alignment(siz
         // motivating use case comes up for Julia, we reject pointers.
         return 0;
     size_t elsz = jl_datatype_size(ty);
-    if (elsz>8 || (1<<elsz & 0x116) == 0)
-        // Element size is not 1, 2, 4, or 8.
+    if (elsz != 1 && elsz != 2 && elsz != 4 && elsz != 8)
+        // Only handle power-of-two-sized elements (for now)
         return 0;
-    size_t size = nfields*elsz;
-    // LLVM's alignment rule for vectors seems to be to round up to
-    // a power of two, even if that's overkill for the target hardware.
-    size_t alignment=1;
-    for( ; size>alignment; alignment*=2 )
-        continue;
-    return alignment;
+    size_t size = nfields * elsz;
+    // Use natural alignment for this vector: this matches LLVM and clang.
+    return next_power_of_two(size);
 }
 
 STATIC_INLINE int jl_is_datatype_make_singleton(jl_datatype_t *d)
@@ -236,7 +215,7 @@ STATIC_INLINE int jl_is_datatype_make_si
             d->uid != 0 && !d->mutabl);
 }
 
-STATIC_INLINE void jl_allocate_singleton_instance(jl_datatype_t *st)
+STATIC_INLINE void jl_maybe_allocate_singleton_instance(jl_datatype_t *st)
 {
     if (jl_is_datatype_make_singleton(st)) {
         st->instance = jl_gc_alloc(jl_get_ptls_states(), 0, st);
@@ -244,18 +223,18 @@ STATIC_INLINE void jl_allocate_singleton
     }
 }
 
-static unsigned union_isbits(jl_value_t *ty, size_t *nbytes, size_t *align) JL_NOTSAFEPOINT
+static unsigned union_isinlinable(jl_value_t *ty, int pointerfree, size_t *nbytes, size_t *align) JL_NOTSAFEPOINT
 {
     if (jl_is_uniontype(ty)) {
-        unsigned na = union_isbits(((jl_uniontype_t*)ty)->a, nbytes, align);
+        unsigned na = union_isinlinable(((jl_uniontype_t*)ty)->a, 1, nbytes, align);
         if (na == 0)
             return 0;
-        unsigned nb = union_isbits(((jl_uniontype_t*)ty)->b, nbytes, align);
+        unsigned nb = union_isinlinable(((jl_uniontype_t*)ty)->b, 1, nbytes, align);
         if (nb == 0)
             return 0;
         return na + nb;
     }
-    if (jl_isbits(ty)) {
+    if (jl_is_datatype(ty) && jl_datatype_isinlinealloc(ty) && (!pointerfree || ((jl_datatype_t*)ty)->layout->npointers == 0)) {
         size_t sz = jl_datatype_size(ty);
         size_t al = jl_datatype_align(ty);
         if (*nbytes < sz)
@@ -269,10 +248,36 @@ static unsigned union_isbits(jl_value_t
 
 JL_DLLEXPORT int jl_islayout_inline(jl_value_t *eltype, size_t *fsz, size_t *al) JL_NOTSAFEPOINT
 {
-    unsigned countbits = union_isbits(eltype, fsz, al);
+    unsigned countbits = union_isinlinable(eltype, 0, fsz, al);
     return (countbits > 0 && countbits < 127) ? countbits : 0;
 }
 
+JL_DLLEXPORT int jl_stored_inline(jl_value_t *eltype) JL_NOTSAFEPOINT
+{
+    size_t fsz = 0, al = 0;
+    return jl_islayout_inline(eltype, &fsz, &al);
+}
+
+// whether instances of this type can use pointer comparison for `===`
+int jl_pointer_egal(jl_value_t *t)
+{
+    if (t == (jl_value_t*)jl_any_type)
+        return 0; // when setting up the initial types, jl_is_type_type gets confused about this
+    if (t == (jl_value_t*)jl_symbol_type)
+        return 1;
+    if (jl_is_mutable_datatype(t) && // excludes abstract types
+        t != (jl_value_t*)jl_string_type && // technically mutable, but compared by contents
+        t != (jl_value_t*)jl_simplevector_type &&
+        !jl_is_kind(t))
+        return 1;
+    if (jl_is_type_type(t) && jl_is_concrete_type(jl_tparam0(t))) {
+        // need to use typeseq for most types
+        // but can compare some types by pointer
+        return 1;
+    }
+    return 0;
+}
+
 static int references_name(jl_value_t *p, jl_typename_t *name) JL_NOTSAFEPOINT
 {
     if (jl_is_uniontype(p))
@@ -287,6 +292,8 @@ static int references_name(jl_value_t *p
     if (jl_is_datatype(p)) {
         if (((jl_datatype_t*)p)->name == name)
             return 1;
+        if (((jl_datatype_t*)p)->layout && jl_datatype_nfields(p) == 0)
+            return 0;
         size_t i, l = jl_nparams(p);
         for (i = 0; i < l; i++) {
             if (references_name(jl_tparam(p, i), name))
@@ -296,161 +303,216 @@ static int references_name(jl_value_t *p
     return 0;
 }
 
+static void throw_ovf(int should_malloc, void *desc, jl_datatype_t* st, int offset)
+{
+    if (should_malloc)
+        free(desc);
+    jl_errorf("type %s has field offset %d that exceeds the page size", jl_symbol_name(st->name->name), offset);
+}
+
 void jl_compute_field_offsets(jl_datatype_t *st)
 {
-    size_t sz = 0, alignm = 1;
-    int homogeneous = 1;
-    jl_value_t *lastty = NULL;
-    uint64_t max_offset = (((uint64_t)1) << 32) - 1;
-    uint64_t max_size = max_offset >> 1;
-
-    if (st->name->wrapper) {
-        jl_datatype_t *w = (jl_datatype_t*)jl_unwrap_unionall(st->name->wrapper);
-        // compute whether this type can be inlined
-        // based on whether its definition is self-referential
-        if (w->types != NULL) {
-            st->isbitstype = st->isconcretetype && !st->mutabl;
-            size_t i, nf = jl_svec_len(st->types);
-            for (i = 0; i < nf; i++) {
-                jl_value_t *fld = jl_svecref(st->types, i);
-                if (st->isbitstype)
-                    st->isbitstype = jl_is_datatype(fld) && ((jl_datatype_t*)fld)->isbitstype;
-                if (!st->zeroinit)
-                    st->zeroinit = (jl_is_datatype(fld) && ((jl_datatype_t*)fld)->isinlinealloc) ? ((jl_datatype_t*)fld)->zeroinit : 1;
-                if (i < st->ninitialized) {
-                    if (fld == jl_bottom_type)
-                        st->has_concrete_subtype = 0;
-                    else
-                        st->has_concrete_subtype &= !jl_is_datatype(fld) || ((jl_datatype_t *)fld)->has_concrete_subtype;
-                }
-            }
-            if (st->isbitstype) {
-                st->isinlinealloc = 1;
-                size_t i, nf = jl_svec_len(w->types);
-                for (i = 0; i < nf; i++) {
-                    jl_value_t *fld = jl_svecref(w->types, i);
-                    if (references_name(fld, w->name)) {
-                        st->isinlinealloc = 0;
-                        st->isbitstype = 0;
-                        st->zeroinit = 1;
-                        break;
-                    }
-                }
-            }
-        }
-        // If layout doesn't depend on type parameters, it's stored in st->name->wrapper
-        // and reused by all subtypes.
-        if (st != w && // this check allows us to re-compute layout for some types during init
-                w->layout) {
-            st->layout = w->layout;
-            st->size = w->size;
-            jl_allocate_singleton_instance(st);
+    const uint64_t max_offset = (((uint64_t)1) << 32) - 1;
+    const uint64_t max_size = max_offset >> 1;
+
+    if (st->types == NULL || st->name->wrapper == NULL || (jl_is_namedtuple_type(st) && !jl_is_concrete_type((jl_value_t*)st)))
+        return;
+    jl_datatype_t *w = (jl_datatype_t*)jl_unwrap_unionall(st->name->wrapper);
+    if (w->types == NULL) // we got called too early--we'll be back
+        return;
+    size_t i, nfields = jl_svec_len(st->types);
+    int isinlinealloc = st->isconcretetype && !st->mutabl;
+    int isbitstype = isinlinealloc;
+    assert(st->ninitialized <= nfields);
+    if (st == w && st->layout) {
+        // this check allows us to force re-computation of the layout for some types during init
+        st->layout = NULL;
+        st->size = 0;
+        st->zeroinit = 0;
+        st->has_concrete_subtype = 1;
+    }
+    // If layout doesn't depend on type parameters, it's stored in st->name->wrapper
+    // and reused by all subtypes.
+    if (w->layout) {
+        st->layout = w->layout;
+        st->size = w->size;
+        st->zeroinit = w->zeroinit;
+        st->has_concrete_subtype = w->has_concrete_subtype;
+        if (jl_is_layout_opaque(st->layout)) { // e.g. jl_array_typename
             return;
         }
     }
-    if (st->types == NULL || (jl_is_namedtuple_type(st) && !jl_is_concrete_type((jl_value_t*)st)))
-        return;
-    uint32_t nfields = jl_svec_len(st->types);
-    if (nfields == 0) {
+    else if (nfields == 0) {
+        // if we have no fields, we can trivially skip the rest
         if (st == jl_symbol_type || st == jl_string_type) {
             // opaque layout - heap-allocated blob
-            static const jl_datatype_layout_t opaque_byte_layout = {0, 1, 0, 1, 0};
+            static const jl_datatype_layout_t opaque_byte_layout = {0, 1, -1, 1, 0, 0};
             st->layout = &opaque_byte_layout;
+            return;
         }
         else if (st == jl_simplevector_type || st->name == jl_array_typename) {
-            static const jl_datatype_layout_t opaque_ptr_layout = {0, sizeof(void*), 0, 1, 0};
+            static const jl_datatype_layout_t opaque_ptr_layout = {0, 1, -1, sizeof(void*), 0, 0};
             st->layout = &opaque_ptr_layout;
+            return;
         }
         else {
             // reuse the same layout for all singletons
-            static const jl_datatype_layout_t singleton_layout = {0, 1, 0, 0, 0};
+            static const jl_datatype_layout_t singleton_layout = {0, 0, -1, 1, 0, 0};
             st->layout = &singleton_layout;
-            jl_allocate_singleton_instance(st);
         }
-        return;
     }
-    if (!jl_is_concrete_type((jl_value_t*)st)) {
-        // compute layout whenever field types have no free variables
-        for (size_t i = 0; i < nfields; i++) {
-            if (jl_has_free_typevars(jl_field_type(st, i)))
-                return;
+    else {
+        // compute a conservative estimate of whether there could exist an instance of a subtype of this
+        for (i = 0; st->has_concrete_subtype && i < st->ninitialized; i++) {
+            jl_value_t *fld = jl_svecref(st->types, i);
+            if (fld == jl_bottom_type)
+                st->has_concrete_subtype = 0;
+            else
+                st->has_concrete_subtype = !jl_is_datatype(fld) || ((jl_datatype_t *)fld)->has_concrete_subtype;
+        }
+        // compute layout for the wrapper object if the field types have no free variables
+        if (!st->isconcretetype) {
+            if (st != w)
+                return; // otherwise we would leak memory
+            for (i = 0; i < nfields; i++) {
+                if (jl_has_free_typevars(jl_field_type(st, i)))
+                    return; // not worthwhile computing the rest
+            }
         }
     }
 
-    size_t descsz = nfields * sizeof(jl_fielddesc32_t);
-    jl_fielddesc32_t *desc;
-    int should_malloc = descsz >= jl_page_size;
-    if (should_malloc)
-        desc = (jl_fielddesc32_t*)malloc(descsz);
-    else
-        desc = (jl_fielddesc32_t*)alloca(descsz);
-    int haspadding = 0;
-    assert(st->name == jl_tuple_typename ||
-           st == jl_symbol_type ||
-           st == jl_simplevector_type ||
-           nfields != 0);
+    // compute whether this type may ever be inlined
+    // based solely on whether its definition is self-referential
+    if (isinlinealloc) {
+        size_t i, nf = jl_svec_len(w->types);
+        for (i = 0; i < nf; i++) {
+            jl_value_t *fld = jl_svecref(w->types, i);
+            if (references_name(fld, w->name)) {
+                isinlinealloc = 0;
+                isbitstype = 0;
+                break;
+            }
+        }
+        for (i = 0; isbitstype && i < nfields; i++) {
+            jl_value_t *fld = jl_field_type(st, i);
+            isbitstype = jl_isbits(fld);
+        }
+    }
 
-    for (size_t i = 0; i < nfields; i++) {
-        jl_value_t *ty = jl_field_type(st, i);
-        size_t fsz = 0, al = 1;
-        if (jl_islayout_inline(ty, &fsz, &al)) {
-            if (__unlikely(fsz > max_size))
-                // Should never happen
-                goto throw_ovf;
-            desc[i].isptr = 0;
-            if (jl_is_uniontype(ty)) {
-                haspadding = 1;
-                fsz += 1; // selector byte
+    // if we didn't reuse the layout above, compute it now
+    if (st->layout == NULL) {
+        size_t descsz = nfields * sizeof(jl_fielddesc32_t);
+        jl_fielddesc32_t *desc;
+        uint32_t *pointers;
+        int should_malloc = descsz >= jl_page_size;
+        if (should_malloc)
+            desc = (jl_fielddesc32_t*)malloc_s(descsz);
+        else
+            desc = (jl_fielddesc32_t*)alloca(descsz);
+        size_t sz = 0;
+        size_t alignm = 1;
+        int zeroinit = 0;
+        int haspadding = 0;
+        int homogeneous = 1;
+        uint32_t npointers = 0;
+        jl_value_t *firstty = jl_field_type(st, 0);
+        for (i = 0; i < nfields; i++) {
+            jl_value_t *fld = jl_field_type(st, i);
+            size_t fsz = 0, al = 1;
+            if (jl_islayout_inline(fld, &fsz, &al)) { // aka jl_datatype_isinlinealloc
+                if (__unlikely(fsz > max_size))
+                    // Should never happen
+                    throw_ovf(should_malloc, desc, st, fsz);
+                desc[i].isptr = 0;
+                if (jl_is_uniontype(fld)) {
+                    haspadding = 1;
+                    fsz += 1; // selector byte
+                    zeroinit = 1;
+                }
+                else {
+                    if (((jl_datatype_t*)fld)->layout->haspadding)
+                        haspadding = 1;
+                    if (!zeroinit)
+                        zeroinit = ((jl_datatype_t*)fld)->zeroinit;
+                    npointers += ((jl_datatype_t*)fld)->layout->npointers;
+                }
+            }
+            else {
+                fsz = sizeof(void*);
+                if (fsz > MAX_ALIGN)
+                    fsz = MAX_ALIGN;
+                al = fsz;
+                desc[i].isptr = 1;
+                zeroinit = 1;
+                npointers++;
+                if (!jl_pointer_egal(fld)) {
+                    // this somewhat poorly named flag says whether some of the bits can be non-unique
+                    haspadding = 1;
+                }
             }
-            else { // isbits struct
-                if (((jl_datatype_t*)ty)->layout->haspadding)
+            if (al != 0) {
+                size_t alsz = LLT_ALIGN(sz, al);
+                if (sz & (al - 1))
                     haspadding = 1;
+                sz = alsz;
+                if (al > alignm)
+                    alignm = al;
             }
-        }
-        else {
-            fsz = sizeof(void*);
-            if (fsz > MAX_ALIGN)
-                fsz = MAX_ALIGN;
-            al = fsz;
-            desc[i].isptr = 1;
-        }
-        assert(al <= JL_HEAP_ALIGNMENT && (JL_HEAP_ALIGNMENT % al) == 0);
-        if (al != 0) {
-            size_t alsz = LLT_ALIGN(sz, al);
-            if (sz & (al - 1))
-                haspadding = 1;
-            sz = alsz;
+            homogeneous &= firstty == fld;
+            desc[i].offset = sz;
+            desc[i].size = fsz;
+            if (__unlikely(max_offset - sz < fsz))
+                throw_ovf(should_malloc, desc, st, sz);
+            sz += fsz;
+        }
+        if (homogeneous && jl_is_tuple_type(st)) {
+            // Some tuples become LLVM vectors with stronger alignment than what was calculated above.
+            unsigned al = jl_special_vector_alignment(nfields, firstty);
+            assert(al % alignm == 0);
             if (al > alignm)
                 alignm = al;
         }
-        homogeneous &= lastty==NULL || lastty==ty;
-        lastty = ty;
-        desc[i].offset = sz;
-        desc[i].size = fsz;
-        if (__unlikely(max_offset - sz < fsz))
-            goto throw_ovf;
-        sz += fsz;
-    }
-    if (homogeneous && lastty != NULL && jl_is_tuple_type(st)) {
-        // Some tuples become LLVM vectors with stronger alignment than what was calculated above.
-        unsigned al = jl_special_vector_alignment(nfields, lastty);
-        assert(al % alignm == 0);
-        // JL_HEAP_ALIGNMENT is the biggest alignment we can guarantee on the heap.
-        if (al > JL_HEAP_ALIGNMENT)
-            alignm = JL_HEAP_ALIGNMENT;
-        else if (al)
-            alignm = al;
-    }
-    st->size = LLT_ALIGN(sz, alignm);
-    if (st->size > sz)
-        haspadding = 1;
-    st->layout = jl_get_layout(nfields, alignm, haspadding, desc);
-    if (should_malloc) free(desc);
-    jl_allocate_singleton_instance(st);
+        st->size = LLT_ALIGN(sz, alignm);
+        if (st->size > sz)
+            haspadding = 1;
+        if (should_malloc && npointers)
+            pointers = (uint32_t*)malloc_s(npointers * sizeof(uint32_t));
+        else
+            pointers = (uint32_t*)alloca(npointers * sizeof(uint32_t));
+        size_t ptr_i = 0;
+        for (i = 0; i < nfields; i++) {
+            jl_value_t *fld = jl_field_type(st, i);
+            uint32_t offset = desc[i].offset / sizeof(jl_value_t**);
+            if (desc[i].isptr)
+                pointers[ptr_i++] = offset;
+            else if (jl_is_datatype(fld)) {
+                int j, npointers = ((jl_datatype_t*)fld)->layout->npointers;
+                for (j = 0; j < npointers; j++) {
+                    pointers[ptr_i++] = offset + jl_ptr_offset((jl_datatype_t*)fld, j);
+                }
+            }
+        }
+        assert(ptr_i == npointers);
+        st->layout = jl_get_layout(nfields, npointers, alignm, haspadding, desc, pointers);
+        if (should_malloc) {
+            free(desc);
+            if (npointers)
+                free(pointers);
+        }
+    }
+    // now finish deciding if this instantiation qualifies for special properties
+    assert(!isbitstype || st->layout->npointers == 0); // the definition of isbits
+    if (isinlinealloc && st->layout->npointers > 0) {
+        //if (st->ninitialized != nfields)
+        //    isinlinealloc = 0;
+        //else if (st->layout->fielddesc_type != 0) // GC only implements support for this
+        //    isinlinealloc = 0;
+        isinlinealloc = 0;
+    }
+    st->isbitstype = isbitstype;
+    st->isinlinealloc = isinlinealloc;
+    jl_maybe_allocate_singleton_instance(st);
     return;
- throw_ovf:
-    if (should_malloc) free(desc);
-    jl_errorf("type %s has field offset %d that exceeds the page size", jl_symbol_name(st->name->name), descsz);
 }
 
 static int is_anonfn_typename(char *name)
@@ -552,7 +614,7 @@ JL_DLLEXPORT jl_datatype_t *jl_new_primi
         alignm = MAX_ALIGN;
     bt->isbitstype = bt->isinlinealloc = (parameters == jl_emptysvec);
     bt->size = nbytes;
-    bt->layout = jl_get_layout(0, alignm, 0, NULL);
+    bt->layout = jl_get_layout(0, 0, alignm, 0, NULL, NULL);
     bt->instance = NULL;
     return bt;
 }
@@ -820,7 +882,7 @@ JL_DLLEXPORT jl_value_t *jl_new_struct(j
     va_start(args, type);
     jl_value_t *jv = jl_gc_alloc(ptls, jl_datatype_size(type), type);
     for (size_t i = 0; i < nf; i++) {
-        jl_set_nth_field(jv, i, va_arg(args, jl_value_t*));
+        set_nth_field(type, (void*)jv, i, va_arg(args, jl_value_t*));
     }
     va_end(args);
     return jv;
@@ -829,14 +891,15 @@ JL_DLLEXPORT jl_value_t *jl_new_struct(j
 static void init_struct_tail(jl_datatype_t *type, jl_value_t *jv, size_t na)
 {
     size_t nf = jl_datatype_nfields(type);
-    for(size_t i=na; i < nf; i++) {
+    char *data = (char*)jl_data_ptr(jv);
+    for (size_t i = na; i < nf; i++) {
         if (jl_field_isptr(type, i)) {
-            *(jl_value_t**)((char*)jl_data_ptr(jv)+jl_field_offset(type,i)) = NULL;
+            *(jl_value_t**)(data + jl_field_offset(type, i)) = NULL;
         }
         else {
             jl_value_t *ft = jl_field_type(type, i);
             if (jl_is_uniontype(ft)) {
-                uint8_t *psel = &((uint8_t *)jv)[jl_field_offset(type, i) + jl_field_size(type, i) - 1];
+                uint8_t *psel = &((uint8_t *)data)[jl_field_offset(type, i) + jl_field_size(type, i) - 1];
                 *psel = 0;
             }
         }
@@ -846,6 +909,10 @@ static void init_struct_tail(jl_datatype
 JL_DLLEXPORT jl_value_t *jl_new_structv(jl_datatype_t *type, jl_value_t **args, uint32_t na)
 {
     jl_ptls_t ptls = jl_get_ptls_states();
+    if (!jl_is_datatype(type) || type->layout == NULL)
+        jl_type_error("new", (jl_value_t*)jl_datatype_type, (jl_value_t*)type);
+    if (type->ninitialized > na || na > jl_datatype_nfields(type))
+        jl_error("invalid struct allocation");
     if (type->instance != NULL) {
         for (size_t i = 0; i < na; i++) {
             jl_value_t *ft = jl_field_type(type, i);
@@ -854,15 +921,13 @@ JL_DLLEXPORT jl_value_t *jl_new_structv(
         }
         return type->instance;
     }
-    if (type->layout == NULL)
-        jl_type_error("new", (jl_value_t*)jl_datatype_type, (jl_value_t*)type);
     jl_value_t *jv = jl_gc_alloc(ptls, jl_datatype_size(type), type);
     JL_GC_PUSH1(&jv);
     for (size_t i = 0; i < na; i++) {
         jl_value_t *ft = jl_field_type(type, i);
         if (!jl_isa(args[i], ft))
             jl_type_error("new", ft, args[i]);
-        jl_set_nth_field(jv, i, args[i]);
+        set_nth_field(type, (void*)jv, i, args[i]);
     }
     init_struct_tail(type, jv, na);
     JL_GC_POP();
@@ -874,7 +939,7 @@ JL_DLLEXPORT jl_value_t *jl_new_structt(
     jl_ptls_t ptls = jl_get_ptls_states();
     if (!jl_is_tuple(tup))
         jl_type_error("new", (jl_value_t*)jl_tuple_type, tup);
-    if (type->layout == NULL)
+    if (!jl_is_datatype(type) || type->layout == NULL)
         jl_type_error("new", (jl_value_t *)jl_datatype_type, (jl_value_t *)type);
     size_t nargs = jl_nfields(tup);
     size_t nf = jl_datatype_nfields(type);
@@ -898,7 +963,7 @@ JL_DLLEXPORT jl_value_t *jl_new_structt(
         fi = jl_get_nth_field(tup, i);
         if (!jl_isa(fi, ft))
             jl_type_error("new", ft, fi);
-        jl_set_nth_field(jv, i, fi);
+        set_nth_field(type, (void*)jv, i, fi);
     }
     JL_GC_POP();
     return jv;
@@ -982,7 +1047,7 @@ JL_DLLEXPORT jl_value_t *jl_get_nth_fiel
     size_t offs = jl_field_offset(st, i);
     if (jl_field_isptr(st, i)) {
         jl_value_t *fval = *(jl_value_t**)((char*)v + offs);
-        if (fval == NULL)
+        if (__unlikely(fval == NULL))
             jl_throw(jl_undefref_exception);
         return fval;
     }
@@ -994,16 +1059,16 @@ JL_DLLEXPORT jl_value_t *jl_get_nth_fiel
         if (jl_is_datatype_singleton((jl_datatype_t*)ty))
             return ((jl_datatype_t*)ty)->instance;
     }
-    return jl_new_bits(ty, (char*)v + offs);
+    return undefref_check((jl_datatype_t*)ty, jl_new_bits(ty, (char*)v + offs));
 }
 
-JL_DLLEXPORT void jl_set_nth_field(jl_value_t *v, size_t i, jl_value_t *rhs) JL_NOTSAFEPOINT
+void set_nth_field(jl_datatype_t *st, void *v, size_t i, jl_value_t *rhs) JL_NOTSAFEPOINT
 {
-    jl_datatype_t *st = (jl_datatype_t*)jl_typeof(v);
     size_t offs = jl_field_offset(st, i);
     if (jl_field_isptr(st, i)) {
         *(jl_value_t**)((char*)v + offs) = rhs;
-        if (rhs != NULL) jl_gc_wb(v, rhs);
+        if (rhs != NULL)
+            jl_gc_wb(v, rhs);
     }
     else {
         jl_value_t *ty = jl_field_type_concrete(st, i);
@@ -1017,6 +1082,7 @@ JL_DLLEXPORT void jl_set_nth_field(jl_va
                 return;
         }
         jl_assign_bits((char*)v + offs, rhs);
+        jl_gc_multi_wb(v, rhs);
     }
 }
 
@@ -1024,8 +1090,13 @@ JL_DLLEXPORT int jl_field_isdefined(jl_v
 {
     jl_datatype_t *st = (jl_datatype_t*)jl_typeof(v);
     size_t offs = jl_field_offset(st, i);
+    char *fld = (char*)v + offs;
     if (jl_field_isptr(st, i)) {
-        return *(jl_value_t**)((char*)v + offs) != NULL;
+        return *(jl_value_t**)fld != NULL;
+    }
+    jl_datatype_t *ft = (jl_datatype_t*)jl_field_type(st, i);
+    if (jl_is_datatype(ft) && ft->layout->first_ptr >= 0) {
+         return ((jl_value_t**)fld)[ft->layout->first_ptr] != NULL;
     }
     return 1;
 }
diff -pruN 1.3.1+dfsg-1/src/debuginfo.cpp 1.4.0+dfsg-1/src/debuginfo.cpp
--- 1.3.1+dfsg-1/src/debuginfo.cpp	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/src/debuginfo.cpp	2020-03-21 16:36:32.000000000 +0000
@@ -66,6 +66,7 @@ struct ObjectInfo {
     const object::ObjectFile *object;
     size_t SectionSize;
     ptrdiff_t slide;
+    object::SectionRef Section;
     DIContext *context;
 };
 
@@ -101,7 +102,7 @@ static void create_PRUNTIME_FUNCTION(uin
     // GC safe
     DWORD mod_size = 0;
 #if defined(_CPU_X86_64_)
-    PRUNTIME_FUNCTION tbl = (PRUNTIME_FUNCTION)malloc(sizeof(RUNTIME_FUNCTION));
+    PRUNTIME_FUNCTION tbl = (PRUNTIME_FUNCTION)malloc_s(sizeof(RUNTIME_FUNCTION));
     tbl->BeginAddress = (DWORD)(Code - Section);
     tbl->EndAddress = (DWORD)(Code - Section + Size);
     tbl->UnwindData = (DWORD)(UnwindData - Section);
@@ -166,23 +167,24 @@ public:
     JuliaJITEventListener(){}
     virtual ~JuliaJITEventListener() {}
 
-    jl_method_instance_t *lookupLinfo(size_t pointer)
+    jl_method_instance_t *lookupLinfo(size_t pointer) JL_NOTSAFEPOINT
     {
-        auto linfo = linfomap.lower_bound(pointer);
-        if (linfo != linfomap.end() && pointer < linfo->first + linfo->second.first)
-            return linfo->second.second;
-        else
-            return NULL;
+        uv_rwlock_rdlock(&threadsafe);
+        auto region = linfomap.lower_bound(pointer);
+        jl_method_instance_t *linfo = NULL;
+        if (region != linfomap.end() && pointer < region->first + region->second.first)
+            linfo = region->second.second;
+        uv_rwlock_rdunlock(&threadsafe);
+        return linfo;
     }
 
-    virtual void NotifyObjectEmitted(const object::ObjectFile &obj,
+    virtual void NotifyObjectEmitted(const object::ObjectFile &Object,
                                      const RuntimeDyld::LoadedObjectInfo &L)
     {
-        return _NotifyObjectEmitted(obj,obj,L,nullptr);
+        return _NotifyObjectEmitted(Object, L, nullptr);
     }
 
-    virtual void _NotifyObjectEmitted(const object::ObjectFile &obj,
-                                      const object::ObjectFile &debugObj,
+    virtual void _NotifyObjectEmitted(const object::ObjectFile &Object,
                                       const RuntimeDyld::LoadedObjectInfo &L,
                                       RTDyldMemoryManager *memmgr)
     {
@@ -190,16 +192,36 @@ public:
         // This function modify codeinst->fptr in GC safe region.
         // This should be fine since the GC won't scan this field.
         int8_t gc_state = jl_gc_safe_enter(ptls);
-        uv_rwlock_wrlock(&threadsafe);
+
+        auto SavedObject = L.getObjectForDebug(Object).takeBinary();
+        // If the debug object is unavailable, save (a copy of) the original object
+        // for our backtraces
+        if (!SavedObject.first) {
+            // This is unfortunate, but there doesn't seem to be a way to take
+            // ownership of the original buffer
+            auto NewBuffer = MemoryBuffer::getMemBufferCopy(
+                    Object.getData(), Object.getFileName());
+            auto NewObj = object::ObjectFile::createObjectFile(NewBuffer->getMemBufferRef());
+            assert(NewObj);
+            SavedObject = std::make_pair(std::move(*NewObj), std::move(NewBuffer));
+        }
+        const object::ObjectFile &debugObj = *SavedObject.first.release();
+        SavedObject.second.release();
+
         object::section_iterator Section = debugObj.section_begin();
         object::section_iterator EndSection = debugObj.section_end();
 
-        std::map<StringRef,object::SectionRef,strrefcomp> loadedSections;
-        for (const object::SectionRef &lSection: obj.sections()) {
+        std::map<StringRef, object::SectionRef, strrefcomp> loadedSections;
+        for (const object::SectionRef &lSection: Object.sections()) {
+#if JL_LLVM_VERSION >= 100000
+            auto sName = lSection.getName();
+            if (sName)
+                loadedSections[*sName] = lSection;
+#else
             StringRef sName;
-            if (!lSection.getName(sName)) {
+            if (!lSection.getName(sName))
                 loadedSections[sName] = lSection;
-            }
+#endif
         }
         auto getLoadAddress = [&] (const StringRef &sName) -> uint64_t {
             auto search = loadedSections.find(sName);
@@ -214,15 +236,21 @@ public:
         size_t arm_exidx_len = 0;
         uint64_t arm_text_addr = 0;
         size_t arm_text_len = 0;
-        for (auto &section: obj.sections()) {
+        for (auto &section: Object.sections()) {
             bool istext = false;
             if (section.isText()) {
                 istext = true;
             }
             else {
+#if JL_LLVM_VERSION >= 100000
+                auto sName = section.getName();
+                if (!sName)
+                    continue;
+#else
                 StringRef sName;
                 if (section.getName(sName))
                     continue;
+#endif
                 if (sName != ".ARM.exidx") {
                     continue;
                 }
@@ -284,8 +312,14 @@ public:
                 Section = SectionOrError.get();
                 assert(Section != EndSection && Section->isText());
                 SectionAddr = Section->getAddress();
+#if JL_LLVM_VERSION >= 100000
+                auto secName = Section->getName();
+                assert(secName);
+                SectionLoadAddr = getLoadAddress(*secName);
+#else
                 Section->getName(sName);
                 SectionLoadAddr = getLoadAddress(sName);
+#endif
                 Addr -= SectionAddr - SectionLoadAddr;
                 *pAddr = (uint8_t*)Addr;
                 if (SectionAddrCheck)
@@ -324,8 +358,6 @@ public:
 #endif // defined(_OS_X86_64_)
 #endif // defined(_OS_WINDOWS_)
 
-        std::vector<std::pair<jl_code_instance_t*, uintptr_t>> def_spec;
-        std::vector<std::pair<jl_code_instance_t*, uintptr_t>> def_invoke;
         auto symbols = object::computeSymbolSizes(debugObj);
         bool first = true;
         for (const auto &sym_size : symbols) {
@@ -343,9 +375,15 @@ public:
             if (Section == EndSection) continue;
             if (!Section->isText()) continue;
             uint64_t SectionAddr = Section->getAddress();
+#if JL_LLVM_VERSION >= 100000
+            Expected<StringRef> secName = Section->getName();
+            assert(secName);
+            uint64_t SectionLoadAddr = getLoadAddress(*secName);
+#else
             StringRef secName;
             Section->getName(secName);
             uint64_t SectionLoadAddr = getLoadAddress(secName);
+#endif
             Addr -= SectionAddr - SectionLoadAddr;
             auto sNameOrError = sym_iter.getName();
             assert(sNameOrError);
@@ -366,51 +404,30 @@ public:
             if (linfo_it != ncode_in_flight.end()) {
                 codeinst = linfo_it->second;
                 ncode_in_flight.erase(linfo_it);
-                const char *F = codeinst->functionObjectsDecls.functionObject;
-                const char *specF = codeinst->functionObjectsDecls.specFunctionObject;
-                if (codeinst->invoke == NULL) {
-                    if (specF && sName.equals(specF)) {
-                        def_spec.push_back({codeinst, Addr});
-                        if (!strcmp(F, "jl_fptr_args"))
-                            def_invoke.push_back({codeinst, (uintptr_t)&jl_fptr_args});
-                        else if (!strcmp(F, "jl_fptr_sparam"))
-                            def_invoke.push_back({codeinst, (uintptr_t)&jl_fptr_sparam});
-                    }
-                    else if (sName.equals(F)) {
-                        def_invoke.push_back({codeinst, Addr});
-                    }
-                }
             }
+            uv_rwlock_wrlock(&threadsafe);
             if (codeinst)
                 linfomap[Addr] = std::make_pair(Size, codeinst->def);
             if (first) {
                 ObjectInfo tmp = {&debugObj,
                     (size_t)SectionSize,
                     (ptrdiff_t)(SectionAddr - SectionLoadAddr),
-                    DWARFContext::create(debugObj, &L).release(),
+                    *Section,
+                    nullptr,
                     };
                 objectmap[SectionLoadAddr] = tmp;
                 first = false;
-           }
-       }
-       // now process these in order, so we ensure the closure values are updated before enabling the invoke pointer
-       // TODO: this sets these pointers a bit too early, allowing other threads to see
-       // the addresses before the code has been filled in.
-       /*
-       for (auto &def : def_spec)
-           def.first->specptr.fptr = (void*)def.second;
-       for (auto &def : def_invoke)
-           def.first->invoke = (jl_callptr_t)def.second;
-       */
-        uv_rwlock_wrunlock(&threadsafe);
+            }
+            uv_rwlock_wrunlock(&threadsafe);
+        }
         jl_gc_safe_leave(ptls, gc_state);
     }
 
     // must implement if we ever start freeing code
-    // virtual void NotifyFreeingObject(const ObjectImage &obj) {}
+    // virtual void NotifyFreeingObject(const ObjectImage &Object) {}
     // virtual void NotifyFreeingObject(const object::ObjectFile &Obj) {}
 
-    std::map<size_t, ObjectInfo, revcomp>& getObjectMap()
+    std::map<size_t, ObjectInfo, revcomp>& getObjectMap() JL_NOTSAFEPOINT
     {
         uv_rwlock_rdlock(&threadsafe);
         return objectmap;
@@ -418,15 +435,14 @@ public:
 };
 
 JL_DLLEXPORT void ORCNotifyObjectEmitted(JITEventListener *Listener,
-                                         const object::ObjectFile &obj,
-                                         const object::ObjectFile &debugObj,
+                                         const object::ObjectFile &Object,
                                          const RuntimeDyld::LoadedObjectInfo &L,
                                          RTDyldMemoryManager *memmgr)
 {
-    ((JuliaJITEventListener*)Listener)->_NotifyObjectEmitted(obj,debugObj,L,memmgr);
+    ((JuliaJITEventListener*)Listener)->_NotifyObjectEmitted(Object, L, memmgr);
 }
 
-static std::pair<char *, bool> jl_demangle(const char *name)
+static std::pair<char *, bool> jl_demangle(const char *name) JL_NOTSAFEPOINT
 {
     // This function is not allowed to reference any TLS variables since
     // it can be called from an unmanaged thread on OSX.
@@ -450,7 +466,7 @@ static std::pair<char *, bool> jl_demang
     }
     if (end <= start)
         goto done;
-    ret = (char*)malloc(end - start + 1);
+    ret = (char*)malloc_s(end - start + 1);
     memcpy(ret, start, end - start);
     ret[end - start] = '\0';
     return std::make_pair(ret, true);
@@ -468,12 +484,14 @@ JITEventListener *CreateJuliaJITEventLis
 // *frames is a one element array containing whatever we could come up
 // with for the current frame. here we'll try to expand it using debug info
 // func_name and file_name are either NULL or malloc'd pointers
-static int lookup_pointer(DIContext *context, jl_frame_t **frames,
-                          size_t pointer, int demangle, int noInline)
+static int lookup_pointer(
+        object::SectionRef Section, DIContext *context,
+        jl_frame_t **frames, size_t pointer, int64_t slide,
+        bool demangle, bool noInline) JL_NOTSAFEPOINT
 {
     // This function is not allowed to reference any TLS variables
     // since it can be called from an unmanaged thread on OSX.
-    if (!context) {
+    if (!context || !Section.getObject()) {
         if (demangle) {
             char *oldname = (*frames)[0].func_name;
             if (oldname != NULL) {
@@ -492,18 +510,16 @@ static int lookup_pointer(DIContext *con
         }
         return 1;
     }
-    jl_mutex_lock_maybe_nogc(&codegen_lock);
     DILineInfoSpecifier infoSpec(DILineInfoSpecifier::FileLineInfoKind::AbsoluteFilePath,
                                  DILineInfoSpecifier::FunctionNameKind::ShortName);
 
-    auto inlineInfo = context->getInliningInfoForAddress(makeAddress(pointer), infoSpec);
+    auto inlineInfo = context->getInliningInfoForAddress(makeAddress(Section, pointer + slide), infoSpec);
 
     int fromC = (*frames)[0].fromC;
     int n_frames = inlineInfo.getNumberOfFrames();
     if (n_frames == 0) {
-        jl_mutex_unlock_maybe_nogc(&codegen_lock);
         // no line number info available in the context, return without the context
-        return lookup_pointer(NULL, frames, pointer, demangle, noInline);
+        return lookup_pointer(object::SectionRef(), NULL, frames, pointer, slide, demangle, noInline);
     }
     if (noInline)
         n_frames = 1;
@@ -520,7 +536,7 @@ static int lookup_pointer(DIContext *con
             info = inlineInfo.getFrame(i);
         }
         else {
-            info = context->getLineInfoForAddress(makeAddress(pointer), infoSpec);
+            info = context->getLineInfoForAddress(makeAddress(Section, pointer + slide), infoSpec);
         }
 
         jl_frame_t *frame = &(*frames)[i];
@@ -553,7 +569,6 @@ static int lookup_pointer(DIContext *con
         else
             jl_copy_str(&frame->file_name, file_name.c_str());
     }
-    jl_mutex_unlock_maybe_nogc(&codegen_lock);
     return n_frames;
 }
 
@@ -569,12 +584,11 @@ typedef struct {
     const llvm::object::ObjectFile *obj;
     DIContext *ctx;
     int64_t slide;
-    int64_t section_slide;
 } objfileentry_t;
 typedef std::map<uint64_t, objfileentry_t, revcomp> obfiletype;
 static obfiletype objfilemap;
 
-static bool getObjUUID(llvm::object::MachOObjectFile *obj, uint8_t uuid[16])
+static bool getObjUUID(llvm::object::MachOObjectFile *obj, uint8_t uuid[16]) JL_NOTSAFEPOINT
 {
     for (auto Load : obj->load_commands())
     {
@@ -590,14 +604,27 @@ struct debug_link_info {
     StringRef filename;
     uint32_t crc32;
 };
-static debug_link_info getDebuglink(const object::ObjectFile &Obj)
+static debug_link_info getDebuglink(const object::ObjectFile &Obj) JL_NOTSAFEPOINT
 {
     debug_link_info info = {};
     for (const object::SectionRef &Section: Obj.sections()) {
+#if JL_LLVM_VERSION >= 100000
+        Expected<StringRef> sName = Section.getName();
+        if (sName && *sName == ".gnu_debuglink")
+#else
         StringRef sName;
-        if (!Section.getName(sName) && sName == ".gnu_debuglink") {
+        if (!Section.getName(sName) && sName == ".gnu_debuglink")
+#endif
+        {
             StringRef Contents;
-            if (!Section.getContents(Contents)) {
+#if JL_LLVM_VERSION >= 90000
+            auto found = Section.getContents();
+            if (found)
+                Contents = *found;
+#else
+            bool found = !Section.getContents(Contents);
+#endif
+            if (found) {
                 size_t length = Contents.find('\0');
                 info.filename = Contents.substr(0, length);
                 info.crc32 = *(const uint32_t*)Contents.substr(LLT_ALIGN(length + 1, 4), 4).data();
@@ -713,7 +740,7 @@ void jl_register_fptrs(uint64_t sysimage
 }
 
 template<typename T>
-static inline void ignoreError(T &err)
+static inline void ignoreError(T &err) JL_NOTSAFEPOINT
 {
 #if !defined(NDEBUG)
     // Needed only with LLVM assertion build
@@ -721,9 +748,8 @@ static inline void ignoreError(T &err)
 #endif
 }
 
-static void get_function_name_and_base(const object::ObjectFile *object, bool insysimage,
-                                       void **saddr, char **name, size_t pointer,
-                                       int64_t slide, bool untrusted_dladdr)
+static void get_function_name_and_base(llvm::object::SectionRef Section, size_t pointer, int64_t slide, bool insysimage,
+                                       void **saddr, char **name, bool untrusted_dladdr) JL_NOTSAFEPOINT
 {
     // Assume we only need base address for sysimg for now
     if (!insysimage || !sysimg_fptrs.base)
@@ -750,10 +776,12 @@ static void get_function_name_and_base(c
         }
 #endif
     }
-    if (object && (needs_saddr || needs_name)) {
+    if (Section.getObject() && (needs_saddr || needs_name)) {
         size_t distance = (size_t)-1;
         SymRef sym_found;
-        for (auto sym: object->symbols()) {
+        for (auto sym : Section.getObject()->symbols()) {
+            if (!Section.containsSymbol(sym))
+                continue;
             auto addr = sym.getAddress();
             if (!addr)
                 continue;
@@ -777,7 +805,7 @@ static void get_function_name_and_base(c
                 if (auto name_or_err = sym_found.getName()) {
                     auto nameref = name_or_err.get();
                     size_t len = nameref.size();
-                    *name = (char*)realloc(*name, len + 1);
+                    *name = (char*)realloc_s(*name, len + 1);
                     (*name)[len] = 0;
                     memcpy(*name, nameref.data(), len);
                     needs_name = false;
@@ -806,7 +834,7 @@ static void get_function_name_and_base(c
 #endif
 }
 
-static objfileentry_t &find_object_file(uint64_t fbase, StringRef fname)
+static objfileentry_t &find_object_file(uint64_t fbase, StringRef fname) JL_NOTSAFEPOINT
 {
     int isdarwin = 0, islinux = 0, iswindows = 0;
 #if defined(_OS_DARWIN_)
@@ -857,7 +885,7 @@ static objfileentry_t &find_object_file(
         // the DebugSymbols framework is moved or removed, an alternative would
         // be to directly query Spotlight for the dSYM bundle.
 
-        typedef CFURLRef (*DBGCopyFullDSYMURLForUUIDfn)(CFUUIDRef, CFURLRef);
+        typedef CFURLRef (*DBGCopyFullDSYMURLForUUIDfn)(CFUUIDRef, CFURLRef) JL_NOTSAFEPOINT;
         DBGCopyFullDSYMURLForUUIDfn DBGCopyFullDSYMURLForUUID = NULL;
 
         // First, try to load the private DebugSymbols framework.
@@ -980,11 +1008,9 @@ static objfileentry_t &find_object_file(
         }
 
         int64_t slide = 0;
-        int64_t section_slide = 0;
         if (auto *OF = dyn_cast<const object::COFFObjectFile>(debugobj)) {
             assert(iswindows);
             slide = OF->getImageBase() - fbase;
-            section_slide = 0; // Since LLVM 3.8+ addresses are adjusted correctly
         }
         else {
             slide = -(int64_t)fbase;
@@ -995,7 +1021,7 @@ static objfileentry_t &find_object_file(
         binary.first.release();
         binary.second.release();
         // update cache
-        entry = {debugobj, context, slide, section_slide};
+        entry = {debugobj, context, slide};
     }
     else {
         // TODO: report the error instead of silently consuming it?
@@ -1005,14 +1031,25 @@ static objfileentry_t &find_object_file(
     return entry;
 }
 
+// from llvm::SymbolizableObjectFile
+static object::SectionRef getModuleSectionForAddress(const object::ObjectFile *obj, uint64_t Address) JL_NOTSAFEPOINT
+{
+  for (object::SectionRef Sec : obj->sections()) {
+      if (!Sec.isText() || Sec.isVirtual())
+          continue;
+      if (Address >= Sec.getAddress() && Address < Sec.getAddress() + Sec.getSize())
+          return Sec;
+  }
+  return object::SectionRef();
+}
+
+
 extern "C" void jl_refresh_dbg_module_list(void);
-bool jl_dylib_DI_for_fptr(size_t pointer, const llvm::object::ObjectFile **obj, llvm::DIContext **context, int64_t *slide, int64_t *section_slide,
-    bool onlySysImg, bool *isSysImg, void **saddr, char **name, char **filename)
+bool jl_dylib_DI_for_fptr(size_t pointer, object::SectionRef *Section, int64_t *slide, llvm::DIContext **context,
+    bool onlySysImg, bool *isSysImg, void **saddr, char **name, char **filename) JL_NOTSAFEPOINT
 {
-    *obj = NULL;
+    *Section = object::SectionRef();
     *context = NULL;
-    *slide = 0;
-    *section_slide = 0;
     // On Windows and FreeBSD, `dladdr` (or its equivalent) returns the closest exported symbol
     // without checking the size.
     // This causes the lookup to return incorrect non-NULL result for local functions
@@ -1090,17 +1127,16 @@ bool jl_dylib_DI_for_fptr(size_t pointer
     fname = dlinfo.dli_fname;
 #endif // ifdef _OS_WINDOWS_
     auto &entry = find_object_file(fbase, fname);
-    *obj = entry.obj;
-    *context = entry.ctx;
     *slide = entry.slide;
-    *section_slide = entry.section_slide;
-    get_function_name_and_base(entry.obj, insysimage, saddr, name, pointer, entry.slide,
-                               untrusted_dladdr);
+    *context = entry.ctx;
+    if (entry.obj)
+        *Section = getModuleSectionForAddress(entry.obj, pointer + entry.slide);
+    get_function_name_and_base(*Section, pointer, entry.slide, insysimage, saddr, name, untrusted_dladdr);
     return true;
 }
 
 // *name and *filename should be either NULL or malloc'd pointer
-static int jl_getDylibFunctionInfo(jl_frame_t **frames, size_t pointer, int skipC, int noInline)
+static int jl_getDylibFunctionInfo(jl_frame_t **frames, size_t pointer, int skipC, int noInline) JL_NOTSAFEPOINT
 {
     // This function is not allowed to reference any TLS variables if noInline
     // since it can be called from an unmanaged thread on OSX.
@@ -1124,12 +1160,12 @@ static int jl_getDylibFunctionInfo(jl_fr
     }
     jl_in_stackwalk = 0;
 #endif
-    const object::ObjectFile *object;
+    object::SectionRef Section;
     llvm::DIContext *context = NULL;
+    int64_t slide;
     bool isSysImg;
     void *saddr;
-    int64_t slide, section_slide;
-    if (!jl_dylib_DI_for_fptr(pointer, &object, &context, &slide, &section_slide, skipC, &isSysImg, &saddr, &frame0->func_name, &frame0->file_name)) {
+    if (!jl_dylib_DI_for_fptr(pointer, &Section, &slide, &context, skipC, &isSysImg, &saddr, &frame0->func_name, &frame0->file_name)) {
         frame0->fromC = 1;
         return 1;
     }
@@ -1151,26 +1187,24 @@ static int jl_getDylibFunctionInfo(jl_fr
             }
         }
     }
-    return lookup_pointer(context, frames, pointer + slide, isSysImg, noInline);
+    return lookup_pointer(Section, context, frames, pointer, slide, isSysImg, noInline);
 }
 
-int jl_DI_for_fptr(uint64_t fptr, uint64_t *symsize, int64_t *slide, int64_t *section_slide,
-                      const object::ObjectFile **object,
-                      llvm::DIContext **context
-                      )
+int jl_DI_for_fptr(uint64_t fptr, uint64_t *symsize, int64_t *slide,
+        object::SectionRef *Section, llvm::DIContext **context) JL_NOTSAFEPOINT
 {
     int found = 0;
-    *slide = 0;
     std::map<size_t, ObjectInfo, revcomp> &objmap = jl_jit_events->getObjectMap();
     std::map<size_t, ObjectInfo, revcomp>::iterator fit = objmap.lower_bound(fptr);
 
+    if (symsize)
+        *symsize = 0;
     if (fit != objmap.end() && fptr < fit->first + fit->second.SectionSize) {
-        if (symsize)
-            *symsize = 0;
-        if (section_slide)
-            *section_slide = fit->second.slide;
-        *object = fit->second.object;
+        *slide = fit->second.slide;
+        *Section = fit->second.Section;
         if (context) {
+            if (fit->second.context == nullptr)
+                fit->second.context = DWARFContext::create(*fit->second.object).release();
             *context = fit->second.context;
         }
         found = 1;
@@ -1179,54 +1213,6 @@ int jl_DI_for_fptr(uint64_t fptr, uint64
     return found;
 }
 
-extern "C"
-JL_DLLEXPORT jl_value_t *jl_get_dobj_data(uint64_t fptr)
-{
-    jl_ptls_t ptls = jl_get_ptls_states();
-    // Used by Gallium.jl
-    const object::ObjectFile *object = NULL;
-    DIContext *context;
-    int64_t slide, section_slide;
-    int8_t gc_state = jl_gc_safe_enter(ptls);
-    if (!jl_DI_for_fptr(fptr, NULL, &slide, NULL, &object, NULL))
-        if (!jl_dylib_DI_for_fptr(fptr, &object, &context, &slide, &section_slide, false, NULL, NULL, NULL, NULL)) {
-            jl_gc_safe_leave(ptls, gc_state);
-            return jl_nothing;
-        }
-    jl_gc_safe_leave(ptls, gc_state);
-    if (object == NULL)
-        return jl_nothing;
-    return (jl_value_t*)jl_ptr_to_array_1d((jl_value_t*)jl_array_uint8_type,
-        const_cast<char*>(object->getData().data()),
-        object->getData().size(), false);
-}
-
-extern "C"
-JL_DLLEXPORT uint64_t jl_get_section_start(uint64_t fptr)
-{
-    jl_ptls_t ptls = jl_get_ptls_states();
-    // Used by Gallium.jl
-    int8_t gc_state = jl_gc_safe_enter(ptls);
-    std::map<size_t, ObjectInfo, revcomp> &objmap = jl_jit_events->getObjectMap();
-    std::map<size_t, ObjectInfo, revcomp>::iterator fit = objmap.lower_bound(fptr);
-
-    uint64_t ret = 0;
-    if (fit != objmap.end() && fptr < fit->first + fit->second.SectionSize) {
-        ret = fit->first;
-    }
-    else {
-       obfiletype::iterator objit = objfilemap.lower_bound(fptr);
-       // Ideally we'd have a containment check here, but we can't really
-       // get the shared library size easily.
-       if (objit != objfilemap.end()) {
-           ret = objit->first;
-       }
-    }
-    uv_rwlock_rdunlock(&threadsafe);
-    jl_gc_safe_leave(ptls, gc_state);
-    return ret;
-}
-
 // Set *name and *filename to either NULL or malloc'd string
 int jl_getFunctionInfo(jl_frame_t **frames_out, size_t pointer, int skipC, int noInline) JL_NOTSAFEPOINT
 {
@@ -1238,12 +1224,12 @@ int jl_getFunctionInfo(jl_frame_t **fram
     *frames_out = frames;
 
     llvm::DIContext *context;
-    const llvm::object::ObjectFile *object;
+    object::SectionRef Section;
+    int64_t slide;
     uint64_t symsize;
-    int64_t slide = 0;
-    if (jl_DI_for_fptr(pointer, &symsize, &slide, NULL, &object, &context)) {
+    if (jl_DI_for_fptr(pointer, &symsize, &slide, &Section, &context)) {
         frames[0].linfo = jl_jit_events->lookupLinfo(pointer);
-        int nf = lookup_pointer(context, frames_out, pointer+slide, 1, noInline);
+        int nf = lookup_pointer(Section, context, frames_out, pointer, slide, true, noInline);
         return nf;
     }
     return jl_getDylibFunctionInfo(frames_out, pointer, skipC, noInline);
diff -pruN 1.3.1+dfsg-1/src/debuginfo.h 1.4.0+dfsg-1/src/debuginfo.h
--- 1.3.1+dfsg-1/src/debuginfo.h	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/src/debuginfo.h	2020-03-21 16:36:32.000000000 +0000
@@ -2,21 +2,20 @@
 
 // Declarations for debuginfo.cpp
 
-extern int jl_DI_for_fptr(uint64_t fptr, uint64_t *symsize, int64_t *slide, int64_t *section_slide,
-                      const object::ObjectFile **object,
-                      llvm::DIContext **context);
+int jl_DI_for_fptr(uint64_t fptr, uint64_t *symsize, int64_t *slide,
+        llvm::object::SectionRef *Section, llvm::DIContext **context) JL_NOTSAFEPOINT;
 
-extern bool jl_dylib_DI_for_fptr(size_t pointer, const object::ObjectFile **object, llvm::DIContext **context,
-        int64_t *slide, int64_t *section_slide,
-        bool onlySysImg, bool *isSysImg, void **saddr, char **name, char **filename);
+bool jl_dylib_DI_for_fptr(size_t pointer, llvm::object::SectionRef *Section, int64_t *slide, llvm::DIContext **context,
+    bool onlySysImg, bool *isSysImg, void **saddr, char **name, char **filename) JL_NOTSAFEPOINT;
 
 #if JL_LLVM_VERSION >= 90000
-static object::SectionedAddress makeAddress(uint64_t address)
+static object::SectionedAddress makeAddress(
+        llvm::object::SectionRef Section, uint64_t address) JL_NOTSAFEPOINT
 {
-    return object::SectionedAddress(address, object::SectionedAddress::UndefSection);
+    return object::SectionedAddress{address, Section.getIndex()};
 }
 #else
-static uint64_t makeAddress(uint64_t address)
+static uint64_t makeAddress(llvm::object::SectionRef Section, uint64_t address) JL_NOTSAFEPOINT
 {
     return address;
 }
diff -pruN 1.3.1+dfsg-1/src/disasm.cpp 1.4.0+dfsg-1/src/disasm.cpp
--- 1.3.1+dfsg-1/src/disasm.cpp	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/src/disasm.cpp	2020-03-21 16:36:32.000000000 +0000
@@ -448,50 +448,37 @@ jl_value_t *jl_dump_function_ir(void *f,
 
 static void jl_dump_asm_internal(
         uintptr_t Fptr, size_t Fsize, int64_t slide,
-        const object::ObjectFile *object,
+        object::SectionRef Section,
         DIContext *di_ctx,
         raw_ostream &rstream,
         const char* asm_variant,
         const char* debuginfo);
 
 // This isn't particularly fast, but neither is printing assembly, and they're only used for interactive mode
-static uint64_t compute_obj_symsize(const object::ObjectFile *obj, uint64_t offset)
+static uint64_t compute_obj_symsize(object::SectionRef Section, uint64_t offset)
 {
-    // Scan the object file for the closest symbols above and below offset in the .text section
+    // Scan the object file for the closest symbols above and below offset in the given section
     uint64_t lo = 0;
     uint64_t hi = 0;
     bool setlo = false;
-    for (const object::SectionRef &Section : obj->sections()) {
-        uint64_t SAddr, SSize;
-        if (!Section.isText()) continue;
-        SAddr = Section.getAddress();
-        SSize = Section.getSize();
-        if (offset < SAddr || offset >= SAddr + SSize) continue;
-        assert(hi == 0);
-
-        // test for lower and upper symbol bounds relative to other symbols
-        hi = SAddr + SSize;
-        object::section_iterator ESection = obj->section_end();
-        for (const object::SymbolRef &Sym : obj->symbols()) {
-            uint64_t Addr;
-            object::section_iterator Sect = ESection;
-            auto SectOrError = Sym.getSection();
-            assert(SectOrError);
-            Sect = SectOrError.get();
-            if (Sect == ESection) continue;
-            if (Sect != Section) continue;
-            auto AddrOrError = Sym.getAddress();
-            assert(AddrOrError);
-            Addr = AddrOrError.get();
-            if (Addr <= offset && Addr >= lo) {
-                // test for lower bound on symbol
-                lo = Addr;
-                setlo = true;
-            }
-            if (Addr > offset && Addr < hi) {
-                // test for upper bound on symbol
-                hi = Addr;
-            }
+    uint64_t SAddr = Section.getAddress();
+    uint64_t SSize = Section.getSize();
+    if (offset < SAddr || offset >= SAddr + SSize)
+        return 0;
+    // test for lower and upper symbol bounds relative to other symbols
+    hi = SAddr + SSize;
+    for (const object::SymbolRef &Sym : Section.getObject()->symbols()) {
+        if (!Section.containsSymbol(Sym))
+            continue;
+        uint64_t Addr = cantFail(Sym.getAddress());
+        if (Addr <= offset && Addr >= lo) {
+            // test for lower bound on symbol
+            lo = Addr;
+            setlo = true;
+        }
+        if (Addr > offset && Addr < hi) {
+            // test for upper bound on symbol
+            hi = Addr;
         }
     }
     if (setlo)
@@ -509,19 +496,19 @@ jl_value_t *jl_dump_fptr_asm(uint64_t fp
     llvm::raw_string_ostream stream(code);
 
     // Find debug info (line numbers) to print alongside
+    object::SectionRef Section;
+    int64_t slide = 0;
     uint64_t symsize = 0;
-    int64_t slide = 0, section_slide = 0;
     llvm::DIContext *context = NULL;
-    const object::ObjectFile *object = NULL;
-    if (!jl_DI_for_fptr(fptr, &symsize, &slide, &section_slide, &object, &context)) {
-        if (!jl_dylib_DI_for_fptr(fptr, &object, &context, &slide, &section_slide, false,
-            NULL, NULL, NULL, NULL)) {
-                jl_printf(JL_STDERR, "WARNING: Unable to find function pointer\n");
-                return jl_pchar_to_string("", 0);
+    if (!jl_DI_for_fptr(fptr, &symsize, &slide, &Section, &context)) {
+        if (!jl_dylib_DI_for_fptr(fptr, &Section, &slide, &context,
+                    false, NULL, NULL, NULL, NULL)) {
+            jl_printf(JL_STDERR, "WARNING: Unable to find function pointer\n");
+            return jl_pchar_to_string("", 0);
         }
     }
-    if (symsize == 0 && object != NULL)
-        symsize = compute_obj_symsize(object, fptr + slide + section_slide);
+    if (symsize == 0 && Section.getObject())
+        symsize = compute_obj_symsize(Section, fptr + slide);
     if (symsize == 0) {
         jl_printf(JL_STDERR, "WARNING: Could not determine size of symbol\n");
         return jl_pchar_to_string("", 0);
@@ -535,7 +522,7 @@ jl_value_t *jl_dump_fptr_asm(uint64_t fp
     int8_t gc_state = jl_gc_safe_enter(ptls);
     jl_dump_asm_internal(
             fptr, symsize, slide,
-            object, context,
+            Section, context,
             stream,
             asm_variant,
             debuginfo);
@@ -602,20 +589,16 @@ const char *SymbolTable::lookupLocalPC(s
 
 StringRef SymbolTable::getSymbolNameAt(uint64_t offset) const
 {
-    if (object == NULL) return StringRef();
+    if (object == NULL)
+        return StringRef();
     object::section_iterator ESection = object->section_end();
     for (const object::SymbolRef &Sym : object->symbols()) {
-        uint64_t Addr, SAddr;
-        object::section_iterator Sect = ESection;
-        auto SectOrError = Sym.getSection();
-        assert(SectOrError);
-        Sect = SectOrError.get();
-        if (Sect == ESection) continue;
-        SAddr = Sect->getAddress();
-        if (SAddr == 0) continue;
-        auto AddrOrError = Sym.getAddress();
-        assert(AddrOrError);
-        Addr = AddrOrError.get();
+        auto Sect = cantFail(Sym.getSection());
+        if (Sect == ESection)
+            continue;
+        if (Sect->getAddress() == 0)
+            continue;
+        uint64_t Addr = cantFail(Sym.getAddress());
         if (Addr == offset) {
             auto sNameOrError = Sym.getName();
             if (sNameOrError)
@@ -740,7 +723,7 @@ static int OpInfoLookup(void *DisInfo, u
 
 static void jl_dump_asm_internal(
         uintptr_t Fptr, size_t Fsize, int64_t slide,
-        const object::ObjectFile *object,
+        object::SectionRef Section,
         DIContext *di_ctx,
         raw_ostream &rstream,
         const char* asm_variant,
@@ -761,7 +744,12 @@ static void jl_dump_asm_internal(
     std::unique_ptr<MCStreamer> Streamer;
     SourceMgr SrcMgr;
 
-    std::unique_ptr<MCAsmInfo> MAI(TheTarget->createMCAsmInfo(*TheTarget->createMCRegInfo(TheTriple.str()), TheTriple.str()));
+    MCTargetOptions Options;
+    std::unique_ptr<MCAsmInfo> MAI(TheTarget->createMCAsmInfo(*TheTarget->createMCRegInfo(TheTriple.str()), TheTriple.str()
+#if JL_LLVM_VERSION >= 100000
+            , Options
+#endif
+        ));
     assert(MAI && "Unable to create target asm info!");
 
     std::unique_ptr<MCRegisterInfo> MRI(TheTarget->createMCRegInfo(TheTriple.str()));
@@ -797,7 +785,6 @@ static void jl_dump_asm_internal(
     std::unique_ptr<MCAsmBackend> MAB = 0;
     if (ShowEncoding) {
         CE = std::unique_ptr<MCCodeEmitter>(TheTarget->createMCCodeEmitter(*MCII, *MRI, Ctx));
-        MCTargetOptions Options;
         MAB = std::unique_ptr<MCAsmBackend>(TheTarget->createMCAsmBackend(*STI, *MRI, Options));
     }
 #else
@@ -805,7 +792,6 @@ static void jl_dump_asm_internal(
     MCAsmBackend* MAB = 0;
     if (ShowEncoding) {
         CE = TheTarget->createMCCodeEmitter(*MCII, *MRI, Ctx);
-        MCTargetOptions Options;
         MAB = TheTarget->createMCAsmBackend(*STI, *MRI, Options);
     }
 #endif
@@ -813,8 +799,8 @@ static void jl_dump_asm_internal(
     // createAsmStreamer expects a unique_ptr to a formatted stream, which means
     // it will destruct the stream when it is done. We cannot have this, so we
     // start out with a raw stream, and create formatted stream from it here.
-    // LLVM will desctruct the formatted stream, and we keep the raw stream.
-    auto ustream = llvm::make_unique<formatted_raw_ostream>(rstream);
+    // LLVM will destroy the formatted stream, and we keep the raw stream.
+    std::unique_ptr<formatted_raw_ostream> ustream(new formatted_raw_ostream(rstream));
 #if JL_LLVM_VERSION >= 70000
     Streamer.reset(TheTarget->createAsmStreamer(Ctx, std::move(ustream), /*asmverbose*/true,
                                                 /*useDwarfDirectory*/ true,
@@ -828,11 +814,11 @@ static void jl_dump_asm_internal(
 
     // Make the MemoryObject wrapper
     ArrayRef<uint8_t> memoryObject(const_cast<uint8_t*>((const uint8_t*)Fptr),Fsize);
-    SymbolTable DisInfo(Ctx, object, slide, memoryObject);
+    SymbolTable DisInfo(Ctx, Section.getObject(), slide, memoryObject);
 
     DILineInfoTable di_lineinfo;
     if (di_ctx)
-        di_lineinfo = di_ctx->getLineInfoForAddressRange(makeAddress(Fptr + slide), Fsize);
+        di_lineinfo = di_ctx->getLineInfoForAddressRange(makeAddress(Section, Fptr + slide), Fsize);
     if (!di_lineinfo.empty()) {
         auto cur_addr = di_lineinfo[0].first;
         auto nlineinfo = di_lineinfo.size();
@@ -902,7 +888,7 @@ static void jl_dump_asm_internal(
                     std::string buf;
                     DILineInfoSpecifier infoSpec(DILineInfoSpecifier::FileLineInfoKind::Default,
                                                  DILineInfoSpecifier::FunctionNameKind::ShortName);
-                    DIInliningInfo dbg = di_ctx->getInliningInfoForAddress(makeAddress(Index + Fptr + slide), infoSpec);
+                    DIInliningInfo dbg = di_ctx->getInliningInfoForAddress(makeAddress(Section, Index + Fptr + slide), infoSpec);
                     if (dbg.getNumberOfFrames()) {
                         dbgctx.emit_lineinfo(buf, dbg);
                     }
diff -pruN 1.3.1+dfsg-1/src/dlload.c 1.4.0+dfsg-1/src/dlload.c
--- 1.3.1+dfsg-1/src/dlload.c	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/src/dlload.c	2020-03-21 16:36:32.000000000 +0000
@@ -37,15 +37,18 @@ static int endswith_extension(const char
         return 0;
     size_t len = strlen(path);
     // Skip the first one since it is empty
-    for (size_t i = 1;i < N_EXTENSIONS;i++) {
+    for (size_t i = 1; i < N_EXTENSIONS; i++) {
         const char *ext = extensions[i];
         size_t extlen = strlen(ext);
-        if (len < extlen) return 0;
+        if (len < extlen)
+            return 0;
         // Skip version extensions if present
-        size_t j = len-1;
+        size_t j = len - 1;
         while (j > 0) {
-            if (path[j] == '.' || (path[j] >= '0' && path[j] <= '9')) j--;
-            else break;
+            if (path[j] == '.' || (path[j] >= '0' && path[j] <= '9'))
+                j--;
+            else
+                break;
         }
         if ((j == len-1 || path[j+1] == '.') && memcmp(ext, path + j - extlen + 1, extlen) == 0) {
             return 1;
@@ -54,25 +57,39 @@ static int endswith_extension(const char
     return 0;
 }
 
-#define PATHBUF 512
+#define PATHBUF 4096
 
 extern char *julia_bindir;
 
 #define JL_RTLD(flags, FLAG) (flags & JL_RTLD_ ## FLAG ? RTLD_ ## FLAG : 0)
 
-static const char * jl_dlerror(void)
-{
 #ifdef _OS_WINDOWS_
-    static JL_THREAD_LOCAL CHAR reason[256];
-    FormatMessageA(FORMAT_MESSAGE_FROM_SYSTEM | FORMAT_MESSAGE_IGNORE_INSERTS,
-            NULL, GetLastError(),
-            MAKELANGID(LANG_ENGLISH, SUBLANG_ENGLISH_US),
-            reason, sizeof(reason) / sizeof(reason[0]), NULL);
-    return (const char *)&reason[0];
-#else
-    return dlerror();
-#endif
+static void win32_formatmessage(DWORD code, char *reason, int len)
+{
+    DWORD res;
+    LPWSTR errmsg;
+    res = FormatMessageW(FORMAT_MESSAGE_ALLOCATE_BUFFER |
+                         FORMAT_MESSAGE_FROM_SYSTEM |
+                         FORMAT_MESSAGE_IGNORE_INSERTS |
+                         FORMAT_MESSAGE_MAX_WIDTH_MASK,
+                         NULL, code,
+                         MAKELANGID(LANG_ENGLISH, SUBLANG_ENGLISH_US),
+                         (LPWSTR)&errmsg, 0, NULL);
+    if (!res && (GetLastError() == ERROR_MUI_FILE_NOT_FOUND ||
+                 GetLastError() == ERROR_RESOURCE_TYPE_NOT_FOUND)) {
+      res = FormatMessageW(FORMAT_MESSAGE_ALLOCATE_BUFFER |
+                           FORMAT_MESSAGE_FROM_SYSTEM |
+                           FORMAT_MESSAGE_IGNORE_INSERTS |
+                           FORMAT_MESSAGE_MAX_WIDTH_MASK,
+                           NULL, code,
+                           0, (LPWSTR)&errmsg, 0, NULL);
+    }
+    res = WideCharToMultiByte(CP_UTF8, 0, errmsg, -1, reason, len, NULL, NULL);
+    assert(res > 0 || GetLastError() == ERROR_INSUFFICIENT_BUFFER);
+    reason[len - 1] = '\0';
+    LocalFree(errmsg);
 }
+#endif
 
 JL_DLLEXPORT void *jl_dlopen(const char *filename, unsigned flags)
 {
@@ -121,6 +138,9 @@ JL_DLLEXPORT void *jl_load_dynamic_libra
 {
     char path[PATHBUF];
     int i;
+#ifdef _OS_WINDOWS_
+    int err;
+#endif
     uv_stat_t stbuf;
     void *handle;
     int abspath;
@@ -163,16 +183,23 @@ JL_DLLEXPORT void *jl_load_dynamic_libra
                 size_t len = strlen(dl_path);
                 if (len == 0)
                     continue;
-                for (i=0; i < n_extensions; i++) {
+                for (i = 0; i < n_extensions; i++) {
                     const char *ext = extensions[i];
                     path[0] = '\0';
                     if (dl_path[len-1] == PATHSEPSTRING[0])
                         snprintf(path, PATHBUF, "%s%s%s", dl_path, modname, ext);
                     else
                         snprintf(path, PATHBUF, "%s" PATHSEPSTRING "%s%s", dl_path, modname, ext);
-                    handle = jl_dlopen(path, flags);
-                    if (handle)
-                        goto done;
+#ifdef _OS_WINDOWS_
+                    if (i == 0) { // LoadLibrary already tested the extensions, we just need to check the `stat` result
+#endif
+                        handle = jl_dlopen(path, flags);
+                        if (handle)
+                            goto done;
+#ifdef _OS_WINDOWS_
+                        err = GetLastError();
+                    }
+#endif
                     // bail out and show the error if file actually exists
                     if (jl_stat(path, (char*)&stbuf) == 0)
                         goto notfound;
@@ -182,21 +209,30 @@ JL_DLLEXPORT void *jl_load_dynamic_libra
     }
 
     // now fall back and look in default library paths, for all extensions
-    for(i=0; i < n_extensions; i++) {
+    for (i = 0; i < n_extensions; i++) {
         const char *ext = extensions[i];
         path[0] = '\0';
         snprintf(path, PATHBUF, "%s%s", modname, ext);
         handle = jl_dlopen(path, flags);
         if (handle)
             goto done;
+#ifdef _OS_WINDOWS_
+        err = GetLastError();
+        break; // LoadLibrary already tested the rest
+#endif
     }
 
 notfound:
     if (throw_err) {
-        const char * reason = jl_dlerror();
+#ifdef _OS_WINDOWS_
+        char reason[256];
+        win32_formatmessage(err, reason, sizeof(reason));
+#else
+        const char *reason = dlerror();
+#endif
         jl_errorf("could not load library \"%s\"\n%s", modname, reason);
     }
-    return NULL;
+    handle = NULL;
 
 done:
     return handle;
@@ -216,20 +252,19 @@ JL_DLLEXPORT int jl_dlsym(void *handle,
 
     /* Next, check for errors.  On Windows, a NULL pointer means the symbol
      * was not found.  On everything else, we can have NULL symbols, so we check
-     * for non-NULL returns from dlerror().  Note that we unconditionally call
-     * jl_dlerror() on POSIX systems, but on Windows systems we only call it
-     * when we have been returned a NULL symbol.*/
-    const char * err = NULL;
+     * for non-NULL returns from dlerror().  Note that means we unconditionally
+     * call dlerror() on POSIX systems.*/
 #ifdef _OS_WINDOWS_
     symbol_found = *value != NULL;
 #else
-    err = jl_dlerror();
+    const char *err = dlerror();
     symbol_found = err == NULL;
 #endif
 
     if (!symbol_found && throw_err) {
 #ifdef _OS_WINDOWS_
-        err = jl_dlerror();
+        char err[256];
+        win32_formatmessage(GetLastError(), err, sizeof(err));
 #endif
         jl_errorf("could not load symbol \"%s\":\n%s", symbol, err);
     }
diff -pruN 1.3.1+dfsg-1/src/dump.c 1.4.0+dfsg-1/src/dump.c
--- 1.3.1+dfsg-1/src/dump.c	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/src/dump.c	2020-03-21 16:36:32.000000000 +0000
@@ -87,7 +87,7 @@ htable_t edges_map;
 #define TAG_STRING             18
 #define TAG_SHORT_INT64        19
 #define TAG_SHORT_GENERAL      20
-#define TAG_TYPEMAP_ENTRY      21
+#define TAG_CNULL              21
 #define TAG_ARRAY1D            22
 #define TAG_SINGLETON          23
 #define TAG_MODULE             24
@@ -219,6 +219,13 @@ static void write_float64(ios_t *s, doub
 static void jl_serialize_value_(jl_serializer_state *s, jl_value_t *v, int as_literal) JL_GC_DISABLED;
 static jl_value_t *jl_deserialize_value(jl_serializer_state *s, jl_value_t **loc) JL_GC_DISABLED;
 
+static void jl_serialize_cnull(jl_serializer_state *s, jl_value_t *t)
+{
+    backref_table_numel++;
+    write_uint8(s->s, TAG_CNULL);
+    jl_serialize_value(s, t);
+}
+
 static int module_in_worklist(jl_module_t *mod) JL_NOTSAFEPOINT
 {
     int i, l = jl_array_len(serializer_worklist);
@@ -317,7 +324,9 @@ static void jl_serialize_datatype(jl_ser
         tag = 10;
     }
 
-    if (strncmp(jl_symbol_name(dt->name->name), "#kw#", 4) == 0 && !internal && tag != 0) {
+    char *dtname = jl_symbol_name(dt->name->name);
+    size_t dtnl = strlen(dtname);
+    if (dtnl > 4 && strcmp(&dtname[dtnl - 4], "##kw") == 0 && !internal && tag != 0) {
         /* XXX: yuck, this is horrible, but the auto-generated kw types from the serializer isn't a real type, so we *must* be very careful */
         assert(tag == 6); // other struct types should never exist
         tag = 9;
@@ -332,9 +341,11 @@ static void jl_serialize_datatype(jl_ser
             jl_methtable_t *mt = dt->name->mt;
             size_t l = strlen(jl_symbol_name(mt->name));
             char *prefixed;
-            prefixed = (char*)malloc(l + 2);
+            prefixed = (char*)malloc_s(l + 2);
             prefixed[0] = '#';
             strcpy(&prefixed[1], jl_symbol_name(mt->name));
+            // remove ##kw suffix
+            prefixed[l-3] = 0;
             jl_sym_t *tname = jl_symbol(prefixed);
             free(prefixed);
             jl_value_t *primarydt = jl_get_global(mt->module, tname);
@@ -389,13 +400,13 @@ static void jl_serialize_datatype(jl_ser
         write_uint8(s->s, layout);
         if (layout == 0) {
             uint32_t nf = dt->layout->nfields;
-            write_int32(s->s, nf);
-            uint32_t alignment = ((uint32_t*)dt->layout)[1];
-            write_int32(s->s, alignment);
-            if (dt->layout->npointers && nf)
-                write_int32(s->s, ((uint32_t*)dt->layout)[-1]);
+            uint32_t np = dt->layout->npointers;
             size_t fieldsize = jl_fielddesc_size(dt->layout->fielddesc_type);
-            ios_write(s->s, (char*)(&dt->layout[1]), nf * fieldsize);
+            ios_write(s->s, (const char*)dt->layout, sizeof(*dt->layout));
+            size_t fldsize = nf * fieldsize;
+            if (dt->layout->first_ptr != -1)
+                fldsize += np << dt->layout->fielddesc_type;
+            ios_write(s->s, (const char*)(dt->layout + 1), fldsize);
         }
     }
 
@@ -439,12 +450,17 @@ static void jl_serialize_module(jl_seria
     write_int8(s->s, 0);
     jl_serialize_value(s, m->parent);
     void **table = m->bindings.table;
-    for(i=1; i < m->bindings.size; i+=2) {
+    for (i = 1; i < m->bindings.size; i += 2) {
         if (table[i] != HT_NOTFOUND) {
             jl_binding_t *b = (jl_binding_t*)table[i];
             if (b->owner == m || m != jl_main_module) {
                 jl_serialize_value(s, b->name);
-                jl_serialize_value(s, b->value);
+                jl_value_t *e = b->value;
+                if (!b->constp && e && jl_is_cpointer(e) && jl_unbox_voidpointer(e) != (void*)-1 && jl_unbox_voidpointer(e) != NULL)
+                    // reset Ptr fields to C_NULL (but keep MAP_FAILED / INVALID_HANDLE)
+                    jl_serialize_cnull(s, jl_typeof(e));
+                else
+                    jl_serialize_value(s, e);
                 jl_serialize_value(s, b->globalref);
                 jl_serialize_value(s, b->owner);
                 write_int8(s->s, (b->deprecated<<3) | (b->constp<<2) | (b->exportp<<1) | (b->imported));
@@ -664,29 +680,66 @@ static void jl_serialize_value_(jl_seria
     }
     else if (jl_is_array(v)) {
         jl_array_t *ar = (jl_array_t*)v;
-        int isunion = jl_is_uniontype(jl_tparam0(jl_typeof(ar)));
-        if (ar->flags.ndims == 1 && ar->elsize <= 0x3f) {
+        jl_value_t *et = jl_tparam0(jl_typeof(ar));
+        int isunion = jl_is_uniontype(et);
+        if (ar->flags.ndims == 1 && ar->elsize <= 0x1f) {
             write_uint8(s->s, TAG_ARRAY1D);
-            write_uint8(s->s, (ar->flags.ptrarray<<7) | (isunion << 6) | (ar->elsize & 0x3f));
+            write_uint8(s->s, (ar->flags.ptrarray << 7) | (ar->flags.hasptr << 6) | (isunion << 5) | (ar->elsize & 0x1f));
         }
         else {
             write_uint8(s->s, TAG_ARRAY);
             write_uint16(s->s, ar->flags.ndims);
-            write_uint16(s->s, (ar->flags.ptrarray << 15) | (isunion << 14) | (ar->elsize & 0x3fff));
+            write_uint16(s->s, (ar->flags.ptrarray << 15) | (ar->flags.hasptr << 14) | (isunion << 13) | (ar->elsize & 0x1fff));
         }
         for (i = 0; i < ar->flags.ndims; i++)
             jl_serialize_value(s, jl_box_long(jl_array_dim(ar,i)));
         jl_serialize_value(s, jl_typeof(ar));
-        if (!ar->flags.ptrarray) {
-            ios_write(s->s, (char*)jl_array_data(ar), jl_array_len(ar) * ar->elsize);
-            if (jl_array_isbitsunion(ar))
-                ios_write(s->s, jl_array_typetagdata(ar), jl_array_len(ar));
+        size_t l = jl_array_len(ar);
+        if (ar->flags.ptrarray) {
+            for (i = 0; i < l; i++) {
+                jl_value_t *e = jl_array_ptr_ref(v, i);
+                if (e && jl_is_cpointer(e) && jl_unbox_voidpointer(e) != (void*)-1 && jl_unbox_voidpointer(e) != NULL)
+                    // reset Ptr elements to C_NULL (but keep MAP_FAILED / INVALID_HANDLE)
+                    jl_serialize_cnull(s, jl_typeof(e));
+                else
+                    jl_serialize_value(s, e);
+            }
         }
-        else {
-            for (i = 0; i < jl_array_len(ar); i++) {
-                jl_serialize_value(s, jl_array_ptr_ref(v, i));
+        else if (ar->flags.hasptr) {
+            const char *data = (const char*)jl_array_data(ar);
+            uint16_t elsz = ar->elsize;
+            size_t j, np = ((jl_datatype_t*)et)->layout->npointers;
+            for (i = 0; i < l; i++) {
+                const char *start = data;
+                for (j = 0; j < np; j++) {
+                    uint32_t ptr = jl_ptr_offset((jl_datatype_t*)et, j);
+                    const jl_value_t *const *fld = &((const jl_value_t *const *)data)[ptr];
+                    if ((const char*)fld != start)
+                        ios_write(s->s, start, (const char*)fld - start);
+                    JL_GC_PROMISE_ROOTED(*fld);
+                    jl_serialize_value(s, *fld);
+                    start = (const char*)&fld[1];
+                }
+                data += elsz;
+                if (data != start)
+                    ios_write(s->s, start, data - start);
+            }
+        }
+        else if (jl_is_cpointer_type(et)) {
+            // reset Ptr elements to C_NULL
+            const void **data = (const void**)jl_array_data(ar);
+            for (i = 0; i < l; i++) {
+                const void *e = data[i];
+                if (e != (void*)-1)
+                    e = NULL;
+                ios_write(s->s, (const char*)&e, sizeof(e));
             }
         }
+        else {
+            ios_write(s->s, (char*)jl_array_data(ar), l * ar->elsize);
+            if (jl_array_isbitsunion(ar))
+                ios_write(s->s, jl_array_typetagdata(ar), l);
+        }
     }
     else if (jl_is_expr(v)) {
         jl_expr_t *e = (jl_expr_t*)v;
@@ -821,6 +874,7 @@ static void jl_serialize_value_(jl_seria
         write_int32(s->s, m->called);
         write_int32(s->s, m->nargs);
         write_int32(s->s, m->nospecialize);
+        write_int32(s->s, m->nkw);
         write_int8(s->s, m->isva);
         write_int8(s->s, m->pure);
         jl_serialize_value(s, (jl_value_t*)m->module);
@@ -911,28 +965,6 @@ static void jl_serialize_value_(jl_seria
         write_int32(s->s, jl_string_len(v));
         ios_write(s->s, jl_string_data(v), jl_string_len(v));
     }
-    else if (jl_typeis(v, jl_typemap_entry_type)) {
-        write_uint8(s->s, TAG_TYPEMAP_ENTRY);
-        size_t n = 0;
-        jl_typemap_entry_t *te = (jl_typemap_entry_t*)v;
-        while ((jl_value_t*)te != jl_nothing) {
-            n++;
-            te = te->next;
-        }
-        write_int32(s->s, n);
-        te = (jl_typemap_entry_t*)v;
-        size_t i, nf = jl_datatype_nfields(jl_typemap_entry_type);
-        while ((jl_value_t*)te != jl_nothing) {
-            for (i = 1; i < nf; i++) {
-                if (jl_field_size(jl_typemap_entry_type, i) > 0) {
-                    jl_serialize_value(s, jl_get_nth_field((jl_value_t*)te, i));
-                    if (!jl_field_isptr(jl_typemap_entry_type, i))
-                        write_int8(s->s, 0); // union-selector byte
-                }
-            }
-            te = te->next;
-        }
-    }
     else if (jl_typeis(v, jl_int64_type)) {
         void *data = jl_data_ptr(v);
         if (*(int64_t*)data >= INT16_MIN && *(int64_t*)data <= INT16_MAX) {
@@ -963,6 +995,11 @@ static void jl_serialize_value_(jl_seria
         write_uint8(s->s, TAG_UINT8);
         write_int8(s->s, *(int8_t*)jl_data_ptr(v));
     }
+    else if (jl_is_cpointer(v) && jl_unbox_voidpointer(v) == NULL) {
+        write_uint8(s->s, TAG_CNULL);
+        jl_serialize_value(s, jl_typeof(v));
+        return;
+    }
     else if (jl_typeis(v, jl_lineinfonode_type)) {
         write_uint8(s->s, TAG_LINEINFO);
         for (i = 0; i < jl_datatype_nfields(jl_lineinfonode_type); i++)
@@ -981,105 +1018,113 @@ static void jl_serialize_value_(jl_seria
     }
     else {
         jl_datatype_t *t = (jl_datatype_t*)jl_typeof(v);
-        void *data = jl_data_ptr(v);
-        {
-            if (v == t->instance) {
-                if (s->mode == MODE_MODULE && !type_in_worklist(t)) {
-                    // also flag this in the backref table as special
-                    // if it might not be unique (is external)
-                    uintptr_t *bp = (uintptr_t*)ptrhash_bp(&backref_table, v);
-                    assert(*bp != (uintptr_t)HT_NOTFOUND);
-                    *bp |= 1;
-                }
-                write_uint8(s->s, TAG_SINGLETON);
-                jl_serialize_value(s, t);
-                return;
-            }
-            assert(!t->instance && "detected singleton construction corruption");
-
-            if (t == jl_typename_type) {
-                void *bttag = ptrhash_get(&ser_tag, ((jl_typename_t*)t)->wrapper);
-                if (bttag != HT_NOTFOUND) {
-                    write_uint8(s->s, TAG_BITYPENAME);
-                    write_uint8(s->s, (uint8_t)(intptr_t)bttag);
-                    return;
-                }
-            }
-            if (t->size <= 255) {
-                write_uint8(s->s, TAG_SHORT_GENERAL);
-                write_uint8(s->s, t->size);
-            }
-            else {
-                write_uint8(s->s, TAG_GENERAL);
-                write_int32(s->s, t->size);
+        if (v == t->instance) {
+            if (s->mode == MODE_MODULE && !type_in_worklist(t)) {
+                // also flag this in the backref table as special
+                // if it might not be unique (is external)
+                uintptr_t *bp = (uintptr_t*)ptrhash_bp(&backref_table, v);
+                assert(*bp != (uintptr_t)HT_NOTFOUND);
+                *bp |= 1;
             }
+            write_uint8(s->s, TAG_SINGLETON);
             jl_serialize_value(s, t);
-            if (t == jl_typename_type) {
-                jl_typename_t *tn = (jl_typename_t*)v;
-                int internal = module_in_worklist(tn->module);
-                write_uint8(s->s, internal);
-                jl_serialize_value(s, tn->module);
-                jl_serialize_value(s, tn->name);
-                if (internal) {
-                    jl_serialize_value(s, tn->names);
-                    jl_serialize_value(s, tn->wrapper);
-                    jl_serialize_value(s, tn->mt);
-                    ios_write(s->s, (char*)&tn->hash, sizeof(tn->hash));
-                }
+            return;
+        }
+        assert(!t->instance && "detected singleton construction corruption");
+
+        if (t == jl_typename_type) {
+            void *bttag = ptrhash_get(&ser_tag, ((jl_typename_t*)t)->wrapper);
+            if (bttag != HT_NOTFOUND) {
+                write_uint8(s->s, TAG_BITYPENAME);
+                write_uint8(s->s, (uint8_t)(intptr_t)bttag);
                 return;
             }
-            if (t == jl_typemap_level_type) {
-                // perform some compression on the typemap levels
-                // (which will need to be rehashed during deserialization anyhow)
-                jl_typemap_level_t *node = (jl_typemap_level_t*)v;
-                assert( // make sure this type has the expected ordering
-                    offsetof(jl_typemap_level_t, arg1) == 0 * sizeof(jl_value_t*) &&
-                    offsetof(jl_typemap_level_t, targ) == 2 * sizeof(jl_value_t*) &&
-                    offsetof(jl_typemap_level_t, linear) == 4 * sizeof(jl_value_t*) &&
-                    offsetof(jl_typemap_level_t, any) == 5 * sizeof(jl_value_t*) &&
-                    offsetof(jl_typemap_level_t, key) == 6 * sizeof(jl_value_t*) &&
-                    sizeof(jl_typemap_level_t) == 7 * sizeof(jl_value_t*));
-                jl_serialize_value(s, jl_nothing);
-                jl_serialize_value(s, node->arg1.values);
-                jl_serialize_value(s, jl_nothing);
-                jl_serialize_value(s, node->targ.values);
-                jl_serialize_value(s, node->linear);
-                jl_serialize_value(s, node->any);
-                jl_serialize_value(s, node->key);
-                return;
+        }
+        if (t->size <= 255) {
+            write_uint8(s->s, TAG_SHORT_GENERAL);
+            write_uint8(s->s, t->size);
+        }
+        else {
+            write_uint8(s->s, TAG_GENERAL);
+            write_int32(s->s, t->size);
+        }
+        jl_serialize_value(s, t);
+        if (t == jl_typename_type) {
+            jl_typename_t *tn = (jl_typename_t*)v;
+            int internal = module_in_worklist(tn->module);
+            write_uint8(s->s, internal);
+            jl_serialize_value(s, tn->module);
+            jl_serialize_value(s, tn->name);
+            if (internal) {
+                jl_serialize_value(s, tn->names);
+                jl_serialize_value(s, tn->wrapper);
+                jl_serialize_value(s, tn->mt);
+                ios_write(s->s, (char*)&tn->hash, sizeof(tn->hash));
             }
-            size_t nf = jl_datatype_nfields(t);
-            if (nf == 0 && jl_datatype_size(t) > 0) {
-                if (t->name == jl_pointer_typename && jl_unbox_voidpointer(v) != (void*)-1) {
-                    // normalize most pointers to NULL, to help catch memory errors
-                    // but permit MAP_FAILED / INVALID_HANDLE to be stored unchanged
-                    write_int32(s->s, 0);
-#ifdef _P64
-                    write_int32(s->s, 0);
-#endif
-                }
-                else {
-                    ios_write(s->s, (char*)data, jl_datatype_size(t));
+            return;
+        }
+        if (t == jl_typemap_level_type) {
+            // perform some compression on the typemap levels
+            // (which will need to be rehashed during deserialization anyhow)
+            jl_typemap_level_t *node = (jl_typemap_level_t*)v;
+            assert( // make sure this type has the expected ordering and layout
+                offsetof(jl_typemap_level_t, arg1) == 0 * sizeof(jl_value_t*) &&
+                offsetof(jl_typemap_level_t, targ) == 2 * sizeof(jl_value_t*) &&
+                offsetof(jl_typemap_level_t, linear) == 4 * sizeof(jl_value_t*) &&
+                offsetof(jl_typemap_level_t, any) == 5 * sizeof(jl_value_t*) &&
+                offsetof(jl_typemap_level_t, key) == 6 * sizeof(jl_value_t*) &&
+                sizeof(jl_typemap_level_t) == 7 * sizeof(jl_value_t*));
+            jl_serialize_value(s, jl_nothing);
+            jl_serialize_value(s, node->arg1.values);
+            jl_serialize_value(s, jl_nothing);
+            jl_serialize_value(s, node->targ.values);
+            jl_serialize_value(s, node->linear);
+            jl_serialize_value(s, node->any);
+            jl_serialize_value(s, node->key);
+            return;
+        }
+
+        char *data = (char*)jl_data_ptr(v);
+        size_t i, j, np = t->layout->npointers;
+        uint32_t nf = t->layout->nfields;
+        char *last = data;
+        for (i = 0, j = 0; i < nf+1; i++) {
+            char *ptr = data + (i < nf ? jl_field_offset(t, i) : jl_datatype_size(t));
+            if (j < np) {
+                char *prevptr = (char*)&((jl_value_t**)data)[jl_ptr_offset(t, j)];
+                while (ptr > prevptr) {
+                    // previous field contained pointers; write them and their interleaved data
+                    if (prevptr > last)
+                        ios_write(s->s, last, prevptr - last);
+                    jl_value_t *e = *(jl_value_t**)prevptr;
+                    JL_GC_PROMISE_ROOTED(e);
+                    if (t->mutabl && e && jl_field_isptr(t, i - 1) && jl_is_cpointer(e) &&
+                        jl_unbox_voidpointer(e) != (void*)-1 && jl_unbox_voidpointer(e) != NULL)
+                        // reset Ptr fields to C_NULL (but keep MAP_FAILED / INVALID_HANDLE)
+                        jl_serialize_cnull(s, jl_typeof(e));
+                    else
+                        jl_serialize_value(s, e);
+                    last = prevptr + sizeof(jl_value_t*);
+                    j++;
+                    if (j < np)
+                        prevptr = (char*)&((jl_value_t**)data)[jl_ptr_offset(t, j)];
+                    else
+                        break;
                 }
             }
-            else {
-                size_t i;
-                for (i = 0; i < nf; i++) {
-                    size_t offs = jl_field_offset(t, i);
-                    size_t fsz = jl_field_size(t, i);
-                    if (fsz > 0) {
-                        jl_serialize_value(s, jl_get_nth_field(v, i));
-                        if (!jl_field_isptr(t, i)) {
-                            uint8_t sel = 0;
-                            if (jl_is_uniontype(jl_field_type(t, i))) {
-                                sel = ((uint8_t*)v)[offs + fsz - 1] + 1;
-                            }
-                            write_int8(s->s, sel);
-                        }
-                    }
-                }
+            if (i == nf)
+                break;
+            if (t->mutabl && jl_is_cpointer_type(jl_field_type(t, i)) && *(void**)ptr != (void*)-1) {
+                if (ptr > last)
+                    ios_write(s->s, last, ptr - last);
+                char *n = NULL;
+                ios_write(s->s, (char*)&n, sizeof(n));
+                last = ptr + sizeof(n);
             }
         }
+        char *ptr = data + jl_datatype_size(t);
+        if (ptr > last)
+            ios_write(s->s, last, ptr - last);
     }
 }
 
@@ -1252,7 +1297,7 @@ static void write_mod_list(ios_t *s, jl_
 }
 
 // "magic" string and version header of .ji file
-static const int JI_FORMAT_VERSION = 9;
+static const int JI_FORMAT_VERSION = 10;
 static const char JI_MAGIC[] = "\373jli\r\n\032\n"; // based on PNG signature
 static const uint16_t BOM = 0xFEFF; // byte-order marker
 static void write_header(ios_t *s)
@@ -1436,29 +1481,20 @@ static jl_value_t *jl_deserialize_dataty
         }
         else {
             assert(layout == 0);
-            uint32_t nf = read_int32(s->s);
-            uint32_t alignment = read_int32(s->s);
-            union {
-                struct {
-                    uint32_t nf;
-                    uint32_t alignment;
-                } buffer;
-                jl_datatype_layout_t layout;
-            } header;
-            header.buffer.nf = nf;
-            header.buffer.alignment = alignment;
-            int has_padding = header.layout.npointers && nf;
-            uint8_t fielddesc_type = header.layout.fielddesc_type;
+            jl_datatype_layout_t buffer;
+            ios_read(s->s, (char*)&buffer, sizeof(buffer));
+            uint32_t nf = buffer.nfields;
+            uint32_t np = buffer.npointers;
+            uint8_t fielddesc_type = buffer.fielddesc_type;
             size_t fielddesc_size = nf > 0 ? jl_fielddesc_size(fielddesc_type) : 0;
+            size_t fldsize = nf * fielddesc_size;
+            if (buffer.first_ptr != -1)
+                fldsize += np << fielddesc_type;
             jl_datatype_layout_t *layout = (jl_datatype_layout_t*)jl_gc_perm_alloc(
-                    sizeof(jl_datatype_layout_t) + nf * fielddesc_size +
-                    (has_padding ? sizeof(uint32_t) : 0), 0, 4, 0);
-            if (has_padding) {
-                layout = (jl_datatype_layout_t*)(((char*)layout) + sizeof(uint32_t));
-                jl_datatype_layout_n_nonptr(layout) = read_int32(s->s);
-            }
-            *layout = header.layout;
-            ios_read(s->s, (char*)&layout[1], nf * fielddesc_size);
+                    sizeof(jl_datatype_layout_t) + fldsize,
+                    0, 4, 0);
+            *layout = buffer;
+            ios_read(s->s, (char*)(layout + 1), fldsize);
             dt->layout = layout;
         }
     }
@@ -1518,7 +1554,7 @@ static jl_value_t *jl_deserialize_value_
         len = read_uint8(s->s);
     else
         len = read_int32(s->s);
-    char *name = (char*)(len >= 256 ? malloc(len + 1) : alloca(len + 1));
+    char *name = (char*)(len >= 256 ? malloc_s(len + 1) : alloca(len + 1));
     ios_read(s->s, name, len);
     name[len] = '\0';
     jl_value_t *sym = (jl_value_t*)jl_symbol(name);
@@ -1533,19 +1569,21 @@ static jl_value_t *jl_deserialize_value_
 {
     int usetable = (s->mode != MODE_IR);
     int16_t i, ndims;
-    int isunboxed, isunion, elsize;
+    int isptr, isunion, hasptr, elsize;
     if (tag == TAG_ARRAY1D) {
         ndims = 1;
         elsize = read_uint8(s->s);
-        isunboxed = !(elsize >> 7);
-        isunion = elsize >> 6;
-        elsize = elsize & 0x3f;
+        isptr = (elsize >> 7) & 1;
+        hasptr = (elsize >> 6) & 1;
+        isunion = (elsize >> 5) & 1;
+        elsize = elsize & 0x1f;
     }
     else {
         ndims = read_uint16(s->s);
         elsize = read_uint16(s->s);
-        isunboxed = !(elsize >> 15);
-        isunion = elsize >> 14;
+        isptr = (elsize >> 15) & 1;
+        hasptr = (elsize >> 14) & 1;
+        isunion = (elsize >> 13) & 1;
         elsize = elsize & 0x3fff;
     }
     uintptr_t pos = backref_list.len;
@@ -1556,24 +1594,49 @@ static jl_value_t *jl_deserialize_value_
         dims[i] = jl_unbox_long(jl_deserialize_value(s, NULL));
     }
     jl_array_t *a = jl_new_array_for_deserialization(
-            (jl_value_t*)NULL, ndims, dims, isunboxed, isunion, elsize);
+            (jl_value_t*)NULL, ndims, dims, !isptr, hasptr, isunion, elsize);
     if (usetable)
         backref_list.items[pos] = a;
     jl_value_t *aty = jl_deserialize_value(s, &jl_astaggedvalue(a)->type);
     jl_set_typeof(a, aty);
-    if (!a->flags.ptrarray) {
-        size_t extra = jl_array_isbitsunion(a) ? jl_array_len(a) : 0;
-        size_t tot = jl_array_len(a) * a->elsize + extra;
-        ios_read(s->s, (char*)jl_array_data(a), tot);
-    }
-    else {
+    if (a->flags.ptrarray) {
         jl_value_t **data = (jl_value_t**)jl_array_data(a);
         size_t i, numel = jl_array_len(a);
         for (i = 0; i < numel; i++) {
             data[i] = jl_deserialize_value(s, &data[i]);
-            if (data[i])
-                jl_gc_wb(a, data[i]);
+            //if (data[i]) // not needed because `a` is new (gc is disabled)
+            //    jl_gc_wb(a, data[i]);
+        }
+        assert(jl_astaggedvalue(a)->bits.gc == GC_CLEAN); // gc is disabled
+    }
+    else if (a->flags.hasptr) {
+        size_t i, numel = jl_array_len(a);
+        char *data = (char*)jl_array_data(a);
+        uint16_t elsz = a->elsize;
+        jl_datatype_t *et = (jl_datatype_t*)jl_tparam0(jl_typeof(a));
+        size_t j, np = et->layout->npointers;
+        for (i = 0; i < numel; i++) {
+            char *start = data;
+            for (j = 0; j < np; j++) {
+                uint32_t ptr = jl_ptr_offset(et, j);
+                jl_value_t **fld = &((jl_value_t**)data)[ptr];
+                if ((char*)fld != start)
+                    ios_read(s->s, start, (const char*)fld - start);
+                *fld = jl_deserialize_value(s, fld);
+                //if (*fld) // not needed because `a` is new (gc is disabled)
+                //    jl_gc_wb(a, *fld);
+                start = (char*)&fld[1];
+            }
+            data += elsz;
+            if (data != start)
+                ios_read(s->s, start, data - start);
         }
+        assert(jl_astaggedvalue(a)->bits.gc == GC_CLEAN); // gc is disabled
+    }
+    else {
+        size_t extra = jl_array_isbitsunion(a) ? jl_array_len(a) : 0;
+        size_t tot = jl_array_len(a) * a->elsize + extra;
+        ios_read(s->s, (char*)jl_array_data(a), tot);
     }
     return (jl_value_t*)a;
 }
@@ -1692,6 +1755,7 @@ static jl_value_t *jl_deserialize_value_
     m->called = read_int32(s->s);
     m->nargs = read_int32(s->s);
     m->nospecialize = read_int32(s->s);
+    m->nkw = read_int32(s->s);
     m->isva = read_int8(s->s);
     m->pure = read_int8(s->s);
     m->module = (jl_module_t*)jl_deserialize_value(s, (jl_value_t**)&m->module);
@@ -1887,30 +1951,25 @@ static jl_value_t *jl_deserialize_value_
     return v;
 }
 
-static void jl_deserialize_struct(jl_serializer_state *s, jl_value_t *v, size_t startfield) JL_GC_DISABLED
+static void jl_deserialize_struct(jl_serializer_state *s, jl_value_t *v) JL_GC_DISABLED
 {
     jl_datatype_t *dt = (jl_datatype_t*)jl_typeof(v);
-    size_t i, nf = jl_datatype_nfields(dt);
     char *data = (char*)jl_data_ptr(v);
-    for (i = startfield; i < nf; i++) {
-        size_t offs = jl_field_offset(dt, i);
-        size_t fsz = jl_field_size(dt, i);
-        jl_value_t **fld = (jl_value_t**)(data + offs);
-        if (fsz > 0) {
-            if (jl_field_isptr(dt, i)) {
-                *fld = jl_deserialize_value(s, fld);
-            }
-            else {
-                jl_value_t *fldval = jl_deserialize_value(s, NULL);
-                jl_assign_bits((char*)fld, fldval);
-                uint8_t union_selector = read_uint8(s->s);
-                if (union_selector) {
-                    uint8_t *psel = (uint8_t*)fld + fsz - 1;
-                    *psel = union_selector - 1;
-                }
-            }
-        }
-    }
+    size_t i, np = dt->layout->npointers;
+    char *start = data;
+    for (i = 0; i < np; i++) {
+        uint32_t ptr = jl_ptr_offset(dt, i);
+        jl_value_t **fld = &((jl_value_t**)data)[ptr];
+        if ((char*)fld != start)
+            ios_read(s->s, start, (const char*)fld - start);
+        *fld = jl_deserialize_value(s, fld);
+        //if (*fld)// a is new (gc is disabled)
+        //    jl_gc_wb(a, *fld);
+        start = (char*)&fld[1];
+    }
+    data += jl_datatype_size(dt);
+    if (data != start)
+        ios_read(s->s, start, data - start);
     if (dt == jl_typemap_entry_type) {
         jl_typemap_entry_t *entry = (jl_typemap_entry_t*)v;
         if (entry->max_world == ~(size_t)0) {
@@ -1927,25 +1986,6 @@ static void jl_deserialize_struct(jl_ser
     }
 }
 
-static jl_value_t *jl_deserialize_typemap_entry(jl_serializer_state *s) JL_GC_DISABLED
-{
-    int N = read_int32(s->s); int n = N;
-    jl_value_t *te = jl_nothing;
-    jl_value_t **pn = &te;
-    while (n > 0) {
-        jl_value_t *v = jl_gc_alloc(s->ptls, jl_datatype_size(jl_typemap_entry_type), jl_typemap_entry_type);
-        if (n == N && s->mode != MODE_IR)
-            arraylist_push(&backref_list, v);
-        jl_typemap_entry_t* te = (jl_typemap_entry_t*)v;
-        te->next = (jl_typemap_entry_t*)jl_nothing; // `next` is the first field
-        jl_deserialize_struct(s, v, 1);
-        *pn = v;
-        pn = (jl_value_t**)&te->next;
-        n--;
-    }
-    return te;
-}
-
 static jl_value_t *jl_deserialize_value_any(jl_serializer_state *s, uint8_t tag, jl_value_t **loc) JL_GC_DISABLED
 {
     int usetable = (s->mode != MODE_IR);
@@ -1992,11 +2032,7 @@ static jl_value_t *jl_deserialize_value_
         return (jl_value_t*)tn;
     }
     jl_set_typeof(v, dt);
-    if (jl_datatype_nfields(dt) == 0 && jl_datatype_size(dt) > 0) {
-        int nby = jl_datatype_size(dt);
-        ios_read(s->s, (char*)jl_data_ptr(v), nby);
-    }
-    else if ((jl_value_t*)dt == jl_bigint_type) {
+    if ((jl_value_t*)dt == jl_bigint_type) {
         jl_value_t *sizefield = jl_deserialize_value(s, NULL);
         int32_t sz = jl_unbox_int32(sizefield);
         int32_t nw = (sz == 0 ? 1 : (sz < 0 ? -sz : sz));
@@ -2010,7 +2046,7 @@ static jl_value_t *jl_deserialize_value_
         jl_set_nth_field(v, 2, jl_box_voidpointer(buf));
     }
     else {
-        jl_deserialize_struct(s, v, 0);
+        jl_deserialize_struct(s, v);
     }
     return v;
 }
@@ -2089,7 +2125,7 @@ static jl_value_t *jl_deserialize_value(
         v = jl_new_struct_uninit(tag == TAG_GOTONODE ? jl_gotonode_type : jl_quotenode_type);
         if (usetable)
             arraylist_push(&backref_list, v);
-        jl_set_nth_field(v, 0, jl_deserialize_value(s, NULL));
+        set_nth_field(tag == TAG_GOTONODE ? jl_gotonode_type : jl_quotenode_type, (void*)v, 0, jl_deserialize_value(s, NULL));
         return v;
     case TAG_UNIONALL:
         pos = backref_list.len;
@@ -2180,10 +2216,18 @@ static jl_value_t *jl_deserialize_value(
     case TAG_PTRTY:
         v = jl_deserialize_value(s, NULL);
         return jl_apply_type1((jl_value_t*)jl_pointer_type, v);
+    case TAG_CNULL:
+        v = jl_gc_alloc(s->ptls, sizeof(void*), NULL);
+        jl_set_typeof(v, (void*)(intptr_t)0x50);
+        *(void**)v = NULL;
+        uintptr_t pos = backref_list.len;
+        if (usetable)
+            arraylist_push(&backref_list, v);
+        jl_set_typeof(v, jl_deserialize_value(s, &jl_astaggedvalue(v)->type));
+        return v;
     case TAG_BITYPENAME:
         v = deser_tag[read_uint8(s->s)];
-        jl_datatype_t *dt = (jl_datatype_t*)jl_unwrap_unionall(v);
-        return (jl_value_t*)dt->name;
+        return (jl_value_t*)((jl_datatype_t*)jl_unwrap_unionall(v))->name;
     case TAG_STRING:
         n = read_int32(s->s);
         v = jl_alloc_string(n);
@@ -2191,15 +2235,13 @@ static jl_value_t *jl_deserialize_value(
             arraylist_push(&backref_list, v);
         ios_read(s->s, jl_string_data(v), n);
         return v;
-    case TAG_TYPEMAP_ENTRY:
-        return jl_deserialize_typemap_entry(s);
     case TAG_LINEINFO:
         v = jl_new_struct_uninit(jl_lineinfonode_type);
         if (usetable)
             arraylist_push(&backref_list, v);
         for (i = 0; i < jl_datatype_nfields(jl_lineinfonode_type); i++) {
             size_t offs = jl_field_offset(jl_lineinfonode_type, i);
-            jl_set_nth_field(v, i, jl_deserialize_value(s, (jl_value_t**)((char*)v + offs)));
+            set_nth_field(jl_lineinfonode_type, (void*)v, i, jl_deserialize_value(s, (jl_value_t**)((char*)v + offs)));
         }
         return v;
     case TAG_DATATYPE:
@@ -3219,7 +3261,7 @@ static jl_value_t *_jl_restore_increment
 
     arraylist_t *tracee_list = NULL;
     if (jl_newmeth_tracer)
-        tracee_list = arraylist_new((arraylist_t*)malloc(sizeof(arraylist_t)), 0);
+        tracee_list = arraylist_new((arraylist_t*)malloc_s(sizeof(arraylist_t)), 0);
 
     // at this point, the AST is fully reconstructed, but still completely disconnected
     // now all of the interconnects will be created
@@ -3341,7 +3383,6 @@ void jl_init_serializer(void)
     deser_tag[TAG_PHINODE] = (jl_value_t*)jl_phinode_type;
     deser_tag[TAG_PHICNODE] = (jl_value_t*)jl_phicnode_type;
     deser_tag[TAG_STRING] = (jl_value_t*)jl_string_type;
-    deser_tag[TAG_TYPEMAP_ENTRY] = (jl_value_t*)jl_typemap_entry_type;
     deser_tag[TAG_MODULE] = (jl_value_t*)jl_module_type;
     deser_tag[TAG_TVAR] = (jl_value_t*)jl_tvar_type;
     deser_tag[TAG_METHOD_INSTANCE] = (jl_value_t*)jl_method_instance_type;
diff -pruN 1.3.1+dfsg-1/src/flisp/cvalues.c 1.4.0+dfsg-1/src/flisp/cvalues.c
--- 1.3.1+dfsg-1/src/flisp/cvalues.c	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/src/flisp/cvalues.c	2020-03-21 16:36:32.000000000 +0000
@@ -136,6 +136,7 @@ value_t cvalue(fl_context_t *fl_ctx, flt
         pcv = (cvalue_t*)alloc_words(fl_ctx, CVALUE_NWORDS);
         pcv->type = type;
         pcv->data = malloc(sz);
+        // TODO: if pcv->data == NULL
         autorelease(fl_ctx, pcv);
         fl_ctx->malloc_pressure += sz;
     }
@@ -220,6 +221,7 @@ void cv_pin(fl_context_t *fl_ctx, cvalue
     size_t sz = cv_len(cv);
     if (cv_isstr(fl_ctx, cv)) sz++;
     void *data = malloc(sz);
+    // TODO: if data == NULL
     memcpy(data, cv_data(cv), sz);
     cv->data = data;
     autorelease(fl_ctx, cv);
@@ -570,6 +572,7 @@ value_t cvalue_copy(fl_context_t *fl_ctx
         size_t len = cv_len(cv);
         if (cv_isstr(fl_ctx, cv)) len++;
         ncv->data = malloc(len);
+        // TODO: if ncv->data == NULL
         memcpy(ncv->data, cv_data(cv), len);
         autorelease(fl_ctx, ncv);
         if (hasparent(cv)) {
@@ -778,6 +781,7 @@ value_t fl_builtin(fl_context_t *fl_ctx,
 value_t cbuiltin(fl_context_t *fl_ctx, const char *name, builtin_t f)
 {
     cvalue_t *cv = (cvalue_t*)malloc(CVALUE_NWORDS * sizeof(value_t));
+    // TODO: if cv->data == NULL
     cv->type = fl_ctx->builtintype;
     cv->data = &cv->_space[0];
     cv->len = sizeof(value_t);
diff -pruN 1.3.1+dfsg-1/src/flisp/flisp.c 1.4.0+dfsg-1/src/flisp/flisp.c
--- 1.3.1+dfsg-1/src/flisp/flisp.c	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/src/flisp/flisp.c	2020-03-21 16:36:32.000000000 +0000
@@ -226,6 +226,7 @@ static symbol_t *mk_symbol(const char *s
     size_t len = strlen(str);
 
     sym = (symbol_t*)malloc((offsetof(symbol_t,name)+len+1+7)&-8);
+    // TODO: if sym == NULL
     CHECK_ALIGN8(sym);
     sym->left = sym->right = NULL;
     sym->flags = 0;
@@ -330,6 +331,7 @@ static value_t mk_cons(fl_context_t *fl_
     if (fl_ctx->n_allocd > GC_INTERVAL)
         gc(fl_ctx, 0);
     c = (cons_t*)((void**)malloc(3*sizeof(void*)) + 1);
+    // TODO: if c == NULL
     CHECK_ALIGN8(c);
     ((void**)c)[-1] = fl_ctx->tochain;
     fl_ctx->tochain = c;
@@ -353,6 +355,7 @@ static value_t *alloc_words(fl_context_t
     if (fl_ctx->n_allocd > GC_INTERVAL)
         gc(fl_ctx, 0);
     first = (value_t*)malloc((n+1)*sizeof(value_t)) + 1;
+    // TODO: if first == NULL
     CHECK_ALIGN8(first);
     first[-1] = (value_t)fl_ctx->tochain;
     fl_ctx->tochain = first;
@@ -2339,6 +2342,7 @@ static void lisp_init(fl_context_t *fl_c
     comparehash_init(fl_ctx);
     fl_ctx->N_STACK = 262144;
     fl_ctx->Stack = (value_t*)malloc(fl_ctx->N_STACK*sizeof(value_t));
+    // TODO: if fl_ctx->Stack == NULL
     CHECK_ALIGN8(fl_ctx->Stack);
 
     fl_ctx->NIL = builtin(OP_THE_EMPTY_LIST);
diff -pruN 1.3.1+dfsg-1/src/flisp/julia_extensions.c 1.4.0+dfsg-1/src/flisp/julia_extensions.c
--- 1.3.1+dfsg-1/src/flisp/julia_extensions.c	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/src/flisp/julia_extensions.c	2020-03-21 16:36:32.000000000 +0000
@@ -241,6 +241,7 @@ value_t fl_julia_strip_op_suffix(fl_cont
     if (!op[i]) return args[0]; // no suffix to strip
     if (!i) return args[0]; // only suffix chars --- might still be a valid identifier
     char *opnew = strncpy((char*)malloc(i+1), op, i);
+    // TODO: if argument to opnew == NULL
     opnew[i] = 0;
     value_t opnew_symbol = symbol(fl_ctx, opnew);
     free(opnew);
diff -pruN 1.3.1+dfsg-1/src/flisp/Makefile 1.4.0+dfsg-1/src/flisp/Makefile
--- 1.3.1+dfsg-1/src/flisp/Makefile	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/src/flisp/Makefile	2020-03-21 16:36:32.000000000 +0000
@@ -110,10 +110,12 @@ $(BUILDDIR)/host/Makefile:
 $(BUILDDIR)/host/$(EXENAME): $(BUILDDIR)/host/Makefile
 	make -C $(BUILDDIR)/host $(EXENAME)
 
-ifneq ($(BUILDDIR)$(BUILDING_HOST_TOOLS),.)
+ifneq ($(BUILDDIR),.)
+ifneq ($(BUILDDIR),$(SRCDIR))
 $(BUILDDIR)/flisp.boot: $(SRCDIR)/flisp.boot | $(BUILDDIR)
 	cp $< $@
 endif
+endif
 
 test:
 ifneq ($(USEMSVC), 1)
diff -pruN 1.3.1+dfsg-1/src/flisp/read.c 1.4.0+dfsg-1/src/flisp/read.c
--- 1.3.1+dfsg-1/src/flisp/read.c	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/src/flisp/read.c	2020-03-21 16:36:32.000000000 +0000
@@ -460,6 +460,9 @@ static value_t read_string(fl_context_t
     uint32_t wc=0;
 
     buf = (char*)malloc(sz);
+    if (buf == NULL) {
+        lerror(fl_ctx, fl_ctx->ParseError, "read: out of memory reading string");
+    }
     while (1) {
         if (i >= sz-4) {  // -4: leaves room for longest utf8 sequence
             sz *= 2;
diff -pruN 1.3.1+dfsg-1/src/flisp/types.c 1.4.0+dfsg-1/src/flisp/types.c
--- 1.3.1+dfsg-1/src/flisp/types.c	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/src/flisp/types.c	2020-03-21 16:36:32.000000000 +0000
@@ -23,6 +23,7 @@ fltype_t *get_type(fl_context_t *fl_ctx,
     }
 
     ft = (fltype_t*)malloc(sizeof(fltype_t));
+    // TODO: if ft == NULL
     ft->type = t;
     if (issymbol(t)) {
         ft->numtype = sym_to_numtype(fl_ctx, t);
diff -pruN 1.3.1+dfsg-1/src/gc.c 1.4.0+dfsg-1/src/gc.c
--- 1.3.1+dfsg-1/src/gc.c	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/src/gc.c	2020-03-21 16:36:32.000000000 +0000
@@ -45,7 +45,7 @@ static void jl_gc_register_callback(jl_g
             return;
         list = &((*list)->next);
     }
-    *list = (jl_gc_callback_list_t *)malloc(sizeof(jl_gc_callback_list_t));
+    *list = (jl_gc_callback_list_t *)malloc_s(sizeof(jl_gc_callback_list_t));
     (*list)->next = NULL;
     (*list)->func = func;
 }
@@ -209,6 +209,52 @@ static void jl_gc_wait_for_the_world(voi
 
 // malloc wrappers, aligned allocation
 
+#if defined(_OS_WINDOWS_)
+STATIC_INLINE void *jl_malloc_aligned(size_t sz, size_t align)
+{
+    return _aligned_malloc(sz ? sz : 1, align);
+}
+STATIC_INLINE void *jl_realloc_aligned(void *p, size_t sz, size_t oldsz,
+                                       size_t align)
+{
+    (void)oldsz;
+    return _aligned_realloc(p, sz ? sz : 1, align);
+}
+STATIC_INLINE void jl_free_aligned(void *p) JL_NOTSAFEPOINT
+{
+    _aligned_free(p);
+}
+#else
+STATIC_INLINE void *jl_malloc_aligned(size_t sz, size_t align)
+{
+#if defined(_P64) || defined(__APPLE__)
+    if (align <= 16)
+        return malloc(sz);
+#endif
+    void *ptr;
+    if (posix_memalign(&ptr, align, sz))
+        return NULL;
+    return ptr;
+}
+STATIC_INLINE void *jl_realloc_aligned(void *d, size_t sz, size_t oldsz,
+                                       size_t align)
+{
+#if defined(_P64) || defined(__APPLE__)
+    if (align <= 16)
+        return realloc(d, sz);
+#endif
+    void *b = jl_malloc_aligned(sz, align);
+    if (b != NULL) {
+        memcpy(b, d, oldsz > sz ? sz : oldsz);
+        free(d);
+    }
+    return b;
+}
+STATIC_INLINE void jl_free_aligned(void *p) JL_NOTSAFEPOINT
+{
+    free(p);
+}
+#endif
 #define malloc_cache_align(sz) jl_malloc_aligned(sz, JL_CACHE_BYTE_ALIGNMENT)
 #define realloc_cache_align(p, sz, oldsz) jl_realloc_aligned(p, sz, oldsz, JL_CACHE_BYTE_ALIGNMENT)
 
@@ -295,7 +341,7 @@ static void finalize_object(arraylist_t
 static void jl_gc_push_arraylist(jl_ptls_t ptls, arraylist_t *list)
 {
     void **items = list->items;
-    items[0] = (void*)(((uintptr_t)list->len - 2) << 1);
+    items[0] = (void*)JL_GC_ENCODE_PUSHARGS(list->len - 2);
     items[1] = ptls->pgcstack;
     ptls->pgcstack = (jl_gcframe_t*)items;
 }
@@ -778,7 +824,7 @@ void jl_gc_force_mark_old(jl_ptls_t ptls
 static inline void maybe_collect(jl_ptls_t ptls)
 {
     if (ptls->gc_num.allocd >= 0 || gc_debug_check_other()) {
-        jl_gc_collect(0);
+        jl_gc_collect(JL_GC_AUTO);
     }
     else {
         jl_gc_safepoint_(ptls);
@@ -927,7 +973,7 @@ void jl_gc_track_malloced_array(jl_ptls_
     // This is **NOT** a GC safe point.
     mallocarray_t *ma;
     if (ptls->heap.mafreelist == NULL) {
-        ma = (mallocarray_t*)malloc(sizeof(mallocarray_t));
+        ma = (mallocarray_t*)malloc_s(sizeof(mallocarray_t));
     }
     else {
         ma = ptls->heap.mafreelist;
@@ -1074,7 +1120,7 @@ static NOINLINE jl_taggedvalue_t *add_pa
     jl_ptls_t ptls = jl_get_ptls_states();
     jl_gc_pagemeta_t *pg = jl_gc_alloc_page();
     pg->osize = p->osize;
-    pg->ages = (uint8_t*)malloc(GC_PAGE_SZ / 8 / p->osize + 1);
+    pg->ages = (uint8_t*)malloc_s(GC_PAGE_SZ / 8 / p->osize + 1);
     pg->thread_n = ptls->tid;
     jl_taggedvalue_t *fl = reset_page(p, pg, NULL);
     p->newpages = fl;
@@ -1453,6 +1499,45 @@ JL_DLLEXPORT void jl_gc_queue_root(jl_va
     ptls->heap.remset_nptr++; // conservative
 }
 
+void jl_gc_queue_multiroot(jl_value_t *parent, jl_value_t *ptr) JL_NOTSAFEPOINT
+{
+    // first check if this is really necessary
+    // TODO: should we store this info in one of the extra gc bits?
+    jl_datatype_t *dt = (jl_datatype_t*)jl_typeof(ptr);
+    const jl_datatype_layout_t *ly = dt->layout;
+    uint32_t npointers = ly->npointers;
+    //if (npointers == 0) // this was checked by the caller
+    //    return;
+    jl_value_t *ptrf = ((jl_value_t**)ptr)[ly->first_ptr];
+    if (ptrf && (jl_astaggedvalue(ptrf)->bits.gc & 1) == 0) {
+        // this pointer was young, move the barrier back now
+        jl_gc_wb_back(parent);
+        return;
+    }
+    const uint8_t *ptrs8 = (const uint8_t *)jl_dt_layout_ptrs(ly);
+    const uint16_t *ptrs16 = (const uint16_t *)jl_dt_layout_ptrs(ly);
+    const uint32_t *ptrs32 = (const uint32_t*)jl_dt_layout_ptrs(ly);
+    for (size_t i = 1; i < npointers; i++) {
+        uint32_t fld;
+        if (ly->fielddesc_type == 0) {
+            fld = ptrs8[i];
+        }
+        else if (ly->fielddesc_type == 1) {
+            fld = ptrs16[i];
+        }
+        else {
+            assert(ly->fielddesc_type == 2);
+            fld = ptrs32[i];
+        }
+        jl_value_t *ptrf = ((jl_value_t**)ptr)[fld];
+        if (ptrf && (jl_astaggedvalue(ptrf)->bits.gc & 1) == 0) {
+            // this pointer was young, move the barrier back now
+            jl_gc_wb_back(parent);
+            return;
+        }
+    }
+}
+
 void gc_queue_binding(jl_binding_t *bnd)
 {
     jl_ptls_t ptls = jl_get_ptls_states();
@@ -1515,10 +1600,10 @@ static void NOINLINE gc_mark_stack_resiz
     void **pc_stack = sp->pc_start;
     size_t stack_size = (char*)sp->pc_end - (char*)pc_stack;
     JL_LOCK_NOGC(&gc_cache->stack_lock);
-    gc_cache->data_stack = (jl_gc_mark_data_t *)realloc(old_data, stack_size * 2 * sizeof(jl_gc_mark_data_t));
+    gc_cache->data_stack = (jl_gc_mark_data_t *)realloc_s(old_data, stack_size * 2 * sizeof(jl_gc_mark_data_t));
     sp->data = (jl_gc_mark_data_t *)(((char*)sp->data) + (((char*)gc_cache->data_stack) - ((char*)old_data)));
 
-    sp->pc_start = gc_cache->pc_stack = (void**)realloc(pc_stack, stack_size * 2 * sizeof(void*));
+    sp->pc_start = gc_cache->pc_stack = (void**)realloc_s(pc_stack, stack_size * 2 * sizeof(void*));
     gc_cache->pc_stack_end = sp->pc_end = sp->pc_start + stack_size * 2;
     sp->pc += sp->pc_start - pc_stack;
     JL_UNLOCK_NOGC(&gc_cache->stack_lock);
@@ -1628,7 +1713,7 @@ JL_DLLEXPORT int jl_gc_mark_queue_obj(jl
 JL_DLLEXPORT void jl_gc_mark_queue_objarray(jl_ptls_t ptls, jl_value_t *parent,
                                             jl_value_t **objs, size_t nobjs)
 {
-    gc_mark_objarray_t data = { parent, objs, objs + nobjs,
+    gc_mark_objarray_t data = { parent, objs, objs + nobjs, 1,
                                 jl_astaggedvalue(parent)->bits.gc & 2 };
     gc_mark_stack_push(&ptls->gc_cache, &ptls->gc_mark_sp,
                        gc_mark_label_addrs[GC_MARK_L_objarray],
@@ -1661,14 +1746,14 @@ STATIC_INLINE int gc_mark_scan_objarray(
                                         jl_value_t **pnew_obj, uintptr_t *ptag, uint8_t *pbits)
 {
     (void)jl_assume(objary == (gc_mark_objarray_t*)sp->data);
-    for (; begin < end; begin++) {
+    for (; begin < end; begin += objary->step) {
         *pnew_obj = *begin;
         if (*pnew_obj)
             verify_parent2("obj array", objary->parent, begin, "elem(%d)",
                            gc_slot_to_arrayidx(objary->parent, begin));
         if (!gc_try_setmark(*pnew_obj, &objary->nptr, ptag, pbits))
             continue;
-        begin++;
+        begin += objary->step;
         // Found an object to mark
         if (begin < end) {
             // Haven't done with this one yet. Update the content and push it back
@@ -1686,17 +1771,64 @@ STATIC_INLINE int gc_mark_scan_objarray(
     return 0;
 }
 
+// Scan a sparse array of object references, see `gc_mark_objarray_t`
+STATIC_INLINE int gc_mark_scan_array8(jl_ptls_t ptls, jl_gc_mark_sp_t *sp,
+                                      gc_mark_array8_t *ary8,
+                                      jl_value_t **begin, jl_value_t **end,
+                                      uint8_t *elem_begin, uint8_t *elem_end,
+                                      jl_value_t **pnew_obj, uintptr_t *ptag, uint8_t *pbits)
+{
+    (void)jl_assume(ary8 == (gc_mark_array8_t*)sp->data);
+    size_t elsize = ((jl_array_t*)ary8->elem.parent)->elsize / sizeof(jl_value_t*);
+    for (; begin < end; begin += elsize) {
+        for (; elem_begin < elem_end; elem_begin++) {
+            jl_value_t **slot = &begin[*elem_begin];
+            *pnew_obj = *slot;
+            if (*pnew_obj)
+                verify_parent2("array", ary8->elem.parent, slot, "elem(%d)",
+                               gc_slot_to_arrayidx(ary8->elem.parent, begin));
+            if (!gc_try_setmark(*pnew_obj, &ary8->elem.nptr, ptag, pbits))
+                continue;
+            elem_begin++;
+            // Found an object to mark
+            if (elem_begin < elem_end) {
+                // Haven't done with this one yet. Update the content and push it back
+                ary8->elem.begin = elem_begin;
+                ary8->begin = begin;
+                gc_repush_markdata(sp, gc_mark_array8_t);
+            }
+            else {
+                begin += elsize;
+                if (begin < end) {
+                    // Haven't done with this array yet. Reset the content and push it back
+                    ary8->elem.begin = ary8->rebegin;
+                    ary8->begin = begin;
+                    gc_repush_markdata(sp, gc_mark_array8_t);
+                }
+                else {
+                    // Finished scanning this one, finish up by checking the GC invariance
+                    // and let the next item replacing the current one directly.
+                    gc_mark_push_remset(ptls, ary8->elem.parent, ary8->elem.nptr);
+                }
+            }
+            return 1;
+        }
+        elem_begin = ary8->rebegin;
+    }
+    gc_mark_push_remset(ptls, ary8->elem.parent, ary8->elem.nptr);
+    return 0;
+}
+
+
 // Scan an object with 8bits field descriptors. see `gc_mark_obj8_t`
 STATIC_INLINE int gc_mark_scan_obj8(jl_ptls_t ptls, jl_gc_mark_sp_t *sp, gc_mark_obj8_t *obj8,
-                                    char *parent, jl_fielddesc8_t *begin, jl_fielddesc8_t *end,
+                                    char *parent, uint8_t *begin, uint8_t *end,
                                     jl_value_t **pnew_obj, uintptr_t *ptag, uint8_t *pbits)
 {
     (void)jl_assume(obj8 == (gc_mark_obj8_t*)sp->data);
     (void)jl_assume(begin < end);
     for (; begin < end; begin++) {
-        if (!begin->isptr)
-            continue;
-        jl_value_t **slot = (jl_value_t**)(parent + begin->offset);
+        jl_value_t **slot = &((jl_value_t**)parent)[*begin];
         *pnew_obj = *slot;
         if (*pnew_obj)
             verify_parent2("object", parent, slot, "field(%d)",
@@ -1723,15 +1855,13 @@ STATIC_INLINE int gc_mark_scan_obj8(jl_p
 
 // Scan an object with 16bits field descriptors. see `gc_mark_obj16_t`
 STATIC_INLINE int gc_mark_scan_obj16(jl_ptls_t ptls, jl_gc_mark_sp_t *sp, gc_mark_obj16_t *obj16,
-                                     char *parent, jl_fielddesc16_t *begin, jl_fielddesc16_t *end,
+                                     char *parent, uint16_t *begin, uint16_t *end,
                                      jl_value_t **pnew_obj, uintptr_t *ptag, uint8_t *pbits) JL_NOTSAFEPOINT
 {
     (void)jl_assume(obj16 == (gc_mark_obj16_t*)sp->data);
     (void)jl_assume(begin < end);
     for (; begin < end; begin++) {
-        if (!begin->isptr)
-            continue;
-        jl_value_t **slot = (jl_value_t**)(parent + begin->offset);
+        jl_value_t **slot = &((jl_value_t**)parent)[*begin];
         *pnew_obj = *slot;
         if (*pnew_obj)
             verify_parent2("object", parent, slot, "field(%d)",
@@ -1758,15 +1888,13 @@ STATIC_INLINE int gc_mark_scan_obj16(jl_
 
 // Scan an object with 32bits field descriptors. see `gc_mark_obj32_t`
 STATIC_INLINE int gc_mark_scan_obj32(jl_ptls_t ptls, jl_gc_mark_sp_t *sp, gc_mark_obj32_t *obj32,
-                                     char *parent, jl_fielddesc32_t *begin, jl_fielddesc32_t *end,
+                                     char *parent, uint32_t *begin, uint32_t *end,
                                      jl_value_t **pnew_obj, uintptr_t *ptag, uint8_t *pbits)
 {
     (void)jl_assume(obj32 == (gc_mark_obj32_t*)sp->data);
     (void)jl_assume(begin < end);
     for (; begin < end; begin++) {
-        if (!begin->isptr)
-            continue;
-        jl_value_t **slot = (jl_value_t**)(parent + begin->offset);
+        jl_value_t **slot = &((jl_value_t**)parent)[*begin];
         *pnew_obj = *slot;
         if (*pnew_obj)
             verify_parent2("object", parent, slot, "field(%d)",
@@ -1806,6 +1934,8 @@ STATIC_INLINE int gc_mark_scan_obj32(jl_
             goto finlist;                       \
         case GC_MARK_L_objarray:                \
             goto objarray;                      \
+        case GC_MARK_L_array8:                  \
+            goto array8;                        \
         case GC_MARK_L_obj8:                    \
             goto obj8;                          \
         case GC_MARK_L_obj16:                   \
@@ -1897,6 +2027,7 @@ JL_EXTENSION NOINLINE void gc_mark_loop(
         gc_mark_label_addrs[GC_MARK_L_scan_only] = gc_mark_laddr(scan_only);
         gc_mark_label_addrs[GC_MARK_L_finlist] = gc_mark_laddr(finlist);
         gc_mark_label_addrs[GC_MARK_L_objarray] = gc_mark_laddr(objarray);
+        gc_mark_label_addrs[GC_MARK_L_array8] = gc_mark_laddr(array8);
         gc_mark_label_addrs[GC_MARK_L_obj8] = gc_mark_laddr(obj8);
         gc_mark_label_addrs[GC_MARK_L_obj16] = gc_mark_laddr(obj16);
         gc_mark_label_addrs[GC_MARK_L_obj32] = gc_mark_laddr(obj32);
@@ -1915,15 +2046,17 @@ JL_EXTENSION NOINLINE void gc_mark_loop(
     jl_value_t **objary_begin;
     jl_value_t **objary_end;
 
+    gc_mark_array8_t *ary8;
+
     gc_mark_obj8_t *obj8;
     char *obj8_parent;
-    jl_fielddesc8_t *obj8_begin;
-    jl_fielddesc8_t *obj8_end;
+    uint8_t *obj8_begin;
+    uint8_t *obj8_end;
 
     gc_mark_obj16_t *obj16;
     char *obj16_parent;
-    jl_fielddesc16_t *obj16_begin;
-    jl_fielddesc16_t *obj16_end;
+    uint16_t *obj16_begin;
+    uint16_t *obj16_end;
 
 pop:
     if (sp.pc == sp.pc_start) {
@@ -1962,6 +2095,19 @@ objarray_loaded:
         goto mark;
     goto pop;
 
+array8:
+    ary8 = gc_pop_markdata(&sp, gc_mark_array8_t);
+    objary_begin = ary8->begin;
+    objary_end = ary8->end;
+    obj8_begin = ary8->elem.begin;
+    obj8_end = ary8->elem.end;
+array8_loaded:
+    if (gc_mark_scan_array8(ptls, &sp, ary8, objary_begin, objary_end, obj8_begin, obj8_end,
+                            &new_obj, &tag, &bits))
+        goto mark;
+    goto pop;
+
+
 obj8:
     obj8 = gc_pop_markdata(&sp, gc_mark_obj8_t);
     obj8_parent = (char*)obj8->parent;
@@ -1987,8 +2133,8 @@ obj16_loaded:
 obj32: {
         gc_mark_obj32_t *obj32 = gc_pop_markdata(&sp, gc_mark_obj32_t);
         char *parent = (char*)obj32->parent;
-        jl_fielddesc32_t *begin = obj32->begin;
-        jl_fielddesc32_t *end = obj32->end;
+        uint32_t *begin = obj32->begin;
+        uint32_t *end = obj32->end;
         if (gc_mark_scan_obj32(ptls, &sp, obj32, parent, begin, end, &new_obj, &tag, &bits))
             goto mark;
         goto pop;
@@ -2005,7 +2151,7 @@ stack: {
         uintptr_t offset = stack->offset;
         uintptr_t lb = stack->lb;
         uintptr_t ub = stack->ub;
-        uint32_t nr = nroots >> 1;
+        uint32_t nr = nroots >> 2;
         uintptr_t nptr = 0;
         while (1) {
             jl_value_t ***rts = (jl_value_t***)(((void**)s) + 2);
@@ -2047,7 +2193,7 @@ stack: {
                 uintptr_t new_nroots = gc_read_stack(&s->nroots, offset, lb, ub);
                 assert(new_nroots <= UINT32_MAX);
                 nroots = stack->nroots = (uint32_t)new_nroots;
-                nr = nroots >> 1;
+                nr = nroots >> 2;
                 continue;
             }
             goto pop;
@@ -2059,34 +2205,41 @@ excstack: {
         gc_mark_excstack_t *stackitr = gc_pop_markdata(&sp, gc_mark_excstack_t);
         jl_excstack_t *excstack = stackitr->s;
         size_t itr = stackitr->itr;
-        size_t i = stackitr->i;
+        size_t bt_index = stackitr->bt_index;
+        size_t jlval_index = stackitr->jlval_index;
         while (itr > 0) {
             size_t bt_size = jl_excstack_bt_size(excstack, itr);
-            uintptr_t *bt_data = jl_excstack_bt_data(excstack, itr);
-            while (i+2 < bt_size) {
-                if (bt_data[i] != JL_BT_INTERP_FRAME) {
-                    i++;
+            jl_bt_element_t *bt_data = jl_excstack_bt_data(excstack, itr);
+            for (; bt_index < bt_size; bt_index += jl_bt_entry_size(bt_data + bt_index)) {
+                jl_bt_element_t *bt_entry = bt_data + bt_index;
+                if (jl_bt_is_native(bt_entry))
                     continue;
-                }
-                // found an interpreter frame to mark
-                new_obj = (jl_value_t*)bt_data[i+1];
-                uintptr_t nptr = 0;
-                i += 3;
-                if (gc_try_setmark(new_obj, &nptr, &tag, &bits)) {
-                    stackitr->i = i;
-                    stackitr->itr = itr;
-                    gc_repush_markdata(&sp, gc_mark_excstack_t);
-                    goto mark;
+                // Found an extended backtrace entry: iterate over any
+                // GC-managed values inside.
+                size_t njlvals = jl_bt_num_jlvals(bt_entry);
+                while (jlval_index < njlvals) {
+                    new_obj = jl_bt_entry_jlvalue(bt_entry, jlval_index);
+                    uintptr_t nptr = 0;
+                    jlval_index += 1;
+                    if (gc_try_setmark(new_obj, &nptr, &tag, &bits)) {
+                        stackitr->itr = itr;
+                        stackitr->bt_index = bt_index;
+                        stackitr->jlval_index = jlval_index;
+                        gc_repush_markdata(&sp, gc_mark_excstack_t);
+                        goto mark;
+                    }
                 }
             }
-            // mark the exception
+            // The exception comes last - mark it
             new_obj = jl_excstack_exception(excstack, itr);
             itr = jl_excstack_next(excstack, itr);
-            i = 0;
+            bt_index = 0;
+            jlval_index = 0;
             uintptr_t nptr = 0;
             if (gc_try_setmark(new_obj, &nptr, &tag, &bits)) {
-                stackitr->i = i;
                 stackitr->itr = itr;
+                stackitr->bt_index = bt_index;
+                stackitr->jlval_index = jlval_index;
                 gc_repush_markdata(&sp, gc_mark_excstack_t);
                 goto mark;
             }
@@ -2156,7 +2309,7 @@ module_binding: {
             // contain the only reference.
             objary_begin = (jl_value_t**)m->usings.items;
             objary_end = objary_begin + nusings;
-            gc_mark_objarray_t data = {(jl_value_t*)m, objary_begin, objary_end, binding->nptr};
+            gc_mark_objarray_t data = {(jl_value_t*)m, objary_begin, objary_end, 1, binding->nptr};
             gc_mark_stack_push(&ptls->gc_cache, &sp, gc_mark_laddr(objarray),
                                &data, sizeof(data), 0);
             if (!scanparent) {
@@ -2234,7 +2387,7 @@ mark: {
             uintptr_t nptr = (l << 2) | (bits & GC_OLD);
             objary_begin = data;
             objary_end = data + l;
-            gc_mark_objarray_t markdata = {new_obj, objary_begin, objary_end, nptr};
+            gc_mark_objarray_t markdata = {new_obj, objary_begin, objary_end, 1, nptr};
             gc_mark_stack_push(&ptls->gc_cache, &sp, gc_mark_laddr(objarray),
                                &markdata, sizeof(markdata), 0);
             objary = (gc_mark_objarray_t*)sp.data;
@@ -2281,17 +2434,50 @@ mark: {
                 }
                 goto pop;
             }
-            if (!flags.ptrarray || a->data == NULL)
+            if (a->data == NULL || jl_array_len(a) == 0)
                 goto pop;
-            size_t l = jl_array_len(a);
-            uintptr_t nptr = (l << 2) | (bits & GC_OLD);
-            objary_begin = (jl_value_t**)a->data;
-            objary_end = objary_begin + l;
-            gc_mark_objarray_t markdata = {new_obj, objary_begin, objary_end, nptr};
-            gc_mark_stack_push(&ptls->gc_cache, &sp, gc_mark_laddr(objarray),
-                               &markdata, sizeof(markdata), 0);
-            objary = (gc_mark_objarray_t*)sp.data;
-            goto objarray_loaded;
+            if (flags.ptrarray) {
+                size_t l = jl_array_len(a);
+                uintptr_t nptr = (l << 2) | (bits & GC_OLD);
+                objary_begin = (jl_value_t**)a->data;
+                objary_end = objary_begin + l;
+                gc_mark_objarray_t markdata = {new_obj, objary_begin, objary_end, 1, nptr};
+                gc_mark_stack_push(&ptls->gc_cache, &sp, gc_mark_laddr(objarray),
+                                   &markdata, sizeof(markdata), 0);
+                objary = (gc_mark_objarray_t*)sp.data;
+                goto objarray_loaded;
+            }
+            else if (flags.hasptr) {
+                jl_datatype_t *et = (jl_datatype_t*)jl_tparam0(vt);
+                const jl_datatype_layout_t *layout = et->layout;
+                unsigned npointers = layout->npointers;
+                unsigned elsize = a->elsize / sizeof(jl_value_t*);
+                size_t l = jl_array_len(a);
+                uintptr_t nptr = ((l * npointers) << 2) | (bits & GC_OLD);
+                objary_begin = (jl_value_t**)a->data;
+                objary_end = objary_begin + l * elsize;
+                if (npointers == 1) { // TODO: detect anytime time stride is uniform?
+                    objary_begin += layout->first_ptr;
+                    gc_mark_objarray_t markdata = {new_obj, objary_begin, objary_end, elsize, nptr};
+                    gc_mark_stack_push(&ptls->gc_cache, &sp, gc_mark_laddr(objarray),
+                                       &markdata, sizeof(markdata), 0);
+                    objary = (gc_mark_objarray_t*)sp.data;
+                    goto objarray_loaded;
+                }
+                else if (layout->fielddesc_type == 0) {
+                    obj8_begin = (uint8_t*)jl_dt_layout_ptrs(layout);
+                    obj8_end = obj8_begin + npointers;
+                    gc_mark_array8_t markdata = {objary_begin, objary_end, obj8_begin, {new_obj, obj8_begin, obj8_end, nptr}};
+                    gc_mark_stack_push(&ptls->gc_cache, &sp, gc_mark_laddr(array8),
+                                       &markdata, sizeof(markdata), 0);
+                    ary8 = (gc_mark_array8_t*)sp.data;
+                    goto array8_loaded;
+                }
+                else {
+                    assert(0 && "unimplemented");
+                }
+            }
+            goto pop;
         }
         else if (vt == jl_module_type) {
             if (update_meta)
@@ -2343,6 +2529,7 @@ mark: {
                 s = ta->gcstack;
 #ifdef COPY_STACKS
                 if (ta->copy_stack) {
+                    assert(tid != -1 && ptls2 != NULL);
                     ub = (uintptr_t)ptls2->stackbase;
                     lb = ub - ta->copy_stack;
                     offset = (uintptr_t)stkbuf - lb;
@@ -2359,18 +2546,18 @@ mark: {
             if (ta->excstack) {
                 gc_setmark_buf_(ptls, ta->excstack, bits, sizeof(jl_excstack_t) +
                                 sizeof(uintptr_t)*ta->excstack->reserved_size);
-                gc_mark_excstack_t stackdata = {ta->excstack, ta->excstack->top, 0};
+                gc_mark_excstack_t stackdata = {ta->excstack, ta->excstack->top, 0, 0};
                 gc_mark_stack_push(&ptls->gc_cache, &sp, gc_mark_laddr(excstack),
                                    &stackdata, sizeof(stackdata), 1);
             }
             const jl_datatype_layout_t *layout = jl_task_type->layout;
             assert(layout->fielddesc_type == 0);
-            size_t nfields = layout->nfields;
-            assert(nfields > 0);
-            obj8_begin = (jl_fielddesc8_t*)jl_dt_layout_fields(layout);
-            obj8_end = obj8_begin + nfields;
+            assert(layout->nfields > 0);
+            uint32_t npointers = layout->npointers;
+            obj8_begin = (uint8_t*)jl_dt_layout_ptrs(layout);
+            obj8_end = obj8_begin + npointers;
             // assume tasks always reference young objects: set lowest bit
-            uintptr_t nptr = (9 << 2) | 1 | bits;
+            uintptr_t nptr = (npointers << 2) | 1 | bits;
             gc_mark_obj8_t markdata = {new_obj, obj8_begin, obj8_end, nptr};
             gc_mark_stack_push(&ptls->gc_cache, &sp, gc_mark_laddr(obj8),
                                &markdata, sizeof(markdata), 0);
@@ -2400,17 +2587,12 @@ mark: {
             uint32_t npointers = layout->npointers;
             if (npointers == 0)
                 goto pop;
-            uintptr_t nptr = ((npointers & 0xff) << (npointers & 0x300)) << 2;
-            nptr = nptr | (bits & GC_OLD);
-            uint32_t offsets = jl_datatype_layout_n_nonptr(layout);
-            size_t nfields = layout->nfields;
-            nfields -= offsets & 0xffff;
-            size_t first = offsets >> 16;
+            uintptr_t nptr = npointers << 2 | (bits & GC_OLD);
+            assert(layout->nfields > 0 && layout->fielddesc_type != 3 && "opaque types should have been handled specially");
             if (layout->fielddesc_type == 0) {
-                jl_fielddesc8_t *desc = (jl_fielddesc8_t*)jl_dt_layout_fields(layout);
                 obj8_parent = (char*)new_obj;
-                obj8_begin = desc + first;
-                obj8_end = desc + nfields;
+                obj8_begin = (uint8_t*)jl_dt_layout_ptrs(layout);
+                obj8_end = obj8_begin + npointers;
                 assert(obj8_begin < obj8_end);
                 gc_mark_obj8_t markdata = {new_obj, obj8_begin, obj8_end, nptr};
                 gc_mark_stack_push(&ptls->gc_cache, &sp, gc_mark_laddr(obj8),
@@ -2419,10 +2601,9 @@ mark: {
                 goto obj8_loaded;
             }
             else if (layout->fielddesc_type == 1) {
-                jl_fielddesc16_t *desc = (jl_fielddesc16_t*)jl_dt_layout_fields(layout);
                 obj16_parent = (char*)new_obj;
-                obj16_begin = desc + first;
-                obj16_end = desc + nfields;
+                obj16_begin = (uint16_t*)jl_dt_layout_ptrs(layout);
+                obj16_end = obj16_begin + npointers;
                 assert(obj16_begin < obj16_end);
                 gc_mark_obj16_t markdata = {new_obj, obj16_begin, obj16_end, nptr};
                 gc_mark_stack_push(&ptls->gc_cache, &sp, gc_mark_laddr(obj16),
@@ -2433,9 +2614,9 @@ mark: {
             else if (layout->fielddesc_type == 2) {
                 // This is very uncommon
                 // Do not do store to load forwarding to save some code size
-                jl_fielddesc32_t *desc = (jl_fielddesc32_t*)jl_dt_layout_fields(layout);
-                assert(first < nfields);
-                gc_mark_obj32_t markdata = {new_obj, desc + first, desc + nfields, nptr};
+                uint32_t *obj32_begin = (uint32_t*)jl_dt_layout_ptrs(layout);
+                uint32_t *obj32_end = obj32_begin + npointers;
+                gc_mark_obj32_t markdata = {new_obj, obj32_begin, obj32_end, nptr};
                 gc_mark_stack_push(&ptls->gc_cache, &sp, gc_mark_laddr(obj32),
                                    &markdata, sizeof(markdata), 0);
                 sp.data = (jl_gc_mark_data_t *)(((char*)sp.data) + sizeof(markdata));
@@ -2444,7 +2625,6 @@ mark: {
             else {
                 assert(layout->fielddesc_type == 3);
                 jl_fielddescdyn_t *desc = (jl_fielddescdyn_t*)jl_dt_layout_fields(layout);
-
                 int old = jl_astaggedvalue(new_obj)->bits.gc & 2;
                 export_gc_state(ptls, &sp);
                 uintptr_t young = desc->markfunc(ptls, new_obj);
@@ -2572,23 +2752,26 @@ JL_DLLEXPORT int jl_gc_enable(int on)
     }
     return prev;
 }
+
 JL_DLLEXPORT int jl_gc_is_enabled(void)
 {
     jl_ptls_t ptls = jl_get_ptls_states();
     return !ptls->disable_gc;
 }
 
-JL_DLLEXPORT int64_t jl_gc_total_bytes(void)
+JL_DLLEXPORT void jl_gc_get_total_bytes(int64_t *bytes)
 {
     jl_gc_num_t num = gc_num;
     combine_thread_gc_counts(&num);
     // Sync this logic with `base/util.jl:GC_Diff`
-    return (num.total_allocd + num.deferred_alloc + num.allocd);
+    *bytes = (num.total_allocd + num.deferred_alloc + num.allocd);
 }
+
 JL_DLLEXPORT uint64_t jl_gc_total_hrtime(void)
 {
     return gc_num.total_time;
 }
+
 JL_DLLEXPORT jl_gc_num_t jl_gc_num(void)
 {
     jl_gc_num_t num = gc_num;
@@ -2596,14 +2779,25 @@ JL_DLLEXPORT jl_gc_num_t jl_gc_num(void)
     return num;
 }
 
+// TODO: these were supposed to be thread local
 JL_DLLEXPORT int64_t jl_gc_diff_total_bytes(void)
 {
     int64_t oldtb = last_gc_total_bytes;
-    int64_t newtb = jl_gc_total_bytes();
+    int64_t newtb;
+    jl_gc_get_total_bytes(&newtb);
     last_gc_total_bytes = newtb;
     return newtb - oldtb;
 }
-void jl_gc_sync_total_bytes(void) {last_gc_total_bytes = jl_gc_total_bytes();}
+
+void jl_gc_sync_total_bytes(void)
+{
+    jl_gc_get_total_bytes(&last_gc_total_bytes);
+}
+
+JL_DLLEXPORT int64_t jl_gc_live_bytes(void)
+{
+    return live_bytes;
+}
 
 static void jl_gc_premark(jl_ptls_t ptls2)
 {
@@ -2654,20 +2848,22 @@ static void jl_gc_queue_remset(jl_gc_mar
 
 static void jl_gc_queue_bt_buf(jl_gc_mark_cache_t *gc_cache, jl_gc_mark_sp_t *sp, jl_ptls_t ptls2)
 {
-    size_t n = 0;
-    while (n+2 < ptls2->bt_size) {
-        if (ptls2->bt_data[n] == JL_BT_INTERP_FRAME) {
-            gc_mark_queue_obj(gc_cache, sp, (jl_value_t*)ptls2->bt_data[n+1]);
-            n += 2;
-        }
-        n++;
+    jl_bt_element_t *bt_data = ptls2->bt_data;
+    size_t bt_size = ptls2->bt_size;
+    for (size_t i = 0; i < bt_size; i += jl_bt_entry_size(bt_data + i)) {
+        jl_bt_element_t *bt_entry = bt_data + i;
+        if (jl_bt_is_native(bt_entry))
+            continue;
+        size_t njlvals = jl_bt_num_jlvals(bt_entry);
+        for (size_t j = 0; j < njlvals; j++)
+            gc_mark_queue_obj(gc_cache, sp, jl_bt_entry_jlvalue(bt_entry, j));
     }
 }
 
 size_t jl_maxrss(void);
 
 // Only one thread should be running in this function
-static int _jl_gc_collect(jl_ptls_t ptls, int full)
+static int _jl_gc_collect(jl_ptls_t ptls, jl_gc_collection_t collection)
 {
     combine_thread_gc_counts(&gc_num);
 
@@ -2697,7 +2893,7 @@ static int _jl_gc_collect(jl_ptls_t ptls
     if (gc_cblist_root_scanner) {
         export_gc_state(ptls, &sp);
         gc_invoke_callbacks(jl_gc_cb_root_scanner_t,
-            gc_cblist_root_scanner, (full));
+            gc_cblist_root_scanner, (collection));
         import_gc_state(ptls, &sp);
     }
     gc_mark_loop(ptls, sp);
@@ -2775,12 +2971,14 @@ static int _jl_gc_collect(jl_ptls_t ptls
     else if (live_bytes >= last_live_bytes) {
         grown_heap_age++;
     }
-    if ((full || large_frontier ||
+    if (collection == JL_GC_INCREMENTAL) {
+        sweep_full = 0;
+    } else if ((collection == JL_GC_FULL || large_frontier ||
          ((not_freed_enough || promoted_bytes >= gc_num.interval) &&
           (promoted_bytes >= default_collect_interval || prev_sweep_full)) ||
          grown_heap_age > 1) &&
         gc_num.pause > 1) {
-        recollect = full;
+        recollect = (collection == JL_GC_FULL);
         if (large_frontier)
             gc_num.interval = last_long_collect_interval;
         if (not_freed_enough || large_frontier) {
@@ -2869,7 +3067,7 @@ static int _jl_gc_collect(jl_ptls_t ptls
     return recollect;
 }
 
-JL_DLLEXPORT void jl_gc_collect(int full)
+JL_DLLEXPORT void jl_gc_collect(jl_gc_collection_t collection)
 {
     jl_ptls_t ptls = jl_get_ptls_states();
     if (jl_gc_disable_counter) {
@@ -2890,18 +3088,23 @@ JL_DLLEXPORT void jl_gc_collect(int full
         return;
     }
     JL_TIMING(GC);
+    int last_errno = errno;
+#ifdef _OS_WINDOWS_
+    DWORD last_error = GetLastError();
+#endif
     // Now we are ready to wait for other threads to hit the safepoint,
     // we can do a few things that doesn't require synchronization.
     // TODO (concurrently queue objects)
     // no-op for non-threading
     jl_gc_wait_for_the_world();
     gc_invoke_callbacks(jl_gc_cb_pre_gc_t,
-        gc_cblist_pre_gc, (full));
+        gc_cblist_pre_gc, (collection));
 
     if (!jl_gc_disable_counter) {
         JL_LOCK_NOGC(&finalizers_lock);
-        if (_jl_gc_collect(ptls, full)) {
-            int ret = _jl_gc_collect(ptls, 0);
+        if (_jl_gc_collect(ptls, collection)) {
+            // recollect
+            int ret = _jl_gc_collect(ptls, JL_GC_AUTO);
             (void)ret;
             assert(!ret);
         }
@@ -2922,7 +3125,11 @@ JL_DLLEXPORT void jl_gc_collect(int full
         ptls->in_finalizer = was_in_finalizer;
     }
     gc_invoke_callbacks(jl_gc_cb_post_gc_t,
-        gc_cblist_post_gc, (full));
+        gc_cblist_post_gc, (collection));
+#ifdef _OS_WINDOWS_
+    SetLastError(last_error);
+#endif
+    errno = last_errno;
 }
 
 void gc_mark_queue_all_roots(jl_ptls_t ptls, jl_gc_mark_sp_t *sp)
@@ -2972,9 +3179,9 @@ void jl_init_thread_heap(jl_ptls_t ptls)
     gc_cache->nbig_obj = 0;
     JL_MUTEX_INIT(&gc_cache->stack_lock);
     size_t init_size = 1024;
-    gc_cache->pc_stack = (void**)malloc(init_size * sizeof(void*));
+    gc_cache->pc_stack = (void**)malloc_s(init_size * sizeof(void*));
     gc_cache->pc_stack_end = gc_cache->pc_stack + init_size;
-    gc_cache->data_stack = (jl_gc_mark_data_t *)malloc(init_size * sizeof(jl_gc_mark_data_t));
+    gc_cache->data_stack = (jl_gc_mark_data_t *)malloc_s(init_size * sizeof(jl_gc_mark_data_t));
 
     memset(&ptls->gc_num, 0, sizeof(jl_thread_gc_num_t));
     assert(gc_num.interval == default_collect_interval);
@@ -3119,9 +3326,17 @@ JL_DLLEXPORT void *jl_gc_managed_malloc(
         jl_throw(jl_memory_exception);
     ptls->gc_num.allocd += allocsz;
     ptls->gc_num.malloc++;
+    int last_errno = errno;
+#ifdef _OS_WINDOWS_
+    DWORD last_error = GetLastError();
+#endif
     void *b = malloc_cache_align(allocsz);
     if (b == NULL)
         jl_throw(jl_memory_exception);
+#ifdef _OS_WINDOWS_
+    SetLastError(last_error);
+#endif
+    errno = last_errno;
     return b;
 }
 
@@ -3145,6 +3360,10 @@ static void *gc_managed_realloc_(jl_ptls
         ptls->gc_num.allocd += (allocsz - oldsz);
     ptls->gc_num.realloc++;
 
+    int last_errno = errno;
+#ifdef _OS_WINDOWS_
+    DWORD last_error = GetLastError();
+#endif
     void *b;
     if (isaligned)
         b = realloc_cache_align(d, allocsz, oldsz);
@@ -3152,6 +3371,10 @@ static void *gc_managed_realloc_(jl_ptls
         b = realloc(d, allocsz);
     if (b == NULL)
         jl_throw(jl_memory_exception);
+#ifdef _OS_WINDOWS_
+    SetLastError(last_error);
+#endif
+    errno = last_errno;
 
     return b;
 }
@@ -3216,7 +3439,17 @@ static void *gc_perm_alloc_large(size_t
     const size_t malloc_align = sizeof(void*) == 8 ? 16 : 4;
     if (align > 1 && (offset != 0 || align > malloc_align))
         sz += align - 1;
+    int last_errno = errno;
+#ifdef _OS_WINDOWS_
+    DWORD last_error = GetLastError();
+#endif
     uintptr_t base = (uintptr_t)(zero ? calloc(1, sz) : malloc(sz));
+    if (base == 0)
+        jl_throw(jl_memory_exception);
+#ifdef _OS_WINDOWS_
+    SetLastError(last_error);
+#endif
+    errno = last_errno;
     jl_may_leak(base);
     unsigned diff = (offset - base) % align;
     return (void*)(base + diff);
@@ -3244,13 +3477,18 @@ void *jl_gc_perm_alloc_nolock(size_t sz,
     void *ptr = gc_try_perm_alloc_pool(sz, align, offset);
     if (__likely(ptr))
         return ptr;
+    int last_errno = errno;
 #ifdef _OS_WINDOWS_
+    DWORD last_error = GetLastError();
     void *pool = VirtualAlloc(NULL, GC_PERM_POOL_SIZE, MEM_COMMIT, PAGE_READWRITE);
+    SetLastError(last_error);
+    errno = last_errno;
     if (__unlikely(pool == NULL))
         return NULL;
 #else
     void *pool = mmap(0, GC_PERM_POOL_SIZE, PROT_READ | PROT_WRITE,
                       MAP_PRIVATE | MAP_ANONYMOUS, -1, 0);
+    errno = last_errno;
     if (__unlikely(pool == MAP_FAILED))
         return NULL;
 #endif
@@ -3332,7 +3570,7 @@ JL_DLLEXPORT int jl_gc_enable_conservati
             // properly. We don't have to worry about race conditions
             // for this part, as allocation itself is unproblematic and
             // a collection will wait for safepoints.
-            jl_gc_collect(1);
+            jl_gc_collect(JL_GC_FULL);
         }
         return result;
     } else {
diff -pruN 1.3.1+dfsg-1/src/gc-debug.c 1.4.0+dfsg-1/src/gc-debug.c
--- 1.3.1+dfsg-1/src/gc-debug.c	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/src/gc-debug.c	2020-03-21 16:36:32.000000000 +0000
@@ -203,7 +203,7 @@ static void gc_verify_track(jl_ptls_t pt
         jl_gc_mark_sp_t sp;
         gc_mark_sp_init(gc_cache, &sp);
         arraylist_push(&lostval_parents_done, lostval);
-        jl_printf(JL_STDERR, "Now looking for %p =======\n", lostval);
+        jl_safe_printf("Now looking for %p =======\n", lostval);
         clear_mark(GC_CLEAN);
         gc_mark_queue_all_roots(ptls, &sp);
         gc_mark_queue_finlist(gc_cache, &sp, &to_finalize, 0);
@@ -214,7 +214,7 @@ static void gc_verify_track(jl_ptls_t pt
         gc_mark_queue_finlist(gc_cache, &sp, &finalizer_list_marked, 0);
         gc_mark_loop(ptls, sp);
         if (lostval_parents.len == 0) {
-            jl_printf(JL_STDERR, "Could not find the missing link. We missed a toplevel root. This is odd.\n");
+            jl_safe_printf("Could not find the missing link. We missed a toplevel root. This is odd.\n");
             break;
         }
         jl_value_t *lostval_parent = NULL;
@@ -235,9 +235,9 @@ static void gc_verify_track(jl_ptls_t pt
             lostval = (jl_value_t*)arraylist_pop(&lostval_parents);
         }
         else {
-            jl_printf(JL_STDERR, "Missing write barrier found !\n");
-            jl_printf(JL_STDERR, "%p was written a reference to %p that was not recorded\n", lostval_parent, lostval);
-            jl_printf(JL_STDERR, "(details above)\n");
+            jl_safe_printf("Missing write barrier found !\n");
+            jl_safe_printf("%p was written a reference to %p that was not recorded\n", lostval_parent, lostval);
+            jl_safe_printf("(details above)\n");
             lostval = NULL;
         }
         restore();
@@ -266,11 +266,11 @@ void gc_verify(jl_ptls_t ptls)
     for(int i = 0; i < clean_len + bits_save[GC_OLD].len; i++) {
         jl_taggedvalue_t *v = (jl_taggedvalue_t*)bits_save[i >= clean_len ? GC_OLD : GC_CLEAN].items[i >= clean_len ? i - clean_len : i];
         if (gc_marked(v->bits.gc)) {
-            jl_printf(JL_STDERR, "Error. Early free of %p type :", v);
+            jl_safe_printf("Error. Early free of %p type :", v);
             jl_(jl_typeof(jl_valueof(v)));
-            jl_printf(JL_STDERR, "val : ");
+            jl_safe_printf("val : ");
             jl_(jl_valueof(v));
-            jl_printf(JL_STDERR, "Let's try to backtrack the missing write barrier :\n");
+            jl_safe_printf("Let's try to backtrack the missing write barrier :\n");
             lostval = jl_valueof(v);
             break;
         }
@@ -667,44 +667,44 @@ static void objprofile_print(htable_t nu
             size_t sz = (uintptr_t)ptrhash_get(&sizes, ty) - 1;
             static const int ptr_hex_width = 2 * sizeof(void*);
             if (sz > 2e9) {
-                jl_printf(JL_STDERR, " %6d : %*.1f GB of (%*p) ",
-                          num, 6, ((double)sz) / 1024 / 1024 / 1024,
-                          ptr_hex_width, ty);
+                jl_safe_printf(" %6d : %*.1f GB of (%*p) ",
+                               num, 6, ((double)sz) / 1024 / 1024 / 1024,
+                               ptr_hex_width, ty);
             }
             else if (sz > 2e6) {
-                jl_printf(JL_STDERR, " %6d : %*.1f MB of (%*p) ",
-                          num, 6, ((double)sz) / 1024 / 1024,
-                          ptr_hex_width, ty);
+                jl_safe_printf(" %6d : %*.1f MB of (%*p) ",
+                               num, 6, ((double)sz) / 1024 / 1024,
+                               ptr_hex_width, ty);
             }
             else if (sz > 2e3) {
-                jl_printf(JL_STDERR, " %6d : %*.1f kB of (%*p) ",
-                          num, 6, ((double)sz) / 1024,
-                          ptr_hex_width, ty);
+                jl_safe_printf(" %6d : %*.1f kB of (%*p) ",
+                               num, 6, ((double)sz) / 1024,
+                               ptr_hex_width, ty);
             }
             else {
-                jl_printf(JL_STDERR, " %6d : %*d  B of (%*p) ",
+                jl_safe_printf(" %6d : %*d  B of (%*p) ",
                           num, 6, (int)sz, ptr_hex_width, ty);
             }
             if (ty == (void*)jl_buff_tag)
-                jl_printf(JL_STDERR, "#<buffer>");
+                jl_safe_printf("#<buffer>");
             else if (ty == jl_malloc_tag)
-                jl_printf(JL_STDERR, "#<malloc>");
+                jl_safe_printf("#<malloc>");
             else if (ty == jl_singleton_tag)
-                jl_printf(JL_STDERR, "#<singletons>");
+                jl_safe_printf("#<singletons>");
             else
                 jl_static_show(JL_STDERR, (jl_value_t*)ty);
-            jl_printf(JL_STDERR, "\n");
+            jl_safe_printf("\n");
         }
     }
 }
 
 void objprofile_printall(void)
 {
-    jl_printf(JL_STDERR, "Transient mark :\n");
+    jl_safe_printf("Transient mark :\n");
     objprofile_print(obj_counts[0], obj_sizes[0]);
-    jl_printf(JL_STDERR, "Perm mark :\n");
+    jl_safe_printf("Perm mark :\n");
     objprofile_print(obj_counts[1], obj_sizes[1]);
-    jl_printf(JL_STDERR, "Remset :\n");
+    jl_safe_printf("Remset :\n");
     objprofile_print(obj_counts[2], obj_sizes[2]);
 }
 #endif
@@ -813,33 +813,33 @@ void jl_print_gc_stats(JL_STREAM *s)
     malloc_stats();
 #endif
     double ptime = jl_clock_now() - process_t0;
-    jl_printf(s, "exec time\t%.5f sec\n", ptime);
+    jl_safe_printf("exec time\t%.5f sec\n", ptime);
     if (gc_num.pause > 0) {
-        jl_printf(s, "gc time  \t%.5f sec (%2.1f%%) in %d (%d full) collections\n",
-                  jl_ns2s(gc_num.total_time),
-                  jl_ns2s(gc_num.total_time) / ptime * 100,
-                  gc_num.pause, gc_num.full_sweep);
-        jl_printf(s, "gc pause \t%.2f ms avg\n\t\t%2.0f ms max\n",
-                  jl_ns2ms(gc_num.total_time) / gc_num.pause,
-                  jl_ns2ms(max_pause));
-        jl_printf(s, "\t\t(%2d%% mark, %2d%% sweep, %2d%% finalizers)\n",
-                  (int)(total_mark_time * 100 / gc_num.total_time),
-                  (int)(total_sweep_time * 100 / gc_num.total_time),
-                  (int)(total_fin_time * 100 / gc_num.total_time));
+        jl_safe_printf("gc time  \t%.5f sec (%2.1f%%) in %d (%d full) collections\n",
+                       jl_ns2s(gc_num.total_time),
+                       jl_ns2s(gc_num.total_time) / ptime * 100,
+                       gc_num.pause, gc_num.full_sweep);
+        jl_safe_printf("gc pause \t%.2f ms avg\n\t\t%2.0f ms max\n",
+                       jl_ns2ms(gc_num.total_time) / gc_num.pause,
+                       jl_ns2ms(max_pause));
+        jl_safe_printf("\t\t(%2d%% mark, %2d%% sweep, %2d%% finalizers)\n",
+                       (int)(total_mark_time * 100 / gc_num.total_time),
+                       (int)(total_sweep_time * 100 / gc_num.total_time),
+                       (int)(total_fin_time * 100 / gc_num.total_time));
     }
     unsigned p2 = 0, p1 = 0, p0 = 0;
     gc_stats_pagetable(&p2, &p1, &p0);
-    jl_printf(s, "page table max utilization : %u (%.1f%%) - %u (%.1f%%) - %u (%.1f%%)\n",
-              p2, p2 * 100.0 / REGION2_PG_COUNT,
-              p1, p1 * 100.0 / REGION1_PG_COUNT / p2,
-              p0, p0 * 100.0 / REGION0_PG_COUNT / p1);
+    jl_safe_printf("page table max utilization : %u (%.1f%%) - %u (%.1f%%) - %u (%.1f%%)\n",
+                   p2, p2 * 100.0 / REGION2_PG_COUNT,
+                   p1, p1 * 100.0 / REGION1_PG_COUNT / p2,
+                   p0, p0 * 100.0 / REGION0_PG_COUNT / p1);
 #ifdef _OS_LINUX_
     double gct = gc_num.total_time / 1e9;
     struct mallinfo mi = mallinfo();
-    jl_printf(s, "malloc size\t%d MB\n", mi.uordblks / 1024 / 1024);
-    jl_printf(s, "max page alloc\t%ld MB\n", max_pg_count * GC_PAGE_SZ / 1024 / 1024);
-    jl_printf(s, "total freed\t%" PRIuPTR " b\n", total_freed_bytes);
-    jl_printf(s, "free rate\t%.1f MB/sec\n", (total_freed_bytes / gct) / 1024 / 1024);
+    jl_safe_printf("malloc size\t%d MB\n", mi.uordblks / 1024 / 1024);
+    jl_safe_printf("max page alloc\t%ld MB\n", max_pg_count * GC_PAGE_SZ / 1024 / 1024);
+    jl_safe_printf("total freed\t%" PRIuPTR " b\n", total_freed_bytes);
+    jl_safe_printf("free rate\t%.1f MB/sec\n", (total_freed_bytes / gct) / 1024 / 1024);
 #endif
 }
 #else
@@ -874,23 +874,21 @@ void gc_time_pool_end(int sweep_full)
     double sweep_pool_sec = (jl_hrtime() - pool_sweep_start) / 1e9;
     double sweep_gb = total_pages * GC_PAGE_SZ / (double)(1024 * 1024 * 1024);
     double sweep_speed = sweep_gb / sweep_pool_sec;
-    jl_printf(JL_STDOUT,
-              "GC sweep pools end %.2f ms at %.1f GB/s "
-              "(skipped %.2f %% of %" PRId64 ", swept %" PRId64 " pgs, "
-              "%" PRId64 " freed with %" PRId64 " lazily) %s\n",
-              sweep_pool_sec * 1000, sweep_speed,
-              (total_pages ? ((double)skipped_pages * 100) / total_pages : 0),
-              total_pages, total_pages - skipped_pages,
-              freed_pages, lazy_freed_pages,
-              sweep_full ? "full" : "quick");
+    jl_safe_printf("GC sweep pools end %.2f ms at %.1f GB/s "
+                   "(skipped %.2f %% of %" PRId64 ", swept %" PRId64 " pgs, "
+                   "%" PRId64 " freed with %" PRId64 " lazily) %s\n",
+                   sweep_pool_sec * 1000, sweep_speed,
+                   (total_pages ? ((double)skipped_pages * 100) / total_pages : 0),
+                   total_pages, total_pages - skipped_pages,
+                   freed_pages, lazy_freed_pages,
+                   sweep_full ? "full" : "quick");
 }
 
 void gc_time_sysimg_end(uint64_t t0)
 {
     double sweep_pool_sec = (jl_hrtime() - t0) / 1e9;
-    jl_printf(JL_STDOUT,
-              "GC sweep sysimg end %.2f ms\n",
-              sweep_pool_sec * 1000);
+    jl_safe_printf("GC sweep sysimg end %.2f ms\n",
+                   sweep_pool_sec * 1000);
 }
 
 static int64_t big_total;
@@ -916,9 +914,9 @@ void gc_time_count_big(int old_bits, int
 void gc_time_big_end(void)
 {
     double t_ms = jl_ns2ms(jl_hrtime() - big_sweep_start);
-    jl_printf(JL_STDOUT, "GC sweep big %.2f ms "
-              "(freed %" PRId64 " / %" PRId64 " with %" PRId64 " rst)\n",
-              t_ms, big_freed, big_total, big_reset);
+    jl_safe_printf("GC sweep big %.2f ms "
+                   "(freed %" PRId64 " / %" PRId64 " with %" PRId64 " rst)\n",
+                   t_ms, big_freed, big_total, big_reset);
 }
 
 static int64_t mallocd_array_total;
@@ -941,9 +939,9 @@ void gc_time_count_mallocd_array(int bit
 void gc_time_mallocd_array_end(void)
 {
     double t_ms = jl_ns2ms(jl_hrtime() - mallocd_array_sweep_start);
-    jl_printf(JL_STDOUT, "GC sweep arrays %.2f ms "
-              "(freed %" PRId64 " / %" PRId64 ")\n",
-              t_ms, mallocd_array_freed, mallocd_array_total);
+    jl_safe_printf("GC sweep arrays %.2f ms "
+                   "(freed %" PRId64 " / %" PRId64 ")\n",
+                   t_ms, mallocd_array_freed, mallocd_array_total);
 }
 
 void gc_time_mark_pause(int64_t t0, int64_t scanned_bytes,
@@ -956,13 +954,13 @@ void gc_time_mark_pause(int64_t t0, int6
         last_remset_len += ptls2->heap.last_remset->len;
         remset_nptr = ptls2->heap.remset_nptr;
     }
-    jl_printf(JL_STDOUT, "GC mark pause %.2f ms | "
-              "scanned %" PRId64 " kB = %" PRId64 " + %" PRId64 " | "
-              "remset %" PRId64 " %" PRId64 "\n",
-              jl_ns2ms(gc_premark_end - t0),
-              (scanned_bytes + perm_scanned_bytes) / 1024,
-              scanned_bytes / 1024, perm_scanned_bytes / 1024,
-              last_remset_len, remset_nptr);
+    jl_safe_printf("GC mark pause %.2f ms | "
+                   "scanned %" PRId64 " kB = %" PRId64 " + %" PRId64 " | "
+                   "remset %" PRId64 " %" PRId64 "\n",
+                   jl_ns2ms(gc_premark_end - t0),
+                   (scanned_bytes + perm_scanned_bytes) / 1024,
+                   scanned_bytes / 1024, perm_scanned_bytes / 1024,
+                   last_remset_len, remset_nptr);
 }
 
 void gc_time_sweep_pause(uint64_t gc_end_t, int64_t actual_allocd,
@@ -971,15 +969,15 @@ void gc_time_sweep_pause(uint64_t gc_end
 {
     uint64_t sweep_pause = gc_end_t - gc_premark_end;
     int pct = actual_allocd ? (gc_num.freed * 100) / actual_allocd : -1;
-    jl_printf(JL_STDOUT, "GC sweep pause %.2f ms live %" PRId64 " kB "
-              "(freed %" PRId64 " kB EST %" PRId64 " kB "
-              "[error %" PRId64 "] = %d%% of allocd b %" PRIu64 ") "
-              "(%.2f ms in post_mark) %s | next in %" PRId64 " kB\n",
-              jl_ns2ms(sweep_pause), live_bytes / 1024,
-              gc_num.freed / 1024, estimate_freed / 1024,
-              gc_num.freed - estimate_freed, pct, gc_num.since_sweep / 1024,
-              jl_ns2ms(gc_postmark_end - gc_premark_end),
-              sweep_full ? "full" : "quick", -gc_num.allocd / 1024);
+    jl_safe_printf("GC sweep pause %.2f ms live %" PRId64 " kB "
+                   "(freed %" PRId64 " kB EST %" PRId64 " kB "
+                   "[error %" PRId64 "] = %d%% of allocd b %" PRIu64 ") "
+                   "(%.2f ms in post_mark) %s | next in %" PRId64 " kB\n",
+                   jl_ns2ms(sweep_pause), live_bytes / 1024,
+                   gc_num.freed / 1024, estimate_freed / 1024,
+                   gc_num.freed - estimate_freed, pct, gc_num.since_sweep / 1024,
+                   jl_ns2ms(gc_postmark_end - gc_premark_end),
+                   sweep_full ? "full" : "quick", -gc_num.allocd / 1024);
 }
 #endif
 
@@ -1053,15 +1051,14 @@ static size_t pool_stats(jl_gc_pool_t *p
     *np = npgs;
     *pnold = nold;
     if (npgs != 0) {
-        jl_printf(JL_STDOUT,
-                  "%4d : %7d/%7d objects (%3d%% old), %5d pages, %5d kB, %5d kB waste\n",
-                  p->osize,
-                  nused,
-                  nused+nfree,
-                  nused ? (nold*100)/nused : 0,
-                  npgs,
-                  (nused*p->osize)/1024,
-                  *pwaste/1024);
+        jl_safe_printf("%4d : %7d/%7d objects (%3d%% old), %5d pages, %5d kB, %5d kB waste\n",
+                       p->osize,
+                       nused,
+                       nused+nfree,
+                       nused ? (nold*100)/nused : 0,
+                       npgs,
+                       (nused*p->osize)/1024,
+                       *pwaste/1024);
     }
     return nused*p->osize;
 }
@@ -1081,9 +1078,8 @@ void gc_stats_all_pool(void)
             noldbytes += nol * ptls2->heap.norm_pools[i].osize;
         }
     }
-    jl_printf(JL_STDOUT,
-              "%d objects (%d%% old), %d kB (%d%% old) total allocated, %d total fragments (%d%% overhead), in %d pages\n",
-              no, (nold*100)/no, nb/1024, (noldbytes*100)/nb, tw, (tw*100)/nb, tp);
+    jl_safe_printf("%d objects (%d%% old), %d kB (%d%% old) total allocated, %d total fragments (%d%% overhead), in %d pages\n",
+                   no, (nold*100)/no, nb/1024, (noldbytes*100)/nb, tw, (tw*100)/nb, tp);
 }
 
 void gc_stats_big_obj(void)
@@ -1116,7 +1112,10 @@ void gc_stats_big_obj(void)
         ma = ma->next;
     }
 
-    jl_printf(JL_STDOUT, "%d kB (%d%% old) in %d large objects (%d%% old)\n", (nbytes + nbytes_old)/1024, nbytes + nbytes_old ? (nbytes_old*100)/(nbytes + nbytes_old) : 0, nused + nused_old, nused+nused_old ? (nused_old*100)/(nused + nused_old) : 0);
+    jl_safe_printf("%d kB (%d%% old) in %d large objects (%d%% old)\n",
+                   (nbytes + nbytes_old)/1024,
+                   nbytes + nbytes_old ? (nbytes_old*100)/(nbytes + nbytes_old) : 0,
+                   nused + nused_old, nused+nused_old ? (nused_old*100)/(nused + nused_old) : 0);
 }
 #endif //MEMPROFILE
 
@@ -1219,6 +1218,7 @@ int gc_slot_to_arrayidx(void *obj, void
     jl_datatype_t *vt = (jl_datatype_t*)jl_typeof(obj);
     char *start = NULL;
     size_t len = 0;
+    size_t elsize = sizeof(void*);
     if (vt == jl_module_type) {
         jl_module_t *m = (jl_module_t*)obj;
         start = (char*)m->usings.items;
@@ -1234,10 +1234,11 @@ int gc_slot_to_arrayidx(void *obj, void
             return -1;
         start = (char*)a->data;
         len = jl_array_len(a);
+        elsize = a->elsize;
     }
-    if (slot < start || slot >= start + sizeof(void*) * len)
+    if (slot < start || slot >= start + elsize * len)
         return -1;
-    return (slot - start) / sizeof(void*);
+    return (slot - start) / elsize;
 }
 
 // Print a backtrace from the bottom (start) of the mark stack up to `sp`
@@ -1248,8 +1249,7 @@ NOINLINE void gc_mark_loop_unwind(jl_ptl
     jl_jmp_buf buf;
     ptls->safe_restore = &buf;
     if (jl_setjmp(buf, 0) != 0) {
-        jl_printf((JL_STREAM*)STDERR_FILENO,
-                  "\n!!! ERROR when unwinding gc mark loop -- ABORTING !!!\n");
+        jl_safe_printf("\n!!! ERROR when unwinding gc mark loop -- ABORTING !!!\n");
         ptls->safe_restore = old_buf;
         return;
     }
@@ -1312,7 +1312,7 @@ NOINLINE void gc_mark_loop_unwind(jl_ptl
                 break;
             }
             jl_datatype_t *vt = (jl_datatype_t*)jl_typeof(data->parent);
-            jl_fielddesc8_t *desc = (jl_fielddesc8_t*)jl_dt_layout_fields(vt->layout);
+            uint8_t *desc = (uint8_t*)jl_dt_layout_ptrs(vt->layout);
             jl_safe_printf("%p:  %s Object (8bit) %p :: %p -- [%d, %d)\n        of type ",
                            (void*)data, prefix, (void*)data->parent, ((void**)data->parent)[-1],
                            (int)(data->begin - desc), (int)(data->end - desc));
@@ -1325,7 +1325,7 @@ NOINLINE void gc_mark_loop_unwind(jl_ptl
                 break;
             }
             jl_datatype_t *vt = (jl_datatype_t*)jl_typeof(data->parent);
-            jl_fielddesc16_t *desc = (jl_fielddesc16_t*)jl_dt_layout_fields(vt->layout);
+            uint16_t *desc = (uint16_t*)jl_dt_layout_ptrs(vt->layout);
             jl_safe_printf("%p:  %s Object (16bit) %p :: %p -- [%d, %d)\n        of type ",
                            (void*)data, prefix, (void*)data->parent, ((void**)data->parent)[-1],
                            (int)(data->begin - desc), (int)(data->end - desc));
@@ -1338,7 +1338,7 @@ NOINLINE void gc_mark_loop_unwind(jl_ptl
                 break;
             }
             jl_datatype_t *vt = (jl_datatype_t*)jl_typeof(data->parent);
-            jl_fielddesc32_t *desc = (jl_fielddesc32_t*)jl_dt_layout_fields(vt->layout);
+            uint32_t *desc = (uint32_t*)jl_dt_layout_ptrs(vt->layout);
             jl_safe_printf("%p:  %s Object (32bit) %p :: %p -- [%d, %d)\n        of type ",
                            (void*)data, prefix, (void*)data->parent, ((void**)data->parent)[-1],
                            (int)(data->begin - desc), (int)(data->end - desc));
diff -pruN 1.3.1+dfsg-1/src/gc.h 1.4.0+dfsg-1/src/gc.h
--- 1.3.1+dfsg-1/src/gc.h	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/src/gc.h	2020-03-21 16:36:32.000000000 +0000
@@ -80,6 +80,7 @@ enum {
     GC_MARK_L_scan_only,
     GC_MARK_L_finlist,
     GC_MARK_L_objarray,
+    GC_MARK_L_array8,
     GC_MARK_L_obj8,
     GC_MARK_L_obj16,
     GC_MARK_L_obj32,
@@ -113,33 +114,41 @@ typedef struct {
     jl_value_t *parent; // The parent object to trigger write barrier on.
     jl_value_t **begin; // The first slot to be scanned.
     jl_value_t **end; // The end address (after the last slot to be scanned)
+    uint32_t step; // Number of pointers to jump between marks
     uintptr_t nptr; // See notes about `nptr` above.
 } gc_mark_objarray_t;
 
 // A normal object with 8bits field descriptors
 typedef struct {
     jl_value_t *parent; // The parent object to trigger write barrier on.
-    jl_fielddesc8_t *begin; // Current field descriptor.
-    jl_fielddesc8_t *end; // End of field descriptor.
+    uint8_t *begin; // Current field descriptor.
+    uint8_t *end; // End of field descriptor.
     uintptr_t nptr; // See notes about `nptr` above.
 } gc_mark_obj8_t;
 
 // A normal object with 16bits field descriptors
 typedef struct {
     jl_value_t *parent; // The parent object to trigger write barrier on.
-    jl_fielddesc16_t *begin; // Current field descriptor.
-    jl_fielddesc16_t *end; // End of field descriptor.
+    uint16_t *begin; // Current field descriptor.
+    uint16_t *end; // End of field descriptor.
     uintptr_t nptr; // See notes about `nptr` above.
 } gc_mark_obj16_t;
 
 // A normal object with 32bits field descriptors
 typedef struct {
     jl_value_t *parent; // The parent object to trigger write barrier on.
-    jl_fielddesc32_t *begin; // Current field descriptor.
-    jl_fielddesc32_t *end; // End of field descriptor.
+    uint32_t *begin; // Current field descriptor.
+    uint32_t *end; // End of field descriptor.
     uintptr_t nptr; // See notes about `nptr` above.
 } gc_mark_obj32_t;
 
+typedef struct {
+    jl_value_t **begin; // The first slot to be scanned.
+    jl_value_t **end; // The end address (after the last slot to be scanned)
+    uint8_t *rebegin;
+    gc_mark_obj8_t elem;
+} gc_mark_array8_t;
+
 // Stack frame
 typedef struct {
     jl_gcframe_t *s; // The current stack frame
@@ -153,9 +162,10 @@ typedef struct {
 
 // Exception stack data
 typedef struct {
-    jl_excstack_t *s;  // Stack of exceptions
-    size_t itr;        // Iterator into exception stack
-    size_t i;          // Iterator into backtrace data for exception
+    jl_excstack_t *s;   // Stack of exceptions
+    size_t itr;         // Iterator into exception stack
+    size_t bt_index;    // Current backtrace buffer entry index
+    size_t jlval_index; // Index into GC managed values for current bt entry
 } gc_mark_excstack_t;
 
 // Module bindings. This is also the beginning of module scanning.
@@ -181,6 +191,7 @@ typedef struct {
 union _jl_gc_mark_data {
     gc_mark_marked_obj_t marked;
     gc_mark_objarray_t objarray;
+    gc_mark_array8_t array8;
     gc_mark_obj8_t obj8;
     gc_mark_obj16_t obj16;
     gc_mark_obj32_t obj32;
@@ -363,7 +374,7 @@ STATIC_INLINE unsigned ffs_u32(uint32_t
     _BitScanForward(&j, bitvec);
     return j;
 #else
-    return ffs(bitvec) - 1;
+    return __builtin_ffs(bitvec) - 1;
 #endif
 }
 #endif
diff -pruN 1.3.1+dfsg-1/src/gc-pages.c 1.4.0+dfsg-1/src/gc-pages.c
--- 1.3.1+dfsg-1/src/gc-pages.c	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/src/gc-pages.c	2020-03-21 16:36:32.000000000 +0000
@@ -173,6 +173,10 @@ NOINLINE jl_gc_pagemeta_t *jl_gc_alloc_p
     struct jl_gc_metadata_ext info;
     JL_LOCK_NOGC(&gc_perm_lock);
 
+    int last_errno = errno;
+#ifdef _OS_WINDOWS_
+    DWORD last_error = GetLastError();
+#endif
     // scan over memory_map page-table for existing allocated but unused pages
     for (info.pagetable_i32 = memory_map.lb; info.pagetable_i32 < (REGION2_PG_COUNT + 31) / 32; info.pagetable_i32++) {
         uint32_t freemap1 = memory_map.freemap1[info.pagetable_i32];
@@ -245,6 +249,10 @@ have_free_page:
 #ifdef _OS_WINDOWS_
     VirtualAlloc(info.meta->data, GC_PAGE_SZ, MEM_COMMIT, PAGE_READWRITE);
 #endif
+#ifdef _OS_WINDOWS_
+    SetLastError(last_error);
+#endif
+    errno = last_errno;
     current_pg_count++;
     gc_final_count_page(current_pg_count);
     JL_UNLOCK_NOGC(&gc_perm_lock);
diff -pruN 1.3.1+dfsg-1/src/gf.c 1.4.0+dfsg-1/src/gf.c
--- 1.3.1+dfsg-1/src/gf.c	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/src/gf.c	2020-03-21 16:36:32.000000000 +0000
@@ -137,7 +137,7 @@ jl_datatype_t *jl_mk_builtin_func(jl_dat
 {
     jl_sym_t *sname = jl_symbol(name);
     if (dt == NULL) {
-        jl_value_t *f = jl_new_generic_function_with_supertype(sname, jl_core_module, jl_builtin_type, 0);
+        jl_value_t *f = jl_new_generic_function_with_supertype(sname, jl_core_module, jl_builtin_type);
         jl_set_const(jl_core_module, sname, f);
         dt = (jl_datatype_t*)jl_typeof(f);
     }
@@ -201,6 +201,10 @@ jl_code_info_t *jl_type_infer(jl_method_
     }
 #endif
     jl_ptls_t ptls = jl_get_ptls_states();
+    int last_errno = errno;
+#ifdef _OS_WINDOWS_
+    DWORD last_error = GetLastError();
+#endif
     size_t last_age = ptls->world_age;
     ptls->world_age = jl_typeinf_world;
     mi->inInference = 1;
@@ -218,6 +222,10 @@ jl_code_info_t *jl_type_infer(jl_method_
     ptls->world_age = last_age;
     in_inference--;
     mi->inInference = 0;
+#ifdef _OS_WINDOWS_
+    SetLastError(last_error);
+#endif
+    errno = last_errno;
 
     if (src && !jl_is_code_info(src)) {
         src = NULL;
@@ -1714,7 +1722,7 @@ static void JL_NORETURN jl_method_error_
         jl_static_show((JL_STREAM*)STDERR_FILENO,(jl_value_t*)f); jl_printf((JL_STREAM*)STDERR_FILENO," world %u\n", (unsigned)world);
         jl_static_show((JL_STREAM*)STDERR_FILENO,args); jl_printf((JL_STREAM*)STDERR_FILENO,"\n");
         jl_ptls_t ptls = jl_get_ptls_states();
-        ptls->bt_size = rec_backtrace(ptls->bt_data, JL_MAX_BT_SIZE);
+        ptls->bt_size = rec_backtrace(ptls->bt_data, JL_MAX_BT_SIZE, 0);
         jl_critical_error(0, NULL, ptls->bt_data, &ptls->bt_size);
         abort();
     }
@@ -1905,6 +1913,7 @@ jl_code_instance_t *jl_compile_method_in
     return codeinst;
 }
 
+
 JL_DLLEXPORT jl_value_t *jl_fptr_const_return(jl_value_t *f, jl_value_t **args, uint32_t nargs, jl_code_instance_t *m)
 {
     return m->rettype_const;
@@ -2137,7 +2146,15 @@ STATIC_INLINE jl_value_t *_jl_invoke(jl_
         }
         codeinst = codeinst->next;
     }
+    int last_errno = errno;
+#ifdef _OS_WINDOWS_
+    DWORD last_error = GetLastError();
+#endif
     codeinst = jl_compile_method_internal(mfunc, world);
+#ifdef _OS_WINDOWS_
+    SetLastError(last_error);
+#endif
+    errno = last_errno;
     jl_value_t *res = codeinst->invoke(F, args, nargs, codeinst);
     return verify_type(res);
 }
@@ -2433,21 +2450,14 @@ JL_DLLEXPORT jl_value_t *jl_get_invoke_l
 }
 
 // Return value is rooted globally
-jl_function_t *jl_new_generic_function_with_supertype(jl_sym_t *name, jl_module_t *module, jl_datatype_t *st, int iskw)
+jl_function_t *jl_new_generic_function_with_supertype(jl_sym_t *name, jl_module_t *module, jl_datatype_t *st)
 {
     // type name is function name prefixed with #
     size_t l = strlen(jl_symbol_name(name));
     char *prefixed;
-    if (iskw) {
-        prefixed = (char*)malloc(l+5);
-        strcpy(&prefixed[0], "#kw#");
-        strcpy(&prefixed[4], jl_symbol_name(name));
-    }
-    else {
-        prefixed = (char*)malloc(l+2);
-        prefixed[0] = '#';
-        strcpy(&prefixed[1], jl_symbol_name(name));
-    }
+    prefixed = (char*)malloc_s(l+2);
+    prefixed[0] = '#';
+    strcpy(&prefixed[1], jl_symbol_name(name));
     jl_sym_t *tname = jl_symbol(prefixed);
     free(prefixed);
     jl_datatype_t *ftype = (jl_datatype_t*)jl_new_datatype(
@@ -2471,16 +2481,23 @@ JL_DLLEXPORT jl_function_t *jl_get_kwsor
     if (!mt->kwsorter) {
         JL_LOCK(&mt->writelock);
         if (!mt->kwsorter) {
-            jl_sym_t *name;
+            char *name;
             if (mt == jl_nonfunction_mt) {
-                name = mt->name;
+                name = jl_symbol_name(mt->name);
             }
             else {
                 jl_datatype_t *dt = (jl_datatype_t*)jl_argument_datatype(ty);
                 assert(jl_is_datatype(dt));
-                name = dt->name->name;
-            }
-            mt->kwsorter = jl_new_generic_function_with_supertype(name, mt->module, jl_function_type, 1);
+                name = jl_symbol_name(dt->name->name);
+                if (name[0] == '#')
+                    name++;
+            }
+            size_t l = strlen(name);
+            char *suffixed = (char*)malloc_s(l+5);
+            strcpy(&suffixed[0], name);
+            strcpy(&suffixed[l], "##kw");
+            jl_sym_t *fname = jl_symbol(suffixed);
+            mt->kwsorter = jl_new_generic_function_with_supertype(fname, mt->module, jl_function_type);
             jl_gc_wb(mt, mt->kwsorter);
         }
         JL_UNLOCK(&mt->writelock);
@@ -2490,7 +2507,7 @@ JL_DLLEXPORT jl_function_t *jl_get_kwsor
 
 jl_function_t *jl_new_generic_function(jl_sym_t *name, jl_module_t *module)
 {
-    return jl_new_generic_function_with_supertype(name, module, jl_function_type, 0);
+    return jl_new_generic_function_with_supertype(name, module, jl_function_type);
 }
 
 struct ml_matches_env {
diff -pruN 1.3.1+dfsg-1/src/init.c 1.4.0+dfsg-1/src/init.c
--- 1.3.1+dfsg-1/src/init.c	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/src/init.c	2020-03-21 16:36:32.000000000 +0000
@@ -40,9 +40,6 @@ JL_DLLEXPORT char *dirname(char *);
 #endif
 
 #ifdef _OS_WINDOWS_
-#define WIN32_LEAN_AND_MEAN
-#include <windows.h>
-#include <io.h>
 extern int needsSymRefreshModuleList;
 extern BOOL (WINAPI *hSymRefreshModuleList)(HANDLE);
 #else
@@ -153,7 +150,7 @@ struct uv_shutdown_queue { struct uv_shu
 
 static void jl_uv_exitcleanup_add(uv_handle_t *handle, struct uv_shutdown_queue *queue)
 {
-    struct uv_shutdown_queue_item *item = (struct uv_shutdown_queue_item*)malloc(sizeof(struct uv_shutdown_queue_item));
+    struct uv_shutdown_queue_item *item = (struct uv_shutdown_queue_item*)malloc_s(sizeof(struct uv_shutdown_queue_item));
     item->h = handle;
     item->next = NULL;
     if (queue->last)
@@ -371,7 +368,7 @@ static void *init_stdio_handle(const cha
         jl_errorf("error initializing %s in uv_dup: %s (%s %d)", stdio, uv_strerror(err), uv_err_name(err), err);
     switch(uv_guess_handle(fd)) {
     case UV_TTY:
-        handle = malloc(sizeof(uv_tty_t));
+        handle = malloc_s(sizeof(uv_tty_t));
         if ((err = uv_tty_init(jl_io_loop, (uv_tty_t*)handle, fd, 0))) {
             jl_errorf("error initializing %s in uv_tty_init: %s (%s %d)", stdio, uv_strerror(err), uv_err_name(err), err);
         }
@@ -401,7 +398,7 @@ static void *init_stdio_handle(const cha
         // ...and continue on as in the UV_FILE case
         JL_FALLTHROUGH;
     case UV_FILE:
-        handle = malloc(sizeof(jl_uv_file_t));
+        handle = malloc_s(sizeof(jl_uv_file_t));
         {
             jl_uv_file_t *file = (jl_uv_file_t*)handle;
             file->loop = jl_io_loop;
@@ -411,7 +408,7 @@ static void *init_stdio_handle(const cha
         }
         break;
     case UV_NAMED_PIPE:
-        handle = malloc(sizeof(uv_pipe_t));
+        handle = malloc_s(sizeof(uv_pipe_t));
         if ((err = uv_pipe_init(jl_io_loop, (uv_pipe_t*)handle, 0))) {
             jl_errorf("error initializing %s in uv_pipe_init: %s (%s %d)", stdio, uv_strerror(err), uv_err_name(err), err);
         }
@@ -421,7 +418,7 @@ static void *init_stdio_handle(const cha
         ((uv_pipe_t*)handle)->data = NULL;
         break;
     case UV_TCP:
-        handle = malloc(sizeof(uv_tcp_t));
+        handle = malloc_s(sizeof(uv_tcp_t));
         if ((err = uv_tcp_init(jl_io_loop, (uv_tcp_t*)handle))) {
             jl_errorf("error initializing %s in uv_tcp_init: %s (%s %d)", stdio, uv_strerror(err), uv_err_name(err), err);
         }
@@ -479,9 +476,7 @@ static char *abspath(const char *in, int
     if (out) {
         if (nprefix > 0) {
             size_t sz = strlen(out) + 1;
-            char *cpy = (char*)malloc(sz + nprefix);
-            if (!cpy)
-                jl_errorf("fatal error: failed to allocate memory: %s", strerror(errno));
+            char *cpy = (char*)malloc_s(sz + nprefix);
             memcpy(cpy, in, nprefix);
             memcpy(cpy + nprefix, out, sz);
             free(out);
@@ -491,22 +486,16 @@ static char *abspath(const char *in, int
     else {
         size_t sz = strlen(in + nprefix) + 1;
         if (in[nprefix] == PATHSEPSTRING[0]) {
-            out = (char*)malloc(sz + nprefix);
-            if (!out)
-                jl_errorf("fatal error: failed to allocate memory: %s", strerror(errno));
+            out = (char*)malloc_s(sz + nprefix);
             memcpy(out, in, sz + nprefix);
         }
         else {
             size_t path_size = PATH_MAX;
-            char *path = (char*)malloc(PATH_MAX);
-            if (!path)
-                jl_errorf("fatal error: failed to allocate memory: %s", strerror(errno));
+            char *path = (char*)malloc_s(PATH_MAX);
             if (uv_cwd(path, &path_size)) {
                 jl_error("fatal error: unexpected error while retrieving current working directory");
             }
-            out = (char*)malloc(path_size + 1 + sz + nprefix);
-            if (!out)
-                jl_errorf("fatal error: failed to allocate memory: %s", strerror(errno));
+            out = (char*)malloc_s(path_size + 1 + sz + nprefix);
             memcpy(out, in, nprefix);
             memcpy(out + nprefix, path, path_size);
             out[nprefix + path_size] = PATHSEPSTRING[0];
@@ -519,9 +508,7 @@ static char *abspath(const char *in, int
     if (n <= 0) {
         jl_error("fatal error: jl_options.image_file path too long or GetFullPathName failed");
     }
-    char *out = (char*)malloc(n + nprefix);
-    if (!out)
-        jl_errorf("fatal error: failed to allocate memory: %s", strerror(errno));
+    char *out = (char*)malloc_s(n + nprefix);
     DWORD m = GetFullPathName(in + nprefix, n, out + nprefix, NULL);
     if (n != m + 1) {
         jl_error("fatal error: jl_options.image_file path too long or GetFullPathName failed");
@@ -548,9 +535,7 @@ static const char *absformat(const char
     size_t i, fmt_size = 0;
     for (i = 0; i < path_size; i++)
         fmt_size += (path[i] == '%' ? 2 : 1);
-    char *out = (char*)malloc(fmt_size + 1 + sz);
-    if (!out)
-        jl_errorf("fatal error: failed to allocate memory: %s", strerror(errno));
+    char *out = (char*)malloc_s(fmt_size + 1 + sz);
     fmt_size = 0;
     for (i = 0; i < path_size; i++) { // copy-replace pwd portion
         char c = path[i];
@@ -571,19 +556,15 @@ static void jl_resolve_sysimg_location(J
     // note: if you care about lost memory, you should call the appropriate `free()` function
     // on the original pointer for each `char*` you've inserted into `jl_options`, after
     // calling `julia_init()`
-    char *free_path = (char*)malloc(PATH_MAX);
+    char *free_path = (char*)malloc_s(PATH_MAX);
     size_t path_size = PATH_MAX;
-    if (!free_path)
-        jl_errorf("fatal error: failed to allocate memory: %s", strerror(errno));
     if (uv_exepath(free_path, &path_size)) {
         jl_error("fatal error: unexpected error while retrieving exepath");
     }
     if (path_size >= PATH_MAX) {
         jl_error("fatal error: jl_options.julia_bin path too long");
     }
-    jl_options.julia_bin = (char*)malloc(path_size+1);
-    if (!jl_options.julia_bin)
-        jl_errorf("fatal error: failed to allocate memory: %s", strerror(errno));
+    jl_options.julia_bin = (char*)malloc_s(path_size + 1);
     memcpy((char*)jl_options.julia_bin, free_path, path_size);
     ((char*)jl_options.julia_bin)[path_size] = '\0';
     if (!jl_options.julia_bindir) {
@@ -599,9 +580,7 @@ static void jl_resolve_sysimg_location(J
     if (jl_options.image_file) {
         if (rel == JL_IMAGE_JULIA_HOME && !isabspath(jl_options.image_file)) {
             // build time path, relative to JULIA_BINDIR
-            free_path = (char*)malloc(PATH_MAX);
-            if (!free_path)
-                jl_errorf("fatal error: failed to allocate memory: %s", strerror(errno));
+            free_path = (char*)malloc_s(PATH_MAX);
             int n = snprintf(free_path, PATH_MAX, "%s" PATHSEPSTRING "%s",
                              jl_options.julia_bindir, jl_options.image_file);
             if (n >= PATH_MAX || n < 0) {
@@ -719,18 +698,6 @@ void _julia_init(JL_IMAGE_SEARCH rel)
     }
 #endif
 
-#if defined(__linux__)
-    int ncores = jl_cpu_threads();
-    if (ncores > 1) {
-        cpu_set_t cpumask;
-        CPU_ZERO(&cpumask);
-        for(int i=0; i < ncores; i++) {
-            CPU_SET(i, &cpumask);
-        }
-        sched_setaffinity(0, sizeof(cpu_set_t), &cpumask);
-    }
-#endif
-
     if ((jl_options.outputo || jl_options.outputbc) &&
         (jl_options.code_coverage || jl_options.malloc_log)) {
         jl_error("cannot generate code-coverage or track allocation information while generating a .o or .bc output file");
diff -pruN 1.3.1+dfsg-1/src/interpreter.c 1.4.0+dfsg-1/src/interpreter.c
--- 1.3.1+dfsg-1/src/interpreter.c	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/src/interpreter.c	2020-03-21 16:36:32.000000000 +0000
@@ -25,7 +25,48 @@ typedef struct {
     int continue_at; // statement index to jump to after leaving exception handler (0 if none)
 } interpreter_state;
 
-#include "interpreter-stacktrace.c"
+
+// general alloca rules are incompatible on C and C++, so define a macro that deals with the difference
+#ifdef __cplusplus
+#define JL_CPPALLOCA(var,n)                                                         \
+  var = (decltype(var))alloca((n))
+#else
+#define JL_CPPALLOCA(var,n)                                                         \
+  JL_GCC_IGNORE_START("-Wc++-compat")                                               \
+  var = alloca((n));                                                                \
+  JL_GCC_IGNORE_STOP
+#endif
+
+#ifdef __clang_analyzer__
+
+extern void JL_GC_ENABLEFRAME(interpreter_state*) JL_NOTSAFEPOINT;
+
+// This is necessary, because otherwise the analyzer considers this undefined
+// behavior and terminates the exploration
+#define JL_GC_PUSHFRAME(frame,n)     \
+  JL_CPPALLOCA(frame, sizeof(*frame)+((n) * sizeof(jl_value_t*)));                  \
+  memset(&frame[1], 0, sizeof(void*) * n); \
+  _JL_GC_PUSHARGS((jl_value_t**)&frame[1], n);
+
+#else
+
+#define JL_GC_ENCODE_PUSHFRAME(n)  ((((size_t)(n))<<2)|2)
+
+#define JL_GC_PUSHFRAME(frame,n)                                                    \
+  JL_CPPALLOCA(frame, sizeof(*frame)+(((n)+3)*sizeof(jl_value_t*)));                \
+  ((void**)&frame[1])[0] = NULL;                                                    \
+  ((void**)&frame[1])[1] = (void*)JL_GC_ENCODE_PUSHFRAME(n);                        \
+  ((void**)&frame[1])[2] = jl_pgcstack;                                             \
+  memset(&((void**)&frame[1])[3], 0, (n)*sizeof(jl_value_t*));                      \
+  jl_pgcstack = (jl_gcframe_t*)&(((void**)&frame[1])[1])
+
+// we define this separately so that we can populate the frame before we add it to the backtrace
+// it's recommended to mark the containing function with NOINLINE, though not essential
+#define JL_GC_ENABLEFRAME(frame) \
+  ((void**)&frame[1])[0] = __builtin_frame_address(0);
+
+#endif
+
 
 static jl_value_t *eval_value(jl_value_t *e, interpreter_state *s);
 static jl_value_t *eval_body(jl_array_t *stmts, interpreter_state *s, size_t ip, int toplevel);
@@ -37,7 +78,7 @@ int jl_is_toplevel_only_expr(jl_value_t
 extern int inside_typedef;
 
 // this is a heuristic for allowing "redefining" a type to something identical
-SECT_INTERP static int equiv_type(jl_datatype_t *dta, jl_datatype_t *dtb)
+static int equiv_type(jl_datatype_t *dta, jl_datatype_t *dtb)
 {
     if (!(jl_typeof(dta) == jl_typeof(dtb) &&
           dta->name->name == dtb->name->name &&
@@ -99,7 +140,7 @@ SECT_INTERP static int equiv_type(jl_dat
     return 0;
 }
 
-SECT_INTERP static void check_can_assign_type(jl_binding_t *b, jl_value_t *rhs)
+static void check_can_assign_type(jl_binding_t *b, jl_value_t *rhs)
 {
     if (b->constp && b->value != NULL && jl_typeof(b->value) != jl_typeof(rhs))
         jl_errorf("invalid redefinition of constant %s",
@@ -109,7 +150,7 @@ SECT_INTERP static void check_can_assign
 void jl_reinstantiate_inner_types(jl_datatype_t *t);
 void jl_reset_instantiate_inner_types(jl_datatype_t *t);
 
-SECT_INTERP void jl_set_datatype_super(jl_datatype_t *tt, jl_value_t *super)
+void jl_set_datatype_super(jl_datatype_t *tt, jl_value_t *super)
 {
     if (!jl_is_datatype(super) || !jl_is_abstracttype(super) ||
         tt->name == ((jl_datatype_t*)super)->name ||
@@ -317,7 +358,7 @@ static jl_value_t *eval_methoddef(jl_exp
 
 // expression evaluator
 
-SECT_INTERP static jl_value_t *do_call(jl_value_t **args, size_t nargs, interpreter_state *s)
+static jl_value_t *do_call(jl_value_t **args, size_t nargs, interpreter_state *s)
 {
     jl_value_t **argv;
     assert(nargs >= 1);
@@ -330,7 +371,7 @@ SECT_INTERP static jl_value_t *do_call(j
     return result;
 }
 
-SECT_INTERP static jl_value_t *do_invoke(jl_value_t **args, size_t nargs, interpreter_state *s)
+static jl_value_t *do_invoke(jl_value_t **args, size_t nargs, interpreter_state *s)
 {
     jl_value_t **argv;
     assert(nargs >= 2);
@@ -345,7 +386,7 @@ SECT_INTERP static jl_value_t *do_invoke
     return result;
 }
 
-SECT_INTERP jl_value_t *jl_eval_global_var(jl_module_t *m, jl_sym_t *e)
+jl_value_t *jl_eval_global_var(jl_module_t *m, jl_sym_t *e)
 {
     jl_value_t *v = jl_get_global(m, e);
     if (v == NULL)
@@ -353,23 +394,23 @@ SECT_INTERP jl_value_t *jl_eval_global_v
     return v;
 }
 
-SECT_INTERP static int jl_source_nslots(jl_code_info_t *src) JL_NOTSAFEPOINT
+static int jl_source_nslots(jl_code_info_t *src) JL_NOTSAFEPOINT
 {
     return jl_array_len(src->slotflags);
 }
 
-SECT_INTERP static int jl_source_nssavalues(jl_code_info_t *src) JL_NOTSAFEPOINT
+static int jl_source_nssavalues(jl_code_info_t *src) JL_NOTSAFEPOINT
 {
     return jl_is_long(src->ssavaluetypes) ? jl_unbox_long(src->ssavaluetypes) : jl_array_len(src->ssavaluetypes);
 }
 
-SECT_INTERP static void eval_stmt_value(jl_value_t *stmt, interpreter_state *s)
+static void eval_stmt_value(jl_value_t *stmt, interpreter_state *s)
 {
     jl_value_t *res = eval_value(stmt, s);
     s->locals[jl_source_nslots(s->src) + s->ip] = res;
 }
 
-SECT_INTERP static jl_value_t *eval_value(jl_value_t *e, interpreter_state *s)
+static jl_value_t *eval_value(jl_value_t *e, interpreter_state *s)
 {
     jl_code_info_t *src = s->src;
     if (jl_is_ssavalue(e)) {
@@ -468,7 +509,6 @@ SECT_INTERP static jl_value_t *eval_valu
         JL_GC_PUSHARGS(argv, nargs);
         for (size_t i = 0; i < nargs; i++)
             argv[i] = eval_value(args[i], s);
-        assert(jl_is_structtype(argv[0]));
         jl_value_t *v = jl_new_structv((jl_datatype_t*)argv[0], &argv[1], nargs - 1);
         JL_GC_POP();
         return v;
@@ -478,7 +518,6 @@ SECT_INTERP static jl_value_t *eval_valu
         JL_GC_PUSHARGS(argv, 2);
         argv[0] = eval_value(args[0], s);
         argv[1] = eval_value(args[1], s);
-        assert(jl_is_structtype(argv[0]));
         jl_value_t *v = jl_new_structt((jl_datatype_t*)argv[0], argv[1]);
         JL_GC_POP();
         return v;
@@ -521,7 +560,7 @@ SECT_INTERP static jl_value_t *eval_valu
 }
 
 // phi nodes don't behave like proper instructions, so we require a special interpreter to handle them
-SECT_INTERP static size_t eval_phi(jl_array_t *stmts, interpreter_state *s, size_t ns, size_t to)
+static size_t eval_phi(jl_array_t *stmts, interpreter_state *s, size_t ns, size_t to)
 {
     size_t from = s->ip;
     size_t ip = to;
@@ -602,7 +641,7 @@ SECT_INTERP static size_t eval_phi(jl_ar
     return ip;
 }
 
-SECT_INTERP static jl_value_t *eval_body(jl_array_t *stmts, interpreter_state *s, size_t ip, int toplevel)
+static jl_value_t *eval_body(jl_array_t *stmts, interpreter_state *s, size_t ip, int toplevel)
 {
     jl_handler_t __eh;
     size_t ns = jl_array_len(stmts);
@@ -813,124 +852,111 @@ jl_code_info_t *jl_code_for_interpreter(
 
 // interpreter entry points
 
-struct jl_interpret_call_args {
-    jl_method_instance_t *mi;
-    jl_value_t *f;
-    jl_value_t **args;
-    uint32_t nargs;
-};
-
-SECT_INTERP CALLBACK_ABI void *jl_interpret_call_callback(interpreter_state *s, void *vargs)
-{
-    struct jl_interpret_call_args *args =
-        (struct jl_interpret_call_args *)vargs;
-    JL_GC_PROMISE_ROOTED(args);
-    jl_code_info_t *src = jl_code_for_interpreter(args->mi);
-
+jl_value_t *NOINLINE jl_fptr_interpret_call(jl_value_t *f, jl_value_t **args, uint32_t nargs, jl_code_instance_t *codeinst)
+{
+    interpreter_state *s;
+    jl_method_instance_t *mi = codeinst->def;
+    jl_code_info_t *src = jl_code_for_interpreter(mi);
     jl_array_t *stmts = src->code;
     assert(jl_typeis(stmts, jl_array_any_type));
-    jl_value_t **locals;
-    JL_GC_PUSHARGS(locals, jl_source_nslots(src) + jl_source_nssavalues(src) + 2);
+    unsigned nroots = jl_source_nslots(src) + jl_source_nssavalues(src) + 2;
+    JL_GC_PUSHFRAME(s, nroots);
+    jl_value_t **locals = (jl_value_t**)&s[1] + 3;
     locals[0] = (jl_value_t*)src;
     locals[1] = (jl_value_t*)stmts;
     s->locals = locals + 2;
     s->src = src;
-    if (jl_is_module(args->mi->def.value)) {
-        s->module = args->mi->def.module;
+    if (jl_is_module(mi->def.value)) {
+        s->module = mi->def.module;
     }
     else {
-        s->module = args->mi->def.method->module;
-        size_t nargs = args->mi->def.method->nargs;
-        int isva = args->mi->def.method->isva ? 1 : 0;
+        s->module = mi->def.method->module;
+        size_t defargs = mi->def.method->nargs;
+        int isva = mi->def.method->isva ? 1 : 0;
         size_t i;
-        s->locals[0] = args->f;
-        for (i = 1; i < nargs - isva; i++)
-            s->locals[i] = args->args[i - 1];
+        s->locals[0] = f;
+        assert(isva ? nargs + 2 >= defargs : nargs + 1 == defargs);
+        for (i = 1; i < defargs - isva; i++)
+            s->locals[i] = args[i - 1];
         if (isva) {
-            assert(nargs >= 2);
-            s->locals[nargs - 1] = jl_f_tuple(NULL, &args->args[nargs - 2], args->nargs + 2 - nargs);
+            assert(defargs >= 2);
+            s->locals[defargs - 1] = jl_f_tuple(NULL, &args[defargs - 2], nargs + 2 - defargs);
         }
     }
-    s->sparam_vals = args->mi->sparam_vals;
+    s->sparam_vals = mi->sparam_vals;
     s->preevaluation = 0;
     s->continue_at = 0;
-    s->mi = args->mi;
+    s->mi = mi;
+    JL_GC_ENABLEFRAME(s);
     jl_value_t *r = eval_body(stmts, s, 0, 0);
     JL_GC_POP();
-    return (void*)r;
+    return r;
 }
 
-SECT_INTERP jl_value_t *jl_fptr_interpret_call(jl_value_t *f, jl_value_t **args, uint32_t nargs, jl_code_instance_t *codeinst)
+jl_value_t *NOINLINE jl_interpret_toplevel_thunk(jl_module_t *m, jl_code_info_t *src)
 {
-    struct jl_interpret_call_args callback_args = { codeinst->def, f, args, nargs };
-    return (jl_value_t*)enter_interpreter_frame(jl_interpret_call_callback, (void *)&callback_args);
-}
-
-struct jl_interpret_toplevel_thunk_args {
-    jl_module_t *m;
-    jl_code_info_t *src;
-};
-SECT_INTERP CALLBACK_ABI void *jl_interpret_toplevel_thunk_callback(interpreter_state *s, void *vargs) {
-    struct jl_interpret_toplevel_thunk_args *args =
-        (struct jl_interpret_toplevel_thunk_args*)vargs;
-    JL_GC_PROMISE_ROOTED(args);
-    jl_array_t *stmts = args->src->code;
+    interpreter_state *s;
+    unsigned nroots = jl_source_nslots(src) + jl_source_nssavalues(src);
+    JL_GC_PUSHFRAME(s, nroots);
+    jl_array_t *stmts = src->code;
     assert(jl_typeis(stmts, jl_array_any_type));
-    jl_value_t **locals;
-    JL_GC_PUSHARGS(locals, jl_source_nslots(args->src) + jl_source_nssavalues(args->src));
-    s->src = args->src;
-    s->locals = locals;
-    s->module = args->m;
+    s->src = src;
+    s->locals = (jl_value_t**)&s[1] + 3;
+    s->module = m;
     s->sparam_vals = jl_emptysvec;
     s->continue_at = 0;
     s->mi = NULL;
+    JL_GC_ENABLEFRAME(s);
     size_t last_age = jl_get_ptls_states()->world_age;
     jl_value_t *r = eval_body(stmts, s, 0, 1);
     jl_get_ptls_states()->world_age = last_age;
     JL_GC_POP();
-    return (void*)r;
-}
-
-SECT_INTERP jl_value_t *jl_interpret_toplevel_thunk(jl_module_t *m, jl_code_info_t *src)
-{
-    struct jl_interpret_toplevel_thunk_args args = { m, src };
-    return (jl_value_t *)enter_interpreter_frame(jl_interpret_toplevel_thunk_callback, (void*)&args);
+    return r;
 }
 
 // deprecated: do not use this method in new code
 // it uses special scoping / evaluation / error rules
 // which should instead be handled in lowering
-struct interpret_toplevel_expr_in_args {
-    jl_module_t *m;
-    jl_value_t *e;
-    jl_code_info_t *src;
-    jl_svec_t *sparam_vals;
-};
-
-SECT_INTERP CALLBACK_ABI void *jl_interpret_toplevel_expr_in_callback(interpreter_state *s, void *vargs)
-{
-    struct interpret_toplevel_expr_in_args *args =
-        (struct interpret_toplevel_expr_in_args*)vargs;
-    JL_GC_PROMISE_ROOTED(args);
-    s->src = args->src;
-    s->module = args->m;
-    s->sparam_vals = args->sparam_vals;
-    s->preevaluation = (s->sparam_vals != NULL);
+jl_value_t *NOINLINE jl_interpret_toplevel_expr_in(jl_module_t *m, jl_value_t *e, jl_code_info_t *src, jl_svec_t *sparam_vals)
+{
+    interpreter_state *s;
+    JL_GC_PUSHFRAME(s, 0);
+    s->src = src;
+    s->module = m;
+    s->sparam_vals = sparam_vals;
+    s->preevaluation = (sparam_vals != NULL);
     s->continue_at = 0;
     s->mi = NULL;
-    jl_value_t *v = eval_value(args->e, s);
+    JL_GC_ENABLEFRAME(s);
+    jl_value_t *v = eval_value(e, s);
     assert(v);
-    return (void*)v;
+    JL_GC_POP();
+    return v;
 }
 
-SECT_INTERP jl_value_t *jl_interpret_toplevel_expr_in(jl_module_t *m, jl_value_t *e, jl_code_info_t *src, jl_svec_t *sparam_vals)
+JL_DLLEXPORT size_t jl_capture_interp_frame(jl_bt_element_t *bt_entry,
+        void *stateend, size_t space_remaining)
 {
-    struct interpret_toplevel_expr_in_args args = {
-        m, e, src, sparam_vals
-    };
-    return (jl_value_t *)enter_interpreter_frame(jl_interpret_toplevel_expr_in_callback, (void*)&args);
+    interpreter_state *s = &((interpreter_state*)stateend)[-1];
+    int need_module = !s->mi;
+    int required_space = need_module ? 4 : 3;
+    if (space_remaining < required_space)
+        return 0; // Should not happen
+    size_t njlvalues = need_module ? 2 : 1;
+    uintptr_t entry_tags = jl_bt_entry_descriptor(njlvalues, 0, JL_BT_INTERP_FRAME_TAG, s->ip);
+    bt_entry[0].uintptr = JL_BT_NON_PTR_ENTRY;
+    bt_entry[1].uintptr = entry_tags;
+    bt_entry[2].jlvalue = s->mi  ? (jl_value_t*)s->mi  :
+                          s->src ? (jl_value_t*)s->src : (jl_value_t*)jl_nothing;
+    if (need_module) {
+        // If we only have a CodeInfo (s->src), we are in a top level thunk and
+        // need to record the module separately.
+        bt_entry[3].jlvalue = (jl_value_t*)s->module;
+    }
+    return required_space;
 }
 
+
 #ifdef __cplusplus
 }
 #endif
diff -pruN 1.3.1+dfsg-1/src/interpreter-stacktrace.c 1.4.0+dfsg-1/src/interpreter-stacktrace.c
--- 1.3.1+dfsg-1/src/interpreter-stacktrace.c	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/src/interpreter-stacktrace.c	1970-01-01 00:00:00.000000000 +0000
@@ -1,430 +0,0 @@
-// This file is a part of Julia. License is MIT: https://julialang.org/license
-
-// #include'd from interpreter.c
-
-// Backtrace support
-#if defined(_OS_LINUX_) || defined(_OS_FREEBSD_) || defined(_OS_WINDOWS_)
-extern uintptr_t __start_jl_interpreter_frame_val;
-uintptr_t __start_jl_interpreter_frame = (uintptr_t)&__start_jl_interpreter_frame_val;
-extern uintptr_t __stop_jl_interpreter_frame_val;
-uintptr_t __stop_jl_interpreter_frame = (uintptr_t)&__stop_jl_interpreter_frame_val;
-
-#define SECT_INTERP JL_SECTION("jl_interpreter_frame_val")
-#if defined(_CPU_X86_) && defined(_OS_WINDOWS_)
-#define MANGLE(x) "@" x "@8"
-#else
-#define MANGLE(x) x
-#endif
-
-#if defined(_OS_LINUX_) || defined(_OS_FREEBSD_)
-#if defined(_CPU_ARM_)
-#  define ASM_FUNCTION_TYPE "%function"
-#else
-#  define ASM_FUNCTION_TYPE "@function"
-#endif
-#define ASM_ENTRY                                               \
-    ".text\n"                                                   \
-    ".p2align 4,0x90\n"                                         \
-    ".global enter_interpreter_frame\n"                         \
-    ".type enter_interpreter_frame," ASM_FUNCTION_TYPE "\n"
-#if defined(_OS_LINUX_)
-#define ASM_END ".previous\n"
-#else
-#define ASM_END
-#endif
-#else
-#define ASM_ENTRY                               \
-    ".text\n"                                   \
-    ".globl enter_interpreter_frame\n"
-#define ASM_END
-#endif
-
-#elif defined(_OS_DARWIN_)
-extern uintptr_t __start_jl_interpreter_frame_val __asm("section$start$__TEXT$__jif");
-uintptr_t __start_jl_interpreter_frame = (uintptr_t)&__start_jl_interpreter_frame_val;
-extern uintptr_t __stop_jl_interpreter_frame_val __asm("section$end$__TEXT$__jif");
-uintptr_t __stop_jl_interpreter_frame = (uintptr_t)&__stop_jl_interpreter_frame_val;
-
-#define SECT_INTERP JL_SECTION("__TEXT,__jif")
-
-#define MANGLE(x) "_" x
-#define ASM_ENTRY \
-    ".section __TEXT,__text,regular,pure_instructions\n" \
-    ".globl _enter_interpreter_frame\n"
-#define ASM_END ".previous"
-
-#else
-#define SECT_INTERP
-#define NO_INTERP_BT
-#warning "Interpreter backtraces not implemented for this platform"
-#endif
-
-#define STR(x) #x
-#define XSTR(x) STR(x)
-
-// This function is special. The unwinder looks for this function to find interpreter
-// stack frames.
-#ifdef _CPU_X86_64_
-
-// Instructions: Make sure that MAX_INTERP_STATE_SIZE is a multiple of
-//               alignof(struct interpreter_state) and larger than
-//               sizeof(struct interpreter_state). Additionally, make sure that
-//               MAX_INTERP_STATE_SIZE+STACK_PADDING+8 is a multiple of 16 to
-//               ensure the proper stack alignment.
-#define MAX_INTERP_STATE_SIZE 72
-#define STACK_PADDING 0
-
-static_assert(sizeof(interpreter_state) <= MAX_INTERP_STATE_SIZE, "Stack layout invariants violated.");
-static_assert(MAX_INTERP_STATE_SIZE % alignof(interpreter_state) == 0, "Stack layout invariants violated");
-static_assert(((MAX_INTERP_STATE_SIZE + STACK_PADDING + 8) % 16) == 0, "Stack layout invariants violated");
-
-#ifdef _OS_WINDOWS_
-size_t TOTAL_STACK_PADDING = STACK_PADDING + 32;
-#else
-size_t TOTAL_STACK_PADDING = STACK_PADDING;
-#endif
-
-asm(
-    ASM_ENTRY
-    MANGLE("enter_interpreter_frame") ":\n"
-    ".cfi_startproc\n"
-    "\tsubq $" XSTR(MAX_INTERP_STATE_SIZE) " + " XSTR(STACK_PADDING)", %rsp\n"
-    ".cfi_def_cfa_offset " XSTR(MAX_INTERP_STATE_SIZE) " + " XSTR(STACK_PADDING)" + 8\n"
-#ifdef _OS_WINDOWS_
-#define ARG1_REG "rcx"
-#else
-#define ARG1_REG "rdi"
-#endif
-    "\tmovq %" ARG1_REG ", %rax\n"
-    "\tleaq " XSTR(STACK_PADDING) "(%rsp), %" ARG1_REG "\n"
-    // Zero out the src and mi fields
-    "\tmovq $0, 0(%" ARG1_REG ")\n"
-    "\tmovq $0, 8(%" ARG1_REG ")\n"
-#ifdef _OS_WINDOWS_
-    // Make space for the register parameter area
-    "\tsubq $32, %rsp\n"
-#endif
-    // The L here conviences the OS X linker not to terminate the unwind info early
-    "Lenter_interpreter_frame_start_val:\n"
-    "\tcallq *%rax\n"
-    "Lenter_interpreter_frame_end_val:\n"
-#ifdef _OS_WINDOWS_
-    "\taddq $32, %rsp\n"
-#endif
-    "\taddq $" XSTR(MAX_INTERP_STATE_SIZE) " + " XSTR(STACK_PADDING)", %rsp\n"
-#ifndef _OS_DARWIN_
-    // Somehow this throws off compact unwind info on OS X
-    ".cfi_def_cfa_offset 8\n"
-#endif
-    "\tretq\n"
-    ".cfi_endproc\n"
-    ASM_END
-    );
-
-#define CALLBACK_ABI
-
-#elif defined(_CPU_X86_)
-
-#define MAX_INTERP_STATE_SIZE 36
-#ifdef _OS_WINDOWS_
-#define STACK_PADDING 4
-#else
-#define STACK_PADDING 8
-#endif
-
-size_t TOTAL_STACK_PADDING = STACK_PADDING;
-
-static_assert(sizeof(interpreter_state) <= MAX_INTERP_STATE_SIZE, "Stack layout invariants violated");
-static_assert(MAX_INTERP_STATE_SIZE % alignof(interpreter_state) == 0, "Stack layout invariants violated");
-#ifndef _OS_WINDOWS_
-static_assert((MAX_INTERP_STATE_SIZE + STACK_PADDING + 4) % 16 == 0, "Stack layout invariants violated");
-#endif
-
-asm(
-     ASM_ENTRY
-     MANGLE("enter_interpreter_frame") ":\n"
-     ".cfi_startproc\n"
-#ifdef _OS_WINDOWS_
-/*
- * On win32, we set -mincoming-stack-boundary=2. This causes GCC to emit stack
- * realignment gadgets into the prologue of every function. Unfortunately for
- * us there are two different kinds of such gadgets and since we don't know
- * which one the target function is going to use, we can't use the same trick
- * as everywhere else. From https://gcc.gnu.org/ml/gcc/2007-12/msg00503.html,
- * the two prologues are:
- *
- *     pushl     %ebp
- *     movl      %esp, %ebp
- *     andl      $-16, %esp
- *
- * and
- *
- *     pushl     %edi                     // Save callee save reg edi
- *     leal      8(%esp), %edi            // Save address of parameter frame
- *     andl      $-16, %esp               // Align local stack
- *     pushl     $4(%edi)                 //  save return address
- *     pushl     %ebp                     //  save old ebp
- *     movl      %esp, %ebp               //  point ebp to pseudo frame
- *
- * From the perspective of the unwinder, the first case looks like a regular
- * (without the realignment gadget) stack frame. However, for the second one,
- * the compiler deliberately constructs a "fake stack frame" that has an
- * incorrect stack address for the previous frame. To work around all of this,
- * use ebp based addressing on win32
- */
-#define FP_CAPTURE_OFFSET MAX_INTERP_STATE_SIZE
-#define ENTRY_OFFSET 8
-    "\tpushl %ebp\n"
-    ".cfi_def_cfa_offset " XSTR(ENTRY_OFFSET)"\n"
-    "\tmovl %esp, %ebp\n"
-#else
-#define ENTRY_OFFSET 4
-#endif
-     "\tsubl $" XSTR(MAX_INTERP_STATE_SIZE) ", %esp\n"
-     ".cfi_def_cfa_offset " XSTR(MAX_INTERP_STATE_SIZE) " + " XSTR(ENTRY_OFFSET) "\n"
-     "\tmovl %ecx, %eax\n"
-     "\tmovl %esp, %ecx\n"
-     // Zero out the src and mi fields
-     "\tmovl $0, (%esp)\n"
-     "\tmovl $0, 4(%esp)\n"
-     // Restore 16 byte stack alignment
-     // Technically not necessary on windows, because we don't assume this
-     // alignment, but let's be nice if we ever start doing that.
-     "\tsubl $" XSTR(STACK_PADDING) ", %esp\n"
-     ".cfi_def_cfa_offset " XSTR(STACK_PADDING) " + " XSTR(MAX_INTERP_STATE_SIZE) " + " XSTR(ENTRY_OFFSET) "\n"
-     "Lenter_interpreter_frame_start_val:\n"
-     "\tcalll *%eax\n"
-     "Lenter_interpreter_frame_end_val:\n"
-     "\taddl $" XSTR(MAX_INTERP_STATE_SIZE) " + " XSTR(STACK_PADDING) ", %esp\n"
-#ifdef _OS_WINDOWS_
-     ".cfi_def_cfa_offset 8\n"
-     "\tpopl %ebp\n"
-#endif
-     ".cfi_def_cfa_offset 4\n"
-     "\tret\n"
-     ".cfi_endproc\n"
-     ASM_END
-     );
-
-#define CALLBACK_ABI  __attribute__((fastcall))
-static_assert(sizeof(interpreter_state) <= MAX_INTERP_STATE_SIZE, "Update assembly code above");
-
-#elif defined(_CPU_AARCH64_)
-
-#define MAX_INTERP_STATE_SIZE 64
-#define STACK_PADDING 16
-
-// Check that the interpreter state can fit
-static_assert(sizeof(interpreter_state) <= MAX_INTERP_STATE_SIZE,
-              "Stack layout invariants violated.");
-// Check that the alignment of the type is satisfied
-// (16 is stack alignment at function boundary)
-static_assert(alignof(interpreter_state) <= 16, "Stack layout invariants violated");
-static_assert(STACK_PADDING % alignof(interpreter_state) == 0,
-              "Stack layout invariants violated");
-// Check that ABI stack alignment requirement is maintained.
-static_assert(((MAX_INTERP_STATE_SIZE + STACK_PADDING) % 16) == 0,
-              "Stack layout invariants violated");
-// Check that the padding is large enough for lr.
-static_assert(STACK_PADDING >= sizeof(void*), "Stack layout invariants violated");
-
-size_t TOTAL_STACK_PADDING = STACK_PADDING;
-
-asm(
-    ASM_ENTRY
-    MANGLE("enter_interpreter_frame") ":\n"
-    ".cfi_startproc\n"
-    // Save lr
-    "\tstr x30, [sp, #-(" XSTR(MAX_INTERP_STATE_SIZE) " + " XSTR(STACK_PADDING) ")]!\n"
-    "\t.cfi_def_cfa_offset (" XSTR(MAX_INTERP_STATE_SIZE) " + " XSTR(STACK_PADDING) ")\n"
-    "\t.cfi_offset 30, -(" XSTR(MAX_INTERP_STATE_SIZE) " + " XSTR(STACK_PADDING) ")\n"
-    "\tmov x2, x0\n"
-    // Zero out the src and mi fields
-    "\tstp xzr, xzr, [sp, " XSTR(STACK_PADDING) "]\n"
-    "\tadd x0, sp, " XSTR(STACK_PADDING) "\n"
-    "Lenter_interpreter_frame_start_val:\n"
-    "\tblr x2\n"
-    "Lenter_interpreter_frame_end_val:\n"
-    "\tldr x30, [sp], (" XSTR(MAX_INTERP_STATE_SIZE) " + " XSTR(STACK_PADDING) ")\n"
-    "\t.cfi_restore 30\n"
-    "\t.cfi_def_cfa_offset 0\n"
-    "\tret\n"
-    ".cfi_endproc\n"
-    ASM_END
-    );
-
-#define CALLBACK_ABI
-
-#elif defined(_CPU_ARM_)
-
-#define MAX_INTERP_STATE_SIZE 48
-
-// Check that the interpreter state can fit
-static_assert(sizeof(interpreter_state) <= MAX_INTERP_STATE_SIZE,
-              "Stack layout invariants violated.");
-// Check that the alignment of the type is satisfied
-// (16 is what we realign the stack to)
-static_assert(alignof(interpreter_state) <= 16, "Stack layout invariants violated");
-
-size_t TOTAL_STACK_PADDING = 0;
-
-asm(
-    ASM_ENTRY
-    MANGLE("enter_interpreter_frame") ":\n"
-    ".fnstart\n"
-    "\tpush {fp, lr}\n"
-    "\t.save {fp, lr}\n"
-    "\t.setfp fp, sp, #4\n"
-    "\tadd fp, sp, #4\n"
-    "\tmov r2, r0\n"
-    // Reserve enough space and realign stack to 16bytes
-    // The realignment is for consistency with every other architectures.
-    // It isn't strictly necessary since we currently do not rely on it.
-    "\tsub sp, sp, #" XSTR(MAX_INTERP_STATE_SIZE) "\n"
-    "\tbic sp, sp, #15\n"
-    // Zero out the src and mi field
-    "\tmov ip, #0\n"
-    "\tstr ip, [sp]\n"
-    "\tstr ip, [sp, #4]\n"
-    "\tmov r0, sp\n"
-    "Lenter_interpreter_frame_start_val:\n"
-    "\tblx r2\n"
-    "Lenter_interpreter_frame_end_val:\n"
-    "\tsub sp, fp, #4\n"
-    "\tpop {fp, pc}\n"
-    "\t.fnend\n"
-    ASM_END
-    );
-
-#define CALLBACK_ABI
-
-#elif defined(_CPU_PPC64_)
-/**
- * Implementation notes:
- *
- * This needs to follow the PPC ELFv2 ABI. Which means that there is a localentry
- * and a global entry. The local entry expects r2/TOC to be set correctly, while
- * the global entry expects r12 to be set to the function address, and from there
- * restores r2/TOC. The function pointer we are getting passed point to the global
- * entry and thus we need to set r12 correctly.
- *
- * - LR is stored in the caller
- * - r1/SP is a back-chain that needs to be atomically updated
- */
-
-#define MAX_INTERP_STATE_SIZE 64
-#define MIN_STACK 32
-#define STACK_PADDING 0
-#define STACK_SIZE (MIN_STACK + MAX_INTERP_STATE_SIZE + STACK_PADDING)
-
-size_t TOTAL_STACK_PADDING = MIN_STACK;
-
-// Check that the interpreter state can fit
-static_assert(sizeof(interpreter_state) <= MAX_INTERP_STATE_SIZE,
-              "Stack layout invariants violated.");
-// Check that the alignment of the type is satisfied
-static_assert(alignof(interpreter_state) <= 16, "Stack layout invariants violated");
-// Check that ABI stack alignment requirement is maintained.
-static_assert(STACK_SIZE % 16 == 0, "Stack layout invariants violated");
-static_assert(MIN_STACK  % 16 == 0, "Stack layout invariants violated");
-
-asm(
-    ASM_ENTRY
-    MANGLE("enter_interpreter_frame") ":\n"
-    "\taddis 2, 12, .TOC.-enter_interpreter_frame@ha\n"
-    "\taddi 2, 2, .TOC.-enter_interpreter_frame@l\n"
-    "\t.localentry enter_interpreter_frame, .-enter_interpreter_frame\n"
-    ".cfi_startproc\n"
-    // store LR
-    "\tmflr 0\n"
-    "\tstd 0, 16(1)\n"
-    ".cfi_offset lr, 16\n"
-    // set up stack frame
-    "\tstdu 1, -" XSTR(STACK_SIZE) "(1)\n"
-    ".cfi_adjust_cfa_offset " XSTR(STACK_SIZE) "\n"
-    "\tmtctr 3\n" // move arg1 (func pointer) to ctr
-    "\tmr 12, 3\n" // move func pointer to r12 if we jump to global entry point
-    "\tcal 3, " XSTR(MIN_STACK) "(1)\n" // move pointer to INTERP_STATE to arg1
-    // zero out src and mi field
-    "\tli 6, 0\n"
-    "\tstd 6, 0(3)\n"
-    "\tstd 6, 8(3)\n"
-    // store TOC
-    "\tstd 2, 24(1)\n"
-    "Lenter_interpreter_frame_start_val:\n"
-    "\tbctrl\n"
-    "Lenter_interpreter_frame_end_val:\n"
-    // restore TOC
-    "\tld 2, 24(1)\n"
-    // restore stack frame
-    "\tld 1, 0(1)\n"
-    // restore LR
-    "\tld 0, 16(1)\n"
-    "\tmtlr 0\n"
-    ".cfi_same_value lr\n"
-    "\tblr\n"
-    ".cfi_endproc\n"
-    ASM_END
-    );
-
-#define CALLBACK_ABI
-
-#else
-#warning "Interpreter backtraces not implemented for this platform"
-#define NO_INTERP_BT
-#endif
-
-#ifndef NO_INTERP_BT
-extern uintptr_t enter_interpreter_frame_start_val asm("Lenter_interpreter_frame_start_val");
-extern uintptr_t enter_interpreter_frame_end_val asm("Lenter_interpreter_frame_end_val");
-uintptr_t enter_interpreter_frame_start = (uintptr_t)&enter_interpreter_frame_start_val;
-uintptr_t enter_interpreter_frame_end = (uintptr_t)&enter_interpreter_frame_end_val;
-
-JL_DLLEXPORT int jl_is_interpreter_frame(uintptr_t ip)
-{
-    return __start_jl_interpreter_frame <= ip && ip <= __stop_jl_interpreter_frame;
-}
-
-JL_DLLEXPORT int jl_is_enter_interpreter_frame(uintptr_t ip)
-{
-    return enter_interpreter_frame_start <= ip && ip <= enter_interpreter_frame_end;
-}
-
-JL_DLLEXPORT size_t jl_capture_interp_frame(uintptr_t *data, uintptr_t sp, uintptr_t fp, size_t space_remaining)
-{
-#ifdef FP_CAPTURE_OFFSET
-    interpreter_state *s = (interpreter_state *)(fp-FP_CAPTURE_OFFSET);
-#else
-    interpreter_state *s = (interpreter_state *)(sp+TOTAL_STACK_PADDING);
-#endif
-    if (space_remaining <= 1)
-        return 0;
-    // Sentinel value to indicate an interpreter frame
-    data[0] = JL_BT_INTERP_FRAME;
-    data[1] = s->mi ? (uintptr_t)s->mi : s->src ? (uintptr_t)s->src : (uintptr_t)jl_nothing;
-    data[2] = (uintptr_t)s->ip;
-    return 2;
-}
-
-extern void * CALLBACK_ABI enter_interpreter_frame(void * CALLBACK_ABI (*callback)(interpreter_state *, void *), void *arg);
-#else
-JL_DLLEXPORT int jl_is_interpreter_frame(uintptr_t ip)
-{
-    return 0;
-}
-
-JL_DLLEXPORT int jl_is_enter_interpreter_frame(uintptr_t ip)
-{
-    return 0;
-}
-
-JL_DLLEXPORT size_t jl_capture_interp_frame(uintptr_t *data, uintptr_t sp, uintptr_t fp, size_t space_remaining)
-{
-    return 0;
-}
-#define CALLBACK_ABI
-void *NOINLINE enter_interpreter_frame(void *(*callback)(interpreter_state *, void *), void *arg) {
-    interpreter_state state = {};
-    return callback(&state, arg);
-}
-#endif
diff -pruN 1.3.1+dfsg-1/src/intrinsics.cpp 1.4.0+dfsg-1/src/intrinsics.cpp
--- 1.3.1+dfsg-1/src/intrinsics.cpp	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/src/intrinsics.cpp	2020-03-21 16:36:32.000000000 +0000
@@ -70,6 +70,7 @@ static void jl_init_intrinsic_functions_
     float_func[trunc_llvm] = true;
     float_func[rint_llvm] = true;
     float_func[sqrt_llvm] = true;
+    float_func[sqrt_llvm_fast] = true;
 }
 
 extern "C"
@@ -148,32 +149,32 @@ static Value *uint_cnvt(jl_codectx_t &ct
 
 static Constant *julia_const_to_llvm(const void *ptr, jl_datatype_t *bt)
 {
-    // assumes `jl_justbits(bt)`.
+    // assumes `jl_is_pointerfree(bt)`.
     // `ptr` can point to a inline field, do not read the tag from it.
     // make sure to return exactly the type specified by
     // julia_type_to_llvm as this will be assumed by the callee.
     if (bt == jl_bool_type)
         return ConstantInt::get(T_int8, (*(const uint8_t*)ptr) ? 1 : 0);
 
-    if (jl_is_vecelement_type((jl_value_t*)bt))
-        bt = (jl_datatype_t*)jl_tparam0(bt);
-
     Type *lt = julia_struct_to_llvm((jl_value_t*)bt, NULL, NULL);
 
+    if (jl_is_vecelement_type((jl_value_t*)bt) && !jl_is_uniontype(jl_tparam0(bt)))
+        bt = (jl_datatype_t*)jl_tparam0(bt);
+
     if (type_is_ghost(lt))
         return UndefValue::get(lt);
 
-    if (jl_is_primitivetype(bt)) {
-        if (lt->isFloatTy()) {
-            uint32_t data32 = *(const uint32_t*)ptr;
-            return ConstantFP::get(jl_LLVMContext,
-                    APFloat(lt->getFltSemantics(), APInt(32, data32)));
-        }
-        if (lt->isDoubleTy()) {
-            uint64_t data64 = *(const uint64_t*)ptr;
-            return ConstantFP::get(jl_LLVMContext,
-                    APFloat(lt->getFltSemantics(), APInt(64, data64)));
-        }
+    if (lt->isFloatTy()) {
+        uint32_t data32 = *(const uint32_t*)ptr;
+        return ConstantFP::get(jl_LLVMContext,
+                APFloat(lt->getFltSemantics(), APInt(32, data32)));
+    }
+    if (lt->isDoubleTy()) {
+        uint64_t data64 = *(const uint64_t*)ptr;
+        return ConstantFP::get(jl_LLVMContext,
+                APFloat(lt->getFltSemantics(), APInt(64, data64)));
+    }
+    if (lt->isFloatingPointTy() || lt->isIntegerTy()) {
         int nb = jl_datatype_size(bt);
         APInt val(8 * nb, 0);
         void *bits = const_cast<uint64_t*>(val.getRawData());
@@ -192,11 +193,11 @@ static Constant *julia_const_to_llvm(con
     std::vector<Constant*> fields(0);
     for (size_t i = 0; i < nf; i++) {
         size_t offs = jl_field_offset(bt, i);
-        assert(!jl_field_isptr(bt, i));
         jl_value_t *ft = jl_field_type(bt, i);
         Type *lft = julia_type_to_llvm(ft);
         if (type_is_ghost(lft))
             continue;
+        assert(!jl_field_isptr(bt, i));
         unsigned llvm_idx = isa<StructType>(lt) ? convert_struct_offset(lt, offs) : i;
         while (fields.size() < llvm_idx)
             fields.push_back(UndefValue::get(lct->getTypeAtIndex(fields.size())));
@@ -269,7 +270,7 @@ static Constant *julia_const_to_llvm(jl_
     if (e == jl_false)
         return ConstantInt::get(T_int8, 0);
     jl_value_t *bt = jl_typeof(e);
-    if (!jl_justbits(bt))
+    if (!jl_is_pointerfree(bt))
         return NULL;
     return julia_const_to_llvm(e, (jl_datatype_t*)bt);
 }
@@ -334,13 +335,13 @@ static Value *emit_unbox(jl_codectx_t &c
 
     Constant *c = x.constant ? julia_const_to_llvm(x.constant) : NULL;
     if (!x.ispointer() || c) { // already unboxed, but sometimes need conversion
-        Value *unboxed = emit_unboxed_coercion(ctx, to, c ? c : x.V);
+        Value *unboxed = c ? c : x.V;
         if (!dest)
-            return unboxed;
+            return emit_unboxed_coercion(ctx, to, unboxed);
         Type *dest_ty = unboxed->getType()->getPointerTo();
         if (dest->getType() != dest_ty)
             dest = emit_bitcast(ctx, dest, dest_ty);
-        tbaa_decorate(tbaa_dest, ctx.builder.CreateStore(unboxed, dest));
+        tbaa_decorate(tbaa_dest, ctx.builder.CreateAlignedStore(unboxed, dest, julia_alignment(jt)));
         return NULL;
     }
 
@@ -653,7 +654,7 @@ static jl_cgval_t emit_pointerset(jl_cod
         // unsafe_store to Ptr{Any} is allowed to implicitly drop GC roots.
         thePtr = emit_unbox(ctx, T_psize, e, e.typ);
         Instruction *store = ctx.builder.CreateAlignedStore(
-          emit_pointer_from_objref(ctx, boxed(ctx, x)),
+          ctx.builder.CreatePtrToInt(emit_pointer_from_objref(ctx, boxed(ctx, x)), T_size),
             ctx.builder.CreateGEP(T_size, thePtr, im1), align_nb);
         tbaa_decorate(tbaa_data, store);
     }
@@ -764,10 +765,8 @@ static jl_cgval_t emit_ifelse(jl_codectx
     }
 
     Value *ifelse_result;
-    bool isboxed;
-    Type *llt1 = julia_type_to_llvm(t1, &isboxed);
-    if (t1 != t2)
-        isboxed = true;
+    bool isboxed = t1 != t2 || !deserves_stack(t1);
+    Type *llt1 = isboxed ? T_prjlvalue : julia_type_to_llvm(t1);
     if (!isboxed) {
         if (type_is_ghost(llt1))
             return x;
@@ -1264,6 +1263,10 @@ static Value *emit_untyped_intrinsic(jl_
         Value *sqrtintr = Intrinsic::getDeclaration(jl_Module, Intrinsic::sqrt, makeArrayRef(t));
         return ctx.builder.CreateCall(sqrtintr, x);
     }
+    case sqrt_llvm_fast: {
+        Value *sqrtintr = Intrinsic::getDeclaration(jl_Module, Intrinsic::sqrt, makeArrayRef(t));
+        return math_builder(ctx, true)().CreateCall(sqrtintr, x);
+    }
 
     default:
         assert(0 && "invalid intrinsic");
diff -pruN 1.3.1+dfsg-1/src/intrinsics.h 1.4.0+dfsg-1/src/intrinsics.h
--- 1.3.1+dfsg-1/src/intrinsics.h	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/src/intrinsics.h	2020-03-21 16:36:32.000000000 +0000
@@ -88,6 +88,7 @@
     ADD_I(trunc_llvm, 1) \
     ADD_I(rint_llvm, 1) \
     ADD_I(sqrt_llvm, 1) \
+    ADD_I(sqrt_llvm_fast, 1) \
     /*  pointer access */ \
     ADD_I(pointerref, 3) \
     ADD_I(pointerset, 4) \
diff -pruN 1.3.1+dfsg-1/src/jitlayers.cpp 1.4.0+dfsg-1/src/jitlayers.cpp
--- 1.3.1+dfsg-1/src/jitlayers.cpp	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/src/jitlayers.cpp	2020-03-21 16:36:32.000000000 +0000
@@ -40,6 +40,10 @@
 #include <llvm/Support/SmallVectorMemoryBuffer.h>
 #endif
 
+#if JL_LLVM_VERSION >= 100000
+#include <llvm/Support/CodeGen.h>
+#endif
+
 namespace llvm {
     extern Pass *createLowerSimdLoopPass();
 }
@@ -73,6 +77,10 @@ using namespace llvm;
 #include "jitlayers.h"
 #include "julia_assert.h"
 
+#if JL_LLVM_VERSION < 100000
+static const TargetMachine::CodeGenFileType CGFT_ObjectFile = TargetMachine::CGFT_ObjectFile;
+#endif
+
 RTDyldMemoryManager* createRTDyldMemoryManager(void);
 
 static IntegerType *T_uint32;
@@ -213,7 +221,6 @@ void addOptimizationPasses(legacy::PassM
 
     // Run instcombine after redundancy elimination to exploit opportunities
     // opened up by them.
-    PM->add(createSinkingPass()); ////////////// ****
 #if JL_LLVM_VERSION < 70000
     // This pass is a subset of InstructionCombiningPass in LLVM 7
     // and therefore not required.
@@ -292,7 +299,6 @@ JuliaOJIT::DebugObjectRegistrar::DebugOb
 
 JL_DLLEXPORT void ORCNotifyObjectEmitted(JITEventListener *Listener,
                                          const object::ObjectFile &obj,
-                                         const object::ObjectFile &debugObj,
                                          const RuntimeDyld::LoadedObjectInfo &L,
                                          RTDyldMemoryManager *memmgr);
 
@@ -306,28 +312,8 @@ void JuliaOJIT::DebugObjectRegistrar::re
     const ObjT& Object = Obj;
 #endif
 
-    object::OwningBinary<object::ObjectFile> SavedObject = LO->getObjectForDebug(*Object);
-
-    // If the debug object is unavailable, save (a copy of) the original object
-    // for our backtraces
-    if (!SavedObject.getBinary()) {
-        // This is unfortunate, but there doesn't seem to be a way to take
-        // ownership of the original buffer
-        auto NewBuffer = MemoryBuffer::getMemBufferCopy(Object->getData(),
-                                                        Object->getFileName());
-        auto NewObj = object::ObjectFile::createObjectFile(NewBuffer->getMemBufferRef());
-        assert(NewObj);
-        SavedObject = object::OwningBinary<object::ObjectFile>(std::move(*NewObj),
-                                                       std::move(NewBuffer));
-    }
-    else {
-        JIT.NotifyFinalizer(H, *(SavedObject.getBinary()), *LO);
-    }
-
-    SavedObjects.push_back(std::move(SavedObject));
-
+    JIT.NotifyFinalizer(H, *Object, *LO);
     ORCNotifyObjectEmitted(JuliaListener.get(), *Object,
-                           *SavedObjects.back().getBinary(),
                            *LO, JIT.MemMgr.get());
 
     // record all of the exported symbols defined in this object
@@ -844,8 +830,12 @@ void jl_init_function(Function *F)
     F->setHasUWTable(); // force NeedsWinEH
 #endif
 #ifdef JL_DISABLE_FPO
+#if LLVM_VERSION_MAJOR >= 8
+    F->addFnAttr("frame-pointer", "all");
+#else
     F->addFnAttr("no-frame-pointer-elim", "true");
 #endif
+#endif
     // record the WIP name
     incomplete_fname.insert(F->getName());
 }
@@ -1057,11 +1047,11 @@ void jl_dump_native(const char *bc_fname
         PM.add(createBitcodeWriterPass(bc_OS));
 #if JL_LLVM_VERSION >= 70000
     if (obj_fname)
-        if (TM->addPassesToEmitFile(PM, obj_OS, nullptr, TargetMachine::CGFT_ObjectFile, false))
+        if (TM->addPassesToEmitFile(PM, obj_OS, nullptr, CGFT_ObjectFile, false))
             jl_safe_printf("ERROR: target does not support generation of object files\n");
 #else
     if (obj_fname)
-        if (TM->addPassesToEmitFile(PM, obj_OS, TargetMachine::CGFT_ObjectFile, false))
+        if (TM->addPassesToEmitFile(PM, obj_OS, CGFT_ObjectFile, false))
             jl_safe_printf("ERROR: target does not support generation of object files\n");
 #endif
 
@@ -1122,7 +1112,7 @@ void jl_dump_native(const char *bc_fname
             ArrayRef<uint8_t>((const unsigned char*)sysimg_data, sysimg_len));
         addComdat(new GlobalVariable(*sysimage, data->getType(), false,
                                      GlobalVariable::ExternalLinkage,
-                                     data, "jl_system_image_data"))->setAlignment(64);
+                                     data, "jl_system_image_data"))->setAlignment(Align(64));
         Constant *len = ConstantInt::get(T_size, sysimg_len);
         addComdat(new GlobalVariable(*sysimage, len->getType(), true,
                                      GlobalVariable::ExternalLinkage,
diff -pruN 1.3.1+dfsg-1/src/jitlayers.h 1.4.0+dfsg-1/src/jitlayers.h
--- 1.3.1+dfsg-1/src/jitlayers.h	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/src/jitlayers.h	2020-03-21 16:36:32.000000000 +0000
@@ -112,7 +112,6 @@ class JuliaOJIT {
     private:
         template <typename ObjT, typename LoadResult>
         void registerObject(RTDyldObjHandleT H, const ObjT &Obj, const LoadResult &LO);
-        std::vector<object::OwningBinary<object::ObjectFile>> SavedObjects;
         std::unique_ptr<JITEventListener> JuliaListener;
         JuliaOJIT &JIT;
     };
diff -pruN 1.3.1+dfsg-1/src/jlapi.c 1.4.0+dfsg-1/src/jlapi.c
--- 1.3.1+dfsg-1/src/jlapi.c	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/src/jlapi.c	2020-03-21 16:36:32.000000000 +0000
@@ -36,6 +36,26 @@ JL_DLLEXPORT int jl_is_initialized(void)
     return jl_main_module != NULL;
 }
 
+JL_DLLEXPORT void jl_set_ARGS(int argc, char **argv)
+{
+    if (jl_core_module != NULL) {
+        jl_array_t *args = (jl_array_t*)jl_get_global(jl_core_module, jl_symbol("ARGS"));
+        if (args == NULL) {
+            args = jl_alloc_vec_any(0);
+            JL_GC_PUSH1(&args);
+            jl_set_const(jl_core_module, jl_symbol("ARGS"), (jl_value_t*)args);
+            JL_GC_POP();
+        }
+        assert(jl_array_len(args) == 0);
+        jl_array_grow_end(args, argc);
+        int i;
+        for (i = 0; i < argc; i++) {
+            jl_value_t *s = (jl_value_t*)jl_cstr_to_string(argv[i]);
+            jl_arrayset(args, s, i);
+        }
+    }
+}
+
 // First argument is the usr/bin directory where the julia binary is, or NULL to guess.
 // Second argument is the path of a system image file (*.ji) relative to the
 // first argument path, or relative to the default julia home dir.
diff -pruN 1.3.1+dfsg-1/src/jlfrontend.scm 1.4.0+dfsg-1/src/jlfrontend.scm
--- 1.3.1+dfsg-1/src/jlfrontend.scm	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/src/jlfrontend.scm	2020-03-21 16:36:32.000000000 +0000
@@ -111,8 +111,7 @@
   (and (pair? e)
        (or (memq (car e) '(toplevel line module import using export
                                     error incomplete))
-           (and (memq (car e) '(global const)) (every symbol? (cdr e))
-                (every (lambda (x) (not (memq x '(true false)))) (cdr e))))))
+           (and (memq (car e) '(global const)) (every symbol? (cdr e))))))
 
 (define *in-expand* #f)
 
diff -pruN 1.3.1+dfsg-1/src/jloptions.c 1.4.0+dfsg-1/src/jloptions.c
--- 1.3.1+dfsg-1/src/jloptions.c	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/src/jloptions.c	2020-03-21 16:36:32.000000000 +0000
@@ -149,7 +149,9 @@ static const char opts_hidden[]  =
     " --output-unopt-bc name    Generate unoptimized LLVM bitcode (.bc)\n"
     " --output-jit-bc name      Dump all IR generated by the frontend (not including system image)\n"
     " --output-bc name          Generate LLVM bitcode (.bc)\n"
-    " --output-incremental=no   Generate an incremental output file (rather than complete)\n\n"
+    " --output-incremental=no   Generate an incremental output file (rather than complete)\n"
+    " --trace-compile={stdout,stderr}\n"
+    "                           Print precompile statements for methods compiled during execution.\n\n"
 ;
 
 JL_DLLEXPORT void jl_parse_opts(int *argcp, char ***argvp)
@@ -330,17 +332,11 @@ restart_switch:
         case 'L': // load
         {
             size_t sz = strlen(optarg) + 1;
-            char *arg = (char*)malloc(sz + 1);
+            char *arg = (char*)malloc_s(sz + 1);
             const char **newcmds;
-            if (!arg)
-                jl_errorf("fatal error: failed to allocate memory: %s", strerror(errno));
             arg[0] = c;
             memcpy(arg + 1, optarg, sz);
-            newcmds = (const char**)realloc(cmds, (ncmds + 2) * sizeof(char*));
-            if (!newcmds) {
-                free(cmds);
-                jl_errorf("fatal error: failed to allocate memory: %s", strerror(errno));
-            }
+            newcmds = (const char**)realloc_s(cmds, (ncmds + 2) * sizeof(char*));
             cmds = newcmds;
             cmds[ncmds] = arg;
             ncmds++;
@@ -626,26 +622,6 @@ restart_switch:
     *argcp -= proc_args;
 }
 
-JL_DLLEXPORT void jl_set_ARGS(int argc, char **argv)
-{
-    if (jl_core_module != NULL) {
-        jl_array_t *args = (jl_array_t*)jl_get_global(jl_core_module, jl_symbol("ARGS"));
-        if (args == NULL) {
-            args = jl_alloc_vec_any(0);
-            JL_GC_PUSH1(&args);
-            jl_set_const(jl_core_module, jl_symbol("ARGS"), (jl_value_t*)args);
-            JL_GC_POP();
-        }
-        assert(jl_array_len(args) == 0);
-        jl_array_grow_end(args, argc);
-        int i;
-        for (i=0; i < argc; i++) {
-            jl_value_t *s = (jl_value_t*)jl_cstr_to_string(argv[i]);
-            jl_arrayset(args, s, i);
-        }
-    }
-}
-
 JL_DLLEXPORT ssize_t jl_sizeof_jl_options(void)
 {
     return sizeof(jl_options_t);
diff -pruN 1.3.1+dfsg-1/src/jltypes.c 1.4.0+dfsg-1/src/jltypes.c
--- 1.3.1+dfsg-1/src/jltypes.c	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/src/jltypes.c	2020-03-21 16:36:32.000000000 +0000
@@ -995,17 +995,19 @@ void jl_precompute_memoized_dt(jl_dataty
     size_t i, l = jl_nparams(dt);
     for (i = 0; i < l; i++) {
         jl_value_t *p = jl_tparam(dt, i);
-        if (!dt->hasfreetypevars)
+        if (!dt->hasfreetypevars) {
             dt->hasfreetypevars = jl_has_free_typevars(p);
+            if (dt->hasfreetypevars)
+                dt->isconcretetype = 0;
+        }
         if (istuple && dt->isconcretetype)
             dt->isconcretetype = (jl_is_datatype(p) && ((jl_datatype_t*)p)->isconcretetype) || p == jl_bottom_type;
-        if (dt->isdispatchtuple)
+        if (dt->isdispatchtuple) {
             dt->isdispatchtuple = jl_is_datatype(p) &&
                 ((!jl_is_kind(p) && ((jl_datatype_t*)p)->isconcretetype) ||
                  (((jl_datatype_t*)p)->name == jl_type_typename && !((jl_datatype_t*)p)->hasfreetypevars));
+        }
     }
-    if (dt->hasfreetypevars)
-        dt->isconcretetype = 0;
 }
 
 static void check_datatype_parameters(jl_typename_t *tn, jl_value_t **params, size_t np)
@@ -1043,7 +1045,7 @@ static void check_datatype_parameters(jl
 arraylist_t partial_inst;
 int inside_typedef = 0;
 
-static jl_value_t *extract_wrapper(jl_value_t *t)
+static jl_value_t *extract_wrapper(jl_value_t *t JL_PROPAGATES_ROOT)
 {
     t = jl_unwrap_unionall(t);
     if (jl_is_datatype(t))
@@ -1112,7 +1114,9 @@ static jl_value_t *inst_datatype_inner(j
                     jl_types_equal(pi, tw)) {
                 if (jl_is_vararg_type(iparams[i])) {
                     tw = jl_wrap_vararg(tw, jl_tparam1(jl_unwrap_unionall(iparams[i])));
+                    JL_GC_PUSH1(&tw);
                     tw = jl_rewrap_unionall(tw, iparams[i]);
+                    JL_GC_POP();
                 }
                 iparams[i] = tw;
                 if (p) jl_gc_wb(p, tw);
@@ -1273,6 +1277,12 @@ static jl_value_t *inst_datatype_inner(j
     ndt->ditype = NULL;
     ndt->size = 0;
     jl_precompute_memoized_dt(ndt);
+    if (istuple)
+        ndt->ninitialized = ntp - isvatuple;
+    else if (isnamedtuple)
+        ndt->ninitialized = jl_svec_len(ndt->types);
+    else
+        ndt->ninitialized = dt->ninitialized;
 
     // assign uid as early as possible
     if (cacheable && !ndt->abstract)
@@ -1313,22 +1323,16 @@ static jl_value_t *inst_datatype_inner(j
             jl_gc_wb(ndt, ndt->types);
         }
     }
+
     if (jl_is_primitivetype(dt)) {
         ndt->size = dt->size;
         ndt->layout = dt->layout;
-        ndt->isbitstype = ndt->isinlinealloc = (!ndt->hasfreetypevars);
+        ndt->isbitstype = ndt->isinlinealloc = ndt->isconcretetype;
     }
     else if (cacheable && ndt->types != NULL && !ndt->abstract) {
         jl_compute_field_offsets(ndt);
     }
 
-    if (istuple)
-        ndt->ninitialized = ntp - isvatuple;
-    else if (isnamedtuple)
-        ndt->ninitialized = jl_svec_len(ndt->types);
-    else
-        ndt->ninitialized = dt->ninitialized;
-
     if (cacheable) {
         JL_UNLOCK(&typecache_lock); // Might GC
     }
@@ -2113,7 +2117,7 @@ void jl_init_types(void) JL_GC_DISABLED
     jl_method_type =
         jl_new_datatype(jl_symbol("Method"), core,
                         jl_any_type, jl_emptysvec,
-                        jl_perm_symsvec(21,
+                        jl_perm_symsvec(22,
                             "name",
                             "module",
                             "file",
@@ -2133,9 +2137,10 @@ void jl_init_types(void) JL_GC_DISABLED
                             "nargs",
                             "called",
                             "nospecialize",
+                            "nkw",
                             "isva",
                             "pure"),
-                        jl_svec(21,
+                        jl_svec(22,
                             jl_symbol_type,
                             jl_module_type,
                             jl_symbol_type,
@@ -2155,6 +2160,7 @@ void jl_init_types(void) JL_GC_DISABLED
                             jl_int32_type,
                             jl_int32_type,
                             jl_int32_type,
+                            jl_int32_type,
                             jl_bool_type,
                             jl_bool_type),
                         0, 1, 11);
@@ -2341,6 +2347,12 @@ void jl_init_types(void) JL_GC_DISABLED
     jl_compute_field_offsets(jl_unionall_type);
     jl_compute_field_offsets(jl_simplevector_type);
     jl_compute_field_offsets(jl_symbol_type);
+
+    // override the preferred layout for a couple types
+    jl_lineinfonode_type->isinlinealloc = 0; // FIXME: assumed to be a pointer by codegen
+    // It seems like we probably usually end up needing the box for kinds (used in an Any context)--but is that true?
+    jl_uniontype_type->isinlinealloc = 0;
+    jl_unionall_type->isinlinealloc = 0;
 }
 
 #ifdef __cplusplus
diff -pruN 1.3.1+dfsg-1/src/jl_uv.c 1.4.0+dfsg-1/src/jl_uv.c
--- 1.3.1+dfsg-1/src/jl_uv.c	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/src/jl_uv.c	2020-03-21 16:36:32.000000000 +0000
@@ -157,7 +157,7 @@ static void uv_flush_callback(uv_write_t
 // Turn a normal write into a blocking write (primarily for use from C and gdb).
 // Warning: This calls uv_run, so it can have unbounded side-effects.
 // Be care where you call it from! - the libuv loop is also not reentrant.
-void jl_uv_flush(uv_stream_t *stream)
+JL_DLLEXPORT void jl_uv_flush(uv_stream_t *stream)
 {
     if (stream == (void*)STDIN_FILENO ||
         stream == (void*)STDOUT_FILENO ||
@@ -173,7 +173,7 @@ void jl_uv_flush(uv_stream_t *stream)
         uv_buf_t buf;
         buf.base = (char*)(&buf + 1);
         buf.len = 0;
-        uv_write_t *write_req = (uv_write_t*)malloc(sizeof(uv_write_t));
+        uv_write_t *write_req = (uv_write_t*)malloc_s(sizeof(uv_write_t));
         write_req->data = (void*)&fired;
         if (uv_write(write_req, stream, &buf, 1, uv_flush_callback) != 0) {
             JL_UV_UNLOCK();
@@ -203,23 +203,10 @@ JL_DLLEXPORT void *jl_uv_write_handle(uv
 
 extern volatile unsigned _threadedregion;
 
-JL_DLLEXPORT int jl_run_once(uv_loop_t *loop)
-{
-    jl_ptls_t ptls = jl_get_ptls_states();
-    if (loop && (_threadedregion || ptls->tid == 0)) {
-        jl_gc_safepoint_(ptls);
-        JL_UV_LOCK();
-        loop->stop_flag = 0;
-        int r = uv_run(loop, UV_RUN_ONCE);
-        JL_UV_UNLOCK();
-        return r;
-    }
-    return 0;
-}
-
-JL_DLLEXPORT int jl_process_events(uv_loop_t *loop)
+JL_DLLEXPORT int jl_process_events(void)
 {
     jl_ptls_t ptls = jl_get_ptls_states();
+    uv_loop_t *loop = jl_io_loop;
     if (loop && (_threadedregion || ptls->tid == 0)) {
         jl_gc_safepoint_(ptls);
         if (jl_mutex_trylock(&jl_uv_mutex)) {
@@ -260,7 +247,7 @@ JL_DLLEXPORT void jl_close_uv(uv_handle_
     }
 
     if (handle->type == UV_NAMED_PIPE || handle->type == UV_TCP || handle->type == UV_TTY) {
-        uv_write_t *req = (uv_write_t*)malloc(sizeof(uv_write_t));
+        uv_write_t *req = (uv_write_t*)malloc_s(sizeof(uv_write_t));
         req->handle = (uv_stream_t*)handle;
         jl_uv_flush_close_callback(req, 0);
         JL_UV_UNLOCK();
@@ -532,9 +519,9 @@ JL_DLLEXPORT void jl_uv_puts(uv_stream_t
     }
     else {
         // Write to libuv stream...
-        uv_write_t *req = (uv_write_t*)malloc(sizeof(uv_write_t)+n);
-        char *data = (char*)(req+1);
-        memcpy(data,str,n);
+        uv_write_t *req = (uv_write_t*)malloc_s(sizeof(uv_write_t) + n);
+        char *data = (char*)(req + 1);
+        memcpy(data, str, n);
         uv_buf_t buf[1];
         buf[0].base = data;
         buf[0].len = n;
@@ -610,6 +597,10 @@ JL_DLLEXPORT void jl_safe_printf(const c
 {
     static char buf[1000];
     buf[0] = '\0';
+    int last_errno = errno;
+#ifdef _OS_WINDOWS_
+    DWORD last_error = GetLastError();
+#endif
 
     va_list args;
     va_start(args, fmt);
@@ -621,6 +612,10 @@ JL_DLLEXPORT void jl_safe_printf(const c
     if (write(STDERR_FILENO, buf, strlen(buf)) < 0) {
         // nothing we can do; ignore the failure
     }
+#ifdef _OS_WINDOWS_
+    SetLastError(last_error);
+#endif
+    errno = last_errno;
 }
 
 JL_DLLEXPORT void jl_exit(int exitcode)
@@ -836,7 +831,7 @@ JL_DLLEXPORT int jl_tcp_connect(uv_tcp_t
 {
     uv_sockaddr_in addr;
     jl_sockaddr_fill(&addr, port, host, ipv6);
-    uv_connect_t *req = (uv_connect_t*)malloc(sizeof(uv_connect_t));
+    uv_connect_t *req = (uv_connect_t*)malloc_s(sizeof(uv_connect_t));
     req->data = NULL;
     int r = uv_tcp_connect(req, handle, &addr.in, cb);
     if (r)
@@ -996,7 +991,7 @@ void jl_work_notifier(uv_work_t *req, in
 JL_DLLEXPORT int jl_queue_work(work_cb_t work_func, void *work_args, void *work_retval,
                                notify_cb_t notify_func, int notify_idx)
 {
-    struct work_baton *baton = (struct work_baton*) malloc(sizeof(struct work_baton));
+    struct work_baton *baton = (struct work_baton*)malloc_s(sizeof(struct work_baton));
     baton->req.data = (void*) baton;
     baton->work_func = work_func;
     baton->work_args = work_args;
diff -pruN 1.3.1+dfsg-1/src/julia_gcext.h 1.4.0+dfsg-1/src/julia_gcext.h
--- 1.3.1+dfsg-1/src/julia_gcext.h	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/src/julia_gcext.h	2020-03-21 16:36:32.000000000 +0000
@@ -14,16 +14,16 @@ extern "C" {
 // Marking callbacks for global roots and tasks, respectively. These,
 // along with custom mark functions must not alter the GC state except
 // through calling jl_gc_mark_queue_obj() and jl_gc_mark_queue_objarray().
-typedef void (*jl_gc_cb_root_scanner_t)(int full);
-typedef void (*jl_gc_cb_task_scanner_t)(jl_task_t *task, int full);
+typedef void (*jl_gc_cb_root_scanner_t)(int full) JL_NOTSAFEPOINT;
+typedef void (*jl_gc_cb_task_scanner_t)(jl_task_t *task, int full) JL_NOTSAFEPOINT;
 
 // Callbacks that are invoked before and after a collection.
-typedef void (*jl_gc_cb_pre_gc_t)(int full);
-typedef void (*jl_gc_cb_post_gc_t)(int full);
+typedef void (*jl_gc_cb_pre_gc_t)(int full) JL_NOTSAFEPOINT;
+typedef void (*jl_gc_cb_post_gc_t)(int full) JL_NOTSAFEPOINT;
 
 // Callbacks to track external object allocations.
-typedef void (*jl_gc_cb_notify_external_alloc_t)(void *addr, size_t size);
-typedef void (*jl_gc_cb_notify_external_free_t)(void *addr);
+typedef void (*jl_gc_cb_notify_external_alloc_t)(void *addr, size_t size) JL_NOTSAFEPOINT;
+typedef void (*jl_gc_cb_notify_external_free_t)(void *addr) JL_NOTSAFEPOINT;
 
 JL_DLLEXPORT void jl_gc_set_cb_root_scanner(jl_gc_cb_root_scanner_t cb, int enable);
 JL_DLLEXPORT void jl_gc_set_cb_task_scanner(jl_gc_cb_task_scanner_t cb, int enable);
diff -pruN 1.3.1+dfsg-1/src/julia.h 1.4.0+dfsg-1/src/julia.h
--- 1.3.1+dfsg-1/src/julia.h	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/src/julia.h	2020-03-21 16:36:32.000000000 +0000
@@ -159,10 +159,11 @@ typedef struct {
       3 = has a pointer to the object that owns the data
     */
     uint16_t how:2;
-    uint16_t ndims:10;
+    uint16_t ndims:9;
     uint16_t pooled:1;
-    uint16_t ptrarray:1;  // representation is pointer array
-    uint16_t isshared:1;  // data is shared by multiple Arrays
+    uint16_t ptrarray:1; // representation is pointer array
+    uint16_t hasptr:1; // representation has embedded pointers
+    uint16_t isshared:1; // data is shared by multiple Arrays
     uint16_t isaligned:1; // data allocated with memalign
 } jl_array_flags_t;
 
@@ -236,6 +237,13 @@ typedef struct _jl_llvm_functions_t {
 
 typedef struct _jl_method_instance_t jl_method_instance_t;
 
+typedef struct _jl_line_info_node_t {
+    jl_value_t *method;
+    jl_sym_t *file;
+    intptr_t line;
+    intptr_t inlined_at;
+} jl_line_info_node_t;
+
 // This type describes a single function body
 typedef struct _jl_code_info_t {
     // ssavalue-indexed arrays of properties:
@@ -303,6 +311,8 @@ typedef struct _jl_method_t {
     int32_t nargs;
     int32_t called;        // bit flags: whether each of the first 8 arguments is called
     int32_t nospecialize;  // bit flags: which arguments should not be specialized
+    int32_t nkw;           // # of leading arguments that are actually keyword arguments
+                           // of another method.
     uint8_t isva;
     uint8_t pure;
 
@@ -416,14 +426,20 @@ typedef struct {
 
 typedef struct {
     uint32_t nfields;
-    uint32_t alignment : 9; // strictest alignment over all fields
-    uint32_t haspadding : 1; // has internal undefined bytes
-    uint32_t npointers : 20; // number of pointer fields, top 4 bits are exponent (under-approximation)
-    uint32_t fielddesc_type : 2; // 0 -> 8, 1 -> 16, 2 -> 32
+    uint32_t npointers; // number of pointers embedded inside
+    int32_t first_ptr; // index of the first pointer (or -1)
+    uint16_t alignment; // strictest alignment over all fields
+    uint16_t haspadding : 1; // has internal undefined bytes
+    uint16_t fielddesc_type : 2; // 0 -> 8, 1 -> 16, 2 -> 32
     // union {
-    //     jl_fielddesc8_t field8[];
-    //     jl_fielddesc16_t field16[];
-    //     jl_fielddesc32_t field32[];
+    //     jl_fielddesc8_t field8[nfields];
+    //     jl_fielddesc16_t field16[nfields];
+    //     jl_fielddesc32_t field32[nfields];
+    // };
+    // union { // offsets relative to data start in words
+    //     uint8_t ptr8[npointers];
+    //     uint16_t ptr16[npointers];
+    //     uint32_t ptr32[npointers];
     // };
 } jl_datatype_layout_t;
 
@@ -681,6 +697,9 @@ typedef struct _jl_gcframe_t {
 
 #define jl_pgcstack (jl_get_ptls_states()->pgcstack)
 
+#define JL_GC_ENCODE_PUSHARGS(n)   (((size_t)(n))<<2)
+#define JL_GC_ENCODE_PUSH(n)       ((((size_t)(n))<<2)|1)
+
 #ifdef __clang_analyzer__
 
 // When running with the analyzer make these real function calls, that are
@@ -695,43 +714,43 @@ extern void _JL_GC_PUSHARGS(jl_value_t *
 // This is necessary, because otherwise the analyzer considers this undefined
 // behavior and terminates the exploration
 #define JL_GC_PUSHARGS(rts_var, n)     \
-  rts_var = (jl_value_t **)alloca(sizeof(void*) * n); \
-  memset(rts_var,0,sizeof(void*) * n); \
-  _JL_GC_PUSHARGS(rts_var, n);
+  rts_var = (jl_value_t **)alloca(sizeof(void*) * (n)); \
+  memset(rts_var, 0, sizeof(void*) * (n)); \
+  _JL_GC_PUSHARGS(rts_var, (n));
 
 extern void JL_GC_POP() JL_NOTSAFEPOINT;
 
 #else
 
-#define JL_GC_PUSH1(arg1)                                                 \
-  void *__gc_stkf[] = {(void*)3, jl_pgcstack, arg1};                      \
+#define JL_GC_PUSH1(arg1)                                                                               \
+  void *__gc_stkf[] = {(void*)JL_GC_ENCODE_PUSH(1), jl_pgcstack, arg1};                                 \
   jl_pgcstack = (jl_gcframe_t*)__gc_stkf;
 
-#define JL_GC_PUSH2(arg1, arg2)                                           \
-  void *__gc_stkf[] = {(void*)5, jl_pgcstack, arg1, arg2};                \
+#define JL_GC_PUSH2(arg1, arg2)                                                                         \
+  void *__gc_stkf[] = {(void*)JL_GC_ENCODE_PUSH(2), jl_pgcstack, arg1, arg2};                           \
   jl_pgcstack = (jl_gcframe_t*)__gc_stkf;
 
-#define JL_GC_PUSH3(arg1, arg2, arg3)                                     \
-  void *__gc_stkf[] = {(void*)7, jl_pgcstack, arg1, arg2, arg3};          \
+#define JL_GC_PUSH3(arg1, arg2, arg3)                                                                   \
+  void *__gc_stkf[] = {(void*)JL_GC_ENCODE_PUSH(3), jl_pgcstack, arg1, arg2, arg3};                     \
   jl_pgcstack = (jl_gcframe_t*)__gc_stkf;
 
-#define JL_GC_PUSH4(arg1, arg2, arg3, arg4)                               \
-  void *__gc_stkf[] = {(void*)9, jl_pgcstack, arg1, arg2, arg3, arg4};    \
+#define JL_GC_PUSH4(arg1, arg2, arg3, arg4)                                                             \
+  void *__gc_stkf[] = {(void*)JL_GC_ENCODE_PUSH(4), jl_pgcstack, arg1, arg2, arg3, arg4};               \
   jl_pgcstack = (jl_gcframe_t*)__gc_stkf;
 
-#define JL_GC_PUSH5(arg1, arg2, arg3, arg4, arg5)                               \
-  void *__gc_stkf[] = {(void*)11, jl_pgcstack, arg1, arg2, arg3, arg4, arg5};    \
+#define JL_GC_PUSH5(arg1, arg2, arg3, arg4, arg5)                                                       \
+  void *__gc_stkf[] = {(void*)JL_GC_ENCODE_PUSH(5), jl_pgcstack, arg1, arg2, arg3, arg4, arg5};         \
   jl_pgcstack = (jl_gcframe_t*)__gc_stkf;
 
-#define JL_GC_PUSH6(arg1, arg2, arg3, arg4, arg5, arg6)                      \
-  void *__gc_stkf[] = {(void*)13, jl_pgcstack, arg1, arg2, arg3, arg4, arg5, arg6}; \
+#define JL_GC_PUSH6(arg1, arg2, arg3, arg4, arg5, arg6)                                                 \
+  void *__gc_stkf[] = {(void*)JL_GC_ENCODE_PUSH(6), jl_pgcstack, arg1, arg2, arg3, arg4, arg5, arg6};   \
   jl_pgcstack = (jl_gcframe_t*)__gc_stkf;
 
-#define JL_GC_PUSHARGS(rts_var,n)                               \
-  rts_var = ((jl_value_t**)alloca(((n)+2)*sizeof(jl_value_t*)))+2;    \
-  ((void**)rts_var)[-2] = (void*)(((size_t)(n))<<1);                  \
-  ((void**)rts_var)[-1] = jl_pgcstack;                          \
-  memset((void*)rts_var, 0, (n)*sizeof(jl_value_t*));           \
+#define JL_GC_PUSHARGS(rts_var,n)                                                                       \
+  rts_var = ((jl_value_t**)alloca(((n)+2)*sizeof(jl_value_t*)))+2;                                      \
+  ((void**)rts_var)[-2] = (void*)JL_GC_ENCODE_PUSHARGS(n);                                              \
+  ((void**)rts_var)[-1] = jl_pgcstack;                                                                  \
+  memset((void*)rts_var, 0, (n)*sizeof(jl_value_t*));                                                   \
   jl_pgcstack = (jl_gcframe_t*)&(((void**)rts_var)[-2])
 
 #define JL_GC_POP() (jl_pgcstack = jl_pgcstack->prev)
@@ -740,11 +759,14 @@ extern void JL_GC_POP() JL_NOTSAFEPOINT;
 
 JL_DLLEXPORT int jl_gc_enable(int on);
 JL_DLLEXPORT int jl_gc_is_enabled(void);
-JL_DLLEXPORT int64_t jl_gc_total_bytes(void);
-JL_DLLEXPORT uint64_t jl_gc_total_hrtime(void);
-JL_DLLEXPORT int64_t jl_gc_diff_total_bytes(void);
 
-JL_DLLEXPORT void jl_gc_collect(int);
+typedef enum {
+    JL_GC_AUTO = 0,         // use heuristics to determine the collection type
+    JL_GC_FULL = 1,         // force a full collection
+    JL_GC_INCREMENTAL = 2,  // force an incremental collection
+} jl_gc_collection_t;
+
+JL_DLLEXPORT void jl_gc_collect(jl_gc_collection_t);
 
 JL_DLLEXPORT void jl_gc_add_finalizer(jl_value_t *v, jl_function_t *f);
 JL_DLLEXPORT void jl_finalize(jl_value_t *o);
@@ -761,13 +783,14 @@ JL_DLLEXPORT void jl_gc_use(jl_value_t *
 JL_DLLEXPORT void jl_clear_malloc_data(void);
 
 // GC write barriers
-JL_DLLEXPORT void jl_gc_queue_root(jl_value_t *root) JL_NOTSAFEPOINT; // root isa jl_value_t*
+JL_DLLEXPORT void jl_gc_queue_root(jl_value_t *root) JL_NOTSAFEPOINT;
+JL_DLLEXPORT void jl_gc_queue_multiroot(jl_value_t *root, jl_value_t *stored) JL_NOTSAFEPOINT;
 
 STATIC_INLINE void jl_gc_wb(void *parent, void *ptr) JL_NOTSAFEPOINT
 {
     // parent and ptr isa jl_value_t*
-    if (__unlikely(jl_astaggedvalue(parent)->bits.gc == 3 &&
-                   (jl_astaggedvalue(ptr)->bits.gc & 1) == 0))
+    if (__unlikely(jl_astaggedvalue(parent)->bits.gc == 3 && // parent is old and not in remset
+                   (jl_astaggedvalue(ptr)->bits.gc & 1) == 0)) // ptr is young
         jl_gc_queue_root((jl_value_t*)parent);
 }
 
@@ -779,6 +802,19 @@ STATIC_INLINE void jl_gc_wb_back(void *p
     }
 }
 
+STATIC_INLINE void jl_gc_multi_wb(void *parent, jl_value_t *ptr) JL_NOTSAFEPOINT
+{
+    // ptr is an immutable object
+    if (__likely(jl_astaggedvalue(parent)->bits.gc != 3))
+        return; // parent is young or in remset
+    if (__likely(jl_astaggedvalue(ptr)->bits.gc == 3))
+        return; // ptr is old and not in remset (thus it does not point to young)
+    jl_datatype_t *dt = (jl_datatype_t*)jl_typeof(ptr);
+    const jl_datatype_layout_t *ly = dt->layout;
+    if (ly->npointers)
+        jl_gc_queue_multiroot((jl_value_t*)parent, ptr);
+}
+
 JL_DLLEXPORT void *jl_gc_managed_malloc(size_t sz);
 JL_DLLEXPORT void *jl_gc_managed_realloc(void *d, size_t sz, size_t oldsz,
                                          int isaligned, jl_value_t *owner);
@@ -839,6 +875,7 @@ STATIC_INLINE jl_value_t *jl_array_ptr_s
 #define jl_array_ptr_data(a)  ((jl_value_t**)((jl_array_t*)(a))->data)
 STATIC_INLINE jl_value_t *jl_array_ptr_ref(void *a JL_PROPAGATES_ROOT, size_t i) JL_NOTSAFEPOINT
 {
+    assert(((jl_array_t*)a)->flags.ptrarray);
     assert(i < jl_array_len(a));
     return ((jl_value_t**)(jl_array_data(a)))[i];
 }
@@ -846,6 +883,7 @@ STATIC_INLINE jl_value_t *jl_array_ptr_s
     void *a JL_ROOTING_ARGUMENT, size_t i,
     void *x JL_ROOTED_ARGUMENT) JL_NOTSAFEPOINT
 {
+    assert(((jl_array_t*)a)->flags.ptrarray);
     assert(i < jl_array_len(a));
     ((jl_value_t**)(jl_array_data(a)))[i] = (jl_value_t*)x;
     if (x) {
@@ -931,6 +969,7 @@ STATIC_INLINE jl_value_t *jl_field_type_
 #define jl_datatype_align(t)   (((jl_datatype_t*)t)->layout->alignment)
 #define jl_datatype_nbits(t)   ((((jl_datatype_t*)t)->size)*8)
 #define jl_datatype_nfields(t) (((jl_datatype_t*)(t))->layout->nfields)
+#define jl_datatype_isinlinealloc(t) (((jl_datatype_t *)(t))->isinlinealloc)
 
 // inline version with strong type check to detect typos in a `->name` chain
 STATIC_INLINE char *jl_symbol_name_(jl_sym_t *s) JL_NOTSAFEPOINT
@@ -939,7 +978,25 @@ STATIC_INLINE char *jl_symbol_name_(jl_s
 }
 #define jl_symbol_name(s) jl_symbol_name_(s)
 
+static inline uint32_t jl_fielddesc_size(int8_t fielddesc_type) JL_NOTSAFEPOINT
+{
+    return 2 << fielddesc_type;
+    //if (fielddesc_type == 0) {
+    //    return sizeof(jl_fielddesc8_t);
+    //}
+    //else if (fielddesc_type == 1) {
+    //    return sizeof(jl_fielddesc16_t);
+    //}
+    //else {
+    //    return sizeof(jl_fielddesc32_t);
+    //}
+}
+
 #define jl_dt_layout_fields(d) ((const char*)(d) + sizeof(jl_datatype_layout_t))
+static inline const char *jl_dt_layout_ptrs(const jl_datatype_layout_t *l) JL_NOTSAFEPOINT
+{
+    return jl_dt_layout_fields(l) + jl_fielddesc_size(l->fielddesc_type) * l->nfields;
+}
 
 #define DEFINE_FIELD_ACCESSORS(f)                                             \
     static inline uint32_t jl_field_##f(jl_datatype_t *st,                    \
@@ -960,28 +1017,32 @@ STATIC_INLINE char *jl_symbol_name_(jl_s
 
 DEFINE_FIELD_ACCESSORS(offset)
 DEFINE_FIELD_ACCESSORS(size)
+#undef DEFINE_FIELD_ACCESSORS
+
 static inline int jl_field_isptr(jl_datatype_t *st, int i) JL_NOTSAFEPOINT
 {
     const jl_datatype_layout_t *ly = st->layout;
     assert(i >= 0 && (size_t)i < ly->nfields);
-    return ((const jl_fielddesc8_t*)(jl_dt_layout_fields(ly) + (i << (ly->fielddesc_type + 1))))->isptr;
+    return ((const jl_fielddesc8_t*)(jl_dt_layout_fields(ly) + jl_fielddesc_size(ly->fielddesc_type) * i))->isptr;
 }
 
-static inline uint32_t jl_fielddesc_size(int8_t fielddesc_type) JL_NOTSAFEPOINT
+static inline uint32_t jl_ptr_offset(jl_datatype_t *st, int i) JL_NOTSAFEPOINT
 {
-    if (fielddesc_type == 0) {
-        return sizeof(jl_fielddesc8_t);
+    const jl_datatype_layout_t *ly = st->layout;
+    assert(i >= 0 && (size_t)i < ly->npointers);
+    const void *ptrs = jl_dt_layout_ptrs(ly);
+    if (ly->fielddesc_type == 0) {
+        return ((const uint8_t*)ptrs)[i];
     }
-    else if (fielddesc_type == 1) {
-        return sizeof(jl_fielddesc16_t);
+    else if (ly->fielddesc_type == 1) {
+        return ((const uint16_t*)ptrs)[i];
     }
     else {
-        return sizeof(jl_fielddesc32_t);
+        assert(ly->fielddesc_type == 2);
+        return ((const uint32_t*)ptrs)[i];
     }
 }
 
-#undef DEFINE_FIELD_ACCESSORS
-
 static inline int jl_is_layout_opaque(const jl_datatype_layout_t *l) JL_NOTSAFEPOINT
 {
     return l->nfields == 0 && l->npointers > 0;
@@ -1469,7 +1530,7 @@ JL_DLLEXPORT void JL_NORETURN jl_type_er
                                             jl_value_t *got JL_MAYBE_UNROOTED);
 JL_DLLEXPORT void JL_NORETURN jl_type_error_rt(const char *fname,
                                                const char *context,
-                                               jl_value_t *ty,
+                                               jl_value_t *ty JL_MAYBE_UNROOTED,
                                                jl_value_t *got JL_MAYBE_UNROOTED);
 JL_DLLEXPORT void JL_NORETURN jl_undefined_var_error(jl_sym_t *var);
 JL_DLLEXPORT void JL_NORETURN jl_bounds_error(jl_value_t *v,
@@ -1650,6 +1711,7 @@ JL_DLLEXPORT void jl_sigatomic_end(void)
 // tasks and exceptions -------------------------------------------------------
 
 typedef struct _jl_timing_block_t jl_timing_block_t;
+typedef struct _jl_excstack_t jl_excstack_t;
 
 // info describing an exception handler
 typedef struct _jl_handler_t {
@@ -1781,9 +1843,7 @@ extern int had_exception;
 #define JL_STDERR jl_uv_stderr
 #define JL_STDIN  jl_uv_stdin
 
-JL_DLLEXPORT void jl_run_event_loop(uv_loop_t *loop);
-JL_DLLEXPORT int jl_run_once(uv_loop_t *loop);
-JL_DLLEXPORT int jl_process_events(uv_loop_t *loop);
+JL_DLLEXPORT int jl_process_events(void);
 
 JL_DLLEXPORT uv_loop_t *jl_global_event_loop(void);
 
diff -pruN 1.3.1+dfsg-1/src/julia_internal.h 1.4.0+dfsg-1/src/julia_internal.h
--- 1.3.1+dfsg-1/src/julia_internal.h	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/src/julia_internal.h	2020-03-21 16:36:32.000000000 +0000
@@ -8,7 +8,6 @@
 #include <uv.h>
 #if !defined(_MSC_VER) && !defined(__MINGW32__)
 #include <unistd.h>
-#include <sched.h>
 #else
 #define sleep(x) Sleep(1000*x)
 #endif
@@ -21,6 +20,17 @@
 #define JL_ASAN_ENABLED     // GCC flavor
 #endif
 
+#ifdef JL_ASAN_ENABLED
+#ifdef __cplusplus
+extern "C" {
+#endif
+void __sanitizer_start_switch_fiber(void**, const void*, size_t);
+void __sanitizer_finish_switch_fiber(void*, const void**, size_t*);
+#ifdef __cplusplus
+}
+#endif
+#endif
+
 #if defined(__has_feature)
 #if __has_feature(memory_sanitizer)
 #define JL_MSAN_ENABLED
@@ -100,6 +110,9 @@ STATIC_INLINE uint32_t jl_int32hash_fast
     return a;  // identity hashing seems to work well enough here
 }
 
+
+// -- gc.c -- //
+
 #define GC_CLEAN  0 // freshly allocated
 #define GC_MARKED 1 // reachable and young
 #define GC_OLD    2 // if it is reachable it will be marked as old
@@ -277,6 +290,7 @@ jl_value_t *jl_permbox32(jl_datatype_t *
 jl_value_t *jl_permbox64(jl_datatype_t *t, int64_t x);
 jl_svec_t *jl_perm_symsvec(size_t n, ...);
 
+#if !defined(__clang_analyzer__) && !defined(JL_ASAN_ENABLED) // this sizeof(__VA_ARGS__) trick can't be computed until C11, but that only matters to Clang in some situations
 #ifdef __GNUC__
 #define jl_perm_symsvec(n, ...) \
     (jl_perm_symsvec)(__extension__({                                         \
@@ -293,41 +307,14 @@ jl_svec_t *jl_perm_symsvec(size_t n, ...
             n;                                                                \
         }), __VA_ARGS__)
 #endif
-
-// Returns a int32 where the high 16 bits are a lower bound of the number of non-pointer fields
-// at the beginning of the type and the low 16 bits are a lower bound on the number of non-pointer
-// fields at the end of the type. This field only exists for a layout that has at least one
-// pointer fields.
-#define jl_datatype_layout_n_nonptr(layout) ((uint32_t*)(layout))[-1]
+#endif
 
 jl_value_t *jl_gc_realloc_string(jl_value_t *s, size_t sz);
 JL_DLLEXPORT void *jl_gc_counted_malloc(size_t sz);
 
 JL_DLLEXPORT void JL_NORETURN jl_throw_out_of_memory_error(void);
 
-jl_code_info_t *jl_type_infer(jl_method_instance_t *li, size_t world, int force);
-jl_code_instance_t *jl_compile_method_internal(jl_method_instance_t *meth JL_PROPAGATES_ROOT, size_t world);
-void jl_generate_fptr(jl_code_instance_t *codeinst);
-jl_code_instance_t *jl_compile_linfo(
-        jl_method_instance_t *li JL_PROPAGATES_ROOT,
-        jl_code_info_t *src JL_MAYBE_UNROOTED,
-        size_t world,
-        const jl_cgparams_t *params);
-JL_DLLEXPORT jl_code_instance_t *jl_get_method_inferred(
-        jl_method_instance_t *mi JL_PROPAGATES_ROOT, jl_value_t *rettype,
-        size_t min_world, size_t max_world);
-jl_method_instance_t *jl_get_unspecialized(jl_method_instance_t *method JL_PROPAGATES_ROOT);
-
-JL_DLLEXPORT int jl_compile_hint(jl_tupletype_t *types);
-jl_code_info_t *jl_code_for_interpreter(jl_method_instance_t *lam JL_PROPAGATES_ROOT);
-int jl_code_requires_compiler(jl_code_info_t *src);
-jl_code_info_t *jl_new_code_info_from_ast(jl_expr_t *ast);
-JL_DLLEXPORT jl_code_info_t *jl_new_code_info_uninit(void);
-
-jl_value_t *jl_argtype_with_function(jl_function_t *f, jl_value_t *types);
-
-JL_DLLEXPORT jl_value_t *jl_apply_2va(jl_value_t *f, jl_value_t **args, uint32_t nargs);
-
+JL_DLLEXPORT int64_t jl_gc_diff_total_bytes(void);
 void jl_gc_sync_total_bytes(void);
 void jl_gc_track_malloced_array(jl_ptls_t ptls, jl_array_t *a) JL_NOTSAFEPOINT;
 void jl_gc_count_allocd(size_t sz) JL_NOTSAFEPOINT;
@@ -364,6 +351,42 @@ void jl_set_t_uid_ctr(int i);
 uint32_t jl_get_gs_ctr(void);
 void jl_set_gs_ctr(uint32_t ctr);
 
+STATIC_INLINE jl_value_t *undefref_check(jl_datatype_t *dt, jl_value_t *v) JL_NOTSAFEPOINT
+{
+     if (dt->layout->first_ptr >= 0) {
+        jl_value_t *nullp = ((jl_value_t**)v)[dt->layout->first_ptr];
+        if (__unlikely(nullp == NULL))
+            jl_throw(jl_undefref_exception);
+    }
+    return v;
+}
+
+
+// -- functions -- //
+
+jl_code_info_t *jl_type_infer(jl_method_instance_t *li, size_t world, int force);
+jl_code_instance_t *jl_compile_method_internal(jl_method_instance_t *meth JL_PROPAGATES_ROOT, size_t world);
+void jl_generate_fptr(jl_code_instance_t *codeinst);
+jl_code_instance_t *jl_compile_linfo(
+        jl_method_instance_t *li JL_PROPAGATES_ROOT,
+        jl_code_info_t *src JL_MAYBE_UNROOTED,
+        size_t world,
+        const jl_cgparams_t *params);
+JL_DLLEXPORT jl_code_instance_t *jl_get_method_inferred(
+        jl_method_instance_t *mi JL_PROPAGATES_ROOT, jl_value_t *rettype,
+        size_t min_world, size_t max_world);
+jl_method_instance_t *jl_get_unspecialized(jl_method_instance_t *method JL_PROPAGATES_ROOT);
+
+JL_DLLEXPORT int jl_compile_hint(jl_tupletype_t *types);
+jl_code_info_t *jl_code_for_interpreter(jl_method_instance_t *lam JL_PROPAGATES_ROOT);
+int jl_code_requires_compiler(jl_code_info_t *src);
+jl_code_info_t *jl_new_code_info_from_ast(jl_expr_t *ast);
+JL_DLLEXPORT jl_code_info_t *jl_new_code_info_uninit(void);
+
+jl_value_t *jl_argtype_with_function(jl_function_t *f, jl_value_t *types);
+
+JL_DLLEXPORT jl_value_t *jl_apply_2va(jl_value_t *f, jl_value_t **args, uint32_t nargs);
+
 void JL_NORETURN jl_method_error(jl_function_t *f, jl_value_t **args, size_t na, size_t world);
 jl_value_t *jl_get_exceptionf(jl_datatype_t *exception_type, const char *fmt, ...);
 
@@ -416,9 +439,10 @@ void jl_precompute_memoized_dt(jl_dataty
 jl_datatype_t *jl_wrap_Type(jl_value_t *t);  // x -> Type{x}
 jl_value_t *jl_wrap_vararg(jl_value_t *t, jl_value_t *n);
 void jl_assign_bits(void *dest, jl_value_t *bits) JL_NOTSAFEPOINT;
+void set_nth_field(jl_datatype_t *st, void *v, size_t i, jl_value_t *rhs) JL_NOTSAFEPOINT;
 jl_expr_t *jl_exprn(jl_sym_t *head, size_t n);
 jl_function_t *jl_new_generic_function(jl_sym_t *name, jl_module_t *module);
-jl_function_t *jl_new_generic_function_with_supertype(jl_sym_t *name, jl_module_t *module, jl_datatype_t *st, int iskw);
+jl_function_t *jl_new_generic_function_with_supertype(jl_sym_t *name, jl_module_t *module, jl_datatype_t *st);
 void jl_init_main_module(void);
 int jl_is_submodule(jl_module_t *child, jl_module_t *parent);
 jl_array_t *jl_get_loaded_modules(void);
@@ -449,10 +473,11 @@ JL_DLLEXPORT jl_methtable_t *jl_method_t
     jl_value_t *argtypes JL_PROPAGATES_ROOT) JL_NOTSAFEPOINT;
 jl_methtable_t *jl_argument_method_table(jl_value_t *argt JL_PROPAGATES_ROOT);
 
+int jl_pointer_egal(jl_value_t *t);
 jl_value_t *jl_nth_slot_type(jl_value_t *sig JL_PROPAGATES_ROOT, size_t i) JL_NOTSAFEPOINT;
 void jl_compute_field_offsets(jl_datatype_t *st);
 jl_array_t *jl_new_array_for_deserialization(jl_value_t *atype, uint32_t ndims, size_t *dims,
-                                             int isunboxed, int isunion, int elsz);
+                                             int isunboxed, int hasptr, int isunion, int elsz);
 void jl_module_run_initializer(jl_module_t *m);
 jl_binding_t *jl_get_module_binding(jl_module_t *m JL_PROPAGATES_ROOT, jl_sym_t *var) JL_NOTSAFEPOINT;
 extern jl_array_t *jl_module_init_order JL_GLOBALLY_ROOTED;
@@ -470,6 +495,8 @@ extern char jl_using_perf_jitevents;
 #endif
 extern size_t jl_arr_xtralloc_limit;
 
+// -- init.c -- //
+
 void jl_init_types(void) JL_GC_DISABLED;
 void jl_init_box_caches(void);
 void jl_init_frontend(void);
@@ -579,7 +606,109 @@ jl_tupletype_t *arg_type_tuple(jl_value_
 
 int jl_has_meta(jl_array_t *body, jl_sym_t *sym);
 
-// backtraces
+//--------------------------------------------------
+// Backtraces
+
+// Backtrace buffers:
+//
+// A backtrace buffer conceptually contains a stack of instruction pointers
+// ordered from the inner-most frame to the outermost. We store them in a
+// special raw format for two reasons:
+//
+//   * Efficiency: Every `throw()` must populate the trace so it must be as
+//     efficient as possible.
+//   * Signal safety: For signal-based exceptions such as StackOverflowError
+//     the trace buffer needs to be filled from a signal handler where most
+//     operations are not allowed (including malloc) so we choose a flat
+//     preallocated buffer.
+//
+// The raw buffer layout contains "frame entries" composed of one or several
+// values of type `jl_bt_element_t`. From the point of view of the GC, an entry
+// is either:
+//
+// 1. A single instruction pointer to native code, not GC-managed.
+// 2. An "extended entry": a mixture of raw data and pointers to julia objects
+//    which must be treated as GC roots.
+//
+// A single extended entry is seralized using multiple elements from the raw
+// buffer; if `e` is the pointer to the first slot we have:
+//
+//   e[0]  JL_BT_NON_PTR_ENTRY  - Special marker to distinguish extended entries
+//   e[1]  descriptor           - A bit packed uintptr_t containing a tag and
+//                                the number of GC- managed and non-managed values
+//   e[2+j]                     - GC managed data
+//   e[2+ngc+i]                 - Non-GC-managed data
+//
+// The format of `descriptor` is, from LSB to MSB:
+//   0:2     ngc     Number of GC-managed pointers for this frame entry
+//   3:5     nptr    Number of non-GC-managed buffer elements
+//   6:9     tag     Entry type
+//   10:...  header  Entry-specific header data
+typedef struct _jl_bt_element_t {
+    union {
+        uintptr_t   uintptr; // Metadata or native instruction ptr
+        jl_value_t* jlvalue; // Pointer to GC-managed value
+    };
+} jl_bt_element_t;
+
+#define JL_BT_NON_PTR_ENTRY (((uintptr_t)0)-1)
+// Maximum size for an extended backtrace entry (likely significantly larger
+// than the actual size of 3-4 for an interpreter frame)
+#define JL_BT_MAX_ENTRY_SIZE 16
+
+STATIC_INLINE int jl_bt_is_native(jl_bt_element_t *bt_entry) JL_NOTSAFEPOINT
+{
+    return bt_entry[0].uintptr != JL_BT_NON_PTR_ENTRY;
+}
+
+// Extended backtrace entry header packing; the bit packing is done manually
+// for precise layout control for interop with julia side.
+STATIC_INLINE uintptr_t jl_bt_entry_descriptor(int ngc, int nptr,
+                                               int tag, uintptr_t header) JL_NOTSAFEPOINT
+{
+    assert(((ngc & 0x7) == ngc) && ((nptr & 0x7) == nptr) && ((tag & 0xf) == tag));
+    return (ngc & 0x7) | (nptr & 0x7) << 3 | (tag & 0xf) << 6 | header << 10;
+}
+
+// Unpacking of extended backtrace entry data
+STATIC_INLINE size_t jl_bt_num_jlvals(jl_bt_element_t *bt_entry) JL_NOTSAFEPOINT
+{
+    assert(!jl_bt_is_native(bt_entry));
+    return bt_entry[1].uintptr & 0x7;
+}
+STATIC_INLINE size_t jl_bt_num_uintvals(jl_bt_element_t *bt_entry) JL_NOTSAFEPOINT
+{
+    assert(!jl_bt_is_native(bt_entry));
+    return (bt_entry[1].uintptr >> 3) & 0x7;
+}
+STATIC_INLINE int jl_bt_entry_tag(jl_bt_element_t *bt_entry) JL_NOTSAFEPOINT
+{
+    assert(!jl_bt_is_native(bt_entry));
+    return (bt_entry[1].uintptr >> 6) & 0xf;
+}
+STATIC_INLINE uintptr_t jl_bt_entry_header(jl_bt_element_t *bt_entry) JL_NOTSAFEPOINT
+{
+    assert(!jl_bt_is_native(bt_entry));
+    return bt_entry[1].uintptr >> 10;
+}
+
+// Return `i`th GC-managed pointer for extended backtrace entry
+// The returned value is rooted for the lifetime of the parent exception stack.
+STATIC_INLINE jl_value_t *jl_bt_entry_jlvalue(jl_bt_element_t *bt_entry, size_t i) JL_NOTSAFEPOINT
+{
+    return bt_entry[2 + i].jlvalue;
+}
+
+#define JL_BT_INTERP_FRAME_TAG    1  // An interpreter frame
+
+// Number of bt elements in frame.
+STATIC_INLINE size_t jl_bt_entry_size(jl_bt_element_t *bt_entry) JL_NOTSAFEPOINT
+{
+    return jl_bt_is_native(bt_entry) ?
+        1 : 2 + jl_bt_num_jlvals(bt_entry) + jl_bt_num_uintvals(bt_entry);
+}
+
+// Function metadata arising from debug info lookup of instruction pointer
 typedef struct {
     char *func_name;
     char *file_name;
@@ -623,20 +752,23 @@ typedef unw_cursor_t bt_cursor_t;
 typedef int bt_context_t;
 typedef int bt_cursor_t;
 #endif
-// Special marker in backtrace data for encoding interpreter frames
-#define JL_BT_INTERP_FRAME (((uintptr_t)0)-1)
-size_t rec_backtrace(uintptr_t *data, size_t maxsize) JL_NOTSAFEPOINT;
-size_t rec_backtrace_ctx(uintptr_t *data, size_t maxsize, bt_context_t *ctx) JL_NOTSAFEPOINT;
+size_t rec_backtrace(jl_bt_element_t *bt_data, size_t maxsize, int skip) JL_NOTSAFEPOINT;
+// Record backtrace from a signal handler. `ctx` is the context of the code
+// which was asynchronously interrupted.
+size_t rec_backtrace_ctx(jl_bt_element_t *bt_data, size_t maxsize, bt_context_t *ctx,
+                         jl_gcframe_t *pgcstack) JL_NOTSAFEPOINT;
 #ifdef LIBOSXUNWIND
-size_t rec_backtrace_ctx_dwarf(uintptr_t *data, size_t maxsize, bt_context_t *ctx);
+size_t rec_backtrace_ctx_dwarf(jl_bt_element_t *bt_data, size_t maxsize, bt_context_t *ctx, jl_gcframe_t *pgcstack) JL_NOTSAFEPOINT;
 #endif
-JL_DLLEXPORT void jl_get_backtrace(jl_array_t **bt, jl_array_t **bt2);
-void jl_critical_error(int sig, bt_context_t *context, uintptr_t *bt_data, size_t *bt_size);
+JL_DLLEXPORT jl_value_t *jl_get_backtrace(void);
+void jl_critical_error(int sig, bt_context_t *context, jl_bt_element_t *bt_data, size_t *bt_size);
 JL_DLLEXPORT void jl_raise_debugger(void);
 int jl_getFunctionInfo(jl_frame_t **frames, uintptr_t pointer, int skipC, int noInline) JL_NOTSAFEPOINT;
-JL_DLLEXPORT void jl_gdblookup(uintptr_t ip) JL_NOTSAFEPOINT;
+JL_DLLEXPORT void jl_gdblookup(void* ip) JL_NOTSAFEPOINT;
+void jl_print_native_codeloc(uintptr_t ip) JL_NOTSAFEPOINT;
+void jl_print_bt_entry_codeloc(jl_bt_element_t *bt_data) JL_NOTSAFEPOINT;
 // *to is NULL or malloc'd pointer, from is allowed to be NULL
-STATIC_INLINE char *jl_copy_str(char **to, const char *from)
+STATIC_INLINE char *jl_copy_str(char **to, const char *from) JL_NOTSAFEPOINT
 {
     if (!from) {
         free(*to);
@@ -644,41 +776,41 @@ STATIC_INLINE char *jl_copy_str(char **t
         return NULL;
     }
     size_t len = strlen(from) + 1;
-    *to = (char*)realloc(*to, len);
+    *to = (char*)realloc_s(*to, len);
     memcpy(*to, from, len);
     return *to;
 }
-JL_DLLEXPORT int jl_is_interpreter_frame(uintptr_t ip) JL_NOTSAFEPOINT;
-JL_DLLEXPORT int jl_is_enter_interpreter_frame(uintptr_t ip) JL_NOTSAFEPOINT;
-JL_DLLEXPORT size_t jl_capture_interp_frame(uintptr_t *data, uintptr_t sp, uintptr_t fp, size_t space_remaining) JL_NOTSAFEPOINT;
+
+JL_DLLEXPORT size_t jl_capture_interp_frame(jl_bt_element_t *bt_data,
+        void *frameend, size_t space_remaining) JL_NOTSAFEPOINT;
 
 // Exception stack: a stack of pairs of (exception,raw_backtrace).
 // The stack may be traversed and accessed with the functions below.
-typedef struct _jl_excstack_t {
+struct _jl_excstack_t { // typedef in julia.h
     size_t top;
     size_t reserved_size;
     // Pack all stack entries into a growable buffer to amortize allocation
     // across repeated exception handling.
     // Layout: [bt_data1... bt_size1 exc1  bt_data2... bt_size2 exc2  ..]
-    // uintptr_t data[]; // Access with jl_excstack_raw
-} jl_excstack_t;
+    // jl_bt_element_t data[]; // Access with jl_excstack_raw
+};
 
-STATIC_INLINE uintptr_t *jl_excstack_raw(jl_excstack_t *stack) JL_NOTSAFEPOINT
+STATIC_INLINE jl_bt_element_t *jl_excstack_raw(jl_excstack_t *stack) JL_NOTSAFEPOINT
 {
-    return (uintptr_t*)(stack + 1);
+    return (jl_bt_element_t*)(stack + 1);
 }
 
 // Exception stack access
 STATIC_INLINE jl_value_t *jl_excstack_exception(jl_excstack_t *stack JL_PROPAGATES_ROOT,
                                                 size_t itr) JL_NOTSAFEPOINT
 {
-    return (jl_value_t*)(jl_excstack_raw(stack)[itr-1]);
+    return jl_excstack_raw(stack)[itr-1].jlvalue;
 }
 STATIC_INLINE size_t jl_excstack_bt_size(jl_excstack_t *stack, size_t itr) JL_NOTSAFEPOINT
 {
-    return jl_excstack_raw(stack)[itr-2];
+    return jl_excstack_raw(stack)[itr-2].uintptr;
 }
-STATIC_INLINE uintptr_t *jl_excstack_bt_data(jl_excstack_t *stack, size_t itr) JL_NOTSAFEPOINT
+STATIC_INLINE jl_bt_element_t *jl_excstack_bt_data(jl_excstack_t *stack, size_t itr) JL_NOTSAFEPOINT
 {
     return jl_excstack_raw(stack) + itr-2 - jl_excstack_bt_size(stack, itr);
 }
@@ -692,9 +824,10 @@ void jl_reserve_excstack(jl_excstack_t *
                          size_t reserved_size);
 void jl_push_excstack(jl_excstack_t **stack JL_REQUIRE_ROOTED_SLOT JL_ROOTING_ARGUMENT,
                       jl_value_t *exception JL_ROOTED_ARGUMENT,
-                      uintptr_t *bt_data, size_t bt_size);
+                      jl_bt_element_t *bt_data, size_t bt_size);
 void jl_copy_excstack(jl_excstack_t *dest, jl_excstack_t *src) JL_NOTSAFEPOINT;
 
+//--------------------------------------------------
 // timers
 // Returns time in nanosec
 JL_DLLEXPORT uint64_t jl_hrtime(void);
@@ -728,7 +861,8 @@ extern void *jl_crtdll_handle;
 extern void *jl_winsock_handle;
 #endif
 
-void *jl_get_library(const char *f_lib);
+void *jl_get_library_(const char *f_lib, int throw_err);
+#define jl_get_library(f_lib) jl_get_library_(f_lib, 1)
 JL_DLLEXPORT void *jl_load_and_lookup(const char *f_lib, const char *f_name,
                                       void **hnd);
 JL_DLLEXPORT jl_value_t *jl_get_cfunction_trampoline(
@@ -833,12 +967,13 @@ JL_DLLEXPORT jl_value_t *jl_floor_llvm(j
 JL_DLLEXPORT jl_value_t *jl_trunc_llvm(jl_value_t *a);
 JL_DLLEXPORT jl_value_t *jl_rint_llvm(jl_value_t *a);
 JL_DLLEXPORT jl_value_t *jl_sqrt_llvm(jl_value_t *a);
+JL_DLLEXPORT jl_value_t *jl_sqrt_llvm_fast(jl_value_t *a);
 JL_DLLEXPORT jl_value_t *jl_abs_float(jl_value_t *a);
 JL_DLLEXPORT jl_value_t *jl_copysign_float(jl_value_t *a, jl_value_t *b);
 JL_DLLEXPORT jl_value_t *jl_flipsign_int(jl_value_t *a, jl_value_t *b);
 
 JL_DLLEXPORT jl_value_t *jl_arraylen(jl_value_t *a);
-int jl_array_store_unboxed(jl_value_t *el_type);
+JL_DLLEXPORT int jl_stored_inline(jl_value_t *el_type);
 JL_DLLEXPORT jl_value_t *(jl_array_data_owner)(jl_array_t *a);
 JL_DLLEXPORT int jl_array_isassigned(jl_array_t *a, size_t i);
 
@@ -850,59 +985,10 @@ extern jl_mutex_t typecache_lock;
 extern jl_mutex_t codegen_lock;
 extern jl_mutex_t safepoint_lock;
 
-// -- gc.c -- //
-
 #if defined(__APPLE__)
 void jl_mach_gc_end(void);
 #endif
 
-#if defined(_OS_WINDOWS_)
-STATIC_INLINE void *jl_malloc_aligned(size_t sz, size_t align)
-{
-    return _aligned_malloc(sz ? sz : 1, align);
-}
-STATIC_INLINE void *jl_realloc_aligned(void *p, size_t sz, size_t oldsz,
-                                       size_t align)
-{
-    (void)oldsz;
-    return _aligned_realloc(p, sz ? sz : 1, align);
-}
-STATIC_INLINE void jl_free_aligned(void *p) JL_NOTSAFEPOINT
-{
-    _aligned_free(p);
-}
-#else
-STATIC_INLINE void *jl_malloc_aligned(size_t sz, size_t align)
-{
-#if defined(_P64) || defined(__APPLE__)
-    if (align <= 16)
-        return malloc(sz);
-#endif
-    void *ptr;
-    if (posix_memalign(&ptr, align, sz))
-        return NULL;
-    return ptr;
-}
-STATIC_INLINE void *jl_realloc_aligned(void *d, size_t sz, size_t oldsz,
-                                       size_t align)
-{
-#if defined(_P64) || defined(__APPLE__)
-    if (align <= 16)
-        return realloc(d, sz);
-#endif
-    void *b = jl_malloc_aligned(sz, align);
-    if (b != NULL) {
-        memcpy(b, d, oldsz > sz ? sz : oldsz);
-        free(d);
-    }
-    return b;
-}
-STATIC_INLINE void jl_free_aligned(void *p) JL_NOTSAFEPOINT
-{
-    free(p);
-}
-#endif
-
 // -- typemap.c -- //
 
 // a descriptor of a jl_typemap_t that gets
diff -pruN 1.3.1+dfsg-1/src/julia-parser.scm 1.4.0+dfsg-1/src/julia-parser.scm
--- 1.3.1+dfsg-1/src/julia-parser.scm	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/src/julia-parser.scm	2020-03-21 16:36:32.000000000 +0000
@@ -38,8 +38,8 @@
 (define prec-dot         '(|.|))
 
 (define prec-names '(prec-assignment
-                     prec-pair prec-conditional prec-lazy-or prec-lazy-and prec-arrow prec-comparison
-                     prec-pipe< prec-pipe> prec-colon prec-plus prec-bitshift prec-times prec-rational
+                     prec-pair prec-conditional prec-arrow prec-lazy-or prec-lazy-and prec-comparison
+                     prec-pipe< prec-pipe> prec-colon prec-plus prec-times prec-rational prec-bitshift
                      prec-power prec-decl prec-dot))
 
 (define trans-op (string->symbol ".'"))
@@ -160,7 +160,10 @@
                          struct
                          module baremodule using import export))
 
-(define initial-reserved-word? (Set initial-reserved-words))
+(define initial-reserved-word?
+  (let ((reserved? (Set initial-reserved-words)))
+    (lambda (s) (and (reserved? s)
+                     (not (and (eq? s 'begin) end-symbol)))))) ; begin == firstindex inside [...]
 
 (define reserved-words (append initial-reserved-words '(end else elseif catch finally true false))) ;; todo: make this more complete
 
@@ -1046,10 +1049,11 @@
           ((eqv? next #\( )
            (take-token s)
            (let* ((opspc  (ts:space? s))
+                  (lno    (input-port-line (ts:port s)))
                   (parens (parse-paren- s #t)))
              (if (cdr parens) ;; found an argument list
                  (if opspc
-                     (disallowed-space op #\( )
+                     (disallowed-space-error lno op #\( )
                      (parse-factor-with-initial-ex
                       s
                       (fix-syntactic-unary (cons op (tuple-to-arglist (car parens))))))
@@ -1135,9 +1139,14 @@
         (parse-where-chain s decl-sig)
         decl-sig)))
 
-(define (disallowed-space ex t)
+(define (disallowed-space-error lno ex t)
   (error (string "space before \"" t "\" not allowed in \""
-                 (deparse ex) " " t "\"")))
+                 (deparse ex) " " t "\" at "
+                 current-filename ":" lno)))
+
+(define (disallow-space s ex t)
+  (if (ts:space? s)
+      (disallowed-space-error (input-port-line (ts:port s)) ex t)))
 
 ;; string macro suffix for given delimiter t
 (define (macsuffix t)
@@ -1156,7 +1165,7 @@
           ex
           (case t
             ((#\( )
-             (if (ts:space? s) (disallowed-space ex t))
+             (disallow-space s ex t)
              (take-token s)
              (let ((c (let ((al (parse-call-arglist s #\) )))
                         (receive
@@ -1177,7 +1186,7 @@
                         c)
                    (loop c))))
             ((#\[ )
-             (if (ts:space? s) (disallowed-space ex t))
+             (disallow-space s ex t)
              (take-token s)
              ;; ref is syntax, so we can distinguish
              ;; a[i] = x  from
@@ -1197,14 +1206,13 @@
                           (loop (list* 'typed_comprehension ex (cdr al))))
                          (else (error "unknown parse-cat result (internal error)")))))))
             ((|.|)
-             (if (ts:space? s) (disallowed-space ex t))
+             (disallow-space s ex t)
              (take-token s)
              (loop
               (cond ((eqv? (peek-token s) #\()
                      (begin
                        (if (ts:space? s)
-                           (error (string "space before \"(\" not allowed in \""
-                                          (deparse ex) ". (\"")))
+                           (disallow-space s `(|.| ,ex (quote ||)) #\())
                        (take-token s)
                        `(|.| ,ex (tuple ,@(parse-call-arglist s #\) )))))
                     ((eqv? (peek-token s) ':)
@@ -1231,7 +1239,7 @@
              (loop (list t ex)))
             ((|.'|) (error "the \".'\" operator is discontinued"))
             ((#\{ )
-             (if (ts:space? s) (disallowed-space ex t))
+             (disallow-space s ex t)
              (take-token s)
              (loop (list* 'curly ex (parse-call-arglist s #\} ))))
             ((#\" #\`)
@@ -1301,7 +1309,7 @@
   (if (reserved-word? (peek-token s))
       (error (string "invalid type name \"" (take-token s) "\"")))
   (let ((sig (parse-subtype-spec s)))
-    (begin0 (list 'struct (if mut? 'true 'false) sig (parse-block s))
+    (begin0 (list 'struct (if mut? '(true) '(false)) sig (parse-block s))
             (expect-end s word))))
 
 ;; consume any number of line endings from a token stream
@@ -1314,8 +1322,6 @@
 
 ;; parse expressions or blocks introduced by syntactic reserved words
 (define (parse-resword s word)
-  (if (and (eq? word 'begin) end-symbol)
-      (parser-depwarn s "\"begin\" inside indexing expression" ""))
   (with-bindings
    ((expect-end-current-line (input-port-line (ts:port s))))
    (with-normal-context
@@ -1467,8 +1473,8 @@
             (take-token s)
             (cond
              ((eq? nxt 'end)
-              (list* 'try try-block (or catchv 'false)
-                     (or catchb (if finalb 'false (error "try without catch or finally")))
+              (list* 'try try-block (or catchv '(false))
+                     (or catchb (if finalb '(false) (error "try without catch or finally")))
                      (if finalb (list finalb) '())))
              ((and (eq? nxt 'catch)
                    (not catchb))
@@ -1482,8 +1488,7 @@
                           finalb)
                     (let* ((loc (line-number-node s))
                            (var (if nl #f (parse-eq* s)))
-                           (var? (and (not nl) (or (and (symbol? var) (not (eq? var 'false))
-                                                        (not (eq? var 'true)))
+                           (var? (and (not nl) (or (symbol? var)
                                                    (and (length= var 2) (eq? (car var) '$))
                                                    (error (string "invalid syntax \"catch " (deparse var) "\"")))))
                            (catch-block (if (eq? (require-token s) 'finally)
@@ -1497,7 +1502,7 @@
                                                    (linenum? (cadr catch-block)))
                                               '()
                                               (cdr catch-block))))
-                            (if var? var 'false)
+                            (if var? var '(false))
                             finalb)))))
              ((and (eq? nxt 'finally)
                    (not finalb))
@@ -1528,7 +1533,7 @@
           (if (reserved-word? name)
               (error (string "invalid module name \"" name "\"")))
           (expect-end s word)
-          (list 'module (if (eq? word 'module) 'true 'false) name
+          (list 'module (if (eq? word 'module) '(true) '(false)) name
                 `(block ,loc ,@(cdr body)))))
        ((export)
         (let ((es (map macrocall-to-atsym
@@ -1600,9 +1605,9 @@
     (let ((nxt (peek-token s)))
       (cond
        ((eq? nxt '|.|)
-        (if (ts:space? s) (disallowed-space word nxt))
+        (disallow-space s (car path) nxt)
         (take-token s)
-        (loop (cons (macrocall-to-atsym (parse-unary-prefix s)) path)))
+        (loop (cons (unquote (macrocall-to-atsym (parse-unary-prefix s))) path)))
        ((or (memv nxt '(#\newline #\; #\, :))
             (eof-object? nxt))
         (cons '|.| (reverse path)))
@@ -1679,10 +1684,7 @@
   (and (pair? lst) (pair? (car lst)) (eq? (caar lst) 'parameters)))
 
 (define (to-kws lst)
-  (map (lambda (x) (if (assignment? x)
-                       `(kw ,@(cdr x))
-                       x))
-       lst))
+  (map =-to-kw lst))
 
 ;; like parse-arglist, but with `for` parsed as a generator
 (define (parse-call-arglist s closer)
@@ -1906,7 +1908,7 @@
 ;; convert an arglist to a tuple or block expr
 ;; leading-semi? means we saw (; ...)
 ;; comma? means there was a comma after the first expression
-(define (arglist-to-tuple leading-semi? comma? args . first)
+(define (arglist-to-tuple s leading-semi? comma? args . first)
   (if (and (pair? first) (null? args) (not leading-semi?) (not comma?))
       `(block ,@first)  ;; this case is (x;)
       (or (and (not comma?) (length= args 1) (pair? (car args)) (eq? (caar args) 'parameters)
@@ -1914,9 +1916,14 @@
                  (and blk (or (and (not leading-semi?)
                                    `(block ,@first ,@blk))
                               (and (null? first) (null? blk)
-                                   `(block))))))  ;; all semicolons inside ()
+                                   ;; all semicolons inside ()
+                                   (if (length= (car args) 1)
+                                       (begin (parser-depwarn s "(;)" "begin end")
+                                              ;; should eventually be (tuple (parameters))
+                                              `(block))
+                                       `(block)))))))
           (and (null? first) (null? args) (not comma?)
-               `(block))  ;; this case is (;)
+               (error "unreachable"))
           (rm-linenums
            (if (and (pair? args) (pair? (car args)) (eq? (caar args) 'parameters))
                `(tuple ,(car args) ,@first ,@(map kw-to-= (cdr args)))
@@ -1970,7 +1977,7 @@
        (take-token s)  ;; take #\)
        '(|::| . #f))
       ((eqv? nxt #\;)
-       (let ((ex (arglist-to-tuple #t #f (parse-arglist s #\) ))))
+       (let ((ex (arglist-to-tuple s #t #f (parse-arglist s #\) ))))
          (cons ex (eq? (car ex) 'tuple))))
       (else
        ;; here we parse the first subexpression separately, so
@@ -1987,10 +1994,11 @@
                ((eqv? t #\,)
                 ;; tuple (x,) (x,y) etc.
                 (take-token s)
-                (cons (arglist-to-tuple #f #t (parse-arglist s #\) ) ex)
+                (cons (arglist-to-tuple s #f #t (parse-arglist s #\) ) ex)
                       #t))
                ((eqv? t #\;)
                 (cons (arglist-to-tuple
+                       s
                        #f
                        ;; consider `(x...; ` the start of an arglist, since it's not useful as a block
                        (vararg? ex)
@@ -2285,22 +2293,23 @@
                       (if (closing-token? t)
                           (error (string "unexpected \"" (take-token s) "\"")))))
            (take-token s)
-           (if (and (eq? t 'var)
-                    (if (or (ts:pbtok s) (ts:last-tok s))
-                        (and (eqv? (peek-token s) #\") (not (ts:space? s)))
-                        ;; Hack: avoid peek-token if possible to preserve
-                        ;; (io.pos (ts:port s)) for non-greedy Meta.parse
-                        (eqv? (peek-char (ts:port s)) #\")))
-             (begin
-               ;; var"funky identifier" syntax
-               (peek-token s)
-               (take-token s) ;; leading "
-               (let ((str (parse-raw-literal s #\"))
-                     (nxt (peek-token s)))
-                 (if (and (symbol? nxt) (not (operator? nxt)) (not (ts:space? s)))
-                     (error (string "suffix not allowed after `var\"" str "\"`")))
-                 (symbol str)))
-             t))
+           (cond ((and (eq? t 'var)
+                       (if (or (ts:pbtok s) (ts:last-tok s))
+                           (and (eqv? (peek-token s) #\") (not (ts:space? s)))
+                           ;; Hack: avoid peek-token if possible to preserve
+                           ;; (io.pos (ts:port s)) for non-greedy Meta.parse
+                           (eqv? (peek-char (ts:port s)) #\")))
+                  ;; var"funky identifier" syntax
+                  (peek-token s)
+                  (take-token s) ;; leading "
+                  (let ((str (parse-raw-literal s #\"))
+                        (nxt (peek-token s)))
+                    (if (and (symbol? nxt) (not (operator? nxt)) (not (ts:space? s)))
+                        (error (string "suffix not allowed after `var\"" str "\"`")))
+                    (symbol str)))
+                 ((eq? t 'true)  '(true))
+                 ((eq? t 'false) '(false))
+                 (else t)))
 
           ;; parens or tuple
           ((eqv? t #\( )
@@ -2342,8 +2351,7 @@
           ((eqv? t #\@)
            (take-token s)
            (let ((nxt (peek-token s)))
-             (if (ts:space? s)
-                 (disallowed-space '@ nxt)))
+             (disallow-space s '@ nxt))
            (with-space-sensitive
             (let ((startloc  (line-number-node s))
                   (head (if (eq? (peek-token s) '|.|)
diff -pruN 1.3.1+dfsg-1/src/julia-syntax.scm 1.4.0+dfsg-1/src/julia-syntax.scm
--- 1.3.1+dfsg-1/src/julia-syntax.scm	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/src/julia-syntax.scm	2020-03-21 16:36:32.000000000 +0000
@@ -10,7 +10,7 @@
       a))
 (define (fix-arglist l (unused #t))
   (if (any vararg? (butlast l))
-      (error "invalid ... on non-final argument"))
+      (error "invalid \"...\" on non-final argument"))
   (map (lambda (a)
          (cond ((and (pair? a) (eq? (car a) 'kw))
                 `(kw ,(fill-missing-argname (cadr a) unused) ,(caddr a)))
@@ -86,7 +86,7 @@
 (define (expand-compare-chain e)
   (car (expand-vector-compare e)))
 
-;; return the appropriate computation for an `end` symbol for indexing
+;; return the appropriate computation for a `begin` or `end` symbol for indexing
 ;; the array `a` in the `n`th index.
 ;; `tuples` are a list of the splatted arguments that precede index `n`
 ;; `last` = is this last index?
@@ -101,20 +101,31 @@
                                  tuples))))
             `(call (top lastindex) ,a ,dimno))))
 
-;; replace `end` for the closest ref expression, so doesn't go inside nested refs
-(define (replace-end ex a n tuples last)
+(define (begin-val a n tuples last)
+  (if (null? tuples)
+      (if (and last (= n 1))
+          `(call (top firstindex) ,a)
+          `(call (top first) (call (top axes) ,a ,n)))
+      (let ((dimno `(call (top +) ,(- n (length tuples))
+                          ,.(map (lambda (t) `(call (top length) ,t))
+                                 tuples))))
+            `(call (top first) (call (top axes) ,a ,dimno)))))
+
+;; replace `begin` and `end` for the closest ref expression, so doesn't go inside nested refs
+(define (replace-beginend ex a n tuples last)
   (cond ((eq? ex 'end)                (end-val a n tuples last))
+        ((eq? ex 'begin)              (begin-val a n tuples last))
         ((or (atom? ex) (quoted? ex)) ex)
         ((eq? (car ex) 'ref)
          ;; inside ref only replace within the first argument
-         (list* 'ref (replace-end (cadr ex) a n tuples last)
+         (list* 'ref (replace-beginend (cadr ex) a n tuples last)
                 (cddr ex)))
         (else
          (cons (car ex)
-               (map (lambda (x) (replace-end x a n tuples last))
+               (map (lambda (x) (replace-beginend x a n tuples last))
                     (cdr ex))))))
 
-;; go through indices and replace the `end` symbol
+;; go through indices and replace the `begin` or `end` symbol
 ;; a = array being indexed, i = list of indices
 ;; returns (values index-list stmts) where stmts are statements that need
 ;; to execute first.
@@ -133,17 +144,17 @@
                   (loop (cdr lst) (+ n 1)
                         stmts
                         (cons (cadr idx) tuples)
-                        (cons `(... ,(replace-end (cadr idx) a n tuples last))
+                        (cons `(... ,(replace-beginend (cadr idx) a n tuples last))
                               ret))
                   (let ((g (make-ssavalue)))
                     (loop (cdr lst) (+ n 1)
-                          (cons `(= ,g ,(replace-end (cadr idx) a n tuples last))
+                          (cons `(= ,g ,(replace-beginend (cadr idx) a n tuples last))
                                 stmts)
                           (cons g tuples)
                           (cons `(... ,g) ret))))
               (loop (cdr lst) (+ n 1)
                     stmts tuples
-                    (cons (replace-end idx a n tuples last) ret)))))))
+                    (cons (replace-beginend idx a n tuples last) ret)))))))
 
 ;; GF method does not need to keep decl expressions on lambda args
 ;; except for rest arg
@@ -334,7 +345,7 @@
                                                            (cons 'list (map car sparams)))
                                                       ,(if (null? loc) 0 (cadr loc))
                                                       (inert ,(if (null? loc) 'none (caddr loc)))
-                                                      false)))))
+                                                      (false))))))
                              (list gf))
                            '()))
             (types (llist-types argl))
@@ -406,7 +417,10 @@
          (restkw (let ((l (last kargl)))
                    (if (vararg? l)
                        (list (cadr l)) '())))
-         (kargl (if (null? restkw) kargl (butlast kargl)))
+         (kargl (let ((kws (if (null? restkw) kargl (butlast kargl))))
+                  (if (any vararg? kws)
+                      (error "invalid \"...\" on non-final keyword argument"))
+                  kws))
          ;; the keyword::Type expressions
          (vars     (map cadr kargl))
          ;; keyword default values
@@ -440,7 +454,7 @@
                                      (string (current-julia-module-counter)))))))
       ;; this is a hack: nest these statements inside a call so they get closure
       ;; converted together, allowing all needed types to be defined before any methods.
-      `(call (core ifelse) false false (block
+      `(call (core ifelse) (false) (false) (block
         ;; forward-declare function so its type can occur in the signature of the inner method below
         ,@(if (or (symbol? name) (globalref? name)) `((method ,name)) '())
 
@@ -453,7 +467,8 @@
             ,@not-optional ,@vararg)
           (insert-after-meta `(block
                                ,@stmts)
-                             annotations)
+                             (cons `(meta nkw ,(+ (length vars) (length restkw)))
+                                   annotations))
           rett)
 
         ;; call with no keyword args
@@ -480,6 +495,7 @@
              ,(if (any kwarg? pargl) (gensy) UNUSED)
              (call (core kwftype) ,ftype)) ,kw ,@pargl ,@vararg)
           `(block
+            ,@(filter linenum? prologue)
             ,(scopenest
               keynames
               (map (lambda (v dflt)
@@ -737,7 +753,7 @@
                    (if (call (top ult_int) ,(length field-names) ,nf)
                        (call (core throw) (call (top ArgumentError)
                                                 ,(string "new: too many arguments (expected " (length field-names) ")"))))
-                   (new ,tn ,@(map (lambda (fld fty) (field-convert fld fty `(call (core getfield) ,argt ,(+ fld 1) false)))
+                   (new ,tn ,@(map (lambda (fld fty) (field-convert fld fty `(call (core getfield) ,argt ,(+ fld 1) (false))))
                                    (iota (length field-names)) (list-head field-types (length field-names))))))))
           (else
             `(block
@@ -1236,13 +1252,13 @@
            (let ((finalb (cadddr (cdr e))))
              (expand-forms
               `(tryfinally
-                ,(if (not (eq? catchb 'false))
+                ,(if (not (equal? catchb '(false)))
                      `(try ,tryb ,var ,catchb)
                      `(scope-block ,tryb))
                 (scope-block ,finalb)))))
           ((length= e 4)
            (expand-forms
-            (if (and (symbol-like? var) (not (eq? var 'false)))
+            (if (symbol-like? var)
                 `(trycatch (scope-block ,tryb)
                            (scope-block
                             (block (= ,var (the_exception))
@@ -1391,37 +1407,25 @@
 ;; returns a pair (expr . assignments)
 ;; where 'assignments' is a list of needed assignment statements
 (define (remove-argument-side-effects e (tup #f))
-  (if
-   (not (pair? e))
-   (cons e '())
-   (let ((a '()))
-     (cons
-      (cons
-       (car e)
-       (map (lambda (x)
-              (cond ((effect-free? x)  x)
-                    ((or (eq? (car x) '...) (eq? (car x) '&))
-                     (if (effect-free? (cadr x))
-                         x
-                         (let ((g (make-ssavalue)))
-                           (begin (set! a (cons `(= ,g ,(cadr x)) a))
-                                  `(,(car x) ,g)))))
-                    ((or (eq? (car x) 'kw) (and tup (eq? (car x) '=)))
-                     (if (effect-free? (caddr x))
-                         x
-                         (let ((g (make-ssavalue)))
-                           (begin (set! a (cons `(= ,g ,(caddr x)) a))
-                                  `(,(car x) ,(cadr x) ,g)))))
-                    ((eq? (car x) 'tuple)
-                     (let ((tmp (remove-argument-side-effects x #t)))
-                       (set! a (revappend (cdr tmp) a))
-                       (car tmp)))
-                    (else
-                     (let ((g (make-ssavalue)))
-                       (begin (set! a (cons `(= ,g ,x) a))
-                              g)))))
-            (cdr e)))
-      (reverse a)))))
+  (if (not (pair? e))
+      (cons e '())
+      (let ((a '()))
+        (define (arg-to-temp x)
+          (cond ((effect-free? x)  x)
+                ((or (eq? (car x) '...) (eq? (car x) '&))
+                 `(,(car x) ,(arg-to-temp (cadr x))))
+                ((or (eq? (car x) 'kw) (and tup (eq? (car x) '=)))
+                 `(,(car x) ,(cadr x) ,(arg-to-temp (caddr x))))
+                ((eq? (car x) 'tuple)
+                 (let ((tmp (remove-argument-side-effects x #t)))
+                   (set! a (revappend (cdr tmp) a))
+                   (car tmp)))
+                (else
+                 (let ((g (make-ssavalue)))
+                   (begin (set! a (cons `(= ,g ,x) a))
+                          g)))))
+        (cons (cons (car e) (map arg-to-temp (cdr e)))
+              (reverse a)))))
 
 (define (lower-kw-call f args)
   (let* ((para (if (has-parameters? args) (cdar args) '()))
@@ -1483,7 +1487,7 @@
   (let ((a    (cadr e))
         (idxs (cddr e)))
     (let* ((reuse (and (pair? a)
-                       (contains (lambda (x) (eq? x 'end))
+                       (contains (lambda (x) (or (eq? x 'begin) (eq? x 'end)))
                                  idxs)))
            (arr   (if reuse (make-ssavalue) a))
            (stmts (if reuse `((= ,arr ,a)) '())))
@@ -1495,7 +1499,7 @@
 
 (define (expand-update-operator op op= lhs rhs . declT)
   (cond ((and (pair? lhs) (eq? (car lhs) 'ref))
-         ;; expand indexing inside op= first, to remove "end" and ":"
+         ;; expand indexing inside op= first, to remove "begin", "end", and ":"
          (let* ((ex (partially-expand-ref lhs))
                 (stmts (butlast (cdr ex)))
                 (refex (last    (cdr ex)))
@@ -1527,18 +1531,18 @@
   (let ((e (cdr (flatten-ex '&& e))))
     (let loop ((tail e))
       (if (null? tail)
-          'true
+          '(true)
           (if (null? (cdr tail))
               (car tail)
               `(if ,(car tail)
                    ,(loop (cdr tail))
-                   false))))))
+                   (false)))))))
 
 (define (expand-or e)
   (let ((e (cdr (flatten-ex '|\|\|| e))))
     (let loop ((tail e))
       (if (null? tail)
-          'false
+          '(false)
           (if (null? (cdr tail))
               (car tail)
               (if (symbol-like? (car tail))
@@ -1608,22 +1612,28 @@
                       (else
                        `(,@(map (lambda (v) `(local ,v)) myvars)
                          (= (tuple ,@vars) ,argname))))))
-    (if (and (null? splat)
-             (length= expr 3) (eq? (car expr) 'call)
-             (eq? (caddr expr) argname)
-             (not (dotop-named? (cadr expr)))
-             (not (expr-contains-eq argname (cadr expr))))
-        (cadr expr)  ;; eta reduce `x->f(x)` => `f`
-        (let ((expr (cond ((and flat (pair? expr) (eq? (car expr) 'generator))
-                           (expand-generator expr #f (delete-duplicates (append outervars myvars))))
-                          ((and flat (pair? expr) (eq? (car expr) 'flatten))
-                           (expand-generator (cadr expr) #t (delete-duplicates (append outervars myvars))))
-                          ((pair? outervars)
-                           `(let (block ,@(map (lambda (v) `(= ,v ,v)) (filter (lambda (x) (not (underscore-symbol? x)))
-                                                                               outervars)))
-                              ,expr))
-                          (else expr))))
-          `(-> ,argname (block ,@splat ,expr))))))
+    (cond
+     ((eq? expr argname)
+      ;; use `identity` for x->x
+      `(top identity))
+     ((and (null? splat)
+           (length= expr 3) (eq? (car expr) 'call)
+           (eq? (caddr expr) argname)
+           (not (dotop-named? (cadr expr)))
+           (not (expr-contains-eq argname (cadr expr))))
+      ;; eta reduce `x->f(x)` => `f`
+      (cadr expr))
+     (else
+      (let ((expr (cond ((and flat (pair? expr) (eq? (car expr) 'generator))
+                         (expand-generator expr #f (delete-duplicates (append outervars myvars))))
+                        ((and flat (pair? expr) (eq? (car expr) 'flatten))
+                         (expand-generator (cadr expr) #t (delete-duplicates (append outervars myvars))))
+                        ((pair? outervars)
+                         `(let (block ,@(map (lambda (v) `(= ,v ,v)) (filter (lambda (x) (not (underscore-symbol? x)))
+                                                                             outervars)))
+                            ,expr))
+                        (else expr))))
+        `(-> ,argname (block ,@splat ,expr)))))))
 
 (define (expand-generator e flat outervars)
   (let* ((expr  (cadr e))
@@ -1756,6 +1766,10 @@
          (dups (has-dups names)))
     (if dups
         (error (dup-error-fn (car dups)))))
+  (define (not-vararg x)
+    (if (vararg? x)
+        (error (string "\"...\" expression cannot be used as " name-str " value"))
+        x))
   (define (to-nt n v)
     (if (null? n)
         #f
@@ -1771,11 +1785,14 @@
              (current-vals  '())
              (expr          #f))
     (if (null? L)
-        (merge expr (to-nt current-names current-vals))
+        (or (merge expr (to-nt current-names current-vals))
+            ;; if that result is #f the named tuple is empty
+            '(call (core NamedTuple)))
         (let ((el (car L)))
           (cond ((or (assignment? el) (kwarg? el))
                  (if (not (symbol? (cadr el)))
                      (error (string "invalid " name-str " name \"" (deparse (cadr el)) "\"")))
+                 (not-vararg (caddr el))
                  (loop (cdr L)
                        (cons (cadr el) current-names)
                        (cons (caddr el) current-vals)
@@ -1797,7 +1814,7 @@
                        '()
                        '()
                        (merge (merge expr (to-nt current-names current-vals))
-                              (named-tuple-expr (list (caddr el)) (list (cadddr el))))))
+                              (named-tuple-expr (list (caddr el)) (list (not-vararg (cadddr el)))))))
                 ((vararg? el)
                  (loop (cdr L)
                        '()
@@ -1818,7 +1835,7 @@
       `(= ,lhs ,rhs)))
 
 (define (expand-forms e)
-  (if (or (atom? e) (memq (car e) '(quote inert top core globalref outerref line module toplevel ssavalue null meta using import export)))
+  (if (or (atom? e) (memq (car e) '(quote inert top core globalref outerref line module toplevel ssavalue null true false meta using import export)))
       e
       (let ((ex (get expand-table (car e) #f)))
         (if ex
@@ -2097,7 +2114,7 @@
                                            (tuple-wrap (cdr a) '())))
                                 (tuple-wrap (cdr a) (cons x run))))))
                     (expand-forms
-                     `(call (core _apply) ,f ,@(tuple-wrap argl '())))))
+                     `(call (core _apply_iterate) (top iterate) ,f ,@(tuple-wrap argl '())))))
 
                  ((and (eq? (identifier-name f) '^) (length= e 4) (integer? (cadddr e)))
                   (expand-forms
@@ -2301,7 +2318,18 @@
                       ;; TODO: this is a hack to lower simple comprehensions to loops very
                       ;; early, to greatly reduce the # of functions and load on the compiler
                       (lower-comprehension (cadr e) (cadr (caddr e)) ranges))))
-          `(call (top collect) ,(cadr e) ,(caddr e)))))))
+          `(call (top collect) ,(cadr e) ,(caddr e)))))
+
+    'gc_preserve
+    (lambda (e)
+      (let* ((s (make-ssavalue))
+             (r (gensy)))
+        `(block
+          (= ,s (gc_preserve_begin ,@(cddr e)))
+          (= ,r ,(expand-forms (cadr e)))
+          (gc_preserve_end ,s)
+          ,r)))
+    ))
 
 (define (has-return? e)
   (expr-contains-p return? e (lambda (x) (not (function-def? x)))))
@@ -2332,7 +2360,7 @@
     (define (construct-loops itrs iv)
       (if (null? itrs)
           `(block (= ,oneresult ,expr)
-                  (inbounds true)
+                  (inbounds (true))
                   (if ,szunk
                       (call (top push!) ,result ,oneresult)
                       (call (top setindex!) ,result ,oneresult ,idx))
@@ -2447,7 +2475,7 @@
 (define (all-local-names scope)
   (define (all-lists s)
     (if s
-        (list* (scope:args s) (scope:locals s) (all-lists (scope:prev s)))
+        (list* (scope:args s) (scope:sp s) (scope:locals s) (all-lists (scope:prev s)))
         '()))
   (apply append (all-lists scope)))
 
@@ -2497,6 +2525,10 @@
                                    (call (top setindex!) ,d ,var (quote ,v)))))
                           names)
                    ,d)))
+        ((eq? (car e) 'islocal)
+         (if (memq (var-kind (cadr e) scope) '(global none))
+             '(false)
+             '(true)))
         ((eq? (car e) 'lambda)
          (let* ((args (lam:vars e))
                 (body (resolve-scopes- (lam:body e) (make-scope e args '() '() sp '() scope))))
@@ -2592,7 +2624,7 @@
 
 ;; compute set of variables referenced in a lambda but not bound by it
 (define (free-vars- e tab)
-  (cond ((or (eq? e 'true) (eq? e 'false) (eq? e UNUSED) (underscore-symbol? e)) tab)
+  (cond ((or (eq? e UNUSED) (underscore-symbol? e)) tab)
         ((symbol? e) (put! tab e #t))
         ((and (pair? e) (eq? (car e) 'outerref)) tab)
         ((and (pair? e) (eq? (car e) 'break-block)) (free-vars- (caddr e) tab))
@@ -2750,7 +2782,7 @@ f(x) = yt(x)
                (struct_type ,name (call (core svec) ,@P)
                             (call (core svec) ,@(map quotify fields))
                             ,super
-                            (call (core svec) ,@types) false ,(length fields))
+                            (call (core svec) ,@types) (false) ,(length fields))
                (return (null))))))))
 
 (define (type-for-closure name fields super)
@@ -2761,7 +2793,7 @@ f(x) = yt(x)
                                 (call (core svec) ,@(map quotify fields))
                                 ,super
                                 (call (core svec) ,@(map (lambda (v) '(core Box)) fields))
-                                false ,(length fields))
+                                (false) ,(length fields))
                    (return (null)))))))
 
 
@@ -2777,7 +2809,7 @@ f(x) = yt(x)
 ;          (struct_type ,name (call (core svec) ,@P)
 ;                       (call (core svec) ,@(map quotify fields))
 ;                       ,super
-;                       (call (core svec) ,@types) false ,(length fields)))))
+;                       (call (core svec) ,@types) (false) ,(length fields)))))
 
 ;; ... and without parameters
 ;(define (type-for-closure name fields super)
@@ -2787,7 +2819,7 @@ f(x) = yt(x)
 ;                 (call (core svec) ,@(map quotify fields))
 ;                 ,super
 ;                 (call (core svec) ,@(map (lambda (v) 'Any) fields))
-;                 false ,(length fields))))
+;                 (false) ,(length fields))))
 
 
 (define (vinfo:not-capt vi)
@@ -2976,7 +3008,7 @@ f(x) = yt(x)
          meta inbounds boundscheck loopinfo decl aliasscope popaliasscope
          struct_type abstract_type primitive_type thunk with-static-parameters
          global globalref outerref const-if-global
-         const null ssavalue isdefined toplevel module lambda error
+         const null true false ssavalue isdefined toplevel module lambda error
          gc_preserve_begin gc_preserve_end import using export)))
 
 (define (local-in? s lam)
@@ -3163,7 +3195,7 @@ f(x) = yt(x)
        ((atom? e) e)
        (else
         (case (car e)
-          ((quote top core globalref outerref line break inert module toplevel null meta) e)
+          ((quote top core globalref outerref line break inert module toplevel null true false meta) e)
           ((=)
            (let ((var (cadr e))
                  (rhs (cl-convert (caddr e) fname lam namemap defined toplevel interp)))
@@ -3197,7 +3229,7 @@ f(x) = yt(x)
                                           `($ (call (core QuoteNode) ,sym))
                                           `(call (core getfield) ,fname (inert ,sym)))))
                           `(call (core isdefined) ,access (inert contents)))
-                        'true))
+                        '(true)))
                    (vi
                     (if (and (vinfo:asgn vi) (vinfo:capt vi))
                         `(call (core isdefined) ,sym (inert contents))
@@ -3644,7 +3676,7 @@ f(x) = yt(x)
     ;; `tail` means we are in tail position, where a value needs to be `return`ed
     ;; from the current function.
     (define (compile e break-labels value tail (linearize-args #t))
-      (if (or (not (pair? e)) (memq (car e) '(null ssavalue quote inert top core copyast the_exception $
+      (if (or (not (pair? e)) (memq (car e) '(null true false ssavalue quote inert top core copyast the_exception $
                                                    globalref outerref cdecl stdcall fastcall thiscall llvmcall)))
           (let ((e1 (if (and arg-map (symbol? e))
                         (get arg-map e e)
@@ -3656,7 +3688,6 @@ f(x) = yt(x)
                 (error (string "all-underscore identifier used as rvalue" (format-loc current-loc))))
             (cond (tail  (emit-return e1))
                   (value e1)
-                  ((or (eq? e1 'true) (eq? e1 'false)) #f)
                   ((symbol? e1) (emit e1) #f)  ;; keep symbols for undefined-var checking
                   ((and (pair? e1) (eq? (car e1) 'outerref)) (emit e1) #f)  ;; keep globals for undefined-var checking
                   ((and (pair? e1) (eq? (car e1) 'globalref)) (emit e1) #f) ;; keep globals for undefined-var checking
@@ -3940,7 +3971,7 @@ f(x) = yt(x)
                                  (let ((l  (make-ssavalue)))
                                    (emit `(= ,l ,(compile lam break-labels #t #f)))
                                    l))))
-                   (emit `(method ,(or (cadr e) 'false) ,sig ,lam))
+                   (emit `(method ,(or (cadr e) '(false)) ,sig ,lam))
                    (if value (compile '(null) break-labels value tail)))
                  (cond (tail  (emit-return e))
                        (value e)
@@ -3989,10 +4020,8 @@ f(x) = yt(x)
              '(null))
 
             ((gc_preserve_begin)
-             (let ((s    (make-ssavalue))
-                   (args (compile-args (cdr e) break-labels linearize-args)))
-               (emit `(= ,s ,(cons (car e) args)))
-               s))
+             (let ((args (compile-args (cdr e) break-labels linearize-args)))
+               (cons (car e) args)))
 
             ;; metadata expressions
             ((line meta inbounds loopinfo gc_preserve_end aliasscope popaliasscope)
@@ -4013,6 +4042,11 @@ f(x) = yt(x)
                (if (and tail (not have-ret?))
                    (emit-return '(null)))
                '(null)))
+
+            ;; unsupported assignment operators
+            ((≔ ⩴ ≕ :=)
+             (error (string "unsupported assignment operator \"" (deparse (car e)) "\"")))
+
             ((error)
              (error (cadr e)))
             (else
diff -pruN 1.3.1+dfsg-1/src/julia_threads.h 1.4.0+dfsg-1/src/julia_threads.h
--- 1.3.1+dfsg-1/src/julia_threads.h	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/src/julia_threads.h	2020-03-21 16:36:32.000000000 +0000
@@ -155,7 +155,7 @@ typedef struct {
     jl_gc_mark_data_t *data_stack;
 } jl_gc_mark_cache_t;
 
-typedef struct _jl_excstack_t jl_excstack_t;
+struct _jl_bt_element_t;
 // This includes all the thread local states we care about for a thread.
 // Changes to TLS field types must be reflected in codegen.
 #define JL_MAX_BT_SIZE 80000
@@ -193,7 +193,7 @@ struct _jl_tls_states_t {
     // Temp storage for exception thrown in signal handler. Not rooted.
     struct _jl_value_t *sig_exception;
     // Temporary backtrace buffer. Scanned for gc roots when bt_size > 0.
-    uintptr_t *bt_data; // JL_MAX_BT_SIZE + 1 elements long
+    struct _jl_bt_element_t *bt_data; // JL_MAX_BT_SIZE + 1 elements long
     size_t bt_size;    // Size for backtrace in transit in bt_data
     // Atomically set by the sender, reset by the handler.
     volatile sig_atomic_t signal_request;
diff -pruN 1.3.1+dfsg-1/src/llvm-alloc-opt.cpp 1.4.0+dfsg-1/src/llvm-alloc-opt.cpp
--- 1.3.1+dfsg-1/src/llvm-alloc-opt.cpp	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/src/llvm-alloc-opt.cpp	2020-03-21 16:36:32.000000000 +0000
@@ -24,6 +24,10 @@
 #include <llvm/Support/Debug.h>
 #include <llvm/Transforms/Utils/PromoteMemToReg.h>
 
+#if JL_LLVM_VERSION >= 100000
+#include <llvm/InitializePasses.h>
+#endif
+
 #include "codegen_shared.h"
 #include "julia.h"
 #include "julia_internal.h"
@@ -881,25 +885,38 @@ void Optimizer::replaceIntrinsicUseWith(
         args[i] = arg == orig_i ? new_i : arg;
         argTys[i] = args[i]->getType();
     }
+    auto oldfType = call->getFunctionType();
+    auto newfType = FunctionType::get(
+            oldfType->getReturnType(),
+            makeArrayRef(argTys).slice(0, oldfType->getNumParams()),
+            oldfType->isVarArg());
 
     // Accumulate an array of overloaded types for the given intrinsic
+    // and compute the new name mangling schema
     SmallVector<Type*, 4> overloadTys;
     {
         SmallVector<Intrinsic::IITDescriptor, 8> Table;
         getIntrinsicInfoTableEntries(ID, Table);
         ArrayRef<Intrinsic::IITDescriptor> TableRef = Table;
-        auto oldfType = call->getFunctionType();
+#if JL_LLVM_VERSION >= 90000
+        auto res = Intrinsic::matchIntrinsicSignature(newfType, TableRef, overloadTys);
+        assert(res == Intrinsic::MatchIntrinsicTypes_Match);
+        (void)res;
+#else
         bool res = Intrinsic::matchIntrinsicType(oldfType->getReturnType(), TableRef, overloadTys);
         assert(!res);
-        for (auto Ty : argTys) {
+        for (auto Ty : newfType->params()) {
             res = Intrinsic::matchIntrinsicType(Ty, TableRef, overloadTys);
             assert(!res);
         }
-        res = Intrinsic::matchIntrinsicVarArg(oldfType->isVarArg(), TableRef);
-        assert(!res);
         (void)res;
+#endif
+        bool matchvararg = Intrinsic::matchIntrinsicVarArg(newfType->isVarArg(), TableRef);
+        assert(!matchvararg);
+        (void)matchvararg;
     }
     auto newF = Intrinsic::getDeclaration(call->getModule(), ID, overloadTys);
+    assert(newF->getFunctionType() == newfType);
     newF->setCallingConv(call->getCallingConv());
     auto newCall = CallInst::Create(newF, args, "", call);
     newCall->setTailCallKind(call->getTailCallKind());
@@ -921,8 +938,8 @@ void Optimizer::moveToStack(CallInst *or
     // SSA from it are live when we run the allocation again.
     // It is now safe to promote the allocation to an entry block alloca.
     size_t align = 1;
-    // TODO make codegen handling of alignment consistent and pass that as a parameter
-    // to the allocation function directly.
+    // TODO: This is overly conservative. May want to instead pass this as a
+    //       parameter to the allocation function directly.
     if (sz > 1)
         align = MinAlign(JL_SMALL_BYTE_ALIGNMENT, NextPowerOf2(sz));
     // No debug info for prolog instructions
@@ -939,12 +956,12 @@ void Optimizer::moveToStack(CallInst *or
         // The ccall root and GC preserve handling below makes sure that
         // the alloca isn't optimized out.
         buff = prolog_builder.CreateAlloca(pass.T_prjlvalue);
-        buff->setAlignment(align);
+        buff->setAlignment(Align(align));
         ptr = cast<Instruction>(prolog_builder.CreateBitCast(buff, pass.T_pint8));
     }
     else {
         buff = prolog_builder.CreateAlloca(Type::getIntNTy(*pass.ctx, sz * 8));
-        buff->setAlignment(align);
+        buff->setAlignment(Align(align));
         ptr = cast<Instruction>(prolog_builder.CreateBitCast(buff, pass.T_pint8));
     }
     insertLifetime(ptr, ConstantInt::get(pass.T_int64, sz), orig_inst);
diff -pruN 1.3.1+dfsg-1/src/llvm-api.cpp 1.4.0+dfsg-1/src/llvm-api.cpp
--- 1.3.1+dfsg-1/src/llvm-api.cpp	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/src/llvm-api.cpp	2020-03-21 16:36:32.000000000 +0000
@@ -176,37 +176,6 @@ LLVMExtraCreateFunctionPass(const char *
     return wrap(new JuliaFunctionPass(Name, Callback));
 }
 
-class JuliaBasicBlockPass : public BasicBlockPass {
-public:
-    JuliaBasicBlockPass(const char *Name, jl_value_t *Callback)
-        : BasicBlockPass(CreatePassID(Name)), Callback(Callback)
-    {
-    }
-
-    bool runOnBasicBlock(BasicBlock &BB)
-    {
-        jl_value_t **argv;
-        JL_GC_PUSHARGS(argv, 2);
-        argv[0] = Callback;
-        argv[1] = jl_box_voidpointer(wrap(&BB));
-
-        jl_value_t *ret = jl_apply(argv, 2);
-        bool changed = jl_unbox_bool(ret);
-
-        JL_GC_POP();
-        return changed;
-    }
-
-private:
-    jl_value_t *Callback;
-};
-
-extern "C" JL_DLLEXPORT LLVMPassRef
-LLVMExtraCreateBasicBlockPass(const char *Name, jl_value_t *Callback)
-{
-    return wrap(new JuliaBasicBlockPass(Name, Callback));
-}
-
 
 // Various missing functions
 
diff -pruN 1.3.1+dfsg-1/src/llvm-final-gc-lowering.cpp 1.4.0+dfsg-1/src/llvm-final-gc-lowering.cpp
--- 1.3.1+dfsg-1/src/llvm-final-gc-lowering.cpp	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/src/llvm-final-gc-lowering.cpp	2020-03-21 16:36:32.000000000 +0000
@@ -76,6 +76,7 @@ Value *FinalLowerGC::lowerNewGCFrame(Cal
         T_prjlvalue,
         0,
         ConstantInt::get(T_int32, nRoots + 2));
+    gcframe->setAlignment(Align(16));
     gcframe->insertAfter(target);
     gcframe->takeName(target);
 
@@ -88,17 +89,20 @@ Value *FinalLowerGC::lowerNewGCFrame(Cal
         Value *args[4] = {
             tempSlot_i8, // dest
             ConstantInt::get(Type::getInt8Ty(F.getContext()), 0), // val
-            ConstantInt::get(T_int32, sizeof(jl_value_t*)*(nRoots+2)), // len
+            ConstantInt::get(T_int32, sizeof(jl_value_t*) * (nRoots + 2)), // len
             ConstantInt::get(Type::getInt1Ty(F.getContext()), 0)}; // volatile
 #else
         Value *args[5] = {
             tempSlot_i8, // dest
             ConstantInt::get(Type::getInt8Ty(F.getContext()), 0), // val
-            ConstantInt::get(T_int32, sizeof(jl_value_t*)*(nRoots+2)), // len
-            ConstantInt::get(T_int32, 0), // align
+            ConstantInt::get(T_int32, sizeof(jl_value_t*) * (nRoots + 2)), // len
+            ConstantInt::get(T_int32, 16), // align
             ConstantInt::get(Type::getInt1Ty(F.getContext()), 0)}; // volatile
 #endif
     CallInst *zeroing = CallInst::Create(memset, makeArrayRef(args));
+#if JL_LLVM_VERSION >= 70000
+     cast<MemSetInst>(zeroing)->setDestAlignment(16);
+#endif
     zeroing->setMetadata(LLVMContext::MD_tbaa, tbaa_gcframe);
     zeroing->insertAfter(tempSlot_i8);
 
@@ -115,7 +119,7 @@ void FinalLowerGC::lowerPushGCFrame(Call
     builder.SetInsertPoint(&*(++BasicBlock::iterator(target)));
     Instruction *inst =
         builder.CreateStore(
-            ConstantInt::get(T_size, nRoots << 1),
+            ConstantInt::get(T_size, JL_GC_ENCODE_PUSHARGS(nRoots)),
             builder.CreateBitCast(
                 builder.CreateConstGEP1_32(gcframe, 0),
                 T_size->getPointerTo()));
diff -pruN 1.3.1+dfsg-1/src/llvm-late-gc-lowering.cpp 1.4.0+dfsg-1/src/llvm-late-gc-lowering.cpp
--- 1.3.1+dfsg-1/src/llvm-late-gc-lowering.cpp	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/src/llvm-late-gc-lowering.cpp	2020-03-21 16:36:32.000000000 +0000
@@ -26,6 +26,11 @@
 #include <llvm/Transforms/Utils/ModuleUtils.h>
 
 #include "llvm-version.h"
+
+#if JL_LLVM_VERSION >= 100000
+#include <llvm/InitializePasses.h>
+#endif
+
 #include "codegen_shared.h"
 #include "julia.h"
 #include "julia_internal.h"
@@ -224,12 +229,10 @@ using namespace llvm;
 */
 
 struct BBState {
+    // Uses in this BB
     // These do not get updated after local analysis
     BitVector Defs;
     BitVector PhiOuts;
-    //// Upward exposed uses that do not have a preceding safepoint
-    BitVector UpExposedUsesUnrooted;
-    //// All other uses
     BitVector UpExposedUses;
     // These get updated during dataflow
     BitVector LiveIn;
@@ -252,9 +255,7 @@ struct State {
     // Cache of numbers assigned to IR values. This includes caching of numbers
     // for derived values
     std::map<Value *, int> AllPtrNumbering;
-    std::map<Value *, std::vector<int>> AllVectorNumbering;
-    // Numbering of pointers. This only includes Defs
-    std::map<Value *, int> PtrNumbering;
+    std::map<Value *, std::vector<int>> AllCompositeNumbering;
     // The reverse of the previous maps
     std::map<int, Value *> ReversePtrNumbering;
     // Neighbors in the coloring interference graph. I.e. for each value, the
@@ -298,6 +299,9 @@ struct State {
     // We don't bother doing liveness on Allocas that were not mem2reg'ed.
     // they just get directly sunk into the root array.
     std::vector<AllocaInst *> Allocas;
+    DenseMap<AllocaInst *, unsigned> ArrayAllocas;
+    DenseMap<AllocaInst *, AllocaInst *> ShadowAllocas;
+    std::vector<std::pair<StoreInst *, unsigned>> TrackedStores;
     State(Function &F) : F(&F), DT(nullptr), MaxPtrNumber(-1), MaxSafepointNumber(-1) {}
 };
 
@@ -328,22 +332,26 @@ private:
     void NoteUse(State &S, BBState &BBS, Value *V) {
         NoteUse(S, BBS, V, BBS.UpExposedUses);
     }
-    Value *MaybeExtractUnion(std::pair<Value*,int> Val, Instruction *InsertBefore);
-    void LiftPhi(State &S, PHINode *Phi, SmallVector<int, 16> &PHINumbers);
+
+    void LiftPhi(State &S, PHINode *Phi);
     bool LiftSelect(State &S, SelectInst *SI);
+    Value *MaybeExtractScalar(State &S, std::pair<Value*,int> ValExpr, Instruction *InsertBefore);
+    std::vector<Value*> MaybeExtractVector(State &S, Value *BaseVec, Instruction *InsertBefore);
+    Value *GetPtrForNumber(State &S, unsigned Num, Instruction *InsertBefore);
+
     int Number(State &S, Value *V);
-    std::vector<int> NumberVector(State &S, Value *Vec);
-    int NumberBase(State &S, Value *V, Value *Base);
-    std::vector<int> NumberVectorBase(State &S, Value *Base);
-    void NoteOperandUses(State &S, BBState &BBS, User &UI, BitVector &Uses);
-    void NoteOperandUses(State &S, BBState &BBS, User &UI){
-        NoteOperandUses(S, BBS, UI, BBS.UpExposedUses);
-    }
+    int NumberBase(State &S, Value *Base);
+    std::vector<int> NumberAll(State &S, Value *V);
+    std::vector<int> NumberAllBase(State &S, Value *Base);
+
+    void NoteOperandUses(State &S, BBState &BBS, User &UI);
+    void MaybeTrackDst(State &S, MemTransferInst *MI);
+    void MaybeTrackStore(State &S, StoreInst *I);
     State LocalScan(Function &F);
     void ComputeLiveness(State &S);
     void ComputeLiveSets(State &S);
     std::vector<int> ColorRoots(const State &S);
-    void PlaceGCFrameStore(State &S, unsigned R, unsigned MinColorRoot, const std::vector<int> &Colors, Value *GCFrame, Instruction *InsertionPoint);
+    void PlaceGCFrameStore(State &S, unsigned R, unsigned MinColorRoot, const std::vector<int> &Colors, Value *GCFrame, Instruction *InsertBefore);
     void PlaceGCFrameStores(State &S, unsigned MinColorRoot, const std::vector<int> &Colors, Value *GCFrame);
     void PlaceRootsAndUpdateCalls(std::vector<int> &Colors, State &S, std::map<Value *, std::pair<int, int>>);
     bool doInitialization(Module &M) override;
@@ -358,10 +366,12 @@ private:
 };
 
 static unsigned getValueAddrSpace(Value *V) {
-    Type *Ty = V->getType();
-    if (isa<VectorType>(Ty))
-        Ty = cast<VectorType>(V->getType())->getElementType();
-    return cast<PointerType>(Ty)->getAddressSpace();
+    return V->getType()->getPointerAddressSpace();
+}
+
+static unsigned isTrackedValue(Value *V) {
+    PointerType *PT = dyn_cast<PointerType>(V->getType()->getScalarType());
+    return PT && PT->getAddressSpace() == AddressSpace::Tracked;
 }
 
 static bool isSpecialPtr(Type *Ty) {
@@ -372,19 +382,61 @@ static bool isSpecialPtr(Type *Ty) {
     return AddressSpace::FirstSpecial <= AS && AS <= AddressSpace::LastSpecial;
 }
 
-static bool isSpecialPtrVec(Type *Ty) {
-    auto *VTy = dyn_cast<VectorType>(Ty);
-    if (!VTy)
-        return false;
-    return isSpecialPtr(VTy->getElementType());
+// return how many Special pointers are in T (count > 0),
+// and if there is anything else in T (all == false)
+CountTrackedPointers::CountTrackedPointers(Type *T) {
+    if (isa<PointerType>(T)) {
+        if (isSpecialPtr(T)) {
+            count++;
+            if (T->getPointerAddressSpace() != AddressSpace::Tracked)
+                derived = true;
+        }
+    } else if (isa<CompositeType>(T)) {
+        for (Type *ElT : T->subtypes()) {
+            auto sub = CountTrackedPointers(ElT);
+            count += sub.count;
+            all &= sub.all;
+            derived |= sub.derived;
+        }
+        if (isa<SequentialType>(T))
+            count *= cast<SequentialType>(T)->getNumElements();
+    }
+    if (count == 0)
+        all = false;
 }
 
-static bool isUnionRep(Type *Ty) {
-    return Ty->isStructTy() && cast<StructType>(Ty)->getNumElements() == 2 &&
-        isSpecialPtr(cast<StructType>(Ty)->getTypeAtIndex((unsigned)0));
+unsigned getCompositeNumElements(Type *T) {
+    return isa<StructType>(T) ? T->getStructNumElements() : cast<SequentialType>(T)->getNumElements();
 }
 
-// If the input value is a scalar (pointer), we may return a vector value as base
+// Walk through a Type, and record the element path to every tracked value inside
+void TrackCompositeType(Type *T, std::vector<unsigned> &Idxs, std::vector<std::vector<unsigned>> &Numberings) {
+    if (isa<PointerType>(T)) {
+        if (T->getPointerAddressSpace() == AddressSpace::Tracked)
+            Numberings.push_back(Idxs);
+    }
+    else if (isa<CompositeType>(T)) {
+        unsigned Idx, NumEl = getCompositeNumElements(T);
+        for (Idx = 0; Idx < NumEl; Idx++) {
+            Idxs.push_back(Idx);
+            Type *ElT  = cast<CompositeType>(T)->getTypeAtIndex(Idx);
+            TrackCompositeType(ElT, Idxs, Numberings);
+            Idxs.pop_back();
+        }
+    }
+}
+
+std::vector<std::vector<unsigned>> TrackCompositeType(Type *T) {
+    std::vector<unsigned> Idxs;
+    std::vector<std::vector<unsigned>> Numberings;
+    TrackCompositeType(T, Idxs, Numberings);
+    return Numberings;
+}
+
+
+
+// Walk through simple expressions to until we hit something that requires root numbering
+// If the input value is a scalar (pointer), we may return a composite value as base
 // in which case the second member of the pair is the index of the value in the vector.
 static std::pair<Value*,int> FindBaseValue(const State &S, Value *V, bool UseCache = true) {
     Value *CurrentV = V;
@@ -396,11 +448,13 @@ static std::pair<Value*,int> FindBaseVal
                 if (it != S.AllPtrNumbering.end())
                     return std::make_pair(CurrentV, fld_idx);
             } else {
-                auto it = S.AllVectorNumbering.find(CurrentV);
-                if (it != S.AllVectorNumbering.end())
+                auto it = S.AllCompositeNumbering.find(CurrentV);
+                if (it != S.AllCompositeNumbering.end())
                     return std::make_pair(CurrentV, fld_idx);
             }
         }
+        // Note that this is true:
+        //   assert(fld_idx == -1 ? CurrentV->getType()->isPointerTy() : CurrentV->getType()->isVectorPointerTy());
         if (isa<BitCastInst>(CurrentV))
             CurrentV = cast<BitCastInst>(CurrentV)->getOperand(0);
         else if (isa<AddrSpaceCastInst>(CurrentV)) {
@@ -408,51 +462,30 @@ static std::pair<Value*,int> FindBaseVal
             if (getValueAddrSpace(NewV) == 0)
                 break;
             CurrentV = NewV;
-        }
-        else if (isa<GetElementPtrInst>(CurrentV)) {
-            CurrentV = cast<GetElementPtrInst>(CurrentV)->getOperand(0);
+        } else if (auto *GEP = dyn_cast<GetElementPtrInst>(CurrentV)) {
+            CurrentV = GEP->getOperand(0);
             // GEP can make vectors from a single base pointer
-            if (fld_idx != -1 && !isSpecialPtrVec(CurrentV->getType())) {
+            if (fld_idx != -1 && !isa<VectorType>(CurrentV->getType())) {
                 fld_idx = -1;
             }
-        } else if (isa<ExtractValueInst>(CurrentV)) {
-            Value *Operand = cast<ExtractValueInst>(CurrentV)->getOperand(0);
-            if (!isUnionRep(Operand->getType()))
-                break;
-            CurrentV = Operand;
-        }
-        else if (isa<InsertValueInst>(CurrentV)) {
-            if (!isUnionRep(CurrentV->getType()))
-                break;
-            InsertValueInst *IVI = cast<InsertValueInst>(CurrentV);
-            assert(IVI->getNumIndices() == 1);
-            unsigned idx = IVI->getIndices()[0];
-            if (idx == 0) {
-                // Updating the pointer in the union. Follow the pointer.
-                CurrentV = IVI->getOperand(1);
-            } else {
-                // Updating which tindex is active. Follow the union.
-                assert(idx == 1);
-                CurrentV = IVI->getOperand(0);
-            }
         }
         else if (auto EEI = dyn_cast<ExtractElementInst>(CurrentV)) {
             assert(CurrentV->getType()->isPointerTy() && fld_idx == -1);
-            // For now, only support constant index.
+            // TODO: For now, only support constant index.
             auto IdxOp = cast<ConstantInt>(EEI->getIndexOperand());
             fld_idx = IdxOp->getLimitedValue(INT_MAX);
             CurrentV = EEI->getVectorOperand();
         }
         else if (auto LI = dyn_cast<LoadInst>(CurrentV)) {
-            if (auto PtrT = dyn_cast<PointerType>(LI->getType())) {
+            if (auto PtrT = dyn_cast<PointerType>(LI->getType()->getScalarType())) {
                 if (PtrT->getAddressSpace() == AddressSpace::Loaded) {
                     CurrentV = LI->getPointerOperand();
+                    fld_idx = -1;
                     if (!isSpecialPtr(CurrentV->getType())) {
-                        // Special case to bypass the check below.
                         // This could really be anything, but it's not loaded
                         // from a tracked pointer, so it doesn't matter what
-                        // it is.
-                        return std::make_pair(CurrentV, fld_idx);
+                        // it is--just pick something simple.
+                        CurrentV = ConstantPointerNull::get(Type::getInt8PtrTy(V->getContext()));
                     }
                     continue;
                 }
@@ -460,6 +493,34 @@ static std::pair<Value*,int> FindBaseVal
             // In general a load terminates a walk
             break;
         }
+        else if (auto II = dyn_cast<IntrinsicInst>(CurrentV)) {
+            // Some intrinsics behave like LoadInst followed by a SelectInst
+            // This should never happen in a derived addrspace (since those cannot be stored to memory)
+            // so we don't need to lift these operations, but we do need to check if it's loaded and continue walking the base pointer
+            if (II->getIntrinsicID() == Intrinsic::masked_load ||
+                II->getIntrinsicID() == Intrinsic::masked_gather) {
+                if (auto PtrT = dyn_cast<PointerType>(II->getType()->getVectorElementType())) {
+                    if (PtrT->getAddressSpace() == AddressSpace::Loaded) {
+                        assert(isa<UndefValue>(II->getOperand(3)) && "unimplemented");
+                        CurrentV = II->getOperand(0);
+                        if (II->getIntrinsicID() == Intrinsic::masked_load) {
+                            fld_idx = -1;
+                            if (!isSpecialPtr(CurrentV->getType())) {
+                                CurrentV = ConstantPointerNull::get(Type::getInt8PtrTy(V->getContext()));
+                            }
+                        } else {
+                            if (!isSpecialPtr(CurrentV->getType()->getVectorElementType())) {
+                                CurrentV = ConstantPointerNull::get(Type::getInt8PtrTy(V->getContext()));
+                                fld_idx = -1;
+                            }
+                        }
+                        continue;
+                    }
+                }
+                // In general a load terminates a walk
+                break;
+            }
+        }
         else {
             break;
         }
@@ -468,260 +529,418 @@ static std::pair<Value*,int> FindBaseVal
            isa<Argument>(CurrentV) || isa<SelectInst>(CurrentV) ||
            isa<PHINode>(CurrentV) || isa<AddrSpaceCastInst>(CurrentV) ||
            isa<Constant>(CurrentV) || isa<AllocaInst>(CurrentV) ||
+           isa<InsertValueInst>(CurrentV) ||
            isa<ExtractValueInst>(CurrentV) ||
            isa<InsertElementInst>(CurrentV) ||
            isa<ShuffleVectorInst>(CurrentV));
     return std::make_pair(CurrentV, fld_idx);
 }
 
-Value *LateLowerGCFrame::MaybeExtractUnion(std::pair<Value*,int> Val, Instruction *InsertBefore) {
-    if (isUnionRep(Val.first->getType())) {
-        assert(Val.second == -1);
-        return ExtractValueInst::Create(Val.first, {(unsigned)0}, "", InsertBefore);
-    }
-    else if (Val.second != -1) {
-        return ExtractElementInst::Create(Val.first, ConstantInt::get(T_int32, Val.second),
-                                          "", InsertBefore);
+Value *LateLowerGCFrame::MaybeExtractScalar(State &S, std::pair<Value*,int> ValExpr, Instruction *InsertBefore) {
+    Value *V = ValExpr.first;
+    if (isa<PointerType>(V->getType())) {
+        assert(ValExpr.second == -1);
+        if (!isTrackedValue(V)) {
+            int BaseNumber = NumberBase(S, V);
+            if (BaseNumber >= 0)
+                V = GetPtrForNumber(S, BaseNumber, InsertBefore);
+            else
+                V = ConstantPointerNull::get(cast<PointerType>(T_prjlvalue));
+        }
+    }
+    else if (ValExpr.second != -1) {
+        auto Tracked = TrackCompositeType(V->getType());
+        auto Idxs = makeArrayRef(Tracked.at(ValExpr.second));
+        auto IdxsNotVec = Idxs.slice(0, Idxs.size() - 1);
+        Type *FinalT = ExtractValueInst::getIndexedType(V->getType(), IdxsNotVec);
+        bool IsVector = isa<VectorType>(FinalT);
+        PointerType *T = cast<PointerType>(cast<CompositeType>(FinalT)->getTypeAtIndex(Idxs.back()));
+        if (T->getAddressSpace() != AddressSpace::Tracked) {
+            // if V isn't tracked, get the shadow def
+            auto Numbers = NumberAllBase(S, V);
+            int BaseNumber = Numbers.at(ValExpr.second);
+            if (BaseNumber >= 0)
+                V = GetPtrForNumber(S, BaseNumber, InsertBefore);
+            else
+                V = ConstantPointerNull::get(cast<PointerType>(T_prjlvalue));
+            return V;
+        }
+        if (Idxs.size() > IsVector)
+            V = ExtractValueInst::Create(V, IsVector ? IdxsNotVec : Idxs, "", InsertBefore);
+        if (IsVector)
+            V = ExtractElementInst::Create(V,
+                    ConstantInt::get(Type::getInt32Ty(V->getContext()), Idxs.back()),
+                    "", InsertBefore);
+    }
+    return V;
+}
+
+std::vector<Value*> LateLowerGCFrame::MaybeExtractVector(State &S, Value *BaseVec, Instruction *InsertBefore) {
+    auto Numbers = NumberAllBase(S, BaseVec);
+    std::vector<Value*> V{Numbers.size()};
+    Value *V_null = ConstantPointerNull::get(cast<PointerType>(T_prjlvalue));
+    for (unsigned i = 0; i < V.size(); ++i) {
+        if (Numbers[i] >= 0)
+            V[i] = GetPtrForNumber(S, Numbers[i], InsertBefore);
+        else
+            V[i] = V_null;
     }
-    return Val.first;
+    return V;
 }
 
-static Value *GetPtrForNumber(State &S, unsigned Num, Instruction *InsertionPoint)
+Value *LateLowerGCFrame::GetPtrForNumber(State &S, unsigned Num, Instruction *InsertBefore)
 {
     Value *Val = S.ReversePtrNumbering[Num];
-    if (isSpecialPtrVec(Val->getType())) {
-        const std::vector<int> &AllNums = S.AllVectorNumbering[Val];
-        unsigned Idx = 0;
-        for (; Idx < AllNums.size(); ++Idx) {
+    unsigned Idx = -1;
+    if (!isa<PointerType>(Val->getType())) {
+        const std::vector<int> &AllNums = S.AllCompositeNumbering[Val];
+        for (Idx = 0; Idx < AllNums.size(); ++Idx) {
             if ((unsigned)AllNums[Idx] == Num)
                 break;
         }
-        Val = ExtractElementInst::Create(Val, ConstantInt::get(
-            Type::getInt32Ty(Val->getContext()), Idx), "", InsertionPoint);
+        assert(Idx < AllNums.size());
     }
-    return Val;
+    return MaybeExtractScalar(S, std::make_pair(Val, Idx), InsertBefore);
 }
 
 bool LateLowerGCFrame::LiftSelect(State &S, SelectInst *SI) {
-    if (isSpecialPtrVec(SI->getType())) {
-        VectorType *VT = cast<VectorType>(SI->getType());
-        std::vector<int> TrueNumbers = NumberVector(S, SI->getTrueValue());
-        std::vector<int> FalseNumbers = NumberVector(S, SI->getFalseValue());
-        std::vector<int> Numbers;
-        for (unsigned i = 0; i < VT->getNumElements(); ++i) {
-            SelectInst *LSI = SelectInst::Create(SI->getCondition(),
-              TrueNumbers[i] < 0 ?
-                ConstantPointerNull::get(cast<PointerType>(T_prjlvalue)) :
-                GetPtrForNumber(S, TrueNumbers[i], SI),
-              FalseNumbers[i] < 0 ?
-                ConstantPointerNull::get(cast<PointerType>(T_prjlvalue)) :
-                GetPtrForNumber(S, FalseNumbers[i], SI),
-              "gclift", SI);
-            int Number = ++S.MaxPtrNumber;
-            Numbers.push_back(Number);
-            S.PtrNumbering[LSI] = S.AllPtrNumbering[LSI] = Number;
-            S.ReversePtrNumbering[Number] = LSI;
-        }
-        S.AllVectorNumbering[SI] = Numbers;
-    } else {
-        Value *TrueBase = MaybeExtractUnion(FindBaseValue(S, SI->getTrueValue(), false), SI);
-        Value *FalseBase = MaybeExtractUnion(FindBaseValue(S, SI->getFalseValue(), false), SI);
-        if (getValueAddrSpace(TrueBase) != AddressSpace::Tracked)
-            TrueBase = ConstantPointerNull::get(cast<PointerType>(FalseBase->getType()));
-        if (getValueAddrSpace(FalseBase) != AddressSpace::Tracked)
-            FalseBase = ConstantPointerNull::get(cast<PointerType>(TrueBase->getType()));
-        if (getValueAddrSpace(TrueBase) != AddressSpace::Tracked)
-            return false;
-        Value *SelectBase = SelectInst::Create(SI->getCondition(),
-            TrueBase, FalseBase, "gclift", SI);
-        int Number = ++S.MaxPtrNumber;
-        S.PtrNumbering[SelectBase] = S.AllPtrNumbering[SelectBase] =
-            S.AllPtrNumbering[SI] = Number;
-        S.ReversePtrNumbering[Number] = SelectBase;
+    if (isa<PointerType>(SI->getType()) ?
+            S.AllPtrNumbering.count(SI) :
+            S.AllCompositeNumbering.count(SI)) {
+        // already visited here--nothing to do
+        return true;
     }
-    return true;
-}
-
-void LateLowerGCFrame::LiftPhi(State &S, PHINode *Phi, SmallVector<int, 16> &PHINumbers)
-{
-    if (isSpecialPtrVec(Phi->getType())) {
-        VectorType *VT = cast<VectorType>(Phi->getType());
-        std::vector<PHINode *> lifted;
-        for (unsigned i = 0; i < VT->getNumElements(); ++i) {
-            lifted.push_back(PHINode::Create(T_prjlvalue, Phi->getNumIncomingValues(), "gclift", Phi));
-        }
-        for (unsigned i = 0; i < Phi->getNumIncomingValues(); ++i) {
-            std::vector<int> Numbers = NumberVector(S, Phi->getIncomingValue(i));
-            BasicBlock *IncomingBB = Phi->getIncomingBlock(i);
-            Instruction *Terminator = IncomingBB->getTerminator();
-            for (unsigned i = 0; i < VT->getNumElements(); ++i) {
-                if (Numbers[i] < 0)
-                    lifted[i]->addIncoming(ConstantPointerNull::get(cast<PointerType>(T_prjlvalue)), IncomingBB);
+    std::vector<int> Numbers;
+    unsigned NumRoots = 1;
+    if (isa<VectorType>(SI->getType()))
+        Numbers.resize(SI->getType()->getVectorNumElements(), -1);
+    else
+        assert(isa<PointerType>(SI->getType()) && "unimplemented");
+    assert(!isTrackedValue(SI));
+    // find the base root for the arguments
+    Value *TrueBase = MaybeExtractScalar(S, FindBaseValue(S, SI->getTrueValue(), false), SI);
+    Value *FalseBase = MaybeExtractScalar(S, FindBaseValue(S, SI->getFalseValue(), false), SI);
+    Value *V_null = ConstantPointerNull::get(cast<PointerType>(T_prjlvalue));
+    bool didsplit = false;
+    if (TrueBase != V_null && FalseBase != V_null) {
+        std::vector<Value*> TrueBases;
+        std::vector<Value*> FalseBases;
+        if (!isa<PointerType>(TrueBase->getType())) {
+            TrueBases = MaybeExtractVector(S, TrueBase, SI);
+            assert(TrueBases.size() == Numbers.size());
+            NumRoots = TrueBases.size();
+        }
+        if (!isa<PointerType>(FalseBase->getType())) {
+            FalseBases = MaybeExtractVector(S, FalseBase, SI);
+            assert(FalseBases.size() == Numbers.size());
+            NumRoots = FalseBases.size();
+        }
+        if (isa<PointerType>(SI->getType()) ?
+                S.AllPtrNumbering.count(SI) :
+                S.AllCompositeNumbering.count(SI)) {
+            // MaybeExtractScalar or MaybeExtractVector handled this for us (recursively, though a PHINode)
+            return true;
+        }
+        // need to handle each element (may just be one scalar)
+        for (unsigned i = 0; i < NumRoots; ++i) {
+            Value *TrueElem;
+            if (isa<PointerType>(TrueBase->getType()))
+                TrueElem = TrueBase;
+            else
+                TrueElem = TrueBases[i];
+            Value *FalseElem;
+            if (isa<PointerType>(FalseBase->getType()))
+                FalseElem = FalseBase;
+            else
+                FalseElem = FalseBases[i];
+            if (TrueElem != V_null || FalseElem != V_null) {
+                Value *Cond = SI->getCondition();
+                if (isa<VectorType>(Cond->getType())) {
+                    Cond = ExtractElementInst::Create(Cond,
+                            ConstantInt::get(Type::getInt32Ty(Cond->getContext()), i),
+                            "", SI);
+                }
+                SelectInst *SelectBase = SelectInst::Create(Cond, TrueElem, FalseElem, "gclift", SI);
+                int Number = ++S.MaxPtrNumber;
+                S.AllPtrNumbering[SelectBase] = Number;
+                S.ReversePtrNumbering[Number] = SelectBase;
+                if (isa<PointerType>(SI->getType()))
+                   S.AllPtrNumbering[SI] = Number;
                 else
-                    lifted[i]->addIncoming(GetPtrForNumber(S, Numbers[i], Terminator), IncomingBB);
+                    Numbers[i] = Number;
+                didsplit = true;
             }
         }
-        std::vector<int> Numbers;
-        for (unsigned i = 0; i < VT->getNumElements(); ++i) {
-            int Number = ++S.MaxPtrNumber;
-            PHINumbers.push_back(Number);
-            Numbers.push_back(Number);
-            S.PtrNumbering[lifted[i]] = S.AllPtrNumbering[lifted[i]] = Number;
-            S.ReversePtrNumbering[Number] = lifted[i];
+        if (isa<VectorType>(SI->getType()) && NumRoots != Numbers.size()) {
+            // broadcast the scalar root number to fill the vector
+            assert(NumRoots == 1);
+            int Number = Numbers[0];
+            Numbers.resize(0);
+            Numbers.resize(SI->getType()->getVectorNumElements(), Number);
         }
-        S.AllVectorNumbering[Phi] = Numbers;
-    } else {
+    }
+    if (!isa<PointerType>(SI->getType()))
+        S.AllCompositeNumbering[SI] = Numbers;
+    return didsplit;
+}
+
+void LateLowerGCFrame::LiftPhi(State &S, PHINode *Phi) {
+    if (isa<PointerType>(Phi->getType()) ?
+            S.AllPtrNumbering.count(Phi) :
+            S.AllCompositeNumbering.count(Phi))
+        return;
+    // need to handle each element (may just be one scalar)
+    SmallVector<PHINode *, 2> lifted;
+    std::vector<int> Numbers;
+    unsigned NumRoots = 1;
+    if (isa<VectorType>(Phi->getType())) {
+        NumRoots = Phi->getType()->getVectorNumElements();
+        Numbers.resize(NumRoots);
+    }
+    else {
+        assert(isa<PointerType>(Phi->getType()) && "unimplemented");
+    }
+    for (unsigned i = 0; i < NumRoots; ++i) {
         PHINode *lift = PHINode::Create(T_prjlvalue, Phi->getNumIncomingValues(), "gclift", Phi);
-        for (unsigned i = 0; i < Phi->getNumIncomingValues(); ++i) {
-            Value *Incoming = Phi->getIncomingValue(i);
-            Value *Base = MaybeExtractUnion(FindBaseValue(S, Incoming, false),
-                                            Phi->getIncomingBlock(i)->getTerminator());
-            if (getValueAddrSpace(Base) != AddressSpace::Tracked)
-                Base = ConstantPointerNull::get(cast<PointerType>(T_prjlvalue));
-            if (Base->getType() != T_prjlvalue)
-                Base = new BitCastInst(Base, T_prjlvalue, "", Phi->getIncomingBlock(i)->getTerminator());
-            lift->addIncoming(Base, Phi->getIncomingBlock(i));
-        }
         int Number = ++S.MaxPtrNumber;
-        PHINumbers.push_back(Number);
-        S.PtrNumbering[lift] = S.AllPtrNumbering[lift] =
-            S.AllPtrNumbering[Phi] = Number;
+        S.AllPtrNumbering[lift] = Number;
         S.ReversePtrNumbering[Number] = lift;
+        if (!isa<VectorType>(Phi->getType()))
+            S.AllPtrNumbering[Phi] = Number;
+        else
+            Numbers[i] = Number;
+        lifted.push_back(lift);
+    }
+    if (!isa<PointerType>(Phi->getType()))
+        S.AllCompositeNumbering[Phi] = Numbers;
+    for (unsigned i = 0; i < Phi->getNumIncomingValues(); ++i) {
+        Value *Incoming = Phi->getIncomingValue(i);
+        BasicBlock *IncomingBB = Phi->getIncomingBlock(i);
+        Instruction *Terminator = IncomingBB->getTerminator();
+        Value *Base = MaybeExtractScalar(S, FindBaseValue(S, Incoming, false), Terminator);
+        std::vector<Value*> IncomingBases;
+        if (!isa<PointerType>(Base->getType())) {
+            IncomingBases = MaybeExtractVector(S, Base, Terminator);
+            assert(IncomingBases.size() == NumRoots);
+        }
+        for (unsigned i = 0; i < NumRoots; ++i) {
+            PHINode *lift = lifted[i];
+            Value *BaseElem;
+            if (isa<PointerType>(Base->getType())) {
+                BaseElem = Base;
+                if (BaseElem->getType() != T_prjlvalue)
+                    BaseElem = new BitCastInst(BaseElem, T_prjlvalue, "", Terminator);
+            } else {
+                BaseElem = IncomingBases[i];
+            }
+            lift->addIncoming(BaseElem, IncomingBB);
+        }
     }
 }
 
-int LateLowerGCFrame::NumberBase(State &S, Value *V, Value *CurrentV)
+int LateLowerGCFrame::NumberBase(State &S, Value *CurrentV)
 {
     auto it = S.AllPtrNumbering.find(CurrentV);
     if (it != S.AllPtrNumbering.end())
         return it->second;
     int Number;
-    bool isUnion = isUnionRep(CurrentV->getType());
     if (isa<Constant>(CurrentV)) {
         // Perm rooted
         Number = -2;
-    } else if (isa<Argument>(CurrentV) ||
-               ((isa<AllocaInst>(CurrentV) || isa<AddrSpaceCastInst>(CurrentV)) &&
-                getValueAddrSpace(CurrentV) != AddressSpace::Tracked)) {
+    } else if (isa<Argument>(CurrentV) || isa<AllocaInst>(CurrentV) ||
+            (isa<AddrSpaceCastInst>(CurrentV) && !isTrackedValue(CurrentV))) {
         // We know this is rooted in the parent
+        // future note: we could chose to exclude argument of type CalleeRooted here
         Number = -1;
-    } else if (!isSpecialPtr(CurrentV->getType()) && !isUnion) {
+    } else if (!isSpecialPtr(CurrentV->getType())) {
         // Externally rooted somehow hopefully (otherwise there's a bug in the
         // input IR)
         Number = -1;
-    } else if (isa<SelectInst>(CurrentV) && !isUnion && getValueAddrSpace(CurrentV) != AddressSpace::Tracked) {
+    } else if (isa<SelectInst>(CurrentV) && !isTrackedValue(CurrentV)) {
         Number = -1;
-        if (LiftSelect(S, cast<SelectInst>(CurrentV)))
-            Number = S.AllPtrNumbering[V] = S.AllPtrNumbering.at(CurrentV);
+        if (LiftSelect(S, cast<SelectInst>(CurrentV))) // lifting a scalar pointer (if necessary)
+            Number = S.AllPtrNumbering.at(CurrentV);
         return Number;
-    } else if (isa<PHINode>(CurrentV) && !isUnion && getValueAddrSpace(CurrentV) != AddressSpace::Tracked) {
-        SmallVector<int, 16> PHINumbers;
-        LiftPhi(S, cast<PHINode>(CurrentV), PHINumbers);
-        Number = S.AllPtrNumbering[V] = S.AllPtrNumbering.at(CurrentV);
+    } else if (isa<PHINode>(CurrentV) && !isTrackedValue(CurrentV)) {
+        LiftPhi(S, cast<PHINode>(CurrentV));
+        Number = S.AllPtrNumbering.at(CurrentV);
         return Number;
-    } else if (isa<ExtractValueInst>(CurrentV) && !isUnion) {
-        assert(false && "TODO: Extract");
-        abort();
+    } else if (isa<ExtractValueInst>(CurrentV)) {
+        auto Numbers = NumberAllBase(S, CurrentV);
+        assert(Numbers.size() == 1);
+        Number = Numbers[0];
     } else {
-        assert(
-            (CurrentV->getType()->isPointerTy() &&
-                getValueAddrSpace(CurrentV) == AddressSpace::Tracked) ||
-            isUnion);
+        assert((CurrentV->getType()->isPointerTy() && isTrackedValue(CurrentV)));
         Number = ++S.MaxPtrNumber;
         S.ReversePtrNumbering[Number] = CurrentV;
     }
-    S.PtrNumbering[CurrentV] = S.AllPtrNumbering[CurrentV] = S.AllPtrNumbering[V] = Number;
+    S.AllPtrNumbering[CurrentV] = Number;
     return Number;
 }
 
 int LateLowerGCFrame::Number(State &S, Value *V) {
-    assert(isSpecialPtr(V->getType()) || isUnionRep(V->getType()));
+    assert(isSpecialPtr(V->getType()));
     auto CurrentV = FindBaseValue(S, V);
-    if (CurrentV.second == -1)
-        return NumberBase(S, V, CurrentV.first);
-    auto Numbers = NumberVectorBase(S, CurrentV.first);
-    auto Number = Numbers.size() == 0 ? -1 : Numbers[CurrentV.second];
-    S.AllPtrNumbering[V] = Number;
+    int Number;
+    if (CurrentV.second == -1) {
+        Number = NumberBase(S, CurrentV.first);
+    } else {
+        auto Numbers = NumberAllBase(S, CurrentV.first);
+        Number = Numbers.at(CurrentV.second);
+    }
+    if (V != CurrentV.first)
+        S.AllPtrNumbering[V] = Number;
     return Number;
 }
 
-std::vector<int> LateLowerGCFrame::NumberVectorBase(State &S, Value *CurrentV) {
-    auto it = S.AllVectorNumbering.find(CurrentV);
-    if (it != S.AllVectorNumbering.end())
-        return it->second;
-    std::vector<int> Numbers{};
-    if (isa<Constant>(CurrentV) ||
-        ((isa<Argument>(CurrentV) || isa<AllocaInst>(CurrentV) ||
-         isa<AddrSpaceCastInst>(CurrentV)) &&
-         getValueAddrSpace(CurrentV) != AddressSpace::Tracked)) {
-        Numbers.resize(cast<VectorType>(CurrentV->getType())->getNumElements(), -1);
-    }
-    /* We (the frontend) don't insert either of these, but it would be legal -
-       though a bit strange, considering they're pointers - for the optimizer to
-       do so. All that's needed here is to NumberVector the previous vector/value
-       and lift the operation */
+// assign pointer numbers to a def instruction
+std::vector<int> LateLowerGCFrame::NumberAllBase(State &S, Value *CurrentV) {
+    if (isa<PointerType>(CurrentV->getType())) {
+        auto it = S.AllPtrNumbering.find(CurrentV);
+        if (it != S.AllPtrNumbering.end())
+            return std::vector<int>({it->second});
+    } else {
+        auto it = S.AllCompositeNumbering.find(CurrentV);
+        if (it != S.AllCompositeNumbering.end())
+            return it->second;
+    }
+
+    std::vector<int> Numbers;
+    auto tracked = CountTrackedPointers(CurrentV->getType());
+    if (tracked.count == 0)
+        return Numbers;
+    if (isa<Constant>(CurrentV) || isa<AllocaInst>(CurrentV) || isa<Argument>(CurrentV) ||
+            (isa<AddrSpaceCastInst>(CurrentV) && !isTrackedValue(CurrentV))) {
+        Numbers.resize(tracked.count, -1);
+    }
     else if (auto *SVI = dyn_cast<ShuffleVectorInst>(CurrentV)) {
-        std::vector<int> Numbers1 = NumberVectorBase(S, SVI->getOperand(0));
-        std::vector<int> Numbers2 = NumberVectorBase(S, SVI->getOperand(1));
+        std::vector<int> Numbers1 = NumberAll(S, SVI->getOperand(0));
+        std::vector<int> Numbers2 = NumberAll(S, SVI->getOperand(1));
         auto Mask = SVI->getShuffleMask();
-        for (unsigned idx : Mask) {
-            if (idx < Numbers1.size()) {
-                Numbers.push_back(Numbers1[idx]);
+        for (auto idx : Mask) {
+            assert(idx != -1 && "Undef tracked value is invalid");
+            if ((unsigned)idx < Numbers1.size()) {
+                Numbers.push_back(Numbers1.at(idx));
             } else {
-                Numbers.push_back(Numbers2[idx - Numbers1.size()]);
+                Numbers.push_back(Numbers2.at(idx - Numbers1.size()));
             }
         }
     } else if (auto *IEI = dyn_cast<InsertElementInst>(CurrentV)) {
+        // TODO: handle non-constant: LiftInsertElement(S, IEI)
         unsigned idx = cast<ConstantInt>(IEI->getOperand(2))->getZExtValue();
-        Numbers = NumberVectorBase(S, IEI->getOperand(0));
+        Numbers = NumberAll(S, IEI->getOperand(0));
         int ElNumber = Number(S, IEI->getOperand(1));
         Numbers[idx] = ElNumber;
-    } else if (isa<SelectInst>(CurrentV) && getValueAddrSpace(CurrentV) != AddressSpace::Tracked) {
-        LiftSelect(S, cast<SelectInst>(CurrentV));
-        Numbers = S.AllVectorNumbering[CurrentV];
-    } else if (isa<PHINode>(CurrentV) && getValueAddrSpace(CurrentV) != AddressSpace::Tracked) {
-        SmallVector<int, 16> PHINumbers;
-        LiftPhi(S, cast<PHINode>(CurrentV), PHINumbers);
-        Numbers = S.AllVectorNumbering[CurrentV];
-    } else if (isa<LoadInst>(CurrentV) || isa<CallInst>(CurrentV) || isa<PHINode>(CurrentV) ||
-               isa<SelectInst>(CurrentV)) {
+    } else if (auto *IVI = dyn_cast<InsertValueInst>(CurrentV)) {
+        Numbers = NumberAll(S, IVI->getAggregateOperand());
+        auto Tracked = TrackCompositeType(IVI->getType());
+        assert(Tracked.size() == Numbers.size());
+        std::vector<int> InsertNumbers = NumberAll(S, IVI->getInsertedValueOperand());
+        auto Idxs = IVI->getIndices();
+        unsigned j = 0;
+        for (unsigned i = 0; i < Tracked.size(); ++i) {
+            auto Elem = makeArrayRef(Tracked[i]);
+            if (Elem.size() < Idxs.size())
+                continue;
+            if (Idxs.equals(Elem.slice(0, Idxs.size()))) // Tracked.startswith(Idxs)
+                Numbers[i] = InsertNumbers[j++];
+        }
+        assert(j == InsertNumbers.size());
+    } else if (auto *EVI = dyn_cast<ExtractValueInst>(CurrentV)) {
+        auto BaseNumbers = NumberAll(S, EVI->getAggregateOperand());
+        auto Tracked = TrackCompositeType(EVI->getAggregateOperand()->getType());
+        assert(Tracked.size() == BaseNumbers.size());
+        auto Idxs = EVI->getIndices();
+        for (unsigned i = 0; i < Tracked.size(); ++i) {
+            auto Elem = makeArrayRef(Tracked[i]);
+            if (Elem.size() < Idxs.size())
+                continue;
+            if (Idxs.equals(Elem.slice(0, Idxs.size()))) // Tracked.startswith(Idxs)
+                Numbers.push_back(BaseNumbers[i]);
+        }
+        assert(CountTrackedPointers(EVI->getType()).count == Numbers.size());
+    } else if (tracked.derived) {
+        if (isa<SelectInst>(CurrentV)) {
+            LiftSelect(S, cast<SelectInst>(CurrentV));
+        } else if (isa<PHINode>(CurrentV)) {
+            LiftPhi(S, cast<PHINode>(CurrentV));
+        // } else if (isa<ExtractElementInst>(CurrentV)) { // TODO: lifting for non constant index
+        } else {
+            CurrentV->print(errs());
+            llvm_unreachable("Unexpected generating operation for derived values");
+        }
+        if (isa<PointerType>(CurrentV->getType())) {
+            auto Number = S.AllPtrNumbering.at(CurrentV);
+            Numbers.resize(1, Number);
+        } else {
+            Numbers = S.AllCompositeNumbering.at(CurrentV);
+        }
+    } else {
+        assert((isa<LoadInst>(CurrentV) || isa<CallInst>(CurrentV) || isa<PHINode>(CurrentV) || isa<SelectInst>(CurrentV))
+                && "unexpected def expression");
         // This is simple, we can just number them sequentially
-        for (unsigned i = 0; i < cast<VectorType>(CurrentV->getType())->getNumElements(); ++i) {
+        for (unsigned i = 0; i < tracked.count; ++i) {
             int Num = ++S.MaxPtrNumber;
             Numbers.push_back(Num);
             S.ReversePtrNumbering[Num] = CurrentV;
         }
+    }
+    if (isa<PointerType>(CurrentV->getType())) {
+        assert(Numbers.size() == 1);
+        S.AllPtrNumbering[CurrentV] = Numbers[0];
     } else {
-        assert(false && "Unexpected vector generating operation");
+        S.AllCompositeNumbering[CurrentV] = Numbers;
     }
-    S.AllVectorNumbering[CurrentV] = Numbers;
     return Numbers;
 }
 
-std::vector<int> LateLowerGCFrame::NumberVector(State &S, Value *V) {
-    auto it = S.AllVectorNumbering.find(V);
-    if (it != S.AllVectorNumbering.end())
-        return it->second;
-    auto CurrentV = FindBaseValue(S, V);
-    assert(CurrentV.second == -1);
-    // E.g. if this is a gep, it's possible for the base to be a single ptr
-    if (isSpecialPtrVec(CurrentV.first->getType())) {
-        auto Numbers = NumberVectorBase(S, CurrentV.first);
-        S.AllVectorNumbering[V] = Numbers;
-        return Numbers;
+// gets the pointer number for every gc tracked value inside V
+std::vector<int> LateLowerGCFrame::NumberAll(State &S, Value *V) {
+    if (isa<PointerType>(V->getType())) {
+        auto it = S.AllPtrNumbering.find(V);
+        if (it != S.AllPtrNumbering.end())
+            return std::vector<int>({it->second});
     } else {
-        std::vector<int> Numbers{};
-        Numbers.resize(cast<VectorType>(V->getType())->getNumElements(),
-            NumberBase(S, V, CurrentV.first));
+        auto it = S.AllCompositeNumbering.find(V);
+        if (it != S.AllCompositeNumbering.end())
+            return it->second;
+    }
+    std::vector<int> Numbers;
+    auto tracked = CountTrackedPointers(V->getType());
+    if (tracked.count == 0)
         return Numbers;
+    auto CurrentV = FindBaseValue(S, V);
+    int Number = -1;
+    if (isa<PointerType>(CurrentV.first->getType())) {
+        // Base turned out to be a single pointer--number it
+        assert(CurrentV.second == -1);
+        Number = NumberBase(S, CurrentV.first);
+        Numbers.resize(tracked.count, Number);
+    } else {
+        // Base turned out to be an aggregate--get all numbers for it, then sub-select
+        Numbers = NumberAllBase(S, CurrentV.first);
+        if (CurrentV.second != -1) {
+            Number = Numbers[CurrentV.second]; // only needed a subset of the values
+            Numbers.resize(tracked.count, Number);
+        }
+        else
+            assert(!isa<PointerType>(V->getType()));
+    }
+    if (CurrentV.first != V) {
+        if (isa<PointerType>(V->getType())) {
+            S.AllPtrNumbering[V] = Number;
+        } else {
+            S.AllCompositeNumbering[V] = Numbers;
+        }
     }
+    return Numbers;
 }
 
+
 static void MaybeResize(BBState &BBS, unsigned Idx) {
     if (BBS.Defs.size() <= Idx) {
         BBS.Defs.resize(Idx + 1);
         BBS.UpExposedUses.resize(Idx + 1);
-        BBS.UpExposedUsesUnrooted.resize(Idx + 1);
         BBS.PhiOuts.resize(Idx + 1);
     }
 }
@@ -736,7 +955,6 @@ static void NoteDef(State &S, BBState &B
     assert(BBS.Defs[Num] == 0 && "SSA Violation or misnumbering?");
     BBS.Defs[Num] = 1;
     BBS.UpExposedUses[Num] = 0;
-    BBS.UpExposedUsesUnrooted[Num] = 0;
     // This value could potentially be live at any following safe point
     // if it ends up live out, so add it to the LiveIfLiveOut lists for all
     // following safepoints.
@@ -746,32 +964,24 @@ static void NoteDef(State &S, BBState &B
 }
 
 void LateLowerGCFrame::MaybeNoteDef(State &S, BBState &BBS, Value *Def, const std::vector<int> &SafepointsSoFar, SmallVector<int, 1> &&RefinedPtr) {
-    int Num = -1;
     Type *RT = Def->getType();
-    if (isSpecialPtr(RT)) {
-        assert(getValueAddrSpace(Def) == AddressSpace::Tracked &&
-            "Returned value of GC interest, but not tracked?");
-        Num = Number(S, Def);
-    }
-    else if (isUnionRep(RT)) {
-        // Probably a union return. Find the extractvalue
-        Num = Number(S, Def);
+    if (isa<PointerType>(RT)) {
+        if (!isSpecialPtr(RT))
+            return;
+        assert(isTrackedValue(Def) && "Returned value of GC interest, but not tracked?");
+        int Num = Number(S, Def);
+        NoteDef(S, BBS, Num, SafepointsSoFar);
+        if (!RefinedPtr.empty())
+            S.Refinements[Num] = std::move(RefinedPtr);
     }
-    else if (isSpecialPtrVec(RT)) {
-        std::vector<int> Nums = NumberVector(S, Def);
+    else {
+        std::vector<int> Nums = NumberAll(S, Def);
         for (int Num : Nums) {
             NoteDef(S, BBS, Num, SafepointsSoFar);
             if (!RefinedPtr.empty())
                 S.Refinements[Num] = RefinedPtr;
         }
-        return;
-    }
-    else {
-        return;
     }
-    NoteDef(S, BBS, Num, SafepointsSoFar);
-    if (!RefinedPtr.empty())
-        S.Refinements[Num] = std::move(RefinedPtr);
 }
 
 static int NoteSafepoint(State &S, BBState &BBS, CallInst *CI) {
@@ -782,8 +992,6 @@ static int NoteSafepoint(State &S, BBSta
     // considered live at this safepoint even when they have a def earlier
     // in this BB (i.e. even when they don't participate in the dataflow
     // computation)
-    BBS.UpExposedUses |= BBS.UpExposedUsesUnrooted;
-    BBS.UpExposedUsesUnrooted.reset();
     S.LiveSets.push_back(BBS.UpExposedUses);
     S.LiveIfLiveOut.push_back(std::vector<int>{});
     return Number;
@@ -793,8 +1001,16 @@ void LateLowerGCFrame::NoteUse(State &S,
     // Short circuit to avoid having to deal with vectors of constants, etc.
     if (isa<Constant>(V))
         return;
-    else if (isSpecialPtrVec(V->getType())) {
-        std::vector<int> Nums = NumberVector(S, V);
+    if (isa<PointerType>(V->getType())) {
+        if (isSpecialPtr(V->getType())) {
+            int Num = Number(S, V);
+            if (Num < 0)
+                return;
+            MaybeResize(BBS, Num);
+            Uses[Num] = 1;
+        }
+    } else {
+        std::vector<int> Nums = NumberAll(S, V);
         for (int Num : Nums) {
             if (Num < 0)
                 continue;
@@ -802,21 +1018,11 @@ void LateLowerGCFrame::NoteUse(State &S,
             Uses[Num] = 1;
         }
     }
-    else {
-        int Num = Number(S, V);
-        if (Num < 0)
-            return;
-        MaybeResize(BBS, Num);
-        Uses[Num] = 1;
-    }
 }
 
-void LateLowerGCFrame::NoteOperandUses(State &S, BBState &BBS, User &UI, BitVector &Uses) {
+void LateLowerGCFrame::NoteOperandUses(State &S, BBState &BBS, User &UI) {
     for (Use &U : UI.operands()) {
-        Value *V = U;
-        if (!isSpecialPtr(V->getType()) && !isSpecialPtrVec(V->getType()))
-            continue;
-        NoteUse(S, BBS, V, Uses);
+        NoteUse(S, BBS, U);
     }
 }
 
@@ -858,8 +1064,6 @@ JL_USED_FUNC static void dumpLivenessSta
         dumpBitVectorValues(S, S.BBStates[&BB].Defs);
         dbgs() << "\n\tPhiOuts: ";
         dumpBitVectorValues(S, S.BBStates[&BB].PhiOuts);
-        dbgs() << "\n\tUpExposedUsesUnrooted: ";
-        dumpBitVectorValues(S, S.BBStates[&BB].UpExposedUsesUnrooted);
         dbgs() << "\n\tUpExposedUses: ";
         dumpBitVectorValues(S, S.BBStates[&BB].UpExposedUses);
         dbgs() << "\n\tLiveIn: ";
@@ -940,15 +1144,15 @@ JL_USED_FUNC static void DumpRefinements
         int Num = kv.first;
         if (Num < 0)
             continue;
-        jl_safe_printf("Refinements for %d  --  ", Num);
+        dbgs() << "Refinements for " << Num << "  --  ";
         auto V = S->ReversePtrNumbering[Num];
         llvm_dump(V);
         for (auto refine: kv.second) {
             if (refine < 0) {
-                jl_safe_printf("  %d\n", refine);
+                dbgs() << "  " << (int)refine;
                 continue;
             }
-            jl_safe_printf("  %d: ", refine);
+            dbgs() << "  " << (int)refine << ": ";
             auto R = S->ReversePtrNumbering[refine];
             llvm_dump(R);
         }
@@ -1106,7 +1310,7 @@ void LateLowerGCFrame::FixUpRefinements(
 
 State LateLowerGCFrame::LocalScan(Function &F) {
     State S(F);
-    SmallVector<int, 16> PHINumbers;
+    SmallVector<int, 8> PHINumbers;
     for (BasicBlock &BB : F) {
         BBState &BBS = S.BBStates[&BB];
         for (auto it = BB.rbegin(); it != BB.rend(); ++it) {
@@ -1123,6 +1327,23 @@ State LateLowerGCFrame::LocalScan(Functi
                         II->getIntrinsicID() == Intrinsic::lifetime_end) {
                         continue;
                     }
+                    if (II->getIntrinsicID() == Intrinsic::masked_load ||
+                        II->getIntrinsicID() == Intrinsic::masked_gather) {
+                        if (auto PtrT = dyn_cast<PointerType>(II->getType()->getVectorElementType())) {
+                            if (isSpecialPtr(PtrT)) {
+                                // LLVM sometimes tries to materialize these operations with undefined pointers in our non-integral address space.
+                                // Hopefully LLVM didn't already propagate that information and poison our users. Set those to NULL now.
+                                Value *passthru = II->getArgOperand(3);
+                                if (isa<UndefValue>(passthru)) {
+                                    II->setArgOperand(3, Constant::getNullValue(passthru->getType()));
+                                }
+                                if (PtrT->getAddressSpace() == AddressSpace::Loaded) {
+                                    // These are not real defs
+                                    continue;
+                                }
+                            }
+                        }
+                    }
                 }
                 auto callee = CI->getCalledFunction();
                 if (callee && callee == typeof_func) {
@@ -1131,14 +1352,29 @@ State LateLowerGCFrame::LocalScan(Functi
                 else {
                     MaybeNoteDef(S, BBS, CI, BBS.Safepoints);
                 }
-                NoteOperandUses(S, BBS, I, BBS.UpExposedUses);
-                for (Use &U : CI->operands()) {
-                    Value *V = U;
-                    if (isUnionRep(V->getType())) {
-                        NoteUse(S, BBS, V);
-                        continue;
+                if (CI->hasStructRetAttr()) {
+                    AllocaInst *SRet = dyn_cast<AllocaInst>((CI->arg_begin()[0])->stripInBoundsOffsets());
+                    if (SRet) {
+                        Type *ElT = SRet->getAllocatedType();
+                        if (!(SRet->isStaticAlloca() && isa<PointerType>(ElT) && ElT->getPointerAddressSpace() == AddressSpace::Tracked)) {
+                            auto tracked = CountTrackedPointers(ElT);
+                            if (tracked.count) {
+                                assert(!tracked.derived);
+                                if (tracked.all) {
+                                    S.ArrayAllocas[SRet] = tracked.count * cast<ConstantInt>(SRet->getArraySize())->getZExtValue();
+                                }
+                                else {
+                                    AllocaInst *SRet_gc = dyn_cast<AllocaInst>((CI->arg_begin()[1])->stripInBoundsOffsets());
+                                    Type *ElT = SRet_gc->getAllocatedType();
+                                    if (!(SRet_gc->isStaticAlloca() && isa<PointerType>(ElT) && ElT->getPointerAddressSpace() == AddressSpace::Tracked)) {
+                                        S.ArrayAllocas[SRet_gc] = tracked.count * cast<ConstantInt>(SRet_gc->getArraySize())->getZExtValue();
+                                    }
+                                }
+                            }
+                        }
                     }
                 }
+                NoteOperandUses(S, BBS, I);
                 if (CI->canReturnTwice()) {
                     S.ReturnsTwice.push_back(CI);
                 }
@@ -1168,6 +1404,9 @@ State LateLowerGCFrame::LocalScan(Functi
                         callee->hasFnAttribute(Attribute::ArgMemOnly)) {
                         continue;
                     }
+                    if (MemTransferInst *MI = dyn_cast<MemTransferInst>(CI)) {
+                        MaybeTrackDst(S, MI);
+                    }
                 }
                 if (isa<IntrinsicInst>(CI) || CI->hasFnAttr(Attribute::ArgMemOnly) ||
                     CI->hasFnAttr(Attribute::ReadNone) || CI->hasFnAttr(Attribute::ReadOnly)) {
@@ -1185,11 +1424,12 @@ State LateLowerGCFrame::LocalScan(Functi
                 // of this object to uses of the object we're loading
                 // from.
                 SmallVector<int, 1> RefinedPtr{};
+                Type *Ty = LI->getType()->getScalarType();
                 if (isLoadFromImmut(LI) && isSpecialPtr(LI->getPointerOperand()->getType())) {
                     RefinedPtr.push_back(Number(S, LI->getPointerOperand()));
                 } else if (LI->getType()->isPointerTy() &&
-                    isSpecialPtr(LI->getType()) &&
-                    LooksLikeFrameRef(LI->getPointerOperand())) {
+                        isSpecialPtr(Ty) &&
+                        LooksLikeFrameRef(LI->getPointerOperand())) {
                     // Loads from a jlcall argument array
                     RefinedPtr.push_back(-1);
                 }
@@ -1198,79 +1438,60 @@ State LateLowerGCFrame::LocalScan(Functi
                     // we know that the object is a constant as well and doesn't need rooting.
                     RefinedPtr.push_back(-2);
                 }
-                if (!LI->getType()->isPointerTy() ||
-                    cast<PointerType>(LI->getType())->getAddressSpace() != AddressSpace::Loaded) {
+                if (!Ty->isPointerTy() || Ty->getPointerAddressSpace() != AddressSpace::Loaded) {
                     MaybeNoteDef(S, BBS, LI, BBS.Safepoints, std::move(RefinedPtr));
                 }
-                NoteOperandUses(S, BBS, I, BBS.UpExposedUsesUnrooted);
+                NoteOperandUses(S, BBS, I);
             } else if (SelectInst *SI = dyn_cast<SelectInst>(&I)) {
-                // We need to insert an extra select for the GC root
-                if (!isSpecialPtr(SI->getType()) && !isSpecialPtrVec(SI->getType()) &&
-                    !isUnionRep(SI->getType()))
-                    continue;
-                if (!isUnionRep(SI->getType()) && getValueAddrSpace(SI) != AddressSpace::Tracked) {
-                    if (isSpecialPtrVec(SI->getType()) ?
-                        S.AllVectorNumbering.find(SI) != S.AllVectorNumbering.end() :
-                        S.AllPtrNumbering.find(SI) != S.AllPtrNumbering.end())
-                        continue;
-                    if (!LiftSelect(S, SI))
-                        continue;
-                    if (!isSpecialPtrVec(SI->getType())) {
-                        // TODO: Refinements for vector select
-                        int Num = S.AllPtrNumbering[SI];
-                        if (Num < 0)
-                            continue;
-                        auto SelectBase = cast<SelectInst>(S.ReversePtrNumbering[Num]);
-                        SmallVector<int, 2> RefinedPtr{Number(S, SelectBase->getTrueValue()),
-                                Number(S, SelectBase->getFalseValue())};
-                        S.Refinements[Num] = std::move(RefinedPtr);
-                    }
-                } else {
+                auto tracked = CountTrackedPointers(SI->getType());
+                if (tracked.count && !tracked.derived) {
+                    // record the select definition of these values
                     SmallVector<int, 2> RefinedPtr;
-                    if (!isSpecialPtrVec(SI->getType())) {
+                    if (isa<PointerType>(SI->getType())) {
+                        // TODO: Refinements for vector select
                         RefinedPtr = {
                             Number(S, SI->getTrueValue()),
                             Number(S, SI->getFalseValue())
                         };
                     }
                     MaybeNoteDef(S, BBS, SI, BBS.Safepoints, std::move(RefinedPtr));
-                    NoteOperandUses(S, BBS, I, BBS.UpExposedUsesUnrooted);
+                    NoteOperandUses(S, BBS, I);
+                } else if (tracked.count) {
+                    // We need to insert extra selects for the GC roots
+                    LiftSelect(S, SI);
                 }
             } else if (PHINode *Phi = dyn_cast<PHINode>(&I)) {
-                if (!isSpecialPtr(Phi->getType()) && !isSpecialPtrVec(Phi->getType()) &&
-                    !isUnionRep(Phi->getType())) {
-                    continue;
-                }
-                auto nIncoming = Phi->getNumIncomingValues();
-                // We need to insert an extra phi for the GC root
-                if (!isUnionRep(Phi->getType()) && getValueAddrSpace(Phi) != AddressSpace::Tracked) {
-                    if (isSpecialPtrVec(Phi->getType()) ?
-                        S.AllVectorNumbering.find(Phi) != S.AllVectorNumbering.end() :
-                        S.AllPtrNumbering.find(Phi) != S.AllPtrNumbering.end())
-                        continue;
-                    LiftPhi(S, Phi, PHINumbers);
-                } else {
+                auto tracked = CountTrackedPointers(Phi->getType());
+                if (tracked.count && !tracked.derived) {
+                    // record the phi definition of these values
                     SmallVector<int, 1> PHIRefinements;
-                    if (!isSpecialPtrVec(Phi->getType()))
+                    if (isa<PointerType>(Phi->getType()))
+                        // TODO: Vector refinements
                         PHIRefinements = GetPHIRefinements(Phi, S);
                     MaybeNoteDef(S, BBS, Phi, BBS.Safepoints, std::move(PHIRefinements));
-                    if (isSpecialPtrVec(Phi->getType())) {
-                        // TODO: Vector refinements
-                        std::vector<int> Nums = NumberVector(S, Phi);
+                    if (isa<PointerType>(Phi->getType())) {
+                        PHINumbers.push_back(Number(S, Phi));
+                    } else {
+                        std::vector<int> Nums = NumberAll(S, Phi);
                         for (int Num : Nums)
                             PHINumbers.push_back(Num);
-                    } else {
-                        PHINumbers.push_back(Number(S, Phi));
                     }
+                    unsigned nIncoming = Phi->getNumIncomingValues();
                     for (unsigned i = 0; i < nIncoming; ++i) {
                         BBState &IncomingBBS = S.BBStates[Phi->getIncomingBlock(i)];
                         NoteUse(S, IncomingBBS, Phi->getIncomingValue(i), IncomingBBS.PhiOuts);
                     }
-                }
-            } else if (isa<StoreInst>(&I) || isa<ReturnInst>(&I)) {
-                NoteOperandUses(S, BBS, I, BBS.UpExposedUsesUnrooted);
+                } else if (tracked.count) {
+                    // We need to insert extra phis for the GC roots
+                    LiftPhi(S, Phi);
+                }
+            } else if (StoreInst *SI = dyn_cast<StoreInst>(&I)) {
+                NoteOperandUses(S, BBS, I);
+                MaybeTrackStore(S, SI);
+            } else if (isa<ReturnInst>(&I)) {
+                NoteOperandUses(S, BBS, I);
             } else if (auto *ASCI = dyn_cast<AddrSpaceCastInst>(&I)) {
-                if (getValueAddrSpace(ASCI) == AddressSpace::Tracked) {
+                if (isTrackedValue(ASCI)) {
                     SmallVector<int, 1> RefinedPtr{};
                     auto origin = ASCI->getPointerOperand()->stripPointerCasts();
                     if (auto LI = dyn_cast<LoadInst>(origin)) {
@@ -1281,22 +1502,132 @@ State LateLowerGCFrame::LocalScan(Functi
                     MaybeNoteDef(S, BBS, ASCI, BBS.Safepoints, std::move(RefinedPtr));
                 }
             } else if (auto *AI = dyn_cast<AllocaInst>(&I)) {
-                if (isSpecialPtr(AI->getAllocatedType()) && !AI->isArrayAllocation() &&
-                    cast<PointerType>(AI->getAllocatedType())->getAddressSpace() == AddressSpace::Tracked)
-                {
+                Type *ElT = AI->getAllocatedType();
+                if (AI->isStaticAlloca() && isa<PointerType>(ElT) && ElT->getPointerAddressSpace() == AddressSpace::Tracked) {
                     S.Allocas.push_back(AI);
                 }
             }
         }
         // Pre-seed the dataflow variables;
         BBS.LiveIn = BBS.UpExposedUses;
-        BBS.LiveIn |= BBS.UpExposedUsesUnrooted;
         BBS.Done = true;
     }
     FixUpRefinements(PHINumbers, S);
     return S;
 }
 
+static Value *ExtractScalar(Value *V, Type *VTy, bool isptr, ArrayRef<unsigned> Idxs, IRBuilder<> irbuilder) {
+    Type *T_int32 = Type::getInt32Ty(V->getContext());
+    if (isptr) {
+        std::vector<Value*> IdxList{Idxs.size() + 1};
+        IdxList[0] = ConstantInt::get(T_int32, 0);
+        for (unsigned j = 0; j < Idxs.size(); ++j) {
+            IdxList[j + 1] = ConstantInt::get(T_int32, Idxs[j]);
+        }
+        Value *GEP = irbuilder.CreateGEP(VTy, V, IdxList);
+        V = irbuilder.CreateLoad(GEP);
+    } else if (isa<PointerType>(V->getType())) {
+        assert(Idxs.empty());
+    }
+    else if (!Idxs.empty()) {
+        auto IdxsNotVec = Idxs.slice(0, Idxs.size() - 1);
+        Type *FinalT = ExtractValueInst::getIndexedType(V->getType(), IdxsNotVec);
+        bool IsVector = isa<VectorType>(FinalT);
+        if (Idxs.size() > IsVector)
+            V = irbuilder.Insert(ExtractValueInst::Create(V, IsVector ? IdxsNotVec : Idxs));
+        if (IsVector)
+            V = irbuilder.Insert(ExtractElementInst::Create(V,
+                    ConstantInt::get(Type::getInt32Ty(V->getContext()), Idxs.back())));
+    }
+    return V;
+}
+
+std::vector<Value*> ExtractTrackedValues(Value *Src, Type *STy, bool isptr, IRBuilder<> irbuilder) {
+    auto Tracked = TrackCompositeType(STy);
+    std::vector<Value*> Ptrs;
+    for (unsigned i = 0; i < Tracked.size(); ++i) {
+        auto Idxs = makeArrayRef(Tracked[i]);
+        Value *Elem = ExtractScalar(Src, STy, isptr, Idxs, irbuilder);
+        Ptrs.push_back(Elem);
+    }
+    return Ptrs;
+}
+
+unsigned TrackWithShadow(Value *Src, Type *STy, bool isptr, Value *Dst, IRBuilder<> irbuilder) {
+    auto Ptrs = ExtractTrackedValues(Src, STy, isptr, irbuilder);
+    for (unsigned i = 0; i < Ptrs.size(); ++i) {
+        Value *Elem = Ptrs[i];
+        Value *Slot = irbuilder.CreateConstInBoundsGEP1_32(Elem->getType(), Dst, i);
+        Value *shadowStore = irbuilder.CreateStore(Elem, Slot);
+        (void)shadowStore;
+        // TODO: shadowStore->setMetadata(LLVMContext::MD_tbaa, tbaa_gcframe);
+    }
+    return Ptrs.size();
+}
+
+
+// turn a memcpy into a set of loads
+void LateLowerGCFrame::MaybeTrackDst(State &S, MemTransferInst *MI) {
+    //Value *Dst = MI->getRawDest()->stripInBoundsOffsets();
+    //if (AllocaInst *AI = dyn_cast<AllocaInst>(Dst)) {
+    //    Type *STy = AI->getAllocatedType();
+    //    if (!AI->isStaticAlloca() || (isa<PointerType>(STy) && STy->getPointerAddressSpace() == AddressSpace::Tracked) || S.ArrayAllocas.count(AI))
+    //        return; // already numbered this
+    //    auto tracked = CountTrackedPointers(STy);
+    //    unsigned nroots = tracked.count * cast<ConstantInt>(AI->getArraySize())->getZExtValue();
+    //    if (nroots) {
+    //        assert(!tracked.derived);
+    //        if (!tracked.all) {
+    //            // materialize shadow LoadInst and StoreInst ops to make a copy of just the tracked values inside
+    //            //assert(MI->getLength() == DL.getTypeAllocSize(AI->getAllocatedType()) && !AI->isArrayAllocation()); // XXX: handle partial copy
+    //            Value *Src = MI->getSource();
+    //            Src = new BitCastInst(Src, STy->getPointerTo(MI->getSourceAddressSpace()), "", MI);
+    //            auto &Shadow = S.ShadowAllocas[AI];
+    //            if (!Shadow)
+    //                Shadow = new AllocaInst(T_prjlvalue, 0, ConstantInt::get(T_int32, nroots), "", MI);
+    //            AI = Shadow;
+    //            unsigned count = TrackWithShadow(Src, STy, true, AI, IRBuilder<>(MI));
+    //            assert(count == tracked.count); (void)count;
+    //        }
+    //        S.ArrayAllocas[AI] = nroots;
+    //    }
+    //}
+    //// TODO: else???
+}
+
+void LateLowerGCFrame::MaybeTrackStore(State &S, StoreInst *I) {
+    Value *PtrBase = I->getPointerOperand()->stripInBoundsOffsets();
+    auto tracked = CountTrackedPointers(I->getValueOperand()->getType());
+    if (!tracked.count)
+        return; // nothing to track is being stored
+    if (AllocaInst *AI = dyn_cast<AllocaInst>(PtrBase)) {
+        Type *STy = AI->getAllocatedType();
+        if (!AI->isStaticAlloca() || (isa<PointerType>(STy) && STy->getPointerAddressSpace() == AddressSpace::Tracked) || S.ArrayAllocas.count(AI))
+            return; // already numbered this
+        auto tracked = CountTrackedPointers(STy);
+        if (tracked.count) {
+            assert(!tracked.derived);
+            if (tracked.all) {
+                // track the Alloca directly
+                S.ArrayAllocas[AI] = tracked.count * cast<ConstantInt>(AI->getArraySize())->getZExtValue();
+                return;
+            }
+        }
+    }
+    else {
+        return; // assume it is rooted--TODO: should we be more conservative?
+    }
+    // track the Store with a Shadow
+    //auto &Shadow = S.ShadowAllocas[AI];
+    //if (!Shadow)
+    //    Shadow = new AllocaInst(T_prjlvalue, 0, ConstantInt::get(T_int32, tracked.count), "", MI);
+    //AI = Shadow;
+    //Value *Src = I->getValueOperand();
+    //unsigned count = TrackWithShadow(Src, Src->getType(), false, AI, MI, TODO which slots are we actually clobbering?);
+    //assert(count == tracked.count); (void)count;
+    S.TrackedStores.push_back(std::make_pair(I, tracked.count));
+}
+
 /*
  * DataFlow equations:
  * LiveIn[BB] = UpExposedUses[BB] ∪ (LiveOut[BB] - Defs[BB])
@@ -1331,7 +1662,6 @@ void LateLowerGCFrame::ComputeLiveness(S
             FlippedDefs.flip();
             NewLiveIn &= FlippedDefs;
             NewLiveIn |= BBS.UpExposedUses;
-            NewLiveIn |= BBS.UpExposedUsesUnrooted;
             if (NewLiveIn != BBS.LiveIn) {
                 AnyChanged = true;
                 BBS.LiveIn = NewLiveIn;
@@ -1701,25 +2031,20 @@ bool LateLowerGCFrame::CleanupIR(Functio
         Frame = new AllocaInst(T_prjlvalue, 0,
             ConstantInt::get(T_int32, maxframeargs), "", StartOff);
     }
-    SmallVector<CallInst*, 16> write_barriers;
+    std::vector<CallInst*> write_barriers;
     for (BasicBlock &BB : F) {
         for (auto it = BB.begin(); it != BB.end();) {
             Instruction *I = &*it;
-            if (isa<LoadInst>(I) || isa<StoreInst>(I)) {
-                // strip all constant alias information, as it might depend on the gc having
-                // preserved a gc root, which stops being true after this pass (#32215)
-                // we'd like to call RewriteStatepointsForGC::stripNonValidData here, but
-                // that function asserts that the GC strategy must be named either "statepoint-example" or "coreclr",
-                // while we don't give a name to our GC in the IR, and C++ scope rules prohibit us from using it,
-                // so instead we reimplement it here badly
-                if (I->getMetadata(LLVMContext::MD_invariant_load))
-                    I->setMetadata(LLVMContext::MD_invariant_load, NULL);
-                if (MDNode *TBAA = I->getMetadata(LLVMContext::MD_tbaa)) {
-                    if (TBAA->getNumOperands() == 4 && isTBAA(TBAA, {"jtbaa_const"})) {
-                        MDNode *MutableTBAA = createMutableTBAAAccessTag(TBAA);
-                        if (MutableTBAA != TBAA)
-                            I->setMetadata(LLVMContext::MD_tbaa, MutableTBAA);
-                    }
+            // strip all constant alias information, as it might depend on the gc having
+            // preserved a gc root, which stops being true after this pass (#32215)
+            // similar to RewriteStatepointsForGC::stripNonValidData, but less aggressive
+            if (I->getMetadata(LLVMContext::MD_invariant_load))
+                I->setMetadata(LLVMContext::MD_invariant_load, NULL);
+            if (MDNode *TBAA = I->getMetadata(LLVMContext::MD_tbaa)) {
+                if (TBAA->getNumOperands() == 4 && isTBAA(TBAA, {"jtbaa_const"})) {
+                    MDNode *MutableTBAA = createMutableTBAAAccessTag(TBAA);
+                    if (MutableTBAA != TBAA)
+                        I->setMetadata(LLVMContext::MD_tbaa, MutableTBAA);
                 }
             }
             auto *CI = dyn_cast<CallInst>(&*it);
@@ -1785,7 +2110,7 @@ bool LateLowerGCFrame::CleanupIR(Functio
             } else if (write_barrier_func && callee == write_barrier_func) {
                 // The replacement for this requires creating new BasicBlocks
                 // which messes up the loop. Queue all of them to be replaced later.
-                assert(CI->getNumArgOperands() == 2);
+                assert(CI->getNumArgOperands() >= 1);
                 write_barriers.push_back(CI);
                 ChangesMade = true;
                 ++it;
@@ -1858,10 +2183,10 @@ bool LateLowerGCFrame::CleanupIR(Functio
             ChangesMade = true;
         }
     }
-    for (auto CI: write_barriers) {
+    for (auto CI : write_barriers) {
         auto parent = CI->getArgOperand(0);
-        auto child = CI->getArgOperand(1);
-        if (parent == child || IsPermRooted(child, S)) {
+        if (std::all_of(CI->op_begin() + 1, CI->op_end(),
+                    [parent, &S](Value *child) { return parent == child || IsPermRooted(child, S); })) {
             CI->eraseFromParent();
             continue;
         }
@@ -1871,11 +2196,17 @@ bool LateLowerGCFrame::CleanupIR(Functio
         auto parOldMarked = builder.CreateICmpEQ(parBits, ConstantInt::get(T_size, 3));
         auto mayTrigTerm = SplitBlockAndInsertIfThen(parOldMarked, CI, false);
         builder.SetInsertPoint(mayTrigTerm);
-        auto chldBit = builder.CreateAnd(EmitLoadTag(builder, child), 1);
-        auto chldNotMarked = builder.CreateICmpEQ(chldBit, ConstantInt::get(T_size, 0));
+        Value *anyChldNotMarked = NULL;
+        for (unsigned i = 1; i < CI->getNumArgOperands(); i++) {
+            Value *child = CI->getArgOperand(i);
+            Value *chldBit = builder.CreateAnd(EmitLoadTag(builder, child), 1);
+            Value *chldNotMarked = builder.CreateICmpEQ(chldBit, ConstantInt::get(T_size, 0));
+            anyChldNotMarked = anyChldNotMarked ? builder.CreateOr(anyChldNotMarked, chldNotMarked) : chldNotMarked;
+        }
+        assert(anyChldNotMarked); // handled by all_of test above
         MDBuilder MDB(parent->getContext());
         SmallVector<uint32_t, 2> Weights{1, 9};
-        auto trigTerm = SplitBlockAndInsertIfThen(chldNotMarked, mayTrigTerm, false,
+        auto trigTerm = SplitBlockAndInsertIfThen(anyChldNotMarked, mayTrigTerm, false,
                                                   MDB.createBranchWeights(Weights));
         builder.SetInsertPoint(trigTerm);
         builder.CreateCall(getOrDeclare(jl_intrinsics::queueGCRoot), parent);
@@ -1927,23 +2258,20 @@ static void AddInPredLiveOuts(BasicBlock
 
 void LateLowerGCFrame::PlaceGCFrameStore(State &S, unsigned R, unsigned MinColorRoot,
                                          const std::vector<int> &Colors, Value *GCFrame,
-                                         Instruction *InsertionPoint) {
-    Value *Val = GetPtrForNumber(S, R, InsertionPoint);
-
+                                         Instruction *InsertBefore) {
     // Get the slot address.
     auto slotAddress = CallInst::Create(
         getOrDeclare(jl_intrinsics::getGCFrameSlot),
-        {GCFrame, ConstantInt::get(T_int32, Colors[R] + MinColorRoot)});
+        {GCFrame, ConstantInt::get(T_int32, Colors[R] + MinColorRoot)},
+        "", InsertBefore);
 
-    slotAddress->insertBefore(InsertionPoint);
-
-    Val = MaybeExtractUnion(std::make_pair(Val, -1), InsertionPoint);
+    Value *Val = GetPtrForNumber(S, R, InsertBefore);
     // Pointee types don't have semantics, so the optimizer is
     // free to rewrite them if convenient. We need to change
     // it back here for the store.
     if (Val->getType() != T_prjlvalue)
-        Val = new BitCastInst(Val, T_prjlvalue, "", InsertionPoint);
-    new StoreInst(Val, slotAddress, InsertionPoint);
+        Val = new BitCastInst(Val, T_prjlvalue, "", InsertBefore);
+    new StoreInst(Val, slotAddress, InsertBefore);
 }
 
 void LateLowerGCFrame::PlaceGCFrameStores(State &S, unsigned MinColorRoot,
@@ -1977,28 +2305,32 @@ void LateLowerGCFrame::PlaceRootsAndUpda
     for (auto C : Colors)
         if (C > MaxColor)
             MaxColor = C;
+
     // Insert instructions for the actual gc frame
-    if (MaxColor != -1 || S.Allocas.size() != 0) {
-        unsigned NRoots = MaxColor + 1 + S.Allocas.size();
+    if (MaxColor != -1 || !S.Allocas.empty() || !S.ArrayAllocas.empty() || !S.TrackedStores.empty()) {
         // Create and push a GC frame.
         auto gcframe = CallInst::Create(
             getOrDeclare(jl_intrinsics::newGCFrame),
-            {ConstantInt::get(T_int32, NRoots)},
+            {ConstantInt::get(T_int32, 0)},
             "gcframe");
         gcframe->insertBefore(&*F->getEntryBlock().begin());
 
         auto pushGcframe = CallInst::Create(
             getOrDeclare(jl_intrinsics::pushGCFrame),
-            {gcframe, ConstantInt::get(T_int32, NRoots)});
+            {gcframe, ConstantInt::get(T_int32, 0)});
         pushGcframe->insertAfter(ptlsStates);
 
         // Replace Allocas
-        unsigned AllocaSlot = 0;
-        for (AllocaInst *AI : S.Allocas) {
+        unsigned AllocaSlot = 2; // first two words are metadata
+        auto replace_alloca = [this, gcframe, &AllocaSlot](AllocaInst *&AI) {
             // Pick a slot for the alloca.
-            auto slotAddress = CallInst::Create(
+            unsigned align = AI->getAlignment() / sizeof(void*); // TODO: use DataLayout pointer size
+            assert(align <= 16 / sizeof(void*) && "Alignment exceeds llvm-final-gc-lowering abilities");
+            if (align > 1)
+                AllocaSlot = LLT_ALIGN(AllocaSlot, align);
+            Instruction *slotAddress = CallInst::Create(
                 getOrDeclare(jl_intrinsics::getGCFrameSlot),
-                {gcframe, ConstantInt::get(T_int32, AllocaSlot++)});
+                {gcframe, ConstantInt::get(T_int32, AllocaSlot - 2)});
             slotAddress->insertAfter(gcframe);
             slotAddress->takeName(AI);
 
@@ -2012,14 +2344,53 @@ void LateLowerGCFrame::PlaceRootsAndUpda
                     return;
                 ToDelete.push_back(II);
             }, AI);
-            for (CallInst *II : ToDelete)
+            for (CallInst *II : ToDelete) {
                 II->eraseFromParent();
+            }
+            if (slotAddress->getType() != AI->getType()) {
+                // If we're replacing an ArrayAlloca, the pointer element type may need to be fixed up
+                auto BCI  = new BitCastInst(slotAddress, AI->getType());
+                BCI->insertAfter(slotAddress);
+                slotAddress = BCI;
+            }
             AI->replaceAllUsesWith(slotAddress);
             AI->eraseFromParent();
-        }
-        unsigned MinColorRoot = AllocaSlot;
+            AI = NULL;
+        };
+        for (AllocaInst *AI : S.Allocas) {
+            auto ns = cast<ConstantInt>(AI->getArraySize())->getZExtValue();
+            replace_alloca(AI);
+            AllocaSlot += ns;
+        }
+        for (auto AI : S.ArrayAllocas) {
+            replace_alloca(AI.first);
+            AllocaSlot += AI.second;
+        }
+        for (auto Store : S.TrackedStores) {
+            auto SI = Store.first;
+            auto Base = SI->getValueOperand();
+            //auto Tracked = TrackCompositeType(Base->getType());
+            for (unsigned i = 0; i < Store.second; ++i) {
+                auto slotAddress = CallInst::Create(
+                    getOrDeclare(jl_intrinsics::getGCFrameSlot),
+                    {gcframe, ConstantInt::get(T_int32, AllocaSlot - 2)});
+                slotAddress->insertAfter(gcframe);
+                auto ValExpr = std::make_pair(Base, isa<PointerType>(Base->getType()) ? -1 : i);
+                auto Elem = MaybeExtractScalar(S, ValExpr, SI);
+                //auto Idxs = makeArrayRef(Tracked[i]);
+                //Value *Elem = ExtractScalar(Base, true, Idxs, SI);
+                Value *shadowStore = new StoreInst(Elem, slotAddress, SI);
+                (void)shadowStore;
+                // TODO: shadowStore->setMetadata(LLVMContext::MD_tbaa, tbaa_gcframe);
+                AllocaSlot++;
+            }
+        }
+        auto NRoots = ConstantInt::get(T_int32, MaxColor + 1 + AllocaSlot - 2);
+        gcframe->setArgOperand(0, NRoots);
+        pushGcframe->setArgOperand(1, NRoots);
+
         // Insert GC frame stores
-        PlaceGCFrameStores(S, MinColorRoot, Colors, gcframe);
+        PlaceGCFrameStores(S, AllocaSlot - 2, Colors, gcframe);
         // Insert GCFrame pops
         for(Function::iterator I = F->begin(), E = F->end(); I != E; ++I) {
             if (isa<ReturnInst>(I->getTerminator())) {
diff -pruN 1.3.1+dfsg-1/src/llvm-lower-handlers.cpp 1.4.0+dfsg-1/src/llvm-lower-handlers.cpp
--- 1.3.1+dfsg-1/src/llvm-lower-handlers.cpp	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/src/llvm-lower-handlers.cpp	2020-03-21 16:36:32.000000000 +0000
@@ -185,7 +185,7 @@ bool LowerExcHandlers::runOnFunction(Fun
         auto *buff = new AllocaInst(Type::getInt8Ty(F.getContext()),
                                        0,
                                        handler_sz, "", firstInst);
-        buff->setAlignment(16);
+        buff->setAlignment(Align(16));
         buffs.push_back(buff);
     }
 
diff -pruN 1.3.1+dfsg-1/src/llvm-version.h 1.4.0+dfsg-1/src/llvm-version.h
--- 1.3.1+dfsg-1/src/llvm-version.h	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/src/llvm-version.h	2020-03-21 16:36:32.000000000 +0000
@@ -12,3 +12,6 @@
 #if JL_LLVM_VERSION < 60000
     #error Only LLVM versions >= 6.0.0 are supported by Julia
 #endif
+#if JL_LLVM_VERSION < 100000
+#define Align(a) (a)
+#endif
diff -pruN 1.3.1+dfsg-1/src/locks.h 1.4.0+dfsg-1/src/locks.h
--- 1.3.1+dfsg-1/src/locks.h	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/src/locks.h	2020-03-21 16:36:32.000000000 +0000
@@ -122,19 +122,6 @@ static inline int jl_mutex_trylock(jl_mu
     }
     return got;
 }
-
-/* Call this function for code that could be called from either a managed
-   or an unmanaged thread */
-static inline void jl_mutex_lock_maybe_nogc(jl_mutex_t *lock)
-{
-    jl_ptls_t ptls = jl_get_ptls_states();
-    if (ptls->safepoint) {
-        jl_mutex_lock(lock);
-    } else {
-        jl_mutex_lock_nogc(lock);
-    }
-}
-
 static inline void jl_mutex_unlock_nogc(jl_mutex_t *lock) JL_NOTSAFEPOINT
 {
 #ifndef __clang_analyzer__
@@ -156,15 +143,6 @@ static inline void jl_mutex_unlock(jl_mu
     JL_SIGATOMIC_END();
 }
 
-static inline void jl_mutex_unlock_maybe_nogc(jl_mutex_t *lock) {
-    jl_ptls_t ptls = jl_get_ptls_states();
-    if (ptls->safepoint) {
-        jl_mutex_unlock(lock);
-    } else {
-        jl_mutex_unlock_nogc(lock);
-    }
-}
-
 static inline void jl_mutex_init(jl_mutex_t *lock) JL_NOTSAFEPOINT
 {
     lock->owner = 0;
diff -pruN 1.3.1+dfsg-1/src/macroexpand.scm 1.4.0+dfsg-1/src/macroexpand.scm
--- 1.3.1+dfsg-1/src/macroexpand.scm	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/src/macroexpand.scm	2020-03-21 16:36:32.000000000 +0000
@@ -15,9 +15,9 @@
               (loop (cdr lst) (cons nxt out)))))))
 
 (define (julia-bq-expand- x d)
-  (cond ((or (eq? x 'true) (eq? x 'false))  x)
-        ((or (symbol? x) (ssavalue? x))     (list 'inert x))
+  (cond ((or (symbol? x) (ssavalue? x))     (list 'inert x))
         ((atom? x)  x)
+        ((memq (car x) '(true false)) x)
         ((and (= d 0) (eq? (car x) '$))
          (if (length= x 2)
              (if (vararg? (cadr x))
@@ -206,8 +206,7 @@
 
 ;; get the name from a function formal argument expression, allowing `(escape x)`
 (define (try-arg-name v)
-  (cond ((and (symbol? v) (not (eq? v 'true)) (not (eq? v 'false)))
-         (list v))
+  (cond ((symbol? v) (list v))
         ((atom? v) '())
         (else
          (case (car v)
@@ -315,7 +314,7 @@
    m parent-scope inarg))
 
 (define (resolve-expansion-vars- e env m parent-scope inarg)
-  (cond ((or (eq? e 'true) (eq? e 'false) (eq? e 'end) (eq? e 'ccall) (eq? e 'cglobal))
+  (cond ((or (eq? e 'end) (eq? e 'ccall) (eq? e 'cglobal))
          e)
         ((symbol? e)
          (let ((a (assq e env)))
diff -pruN 1.3.1+dfsg-1/src/Makefile 1.4.0+dfsg-1/src/Makefile
--- 1.3.1+dfsg-1/src/Makefile	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/src/Makefile	2020-03-21 16:36:32.000000000 +0000
@@ -39,24 +39,20 @@ ifeq ($(OS),FreeBSD)
 FLAGS += -I$(LOCALBASE)/include
 endif
 
-RUNTIME_C_SRCS := \
+RUNTIME_SRCS := \
 	jltypes gf typemap ast builtins module interpreter symbol \
 	dlload sys init task array dump staticdata toplevel jl_uv datatype \
 	simplevector runtime_intrinsics precompile \
 	threading partr stackwalk gc gc-debug gc-pages gc-stacks method \
-	jlapi signal-handling safepoint jloptions timing subtype \
-	crc32c
-RUNTIME_SRCS := APInt-C runtime_ccall processor rtutils $(RUNTIME_C_SRCS)
-SRCS := $(RUNTIME_SRCS)
-
-ifeq ($(USEMSVC), 1)
-SRCS += getopt
-endif
+	jlapi signal-handling safepoint timing subtype \
+	crc32c APInt-C processor
+SRCS := jloptions runtime_ccall rtutils
 
 LLVMLINK :=
 
 ifeq ($(JULIACODEGEN),LLVM)
-SRCS += codegen jitlayers disasm debuginfo llvm-simdloop llvm-ptls llvm-muladd \
+SRCS += codegen llvm-ptls
+RUNTIME_SRCS += jitlayers debuginfo disasm llvm-simdloop llvm-muladd \
 	llvm-final-gc-lowering llvm-pass-helpers llvm-late-gc-lowering \
 	llvm-lower-handlers llvm-gc-invariant-verifier llvm-propagate-addrspaces \
 	llvm-multiversioning llvm-alloc-opt cgmemmgr llvm-api
@@ -77,10 +73,17 @@ FLAGS += -I$(shell $(LLVM_CONFIG_HOST) -
 endif
 endif
 else
-SRCS += anticodegen
+RUNTIME_SRCS += anticodegen
 LLVM_LIBS := support
 endif
 
+ifeq ($(USEMSVC), 1)
+SRCS += getopt
+endif
+
+SRCS += $(RUNTIME_SRCS)
+
+
 # headers are used for dependency tracking, while public headers will be part of the dist
 UV_HEADERS :=
 HEADERS := $(BUILDDIR)/julia_version.h $(wildcard $(SRCDIR)/support/*.h) $(addprefix $(SRCDIR)/,julia.h julia_assert.h julia_threads.h tls.h locks.h atomics.h julia_internal.h options.h timing.h)
@@ -91,16 +94,19 @@ UV_HEADERS += uv/*.h
 endif
 PUBLIC_HEADER_TARGETS := $(addprefix $(build_includedir)/julia/,$(notdir $(PUBLIC_HEADERS)) $(UV_HEADERS))
 
+LLVM_LDFLAGS := $(shell $(LLVM_CONFIG_HOST) --ldflags)
+LLVM_CXXFLAGS := $(shell $(LLVM_CONFIG_HOST) --cxxflags)
+
 ifeq ($(JULIACODEGEN),LLVM)
 ifneq ($(USE_SYSTEM_LLVM),0)
-LLVMLINK += $(shell $(LLVM_CONFIG_HOST) --ldflags --libs --system-libs)
+LLVMLINK += $(LLVM_LDFLAGS) $(shell $(LLVM_CONFIG_HOST) --libs --system-libs)
 # HACK: llvm-config doesn't correctly point to shared libs on all platforms
 #       https://github.com/JuliaLang/julia/issues/29981
 else
 ifneq ($(USE_LLVM_SHLIB),1)
-LLVMLINK += $(shell $(LLVM_CONFIG_HOST) --ldflags) $(shell $(LLVM_CONFIG_HOST) --libs $(LLVM_LIBS)) $(shell $(LLVM_CONFIG_HOST) --ldflags) $(shell $(LLVM_CONFIG_HOST) --system-libs 2> /dev/null)
+LLVMLINK += $(LLVM_LDFLAGS) $(shell $(LLVM_CONFIG_HOST) --libs $(LLVM_LIBS)) $($(LLVM_LDFLAGS) $(shell $(LLVM_CONFIG_HOST) --system-libs 2> /dev/null)
 else
-LLVMLINK += $(shell $(LLVM_CONFIG_HOST) --ldflags) -lLLVM
+LLVMLINK += $(LLVM_LDFLAGS) -lLLVM
 endif
 endif
 ifeq ($(USE_LLVM_SHLIB),1)
@@ -108,6 +114,12 @@ FLAGS += -DLLVM_SHLIB
 endif # USE_LLVM_SHLIB == 1
 endif
 
+CLANG_LDFLAGS := $(LLVM_LDFLAGS)
+ifeq ($(OS), Darwin)
+CLANG_LDFLAGS += -Wl,-undefined,dynamic_lookup
+endif
+
+
 COMMON_LIBS := -L$(build_shlibdir) -L$(build_libdir) $(LIBUV) $(LIBUTF8PROC) $(NO_WHOLE_ARCHIVE) $(LLVMLINK) $(OSLIBS) $(LIBUNWIND)
 DEBUG_LIBS := $(WHOLE_ARCHIVE) $(BUILDDIR)/flisp/libflisp-debug.a $(WHOLE_ARCHIVE) $(BUILDDIR)/support/libsupport-debug.a $(COMMON_LIBS)
 RELEASE_LIBS := $(WHOLE_ARCHIVE) $(BUILDDIR)/flisp/libflisp.a $(WHOLE_ARCHIVE) $(BUILDDIR)/support/libsupport.a $(COMMON_LIBS)
@@ -150,9 +162,9 @@ $(BUILDDIR)/%.o: $(SRCDIR)/%.c $(HEADERS
 $(BUILDDIR)/%.dbg.obj: $(SRCDIR)/%.c $(HEADERS) | $(BUILDDIR)
 	@$(call PRINT_CC, $(CC) $(JCPPFLAGS) $(JCFLAGS) $(DEBUGFLAGS) -c $< -o $@)
 $(BUILDDIR)/%.o: $(SRCDIR)/%.cpp $(SRCDIR)/llvm-version.h $(HEADERS) $(LLVM_CONFIG_ABSOLUTE) | $(BUILDDIR)
-	@$(call PRINT_CC, $(CXX) $(shell $(LLVM_CONFIG_HOST) --cxxflags) $(JCPPFLAGS) $(JCXXFLAGS) $(SHIPFLAGS) $(CXX_DISABLE_ASSERTION) -c $< -o $@)
+	@$(call PRINT_CC, $(CXX) $(LLVM_CXXFLAGS) $(JCPPFLAGS) $(JCXXFLAGS) $(SHIPFLAGS) $(CXX_DISABLE_ASSERTION) -c $< -o $@)
 $(BUILDDIR)/%.dbg.obj: $(SRCDIR)/%.cpp $(SRCDIR)/llvm-version.h $(HEADERS) $(LLVM_CONFIG_ABSOLUTE) | $(BUILDDIR)
-	@$(call PRINT_CC, $(CXX) $(shell $(LLVM_CONFIG_HOST) --cxxflags) $(JCPPFLAGS) $(JCXXFLAGS) $(DEBUGFLAGS) -c $< -o $@)
+	@$(call PRINT_CC, $(CXX) $(LLVM_CXXFLAGS) $(JCPPFLAGS) $(JCXXFLAGS) $(DEBUGFLAGS) -c $< -o $@)
 
 # public header rules
 $(eval $(call dir_target,$(build_includedir)/julia))
@@ -192,7 +204,7 @@ endif
 	$(INSTALL_NAME_CMD)libccalltest.$(SHLIB_EXT) $@
 
 $(build_shlibdir)/libllvmcalltest.$(SHLIB_EXT): $(SRCDIR)/llvmcalltest.cpp $(LLVM_CONFIG_ABSOLUTE)
-	@$(call PRINT_CC, $(CXX) $(shell $(LLVM_CONFIG_HOST) --cxxflags) $(JCXXFLAGS) $(JCPPFLAGS) $(DEBUGFLAGS) -O3 $< $(fPIC) -shared -o $@ $(JLDFLAGS) -L$(build_shlibdir) -L$(build_libdir) $(NO_WHOLE_ARCHIVE) $(LLVMLINK))
+	@$(call PRINT_CC, $(CXX) $(LLVM_CXXFLAGS) $(JCXXFLAGS) $(JCPPFLAGS) $(DEBUGFLAGS) -O3 $< $(fPIC) -shared -o $@ $(JLDFLAGS) -L$(build_shlibdir) -L$(build_libdir) $(NO_WHOLE_ARCHIVE) $(LLVMLINK))
 
 julia_flisp.boot.inc.phony: $(BUILDDIR)/julia_flisp.boot.inc
 
@@ -206,26 +218,34 @@ $(BUILDDIR)/julia_flisp.boot: $(addprefi
 		$(call cygpath_w,$(SRCDIR)/mk_julia_flisp_boot.scm) $(call cygpath_w,$(dir $<)) $(notdir $<) $(call cygpath_w,$@))
 
 # additional dependency links
+$(BUILDDIR)/anticodegen.o $(BUILDDIR)/anticodegen.dbg.obj: $(SRCDIR)/intrinsics.h
 $(BUILDDIR)/ast.o $(BUILDDIR)/ast.dbg.obj: $(BUILDDIR)/julia_flisp.boot.inc $(SRCDIR)/flisp/*.h
+$(BUILDDIR)/builtins.o $(BUILDDIR)/builtins.dbg.obj: $(SRCDIR)/table.c $(SRCDIR)/builtin_proto.h
 $(BUILDDIR)/codegen.o $(BUILDDIR)/codegen.dbg.obj: $(addprefix $(SRCDIR)/,\
-	intrinsics.cpp jitlayers.h intrinsics.h codegen_shared.h cgutils.cpp ccall.cpp abi_*.cpp processor.h)
-$(BUILDDIR)/processor.o $(BUILDDIR)/processor.dbg.obj: $(addprefix $(SRCDIR)/,processor_*.cpp processor.h features_*.h)
-$(BUILDDIR)/interpreter.o $(BUILDDIR)/interpreter.dbg.obj: $(SRCDIR)/interpreter-stacktrace.c
-$(BUILDDIR)/anticodegen.o $(BUILDDIR)/anticodegen.dbg.obj: $(SRCDIR)/intrinsics.h
-$(BUILDDIR)/debuginfo.o $(BUILDDIR)/debuginfo.dbg.obj: \
-	$(addprefix $(SRCDIR)/,debuginfo.h processor.h)
+	intrinsics.cpp jitlayers.h intrinsics.h codegen_shared.h cgutils.cpp ccall.cpp abi_*.cpp processor.h builtin_proto.h)
+$(BUILDDIR)/debuginfo.o $(BUILDDIR)/debuginfo.dbg.obj: $(addprefix $(SRCDIR)/,debuginfo.h processor.h)
 $(BUILDDIR)/disasm.o $(BUILDDIR)/disasm.dbg.obj: $(SRCDIR)/debuginfo.h $(SRCDIR)/processor.h
-$(BUILDDIR)/jitlayers.o $(BUILDDIR)/jitlayers.dbg.obj: $(SRCDIR)/jitlayers.h
-$(BUILDDIR)/builtins.o $(BUILDDIR)/builtins.dbg.obj: $(SRCDIR)/table.c
-$(BUILDDIR)/staticdata.o $(BUILDDIR)/staticdata.dbg.obj: $(SRCDIR)/processor.h
-$(BUILDDIR)/llvm-final-gc-lowering.o $(BUILDDIR)/llvm-final-gc-lowering.dbg.obj: $(SRCDIR)/llvm-pass-helpers.h
-$(BUILDDIR)/llvm-late-gc-lowering.o $(BUILDDIR)/llvm-late-gc-lowering.dbg.obj: $(SRCDIR)/llvm-pass-helpers.h
-$(BUILDDIR)/llvm-pass-helpers.o $(BUILDDIR)/llvm-pass-helpers.dbg.obj: $(SRCDIR)/llvm-pass-helpers.h
-$(BUILDDIR)/gc.o $(BUILDDIR)/gc.dbg.obj: $(SRCDIR)/gc.h
+$(BUILDDIR)/dump.o $(BUILDDIR)/dump.dbg.obj: $(addprefix $(SRCDIR)/,common_symbols1.inc common_symbols2.inc builtin_proto.h)
 $(BUILDDIR)/gc-debug.o $(BUILDDIR)/gc-debug.dbg.obj: $(SRCDIR)/gc.h
 $(BUILDDIR)/gc-pages.o $(BUILDDIR)/gc-pages.dbg.obj: $(SRCDIR)/gc.h
+$(BUILDDIR)/gc.o $(BUILDDIR)/gc.dbg.obj: $(SRCDIR)/gc.h
+$(BUILDDIR)/init.o $(BUILDDIR)/init.dbg.obj: $(SRCDIR)/builtin_proto.h
+$(BUILDDIR)/interpreter.o $(BUILDDIR)/interpreter.dbg.obj: $(SRCDIR)/builtin_proto.h
+$(BUILDDIR)/jitlayers.o $(BUILDDIR)/jitlayers.dbg.obj: $(SRCDIR)/jitlayers.h $(SRCDIR)/codegen_shared.h
+$(BUILDDIR)/jltypes.o $(BUILDDIR)/jltypes.dbg.obj: $(SRCDIR)/builtin_proto.h
+$(BUILDDIR)/libllvmcalltest.$(SHLIB_EXT): $(SRCDIR)/codegen_shared.h
+$(BUILDDIR)/llvm-alloc-opt.o $(BUILDDIR)/llvm-alloc-opt.dbg.obj: $(SRCDIR)/codegen_shared.h
+$(BUILDDIR)/llvm-final-gc-lowering.o $(BUILDDIR)/llvm-final-gc-lowering.dbg.obj: $(SRCDIR)/llvm-pass-helpers.h
+$(BUILDDIR)/llvm-gc-invariant-verifier.o $(BUILDDIR)/llvm-gc-invariant-verifier.dbg.obj: $(SRCDIR)/codegen_shared.h
+$(BUILDDIR)/llvm-late-gc-lowering.o $(BUILDDIR)/llvm-late-gc-lowering.dbg.obj: $(SRCDIR)/llvm-pass-helpers.h
+$(BUILDDIR)/llvm-multiversioning.o $(BUILDDIR)/llvm-multiversioning.dbg.obj: $(SRCDIR)/codegen_shared.h
+$(BUILDDIR)/llvm-pass-helpers.o $(BUILDDIR)/llvm-pass-helpers.dbg.obj: $(SRCDIR)/llvm-pass-helpers.h $(SRCDIR)/codegen_shared.h
+$(BUILDDIR)/llvm-ptls.o $(BUILDDIR)/llvm-ptls.dbg.obj: $(SRCDIR)/codegen_shared.h
+$(BUILDDIR)/processor.o $(BUILDDIR)/processor.dbg.obj: $(addprefix $(SRCDIR)/,processor_*.cpp processor.h features_*.h)
 $(BUILDDIR)/signal-handling.o $(BUILDDIR)/signal-handling.dbg.obj: $(addprefix $(SRCDIR)/,signals-*.c)
-$(BUILDDIR)/dump.o $(BUILDDIR)/dump.dbg.obj: $(addprefix $(SRCDIR)/,common_symbols1.inc common_symbols2.inc)
+$(BUILDDIR)/staticdata.o $(BUILDDIR)/staticdata.dbg.obj: $(SRCDIR)/processor.h $(SRCDIR)/builtin_proto.h
+$(BUILDDIR)/toplevel.o $(BUILDDIR)/toplevel.dbg.obj: $(SRCDIR)/builtin_proto.h
+
 $(addprefix $(BUILDDIR)/,threading.o threading.dbg.obj gc.o gc.dbg.obj init.c init.dbg.obj task.o task.dbg.obj): $(addprefix $(SRCDIR)/,threading.h)
 $(addprefix $(BUILDDIR)/,APInt-C.o APInt-C.dbg.obj runtime_intrinsics.o runtime_intrinsics.dbg.obj): $(SRCDIR)/APInt-C.h
 
@@ -335,8 +355,9 @@ clean-support:
 
 cleanall: clean clean-flisp clean-support clean-analyzegc
 
-$(build_shlibdir)/libGCCheckerPlugin.$(SHLIB_EXT): $(SRCDIR)/clangsa/GCChecker.cpp
-	@$(call PRINT_CC, $(CXX) -g -shared -o $@ -DCLANG_PLUGIN -I$(build_includedir) $(shell $(LLVM_CONFIG_HOST) --cxxflags) $(CPPFLAGS) $(CFLAGS) $< $(shell $(LLVM_CONFIG_HOST) --ldflags) $(LDFLAGS) -L$(build_libdir) -lclangAnalysis -lclangStaticAnalyzerCore -lclangASTMatchers -lclangAST -lclangLex -lclangBasic)
+$(build_shlibdir)/libGCCheckerPlugin.$(SHLIB_EXT): $(SRCDIR)/clangsa/GCChecker.cpp $(LLVM_CONFIG_ABSOLUTE)
+	@$(call PRINT_CC, $(CXX) -g $(fPIC) -shared -o $@ -DCLANG_PLUGIN -I$(build_includedir) -L$(build_libdir) \
+		$(LLVM_CXXFLAGS) $(CLANG_LDFLAGS) $(CPPFLAGS) $(CXXFLAGS) $(LDFLAGS) $(CXXLDFLAGS) $<)
 
 # Throw an error if a proper version of `clang` is not available.
 # Note that for a default install, you will need to have run the following
@@ -346,24 +367,37 @@ $(build_shlibdir)/libGCCheckerPlugin.$(S
 analyzegc-deps-check: $(BUILDDIR)/julia_version.h $(BUILDDIR)/julia_flisp.boot.inc
 ifeq ($(USE_BINARYBUILDER_LLVM),0)
 ifneq ($(BUILD_LLVM_CLANG),1)
-	$(error Clang must be available to use the clang analyzer. Either build it (BUILD_LLVM_CLANG) or use BinaryBuilder)
+	$(error Clang must be available to use the clang analyzer. Either build it (BUILD_LLVM_CLANG=1) or use BinaryBuilder)
 endif
 endif
 
 
-define CLANG_ANALYZE
-clang-sa-$(1): $$(build_shlibdir)/libGCCheckerPlugin.$$(SHLIB_EXT) | analyzegc-deps-check
-	@$$(call PRINT_ANALYZE, $$(build_depsbindir)/clang --analyze -Xanalyzer -analyzer-werror -Xanalyzer -analyzer-output=text -Xclang -load -Xclang $$(build_shlibdir)/libGCCheckerPlugin.$$(SHLIB_EXT) $$(CPPFLAGS) $$(CFLAGS) $$(DEBUGFLAGS) -Xclang -analyzer-checker=core$$(COMMA)julia.GCChecker --analyzer-no-default-checks -fcolor-diagnostics -Werror -x c $$(SRCDIR)/$(1).c)
-.PHONY: clang-sa-$(1)
+# Note: we're passing *FLAGS here computed based on your system compiler to
+# clang. If that causes you problems, you might want to build and/or run
+# specific clang-sa-* files with clang explicitly selected:
+#   make CC=~+/../usr/tools/clang CXX=~+/../usr/tools/clang USECLANG=1 analyzegc
+#   make USECLANG=1 clang-sa-*
+CLANGSA_FLAGS :=
+CLANGSA_CXXFLAGS :=
+ifeq ($(OS), Darwin) # on new XCode, the files are hidden
+CLANGSA_FLAGS += -isysroot $(shell xcode-select -p)/Platforms/MacOSX.platform/Developer/SDKs/MacOSX.sdk
+CLANGSA_CXXFLAGS += -isystem $(shell xcode-select -p)/Toolchains/XcodeDefault.xctoolchain/usr/include/c++/v1
+endif
+ifeq ($(USEGCC),1)
+# try to help clang find the c++ files for CC by guessing the value for --prefix
+# by dropping lib/gcc/<platform>/<version> from the install directory it reports
+CLANGSA_CXXFLAGS += --gcc-toolchain="$(abspath $(shell LANG=C $(CC) -print-search-dirs | grep '^install: ' | sed -e "s/^install: //")/../../../..)"
+endif
 
-# Add this as a target of `analyzegc`
-analyzegc: clang-sa-$(1)
-endef
+clang-sa-%: $(SRCDIR)/%.c $(build_shlibdir)/libGCCheckerPlugin.$(SHLIB_EXT) | analyzegc-deps-check
+	@$(call PRINT_ANALYZE, $(build_depsbindir)/clang --analyze -Xanalyzer -analyzer-werror -Xanalyzer -analyzer-output=text -Xclang -load -Xclang $(build_shlibdir)/libGCCheckerPlugin.$(SHLIB_EXT) $(CLANGSA_FLAGS) $(JCPPFLAGS) $(JCFLAGS) $(DEBUGFLAGS)  -Xclang -analyzer-checker=core$(COMMA)julia.GCChecker --analyzer-no-default-checks -fcolor-diagnostics -Werror -x c $<)
+clang-sa-%: $(SRCDIR)/%.cpp $(build_shlibdir)/libGCCheckerPlugin.$(SHLIB_EXT) | analyzegc-deps-check
+	@$(call PRINT_ANALYZE, $(build_depsbindir)/clang --analyze -Xanalyzer -analyzer-werror -Xanalyzer -analyzer-output=text -Xclang -load -Xclang $(build_shlibdir)/libGCCheckerPlugin.$(SHLIB_EXT) $(CLANGSA_FLAGS) $(CLANGSA_CXXFLAGS) $(LLVM_CXXFLAGS) $(JCPPFLAGS) $(JCXXFLAGS) $(DEBUGFLAGS) -Xclang -analyzer-checker=core$(COMMA)julia.GCChecker --analyzer-no-default-checks -fcolor-diagnostics -Werror -x c++ $<)
 
-# Build a Makefile target for each file we want to analyze
-$(foreach S,$(RUNTIME_C_SRCS),$(eval $(call CLANG_ANALYZE,$(S))))
+# Add C files as a target of `analyzegc`
+analyzegc: $(addprefix clang-sa-,$(RUNTIME_SRCS))
 
 clean-analyzegc:
 	rm -f $(build_shlibdir)/libGCCheckerPlugin.$(SHLIB_EXT)
 
-.PHONY: default all debug release clean cleanall clean-* libccalltest libllvmcalltest julia_flisp.boot.inc.phony analyzegc
+.PHONY: default all debug release clean cleanall clean-* libccalltest libllvmcalltest julia_flisp.boot.inc.phony analyzegc clang-sa-*
diff -pruN 1.3.1+dfsg-1/src/method.c 1.4.0+dfsg-1/src/method.c
--- 1.3.1+dfsg-1/src/method.c	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/src/method.c	2020-03-21 16:36:32.000000000 +0000
@@ -18,6 +18,8 @@ extern "C" {
 extern jl_value_t *jl_builtin_getfield;
 extern jl_value_t *jl_builtin_tuple;
 
+// Resolve references to non-locally-defined variables to become references to global
+// variables in `module` (unless the rvalue is one of the type parameters in `sparam_vals`).
 static jl_value_t *resolve_globals(jl_value_t *expr, jl_module_t *module, jl_svec_t *sparam_vals,
                                    int binding_effects, int eager_resolve)
 {
@@ -376,7 +378,24 @@ STATIC_INLINE jl_value_t *jl_call_staged
     return code;
 }
 
-// return a newly allocated CodeInfo for the function signature
+// Lower `ex` into Julia IR, and (if it expands into a CodeInfo) resolve global-variable
+// references in light of the provided type parameters.
+// Like `jl_expand`, if there is an error expanding the provided expression, the return value
+// will be an error expression (an `Expr` with `error_sym` as its head), which should be eval'd
+// in the caller's context.
+JL_DLLEXPORT jl_code_info_t *jl_expand_and_resolve(jl_value_t *ex, jl_module_t *module,
+                                                   jl_svec_t *sparam_vals) {
+    jl_code_info_t *func = (jl_code_info_t*)jl_expand((jl_value_t*)ex, module);
+    JL_GC_PUSH1(&func);
+    if (jl_is_code_info(func)) {
+        jl_array_t *stmts = (jl_array_t*)func->code;
+        jl_resolve_globals_in_ir(stmts, module, sparam_vals, 1);
+    }
+    JL_GC_POP();
+    return func;
+}
+
+// Return a newly allocated CodeInfo for the function signature
 // effectively described by the tuple (specTypes, env, Method) inside linfo
 JL_DLLEXPORT jl_code_info_t *jl_code_for_staged(jl_method_instance_t *linfo)
 {
@@ -407,7 +426,9 @@ JL_DLLEXPORT jl_code_info_t *jl_code_for
             func = (jl_code_info_t*)ex;
         }
         else {
-            func = (jl_code_info_t*)jl_expand((jl_value_t*)ex, def->module);
+            // Lower the user's expression and resolve references to the type parameters
+            func = jl_expand_and_resolve(ex, def->module, linfo->sparam_vals);
+
             if (!jl_is_code_info(func)) {
                 if (jl_is_expr(func) && ((jl_expr_t*)func)->head == error_sym) {
                     ptls->in_pure_callback = 0;
@@ -415,9 +436,6 @@ JL_DLLEXPORT jl_code_info_t *jl_code_for
                 }
                 jl_error("The function body AST defined by this @generated function is not pure. This likely means it contains a closure or comprehension.");
             }
-
-            jl_array_t *stmts = (jl_array_t*)func->code;
-            jl_resolve_globals_in_ir(stmts, def->module, linfo->sparam_vals, 1);
         }
 
         ptls->in_pure_callback = last_in;
@@ -545,6 +563,9 @@ static void jl_method_set_source(jl_meth
                 gen_only = 1;
                 st = jl_nothing;
             }
+            else if (nargs == 2 && jl_exprarg(st, 0) == (jl_value_t*)jl_symbol("nkw")) {
+                m->nkw = jl_unbox_long(jl_exprarg(st, 1));
+            }
         }
         else {
             st = resolve_globals(st, m->module, sparam_vars, 1, 0);
@@ -584,6 +605,7 @@ JL_DLLEXPORT jl_method_t *jl_new_method_
     m->line = 0;
     m->called = 0xff;
     m->nospecialize = module->nospecialize;
+    m->nkw = 0;
     m->invokes = NULL;
     m->isva = 0;
     m->nargs = 0;
diff -pruN 1.3.1+dfsg-1/src/partr.c 1.4.0+dfsg-1/src/partr.c
--- 1.3.1+dfsg-1/src/partr.c	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/src/partr.c	2020-03-21 16:36:32.000000000 +0000
@@ -373,10 +373,11 @@ JL_DLLEXPORT void jl_set_task_tid(jl_tas
 }
 
 // get the next runnable task from the multiq
-static jl_task_t *get_next_task(jl_value_t *getsticky)
+static jl_task_t *get_next_task(jl_value_t *trypoptask, jl_value_t *q)
 {
     jl_gc_safepoint();
-    jl_task_t *task = (jl_task_t*)jl_apply(&getsticky, 1);
+    jl_value_t *args[2] = { trypoptask, q };
+    jl_task_t *task = (jl_task_t*)jl_apply(args, 2);
     if (jl_typeis(task, jl_task_type)) {
         int self = jl_get_ptls_states()->tid;
         jl_set_task_tid(task, self);
@@ -393,14 +394,14 @@ static int may_sleep(jl_ptls_t ptls)
 
 extern volatile unsigned _threadedregion;
 
-JL_DLLEXPORT jl_task_t *jl_task_get_next(jl_value_t *getsticky)
+JL_DLLEXPORT jl_task_t *jl_task_get_next(jl_value_t *trypoptask, jl_value_t *q)
 {
     jl_ptls_t ptls = jl_get_ptls_states();
     uint64_t start_cycles = 0;
     jl_task_t *task;
 
     while (1) {
-        task = get_next_task(getsticky);
+        task = get_next_task(trypoptask, q);
         if (task)
             return task;
 
@@ -416,7 +417,7 @@ JL_DLLEXPORT jl_task_t *jl_task_get_next
             if (!sleep_check_now(ptls->tid))
                 continue;
             jl_atomic_store(&ptls->sleep_check_state, sleeping); // acquire sleep-check lock
-            task = get_next_task(getsticky);
+            task = get_next_task(trypoptask, q);
             if (task)
                 return task;
             // one thread should win this race and watch the event loop
@@ -460,6 +461,9 @@ JL_DLLEXPORT jl_task_t *jl_task_get_next
                     // TODO: this relinquishes responsibility for all event
                     //       to the last thread to do an explicit operation,
                     //       which may starve other threads of critical work
+                    if (jl_atomic_load(&jl_uv_n_waiters) == 0) {
+                        continue;
+                    }
                 }
                 if (!_threadedregion && active && ptls->tid == 0) {
                     // thread 0 is the only thread permitted to run the event loop
@@ -483,7 +487,7 @@ JL_DLLEXPORT jl_task_t *jl_task_get_next
 #ifndef JL_HAVE_ASYNCIFY
             // maybe check the kernel for new messages too
             if (jl_atomic_load(&jl_uv_n_waiters) == 0)
-                jl_process_events(jl_global_event_loop());
+                jl_process_events();
 #else
             // Yield back to browser event loop
             return ptls->root_task;
diff -pruN 1.3.1+dfsg-1/src/rtutils.c 1.4.0+dfsg-1/src/rtutils.c
--- 1.3.1+dfsg-1/src/rtutils.c	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/src/rtutils.c	2020-03-21 16:36:32.000000000 +0000
@@ -112,7 +112,7 @@ JL_DLLEXPORT void JL_NORETURN jl_type_er
                                                jl_value_t *expected, jl_value_t *got)
 {
     jl_value_t *ctxt=NULL;
-    JL_GC_PUSH2(&ctxt, &got);
+    JL_GC_PUSH3(&ctxt, &expected, &got);
     ctxt = jl_pchar_to_string((char*)context, strlen(context));
     jl_value_t *ex = jl_new_struct(jl_typeerror_type, jl_symbol(fname), ctxt, expected, got);
     jl_throw(ex);
@@ -194,10 +194,7 @@ JL_DLLEXPORT void JL_NORETURN jl_eof_err
 // get kwsorter field, with appropriate error check and message
 JL_DLLEXPORT jl_value_t *jl_get_keyword_sorter(jl_value_t *f)
 {
-    jl_methtable_t *mt = jl_gf_mtable(f);
-    if (mt->kwsorter == NULL)
-        jl_errorf("function %s does not accept keyword arguments", jl_symbol_name(mt->name));
-    return mt->kwsorter;
+    return jl_get_kwsorter(jl_typeof(f));
 }
 
 JL_DLLEXPORT void jl_typeassert(jl_value_t *x, jl_value_t *t)
@@ -297,7 +294,7 @@ JL_DLLEXPORT void jl_restore_excstack(si
 void jl_copy_excstack(jl_excstack_t *dest, jl_excstack_t *src) JL_NOTSAFEPOINT
 {
     assert(dest->reserved_size >= src->top);
-    memcpy(jl_excstack_raw(dest), jl_excstack_raw(src), sizeof(uintptr_t)*src->top);
+    memcpy(jl_excstack_raw(dest), jl_excstack_raw(src), sizeof(jl_bt_element_t)*src->top);
     dest->top = src->top;
 }
 
@@ -317,15 +314,16 @@ void jl_reserve_excstack(jl_excstack_t *
 }
 
 void jl_push_excstack(jl_excstack_t **stack JL_REQUIRE_ROOTED_SLOT JL_ROOTING_ARGUMENT,
-                       jl_value_t *exception JL_ROOTED_ARGUMENT,
-                       uintptr_t *bt_data, size_t bt_size)
+                      jl_value_t *exception JL_ROOTED_ARGUMENT,
+                      jl_bt_element_t *bt_data, size_t bt_size)
 {
     jl_reserve_excstack(stack, (*stack ? (*stack)->top : 0) + bt_size + 2);
     jl_excstack_t *s = *stack;
-    memcpy(jl_excstack_raw(s) + s->top, bt_data, sizeof(uintptr_t)*bt_size);
+    jl_bt_element_t *rawstack = jl_excstack_raw(s);
+    memcpy(rawstack + s->top, bt_data, sizeof(jl_bt_element_t)*bt_size);
     s->top += bt_size + 2;
-    jl_excstack_raw(s)[s->top-2] = bt_size;
-    jl_excstack_raw(s)[s->top-1] = (uintptr_t)exception;
+    rawstack[s->top-2].uintptr = bt_size;
+    rawstack[s->top-1].jlvalue = exception;
 }
 
 // conversion -----------------------------------------------------------------
@@ -345,6 +343,22 @@ JL_DLLEXPORT jl_value_t *jl_value_ptr(jl
     return a;
 }
 
+// optimization of setfield which bypasses boxing of the idx (and checking field type validity)
+JL_DLLEXPORT void jl_set_nth_field(jl_value_t *v, size_t idx0, jl_value_t *rhs)
+{
+    jl_datatype_t *st = (jl_datatype_t*)jl_typeof(v);
+    if (!st->mutabl)
+        jl_errorf("setfield! immutable struct of type %s cannot be changed", jl_symbol_name(st->name->name));
+    if (idx0 >= jl_datatype_nfields(st))
+        jl_bounds_error_int(v, idx0 + 1);
+    //jl_value_t *ft = jl_field_type(st, idx0);
+    //if (!jl_isa(rhs, ft)) {
+    //    jl_type_error("setfield!", ft, rhs);
+    //}
+    set_nth_field(st, (void*)v, idx0, rhs);
+}
+
+
 // parsing --------------------------------------------------------------------
 
 int substr_isspace(char *p, char *pend)
@@ -385,7 +399,7 @@ JL_DLLEXPORT jl_nullable_float64_t jl_tr
             newstr = (char*)alloca(len + 1);
         }
         else {
-            newstr = tofree = (char*)malloc(len + 1);
+            newstr = tofree = (char*)malloc_s(len + 1);
         }
         memcpy(newstr, bstr, len);
         newstr[len] = 0;
@@ -444,7 +458,7 @@ JL_DLLEXPORT jl_nullable_float32_t jl_tr
             newstr = (char*)alloca(len + 1);
         }
         else {
-            newstr = tofree = (char*)malloc(len + 1);
+            newstr = tofree = (char*)malloc_s(len + 1);
         }
         memcpy(newstr, bstr, len);
         newstr[len] = 0;
@@ -496,16 +510,18 @@ JL_DLLEXPORT void jl_flush_cstdio(void)
 
 JL_DLLEXPORT jl_value_t *jl_stdout_obj(void) JL_NOTSAFEPOINT
 {
-    if (jl_base_module == NULL) return NULL;
-    jl_value_t *stdout_obj = jl_get_module_binding(jl_base_module, jl_symbol("stdout"))->value;
-    return stdout_obj;
+    if (jl_base_module == NULL)
+        return NULL;
+    jl_binding_t *stdout_obj = jl_get_module_binding(jl_base_module, jl_symbol("stdout"));
+    return stdout_obj ? stdout_obj->value : NULL;
 }
 
 JL_DLLEXPORT jl_value_t *jl_stderr_obj(void) JL_NOTSAFEPOINT
 {
-    if (jl_base_module == NULL) return NULL;
-    jl_value_t *stderr_obj = jl_get_module_binding(jl_base_module, jl_symbol("stderr"))->value;
-    return stderr_obj;
+    if (jl_base_module == NULL)
+        return NULL;
+    jl_binding_t *stderr_obj = jl_get_module_binding(jl_base_module, jl_symbol("stderr"));
+    return stderr_obj ? stderr_obj->value : NULL;
 }
 
 // toys for debugging ---------------------------------------------------------
diff -pruN 1.3.1+dfsg-1/src/runtime_ccall.cpp 1.4.0+dfsg-1/src/runtime_ccall.cpp
--- 1.3.1+dfsg-1/src/runtime_ccall.cpp	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/src/runtime_ccall.cpp	2020-03-21 16:36:32.000000000 +0000
@@ -27,7 +27,7 @@ using namespace llvm;
 static std::map<std::string, void*> libMap;
 static jl_mutex_t libmap_lock;
 extern "C"
-void *jl_get_library(const char *f_lib)
+void *jl_get_library_(const char *f_lib, int throw_err)
 {
     void *hnd;
 #ifdef _OS_WINDOWS_
@@ -47,7 +47,7 @@ void *jl_get_library(const char *f_lib)
     if (hnd != NULL)
         return hnd;
     // We might run this concurrently on two threads but it doesn't matter.
-    hnd = jl_load_dynamic_library(f_lib, JL_RTLD_DEFAULT, 1);
+    hnd = jl_load_dynamic_library(f_lib, JL_RTLD_DEFAULT, throw_err);
     if (hnd != NULL)
         jl_atomic_store_release(map_slot, hnd);
     return hnd;
@@ -195,13 +195,22 @@ static void *trampoline_alloc()
 {
     const int sz = 64; // oversized for most platforms. todo: use precise value?
     if (!trampoline_freelist) {
+        int last_errno = errno;
 #ifdef _OS_WINDOWS_
+        DWORD last_error = GetLastError();
         void *mem = VirtualAlloc(NULL, jl_page_size,
                 MEM_RESERVE | MEM_COMMIT, PAGE_EXECUTE_READWRITE);
+        if (mem == NULL)
+            jl_throw(jl_memory_exception);
+        SetLastError(last_error);
 #else
         void *mem = mmap(0, jl_page_size, PROT_READ | PROT_WRITE | PROT_EXEC,
                 MAP_PRIVATE | MAP_ANONYMOUS, -1, 0);
+        errno = last_errno;
+        if (mem == MAP_FAILED)
+            jl_throw(jl_memory_exception);
 #endif
+        errno = last_errno;
         void *next = NULL;
         for (size_t i = 0; i + sz <= jl_page_size; i += sz) {
             void **curr = (void**)((char*)mem + i);
@@ -260,7 +269,7 @@ jl_value_t *jl_get_cfunction_trampoline(
         htable_t **cache2 = (htable_t**)ptrhash_bp(cache, (void*)vals);
         cache = *cache2;
         if (cache == HT_NOTFOUND) {
-            cache = htable_new((htable_t*)malloc(sizeof(htable_t)), 1);
+            cache = htable_new((htable_t*)malloc_s(sizeof(htable_t)), 1);
             *cache2 = cache;
         }
     }
@@ -272,7 +281,7 @@ jl_value_t *jl_get_cfunction_trampoline(
 
     // not found, allocate a new one
     size_t n = jl_svec_len(fill);
-    void **nval = (void**)malloc(sizeof(void*) * (n + 1));
+    void **nval = (void**)malloc_s(sizeof(void*) * (n + 1));
     nval[0] = (void*)fobj;
     jl_value_t *result;
     JL_TRY {
diff -pruN 1.3.1+dfsg-1/src/runtime_intrinsics.c 1.4.0+dfsg-1/src/runtime_intrinsics.c
--- 1.3.1+dfsg-1/src/runtime_intrinsics.c	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/src/runtime_intrinsics.c	2020-03-21 16:36:32.000000000 +0000
@@ -914,6 +914,7 @@ un_fintrinsic(floor_float,floor_llvm)
 un_fintrinsic(trunc_float,trunc_llvm)
 un_fintrinsic(rint_float,rint_llvm)
 un_fintrinsic(sqrt_float,sqrt_llvm)
+un_fintrinsic(sqrt_float,sqrt_llvm_fast)
 
 JL_DLLEXPORT jl_value_t *jl_arraylen(jl_value_t *a)
 {
diff -pruN 1.3.1+dfsg-1/src/signal-handling.c 1.4.0+dfsg-1/src/signal-handling.c
--- 1.3.1+dfsg-1/src/signal-handling.c	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/src/signal-handling.c	2020-03-21 16:36:32.000000000 +0000
@@ -18,7 +18,7 @@ extern "C" {
 #include <threading.h>
 
 // Profiler control variables //
-static volatile intptr_t *bt_data_prof = NULL;
+static volatile jl_bt_element_t *bt_data_prof = NULL;
 static volatile size_t bt_size_max = 0;
 static volatile size_t bt_size_cur = 0;
 static volatile uint64_t nsecprof = 0;
@@ -221,7 +221,7 @@ void jl_show_sigill(void *_ctx)
 }
 
 // what to do on a critical error
-void jl_critical_error(int sig, bt_context_t *context, uintptr_t *bt_data, size_t *bt_size)
+void jl_critical_error(int sig, bt_context_t *context, jl_bt_element_t *bt_data, size_t *bt_size)
 {
     // This function is not allowed to reference any TLS variables.
     // We need to explicitly pass in the TLS buffer pointer when
@@ -230,10 +230,14 @@ void jl_critical_error(int sig, bt_conte
     if (sig)
         jl_safe_printf("\nsignal (%d): %s\n", sig, strsignal(sig));
     jl_safe_printf("in expression starting at %s:%d\n", jl_filename, jl_lineno);
-    if (context)
-        *bt_size = n = rec_backtrace_ctx(bt_data, JL_MAX_BT_SIZE, context);
-    for (i = 0; i < n; i++)
-        jl_gdblookup(bt_data[i] - 1);
+    if (context) {
+        // Must avoid extended backtrace frames here unless we're sure bt_data
+        // is properly rooted.
+        *bt_size = n = rec_backtrace_ctx(bt_data, JL_MAX_BT_SIZE, context, NULL);
+    }
+    for (i = 0; i < n; i += jl_bt_entry_size(bt_data + i)) {
+        jl_print_bt_entry_codeloc(bt_data + i);
+    }
     gc_debug_print_status();
     gc_debug_critical_error();
 }
@@ -247,7 +251,7 @@ JL_DLLEXPORT int jl_profile_init(size_t
     nsecprof = delay_nsec;
     if (bt_data_prof != NULL)
         free((void*)bt_data_prof);
-    bt_data_prof = (intptr_t*) calloc(maxsize, sizeof(intptr_t));
+    bt_data_prof = (jl_bt_element_t*) calloc(maxsize, sizeof(jl_bt_element_t));
     if (bt_data_prof == NULL && maxsize > 0)
         return -1;
     bt_size_cur = 0;
diff -pruN 1.3.1+dfsg-1/src/signals-mach.c 1.4.0+dfsg-1/src/signals-mach.c
--- 1.3.1+dfsg-1/src/signals-mach.c	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/src/signals-mach.c	2020-03-21 16:36:32.000000000 +0000
@@ -142,13 +142,13 @@ static void jl_throw_in_thread(int tid,
     if (!ptls2->safe_restore) {
         assert(exception);
         ptls2->bt_size = rec_backtrace_ctx(ptls2->bt_data, JL_MAX_BT_SIZE,
-                                           (bt_context_t*)&state);
+                                           (bt_context_t*)&state, ptls2->pgcstack);
         ptls2->sig_exception = exception;
     }
     jl_call_in_state(ptls2, &state, &jl_sig_throw);
     ret = thread_set_state(thread, x86_THREAD_STATE64,
                            (thread_state_t)&state, count);
-    HANDLE_MACH_ERROR("thread_set_state",ret);
+    HANDLE_MACH_ERROR("thread_set_state", ret);
 }
 
 //exc_server uses dlsym to find symbol
@@ -343,7 +343,7 @@ static void jl_exit_thread0(int exitstat
     jl_call_in_state(ptls2, &state, (void (*)(void))exit_func);
     ret = thread_set_state(thread, x86_THREAD_STATE64,
                            (thread_state_t)&state, count);
-    HANDLE_MACH_ERROR("thread_set_state",ret);
+    HANDLE_MACH_ERROR("thread_set_state", ret);
 
     ret = thread_resume(thread);
     HANDLE_MACH_ERROR("thread_resume", ret);
@@ -412,7 +412,7 @@ void *mach_profile_listener(void *arg)
 #ifdef LIBOSXUNWIND
     mach_profiler_thread = mach_thread_self();
 #endif
-    mig_reply_error_t *bufRequest = (mig_reply_error_t *) malloc(max_size);
+    mig_reply_error_t *bufRequest = (mig_reply_error_t*)malloc_s(max_size);
     while (1) {
         kern_return_t ret = mach_msg(&bufRequest->Head, MACH_RCV_MSG,
                                      0, max_size, profile_port,
@@ -427,52 +427,50 @@ void *mach_profile_listener(void *arg)
 
             unw_context_t *uc;
             jl_thread_suspend_and_get_state(i, &uc);
-
+            if (running) {
 #ifdef LIBOSXUNWIND
-            /*
-             *  Unfortunately compact unwind info is incorrectly generated for quite a number of
-             *  libraries by quite a large number of compilers. We can fall back to DWARF unwind info
-             *  in some cases, but in quite a number of cases (especially libraries not compiled in debug
-             *  mode, only the compact unwind info may be available). Even more unfortunately, there is no
-             *  way to detect such bogus compact unwind info (other than noticing the resulting segfault).
-             *  What we do here is ugly, but necessary until the compact unwind info situation improves.
-             *  We try to use the compact unwind info and if that results in a segfault, we retry with DWARF info.
-             *  Note that in a small number of cases this may result in bogus stack traces, but at least the topmost
-             *  entry will always be correct, and the number of cases in which this is an issue is rather small.
-             *  Other than that, this implementation is not incorrect as the other thread is paused while we are profiling
-             *  and during stack unwinding we only ever read memory, but never write it.
-             */
-
-            forceDwarf = 0;
-            unw_getcontext(&profiler_uc); // will resume from this point if the next lines segfault at any point
-
-            if (forceDwarf == 0) {
-                // Save the backtrace
-                bt_size_cur += rec_backtrace_ctx((uintptr_t*)bt_data_prof + bt_size_cur, bt_size_max - bt_size_cur - 1, uc);
-            }
-            else if (forceDwarf == 1) {
-                bt_size_cur += rec_backtrace_ctx_dwarf((uintptr_t*)bt_data_prof + bt_size_cur, bt_size_max - bt_size_cur - 1, uc);
-            }
-            else if (forceDwarf == -1) {
-                jl_safe_printf("WARNING: profiler attempt to access an invalid memory location\n");
-            }
+                /*
+                 *  Unfortunately compact unwind info is incorrectly generated for quite a number of
+                 *  libraries by quite a large number of compilers. We can fall back to DWARF unwind info
+                 *  in some cases, but in quite a number of cases (especially libraries not compiled in debug
+                 *  mode, only the compact unwind info may be available). Even more unfortunately, there is no
+                 *  way to detect such bogus compact unwind info (other than noticing the resulting segfault).
+                 *  What we do here is ugly, but necessary until the compact unwind info situation improves.
+                 *  We try to use the compact unwind info and if that results in a segfault, we retry with DWARF info.
+                 *  Note that in a small number of cases this may result in bogus stack traces, but at least the topmost
+                 *  entry will always be correct, and the number of cases in which this is an issue is rather small.
+                 *  Other than that, this implementation is not incorrect as the other thread is paused while we are profiling
+                 *  and during stack unwinding we only ever read memory, but never write it.
+                 */
+
+                forceDwarf = 0;
+                unw_getcontext(&profiler_uc); // will resume from this point if the next lines segfault at any point
+
+                if (forceDwarf == 0) {
+                    // Save the backtrace
+                    bt_size_cur += rec_backtrace_ctx((jl_bt_element_t*)bt_data_prof + bt_size_cur, bt_size_max - bt_size_cur - 1, uc, NULL);
+                }
+                else if (forceDwarf == 1) {
+                    bt_size_cur += rec_backtrace_ctx_dwarf((jl_bt_element_t*)bt_data_prof + bt_size_cur, bt_size_max - bt_size_cur - 1, uc, NULL);
+                }
+                else if (forceDwarf == -1) {
+                    jl_safe_printf("WARNING: profiler attempt to access an invalid memory location\n");
+                }
 
-            forceDwarf = -2;
+                forceDwarf = -2;
 #else
-            bt_size_cur += rec_backtrace_ctx((uintptr_t*)bt_data_prof + bt_size_cur, bt_size_max - bt_size_cur - 1, uc);
+                bt_size_cur += rec_backtrace_ctx((jl_bt_element_t*)bt_data_prof + bt_size_cur, bt_size_max - bt_size_cur - 1, uc, NULL);
 #endif
 
-            // Mark the end of this block with 0
-            bt_data_prof[bt_size_cur++] = 0;
+                // Mark the end of this block with 0
+                bt_data_prof[bt_size_cur++].uintptr = 0;
 
-            // We're done! Resume the thread.
-            jl_thread_resume(i, 0);
-
-            if (running) {
                 // Reset the alarm
                 kern_return_t ret = clock_alarm(clk, TIME_RELATIVE, timerprof, profile_port);
                 HANDLE_MACH_ERROR("clock_alarm", ret)
             }
+            // We're done! Resume the thread.
+            jl_thread_resume(i, 0);
         }
     }
 }
diff -pruN 1.3.1+dfsg-1/src/signals-unix.c 1.4.0+dfsg-1/src/signals-unix.c
--- 1.3.1+dfsg-1/src/signals-unix.c	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/src/signals-unix.c	2020-03-21 16:36:32.000000000 +0000
@@ -176,7 +176,7 @@ static void jl_throw_in_ctx(jl_ptls_t pt
 {
     if (!ptls->safe_restore)
         ptls->bt_size = rec_backtrace_ctx(ptls->bt_data, JL_MAX_BT_SIZE,
-                                          jl_to_bt_context(sigctx));
+                                          jl_to_bt_context(sigctx), ptls->pgcstack);
     ptls->sig_exception = e;
     jl_call_in_ctx(ptls, &jl_sig_throw, sig, sigctx);
 }
@@ -551,7 +551,7 @@ static void kqueue_signal(int *sigqueue,
 
 static void *signal_listener(void *arg)
 {
-    static uintptr_t bt_data[JL_MAX_BT_SIZE + 1];
+    static jl_bt_element_t bt_data[JL_MAX_BT_SIZE + 1];
     static size_t bt_size = 0;
     sigset_t sset;
     int sig, critical, profile;
@@ -600,6 +600,7 @@ static void *signal_listener(void *arg)
         if (sigwait(&sset, &sig)) {
             sig = SIGABRT; // this branch can't occur, unless we had stack memory corruption of sset
         }
+#ifdef _OS_DARWIN_
         else if (!sig || errno == EINTR) {
             // This should never happen, but it has been observed to occur
             // when this thread gets used to handle run a signal handler (without SA_RESTART).
@@ -612,6 +613,7 @@ static void *signal_listener(void *arg)
             // So signals really do seem to always just be lose-lose.
             continue;
         }
+#endif
 #ifndef HAVE_MACH
 #  ifdef HAVE_ITIMER
         profile = (sig == SIGPROF);
@@ -668,8 +670,8 @@ static void *signal_listener(void *arg)
             if (critical) {
                 bt_size += rec_backtrace_ctx(bt_data + bt_size,
                         JL_MAX_BT_SIZE / jl_n_threads - 1,
-                        signal_context);
-                bt_data[bt_size++] = 0;
+                        signal_context, NULL);
+                bt_data[bt_size++].uintptr = 0;
             }
 
             // do backtrace for profiler
@@ -686,13 +688,13 @@ static void *signal_listener(void *arg)
                         jl_safe_printf("WARNING: profiler attempt to access an invalid memory location\n");
                     } else {
                         // Get backtrace data
-                        bt_size_cur += rec_backtrace_ctx((uintptr_t*)bt_data_prof + bt_size_cur,
-                                bt_size_max - bt_size_cur - 1, signal_context);
+                        bt_size_cur += rec_backtrace_ctx((jl_bt_element_t*)bt_data_prof + bt_size_cur,
+                                bt_size_max - bt_size_cur - 1, signal_context, NULL);
                     }
                     ptls->safe_restore = old_buf;
 
                     // Mark the end of this block with 0
-                    bt_data_prof[bt_size_cur++] = 0;
+                    bt_data_prof[bt_size_cur++].uintptr = 0;
                 }
                 if (bt_size_cur >= bt_size_max - 1) {
                     // Buffer full: Delete the timer
diff -pruN 1.3.1+dfsg-1/src/signals-win.c 1.4.0+dfsg-1/src/signals-win.c
--- 1.3.1+dfsg-1/src/signals-win.c	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/src/signals-win.c	2020-03-21 16:36:32.000000000 +0000
@@ -104,7 +104,7 @@ static void JL_NORETURN start_backtrace_
 {
     jl_ptls_t ptls = jl_get_ptls_states();
     // collect the backtrace
-    ptls->bt_size = rec_backtrace_ctx(ptls->bt_data, JL_MAX_BT_SIZE, error_ctx);
+    ptls->bt_size = rec_backtrace_ctx(ptls->bt_data, JL_MAX_BT_SIZE, error_ctx, ptls->pgcstack);
     // switch back to the execution fiber
     jl_setcontext(&error_return_fiber);
     abort();
@@ -130,7 +130,7 @@ void jl_throw_in_ctx(jl_value_t *excpt,
         assert(excpt != NULL);
         ptls->bt_size = 0;
         if (excpt != jl_stackovf_exception) {
-            ptls->bt_size = rec_backtrace_ctx(ptls->bt_data, JL_MAX_BT_SIZE, ctxThread);
+            ptls->bt_size = rec_backtrace_ctx(ptls->bt_data, JL_MAX_BT_SIZE, ctxThread, ptls->pgcstack);
         }
         else if (have_backtrace_fiber) {
             error_ctx = ctxThread;
@@ -297,7 +297,7 @@ LONG WINAPI jl_exception_handler(struct
                 jl_safe_printf("UNKNOWN"); break;
         }
         jl_safe_printf(" at 0x%Ix -- ", (size_t)ExceptionInfo->ExceptionRecord->ExceptionAddress);
-        jl_gdblookup((uintptr_t)ExceptionInfo->ExceptionRecord->ExceptionAddress);
+        jl_print_native_codeloc((uintptr_t)ExceptionInfo->ExceptionRecord->ExceptionAddress);
 
         jl_critical_error(0, ExceptionInfo->ContextRecord,
                           ptls->bt_data, &ptls->bt_size);
@@ -321,35 +321,37 @@ static DWORD WINAPI profile_bt( LPVOID l
     // Note: illegal to use jl_* functions from this thread
 
     TIMECAPS tc;
-    if (MMSYSERR_NOERROR!=timeGetDevCaps(&tc, sizeof(tc))) {
-        fputs("failed to get timer resolution",stderr);
+    if (MMSYSERR_NOERROR != timeGetDevCaps(&tc, sizeof(tc))) {
+        fputs("failed to get timer resolution", stderr);
         hBtThread = 0;
         return 0;
     }
     while (1) {
-        if (running && bt_size_cur < bt_size_max) {
+        if (bt_size_cur < bt_size_max) {
             DWORD timeout = nsecprof/GIGA;
-            timeout = min(max(timeout,tc.wPeriodMin*2),tc.wPeriodMax/2);
+            timeout = min(max(timeout, tc.wPeriodMin*2), tc.wPeriodMax/2);
             Sleep(timeout);
             if ((DWORD)-1 == SuspendThread(hMainThread)) {
-                fputs("failed to suspend main thread. aborting profiling.",stderr);
+                fputs("failed to suspend main thread. aborting profiling.", stderr);
                 break;
             }
-            CONTEXT ctxThread;
-            memset(&ctxThread, 0, sizeof(CONTEXT));
-            ctxThread.ContextFlags = CONTEXT_CONTROL | CONTEXT_INTEGER;
-            if (!GetThreadContext(hMainThread, &ctxThread)) {
-                fputs("failed to get context from main thread. aborting profiling.",stderr);
-                break;
+            if (running) {
+                CONTEXT ctxThread;
+                memset(&ctxThread, 0, sizeof(CONTEXT));
+                ctxThread.ContextFlags = CONTEXT_CONTROL | CONTEXT_INTEGER;
+                if (!GetThreadContext(hMainThread, &ctxThread)) {
+                    fputs("failed to get context from main thread. aborting profiling.", stderr);
+                    break;
+                }
+                // Get backtrace data
+                bt_size_cur += rec_backtrace_ctx((jl_bt_element_t*)bt_data_prof + bt_size_cur,
+                    bt_size_max - bt_size_cur - 1, &ctxThread, NULL);
+                // Mark the end of this block with 0
+                bt_data_prof[bt_size_cur].uintptr = 0;
+                bt_size_cur++;
             }
-            // Get backtrace data
-            bt_size_cur += rec_backtrace_ctx((uintptr_t*)bt_data_prof + bt_size_cur,
-                bt_size_max - bt_size_cur - 1, &ctxThread);
-            // Mark the end of this block with 0
-            bt_data_prof[bt_size_cur] = 0;
-            bt_size_cur++;
             if ((DWORD)-1 == ResumeThread(hMainThread)) {
-                fputs("failed to resume main thread! aborting.",stderr);
+                fputs("failed to resume main thread! aborting.", stderr);
                 gc_debug_critical_error();
                 abort();
             }
@@ -369,11 +371,11 @@ JL_DLLEXPORT int jl_profile_start_timer(
         hBtThread = CreateThread(
             NULL,                   // default security attributes
             0,                      // use default stack size
-            profile_bt,            // thread function name
+            profile_bt,             // thread function name
             0,                      // argument to thread function
             0,                      // use default creation flags
             0);                     // returns the thread identifier
-        (void)SetThreadPriority(hBtThread,THREAD_PRIORITY_ABOVE_NORMAL);
+        (void)SetThreadPriority(hBtThread, THREAD_PRIORITY_ABOVE_NORMAL);
     }
     else {
         if ((DWORD)-1 == ResumeThread(hBtThread)) {
diff -pruN 1.3.1+dfsg-1/src/stackwalk.c 1.4.0+dfsg-1/src/stackwalk.c
--- 1.3.1+dfsg-1/src/stackwalk.c	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/src/stackwalk.c	2020-03-21 16:36:32.000000000 +0000
@@ -25,40 +25,141 @@ extern "C" {
 #endif
 
 static int jl_unw_init(bt_cursor_t *cursor, bt_context_t *context) JL_NOTSAFEPOINT;
-static int jl_unw_step(bt_cursor_t *cursor, uintptr_t *ip, uintptr_t *sp, uintptr_t *fp) JL_NOTSAFEPOINT;
+static int jl_unw_step(bt_cursor_t *cursor, uintptr_t *ip, uintptr_t *sp) JL_NOTSAFEPOINT;
 
-size_t jl_unw_stepn(bt_cursor_t *cursor, uintptr_t *ip, uintptr_t *sp, size_t maxsize, int add_interp_frames) JL_NOTSAFEPOINT
+static jl_gcframe_t *is_enter_interpreter_frame(jl_gcframe_t **ppgcstack, uintptr_t sp) JL_NOTSAFEPOINT
+{
+    jl_gcframe_t *pgcstack = *ppgcstack;
+    while (pgcstack != NULL) {
+        jl_gcframe_t *prev = pgcstack->prev;
+        if (pgcstack->nroots & 2) { // tagged frame
+            uintptr_t frame_fp = ((uintptr_t*)pgcstack)[-1];
+            if (frame_fp != 0) { // check that frame was fully initialized
+                if (frame_fp >= sp)
+                    break; // stack grows down, so frame pointer is monotonically increasing
+                *ppgcstack = prev;
+                return pgcstack;
+            }
+        }
+        *ppgcstack = pgcstack = prev;
+    }
+    return NULL;
+}
+
+
+// Record backtrace entries into bt_data by stepping cursor with jl_unw_step
+// until the outermost frame is encountered or the buffer bt_data is (close to)
+// full. Returned instruction pointers are adjusted to point to the address of
+// the call instruction. The first `skip` frames are not included in `bt_data`.
+//
+// `maxsize` is the size of the buffer `bt_data` (and `sp` if non-NULL). It
+// must be at least JL_BT_MAX_ENTRY_SIZE to accommodate extended backtrace
+// entries.  If `sp != NULL`, the stack pointer corresponding `bt_data[i]` is
+// stored in `sp[i]`.
+//
+// `*ppgcstack` should be given if you want to record extended backtrace
+// entries in `bt_data` for each julia interpreter frame.
+//
+// Flag `from_signal_handler==1` should be set if the cursor was obtained by
+// asynchronously interrupting the code.
+//
+// jl_unw_stepn will return 1 if there are more frames to come. The number of
+// elements written to bt_data (and sp if non-NULL) are returned in bt_size.
+int jl_unw_stepn(bt_cursor_t *cursor, jl_bt_element_t *bt_data, size_t *bt_size,
+                 uintptr_t *sp, size_t maxsize, int skip, jl_gcframe_t **ppgcstack,
+                 int from_signal_handler) JL_NOTSAFEPOINT
 {
-    jl_ptls_t ptls = jl_get_ptls_states();
     volatile size_t n = 0;
-    uintptr_t thesp;
-    uintptr_t thefp;
+    volatile int need_more_space = 0;
+    uintptr_t return_ip = 0;
+    uintptr_t thesp = 0;
 #if defined(_OS_WINDOWS_) && !defined(_CPU_X86_64_)
     assert(!jl_in_stackwalk);
     jl_in_stackwalk = 1;
+    if (!from_signal_handler) {
+        // Workaround 32-bit windows bug missing top frame
+        // See for example https://bugs.chromium.org/p/crashpad/issues/detail?id=53
+        skip--;
+    }
 #endif
 #if !defined(_OS_WINDOWS_)
+    jl_ptls_t ptls = jl_get_ptls_states();
     jl_jmp_buf *old_buf = ptls->safe_restore;
     jl_jmp_buf buf;
     if (!jl_setjmp(buf, 0)) {
         ptls->safe_restore = &buf;
 #endif
-        while (1) {
-           if (n >= maxsize) {
-               n = maxsize; // return maxsize + 1 if ran out of space
-               break;
-           }
-           if (!jl_unw_step(cursor, &ip[n], &thesp, &thefp))
-               break;
-           if (sp)
-               sp[n] = thesp;
-           if (add_interp_frames && jl_is_enter_interpreter_frame(ip[n])) {
-               n += jl_capture_interp_frame(&ip[n], thesp, thefp, maxsize-n-1) + 1;
-           } else {
-               n++;
-           }
+        int have_more_frames = 1;
+        while (have_more_frames) {
+            if (n + JL_BT_MAX_ENTRY_SIZE + 1 > maxsize) {
+                // Postpone advancing the cursor: may need more space
+                need_more_space = 1;
+                break;
+            }
+            have_more_frames = jl_unw_step(cursor, &return_ip, &thesp);
+            if (skip > 0) {
+                skip--;
+                continue;
+            }
+            if (sp)
+                sp[n] = thesp;
+            // For the purposes of looking up debug info for functions, we want
+            // to harvest addresses for the *call* instruction `call_ip` during
+            // stack walking.  However, this information isn't directly
+            // available. Instead, the stack walk discovers the address
+            // `return_ip` which would be *returned to* as the stack is
+            // unwound.
+            //
+            // To infer `call_ip` in full generality we need to understand each
+            // platform ABI instruction pointer encoding and calling
+            // conventions, noting that the latter may vary per stack frame.
+            //
+            // See also:
+            // * The LLVM unwinder functions step() and setInfoBasedOnIPRegister()
+            //   https://github.com/llvm/llvm-project/blob/master/libunwind/src/UnwindCursor.hpp
+            // * The way that libunwind handles it in `unw_get_proc_name`:
+            //   https://lists.nongnu.org/archive/html/libunwind-devel/2014-06/msg00025.html
+            uintptr_t call_ip = return_ip;
+            // ARM instruction pointer encoding uses the low bit as a flag for
+            // thumb mode, which must be cleared before further use. (Note not
+            // needed for ARM AArch64.) See
+            // https://github.com/libunwind/libunwind/pull/131
+            #ifdef _CPU_ARM_
+            call_ip &= ~(uintptr_t)0x1;
+            #endif
+            // Now there's two main cases to adjust for:
+            // * Normal stack frames where compilers emit a `call` instruction
+            //   which we can get from the return address via `call_ip = return_ip - 1`.
+            // * Code which was interrupted asynchronously (eg, via a signal)
+            //   is expected to have `call_ip == return_ip`.
+            if (n != 0 || !from_signal_handler) {
+                // normal frame
+                call_ip -= 1;
+            }
+            if (call_ip == JL_BT_NON_PTR_ENTRY) {
+                // Never leave special marker in the bt data as it can corrupt the GC.
+                call_ip = 0;
+            }
+            jl_bt_element_t *bt_entry = bt_data + n;
+            jl_gcframe_t *pgcstack;
+            if ((pgcstack = is_enter_interpreter_frame(ppgcstack, thesp))) {
+                size_t add = jl_capture_interp_frame(bt_entry, (void*)((char*)pgcstack - sizeof(void*)), maxsize - n);
+                n += add;
+                bt_entry += add;
+                while ((pgcstack = is_enter_interpreter_frame(ppgcstack, thesp))) {
+                    // If the compiler got inlining-happy, or the user tried to
+                    // push multiple frames (or the unwinder got very
+                    // confused), we could end up here. That doesn't happen
+                    // now, so just ignore this possibility. If we want this,
+                    // we can work on adding support for it later.
+                }
+            }
+            bt_entry->uintptr = call_ip;
+            n++;
         }
-        n++;
+        // NOTE: if we have some pgcstack entries remaining (because the
+        // unwinder failed and returned !have_more_frames early), we could
+        // consider still appending those frames here
 #if !defined(_OS_WINDOWS_)
     }
     else {
@@ -73,30 +174,50 @@ size_t jl_unw_stepn(bt_cursor_t *cursor,
 #if defined(_OS_WINDOWS_) && !defined(_CPU_X86_64_)
     jl_in_stackwalk = 0;
 #endif
-    return n;
+    *bt_size = n;
+    return need_more_space;
 }
 
-size_t rec_backtrace_ctx(uintptr_t *data, size_t maxsize,
-                         bt_context_t *context)
+NOINLINE size_t rec_backtrace_ctx(jl_bt_element_t *bt_data, size_t maxsize,
+                                  bt_context_t *context, jl_gcframe_t *pgcstack) JL_NOTSAFEPOINT
 {
-    size_t n = 0;
     bt_cursor_t cursor;
     if (!jl_unw_init(&cursor, context))
         return 0;
-    n = jl_unw_stepn(&cursor, data, NULL, maxsize, 1);
-    return n > maxsize ? maxsize : n;
+    size_t bt_size = 0;
+    jl_unw_stepn(&cursor, bt_data, &bt_size, NULL, maxsize, 0, &pgcstack, 1);
+    return bt_size;
 }
 
-size_t rec_backtrace(uintptr_t *data, size_t maxsize)
+// Record backtrace into buffer `bt_data`, using a maximum of `maxsize`
+// elements, and returning the number of elements written.
+//
+// The first `skip` frames are omitted, in addition to omitting the frame from
+// `rec_backtrace` itself.
+NOINLINE size_t rec_backtrace(jl_bt_element_t *bt_data, size_t maxsize, int skip)
 {
     bt_context_t context;
     memset(&context, 0, sizeof(context));
     jl_unw_get(&context);
-    return rec_backtrace_ctx(data, maxsize, &context);
+    jl_gcframe_t *pgcstack = jl_pgcstack;
+    bt_cursor_t cursor;
+    if (!jl_unw_init(&cursor, &context))
+        return 0;
+    size_t bt_size = 0;
+    jl_unw_stepn(&cursor, bt_data, &bt_size, NULL, maxsize, skip + 1, &pgcstack, 0);
+    return bt_size;
 }
 
 static jl_value_t *array_ptr_void_type JL_ALWAYS_LEAFTYPE = NULL;
-JL_DLLEXPORT jl_value_t *jl_backtrace_from_here(int returnsp)
+// Return backtrace information as an svec of (bt1, bt2, [sp])
+//
+// The stack pointers `sp` are returned only when `returnsp` evaluates to true.
+// bt1 contains raw backtrace entries, while bt2 exists to root any julia
+// objects associated with the entries in bt1.
+//
+// The frame from jl_backtrace_from_here will be skipped; set `skip > 0` to
+// skip additional native frames from the start of the backtrace.
+JL_DLLEXPORT jl_value_t *jl_backtrace_from_here(int returnsp, int skip)
 {
     jl_array_t *ip = NULL;
     jl_array_t *sp = NULL;
@@ -113,25 +234,42 @@ JL_DLLEXPORT jl_value_t *jl_backtrace_fr
     bt_cursor_t cursor;
     memset(&context, 0, sizeof(context));
     jl_unw_get(&context);
+    jl_gcframe_t *pgcstack = jl_pgcstack;
     if (jl_unw_init(&cursor, &context)) {
-        size_t n = 0, offset = 0;
-        do {
+        // Skip frame for jl_backtrace_from_here itself
+        skip += 1;
+        size_t offset = 0;
+        int have_more_frames = 1;
+        while (have_more_frames) {
             jl_array_grow_end(ip, maxincr);
-            if (returnsp) jl_array_grow_end(sp, maxincr);
-            n = jl_unw_stepn(&cursor, (uintptr_t*)jl_array_data(ip) + offset,
-                    returnsp ? (uintptr_t*)jl_array_data(sp) + offset : NULL, maxincr, 1);
-            offset += maxincr;
-        } while (n > maxincr);
-        jl_array_del_end(ip, maxincr - n);
-        if (returnsp) jl_array_del_end(sp, maxincr - n);
+            uintptr_t *sp_ptr = NULL;
+            if (returnsp) {
+                sp_ptr = (uintptr_t*)jl_array_data(sp) + offset;
+                jl_array_grow_end(sp, maxincr);
+            }
+            size_t size_incr = 0;
+            have_more_frames = jl_unw_stepn(&cursor, (jl_bt_element_t*)jl_array_data(ip) + offset,
+                                            &size_incr, sp_ptr, maxincr, skip, &pgcstack, 0);
+            skip = 0;
+            offset += size_incr;
+        }
+        jl_array_del_end(ip, jl_array_len(ip) - offset);
+        if (returnsp)
+            jl_array_del_end(sp, jl_array_len(sp) - offset);
 
-        n = 0;
+        size_t n = 0;
+        jl_bt_element_t *bt_data = (jl_bt_element_t*)jl_array_data(ip);
         while (n < jl_array_len(ip)) {
-            if ((uintptr_t)jl_array_ptr_ref(ip, n) == JL_BT_INTERP_FRAME) {
-                jl_array_ptr_1d_push(bt2, jl_array_ptr_ref(ip, n+1));
-                n += 2;
+            jl_bt_element_t *bt_entry = bt_data + n;
+            if (!jl_bt_is_native(bt_entry)) {
+                size_t njlvals = jl_bt_num_jlvals(bt_entry);
+                for (size_t j = 0; j < njlvals; j++) {
+                    jl_value_t *v = jl_bt_entry_jlvalue(bt_entry, j);
+                    JL_GC_PROMISE_ROOTED(v);
+                    jl_array_ptr_1d_push(bt2, v);
+                }
             }
-            n++;
+            n += jl_bt_entry_size(bt_entry);
         }
     }
     jl_value_t *bt = returnsp ? (jl_value_t*)jl_svec(3, ip, bt2, sp) : (jl_value_t*)jl_svec(2, ip, bt2);
@@ -139,42 +277,48 @@ JL_DLLEXPORT jl_value_t *jl_backtrace_fr
     return bt;
 }
 
-void decode_backtrace(uintptr_t *bt_data, size_t bt_size,
-                      jl_array_t **btout, jl_array_t **bt2out)
+void decode_backtrace(jl_bt_element_t *bt_data, size_t bt_size,
+                      jl_array_t **btout JL_REQUIRE_ROOTED_SLOT,
+                      jl_array_t **bt2out JL_REQUIRE_ROOTED_SLOT)
 {
-    jl_array_t *bt = NULL;
-    jl_array_t *bt2 = NULL;
-    JL_GC_PUSH2(&bt, &bt2);
+    jl_array_t *bt, *bt2;
     if (array_ptr_void_type == NULL) {
         array_ptr_void_type = jl_apply_type2((jl_value_t*)jl_array_type, (jl_value_t*)jl_voidpointer_type, jl_box_long(1));
     }
-    bt = jl_alloc_array_1d(array_ptr_void_type, bt_size);
-    memcpy(bt->data, bt_data, bt_size * sizeof(void*));
-    bt2 = jl_alloc_array_1d(jl_array_any_type, 0);
-    // Scan the stack for any interpreter frames
-    size_t n = 0;
-    while (n < bt_size) {
-        if (bt_data[n] == JL_BT_INTERP_FRAME) {
-            jl_array_ptr_1d_push(bt2, (jl_value_t*)bt_data[n+1]);
-            n += 2;
+    bt = *btout = jl_alloc_array_1d(array_ptr_void_type, bt_size);
+    static_assert(sizeof(jl_bt_element_t) == sizeof(void*),
+                  "jl_bt_element_t is presented as Ptr{Cvoid} on julia side");
+    memcpy(bt->data, bt_data, bt_size * sizeof(jl_bt_element_t));
+    bt2 = *bt2out = jl_alloc_array_1d(jl_array_any_type, 0);
+    // Scan the backtrace buffer for any gc-managed values
+    for (size_t i = 0; i < bt_size; i += jl_bt_entry_size(bt_data + i)) {
+        jl_bt_element_t* bt_entry = bt_data + i;
+        if (jl_bt_is_native(bt_entry))
+            continue;
+        size_t njlvals = jl_bt_num_jlvals(bt_entry);
+        for (size_t j = 0; j < njlvals; j++) {
+            jl_value_t *v = jl_bt_entry_jlvalue(bt_entry, j);
+            JL_GC_PROMISE_ROOTED(v);
+            jl_array_ptr_1d_push(bt2, v);
         }
-        n++;
     }
-    *btout = bt;
-    *bt2out = bt2;
-    JL_GC_POP();
 }
 
-JL_DLLEXPORT void jl_get_backtrace(jl_array_t **btout, jl_array_t **bt2out)
+JL_DLLEXPORT jl_value_t *jl_get_backtrace(void)
 {
     jl_excstack_t *s = jl_get_ptls_states()->current_task->excstack;
-    uintptr_t *bt_data = NULL;
+    jl_bt_element_t *bt_data = NULL;
     size_t bt_size = 0;
     if (s && s->top) {
         bt_data = jl_excstack_bt_data(s, s->top);
         bt_size = jl_excstack_bt_size(s, s->top);
     }
-    decode_backtrace(bt_data, bt_size, btout, bt2out);
+    jl_array_t *bt = NULL, *bt2 = NULL;
+    JL_GC_PUSH2(&bt, &bt2);
+    decode_backtrace(bt_data, bt_size, &bt, &bt2);
+    jl_svec_t *pair = jl_svec2(bt, bt2);
+    JL_GC_POP();
+    return (jl_value_t*)pair;
 }
 
 // Return data from the exception stack for `task` as an array of Any, starting
@@ -323,17 +467,13 @@ static int readable_pointer(LPCVOID poin
     return 1;
 }
 
-static int jl_unw_step(bt_cursor_t *cursor, uintptr_t *ip, uintptr_t *sp, uintptr_t *fp)
+static int jl_unw_step(bt_cursor_t *cursor, uintptr_t *ip, uintptr_t *sp)
 {
     // Might be called from unmanaged thread.
 #ifndef _CPU_X86_64_
     *ip = (uintptr_t)cursor->stackframe.AddrPC.Offset;
     *sp = (uintptr_t)cursor->stackframe.AddrStack.Offset;
-    if (fp)
-        *fp = (uintptr_t)cursor->stackframe.AddrFrame.Offset;
-    if (*ip == 0 || *ip == JL_BT_INTERP_FRAME) {
-        // don't leave special marker in the bt data as it can corrupt the GC.
-        *ip = 0;
+    if (*ip == 0) {
         if (!readable_pointer((LPCVOID)*sp))
             return 0;
         cursor->stackframe.AddrPC.Offset = *(DWORD32*)*sp;      // POP EIP (aka RET)
@@ -347,11 +487,7 @@ static int jl_unw_step(bt_cursor_t *curs
 #else
     *ip = (uintptr_t)cursor->Rip;
     *sp = (uintptr_t)cursor->Rsp;
-    if (fp)
-        *fp = (uintptr_t)cursor->Rbp;
-    if (*ip == 0 || *ip == JL_BT_INTERP_FRAME) {
-        // don't leave special marker in the bt data as it can corrupt the GC.
-        *ip = 0;
+    if (*ip == 0) {
         if (!readable_pointer((LPCVOID)*sp))
             return 0;
         cursor->Rip = *(DWORD64*)*sp;      // POP RIP (aka RET)
@@ -399,42 +535,28 @@ static int jl_unw_init(bt_cursor_t *curs
     return unw_init_local(cursor, context) == 0;
 }
 
-static int jl_unw_step(bt_cursor_t *cursor, uintptr_t *ip, uintptr_t *sp, uintptr_t *fp)
+static int jl_unw_step(bt_cursor_t *cursor, uintptr_t *ip, uintptr_t *sp)
 {
     unw_word_t reg;
     if (unw_get_reg(cursor, UNW_REG_IP, &reg) < 0)
         return 0;
-    // don't leave special marker in the bt data as it can corrupt the GC.
-    *ip = reg == JL_BT_INTERP_FRAME ? 0 : reg;
+    *ip = reg;
     if (unw_get_reg(cursor, UNW_REG_SP, &reg) < 0)
         return 0;
     *sp = reg;
-#ifdef UNW_REG_FP
-    if (unw_get_reg(cursor, UNW_REG_FP, &reg) < 0)
-        return 0;
-    if (fp)
-        *fp = reg;
-#else
-    if (fp)
-        *fp = 0;
-#endif
     return unw_step(cursor) > 0;
 }
 
 #ifdef LIBOSXUNWIND
-int jl_unw_init_dwarf(bt_cursor_t *cursor, bt_context_t *uc)
-{
-    return unw_init_local_dwarf(cursor, uc) != 0;
-}
-size_t rec_backtrace_ctx_dwarf(uintptr_t *data, size_t maxsize,
-                               bt_context_t *context)
+NOINLINE size_t rec_backtrace_ctx_dwarf(jl_bt_element_t *bt_data, size_t maxsize,
+                                        bt_context_t *context, jl_gcframe_t *pgcstack)
 {
-    size_t n;
+    size_t bt_size = 0;
     bt_cursor_t cursor;
-    if (!jl_unw_init_dwarf(&cursor, context))
+    if (unw_init_local_dwarf(&cursor, context) != UNW_ESUCCESS)
         return 0;
-    n = jl_unw_stepn(&cursor, data, NULL, maxsize, 1);
-    return n > maxsize ? maxsize : n;
+    jl_unw_stepn(&cursor, bt_data, &bt_size, NULL, maxsize, 0, &pgcstack, 1);
+    return bt_size;
 }
 #endif
 
@@ -445,7 +567,7 @@ static int jl_unw_init(bt_cursor_t *curs
     return 0;
 }
 
-static int jl_unw_step(bt_cursor_t *cursor, uintptr_t *ip, uintptr_t *sp, uintptr_t *fp)
+static int jl_unw_step(bt_cursor_t *cursor, uintptr_t *ip, uintptr_t *sp)
 {
     return 0;
 }
@@ -462,7 +584,7 @@ JL_DLLEXPORT jl_value_t *jl_lookup_code_
     JL_GC_PUSH1(&rs);
     for (int i = 0; i < n; i++) {
         jl_frame_t frame = frames[i];
-        jl_value_t *r = (jl_value_t*)jl_alloc_svec(7);
+        jl_value_t *r = (jl_value_t*)jl_alloc_svec(6);
         jl_svecset(rs, i, r);
         if (frame.func_name)
             jl_svecset(r, 0, jl_symbol(frame.func_name));
@@ -478,15 +600,28 @@ JL_DLLEXPORT jl_value_t *jl_lookup_code_
         jl_svecset(r, 3, frame.linfo != NULL ? (jl_value_t*)frame.linfo : jl_nothing);
         jl_svecset(r, 4, jl_box_bool(frame.fromC));
         jl_svecset(r, 5, jl_box_bool(frame.inlined));
-        jl_svecset(r, 6, jl_box_voidpointer(ip));
     }
     free(frames);
     JL_GC_POP();
     return rs;
 }
 
-//for looking up functions from gdb:
-JL_DLLEXPORT void jl_gdblookup(uintptr_t ip)
+void jl_safe_print_codeloc(const char* func_name, const char* file_name,
+                           int line, int inlined) JL_NOTSAFEPOINT
+{
+    const char *inlined_str = inlined ? " [inlined]" : "";
+    if (line != -1) {
+        jl_safe_printf("%s at %s:%d%s\n", func_name, file_name, line, inlined_str);
+    }
+    else {
+        jl_safe_printf("%s at %s (unknown line)%s\n", func_name, file_name, inlined_str);
+    }
+}
+
+// Print function, file and line containing native instruction pointer `ip` by
+// looking up debug info. Prints multiple such frames when `ip` points to
+// inlined code.
+void jl_print_native_codeloc(uintptr_t ip) JL_NOTSAFEPOINT
 {
     // This function is not allowed to reference any TLS variables since
     // it can be called from an unmanaged thread on OSX.
@@ -501,15 +636,7 @@ JL_DLLEXPORT void jl_gdblookup(uintptr_t
             jl_safe_printf("unknown function (ip: %p)\n", (void*)ip);
         }
         else {
-            const char *inlined = frame.inlined ? " [inlined]" : "";
-            if (frame.line != -1) {
-                jl_safe_printf("%s at %s:%" PRIuPTR "%s\n", frame.func_name,
-                    frame.file_name, (uintptr_t)frame.line, inlined);
-            }
-            else {
-                jl_safe_printf("%s at %s (unknown line)%s\n", frame.func_name,
-                    frame.file_name, inlined);
-            }
+            jl_safe_print_codeloc(frame.func_name, frame.file_name, frame.line, frame.inlined);
             free(frame.func_name);
             free(frame.file_name);
         }
@@ -517,22 +644,70 @@ JL_DLLEXPORT void jl_gdblookup(uintptr_t
     free(frames);
 }
 
+// Print code location for backtrace buffer entry at *bt_entry
+void jl_print_bt_entry_codeloc(jl_bt_element_t *bt_entry) JL_NOTSAFEPOINT
+{
+    if (jl_bt_is_native(bt_entry)) {
+        jl_print_native_codeloc(bt_entry[0].uintptr);
+    }
+    else if (jl_bt_entry_tag(bt_entry) == JL_BT_INTERP_FRAME_TAG) {
+        size_t ip = jl_bt_entry_header(bt_entry);
+        jl_value_t *code = jl_bt_entry_jlvalue(bt_entry, 0);
+        if (jl_is_method_instance(code)) {
+            // When interpreting a method instance, need to unwrap to find the code info
+            code = ((jl_method_instance_t*)code)->uninferred;
+        }
+        if (jl_is_code_info(code)) {
+            jl_code_info_t *src = (jl_code_info_t*)code;
+            // See also the debug info handling in codegen.cpp.
+            // NB: debuginfoloc is 1-based!
+            intptr_t debuginfoloc = ((int32_t*)jl_array_data(src->codelocs))[ip];
+            while (debuginfoloc != 0) {
+                jl_line_info_node_t *locinfo = (jl_line_info_node_t*)
+                    jl_array_ptr_ref(src->linetable, debuginfoloc - 1);
+                assert(jl_typeis(locinfo, jl_lineinfonode_type));
+                jl_value_t *method = locinfo->method;
+                if (jl_is_method_instance(method)) {
+                    method = ((jl_method_instance_t*)method)->def.value;
+                    if (jl_is_method(method))
+                        method = (jl_value_t*)((jl_method_t*)method)->name;
+                }
+                const char *func_name = jl_is_symbol(method) ?
+                                        jl_symbol_name((jl_sym_t*)method) : "Unknown";
+                jl_safe_print_codeloc(func_name, jl_symbol_name(locinfo->file),
+                                      locinfo->line, locinfo->inlined_at);
+                debuginfoloc = locinfo->inlined_at;
+            }
+        }
+        else {
+            // If we're using this function something bad has already happened;
+            // be a bit defensive to avoid crashing while reporting the crash.
+            jl_safe_printf("No code info - unknown interpreter state!\n");
+        }
+    }
+    else {
+        jl_safe_printf("Non-native bt entry with tag and header bits 0x%" PRIxPTR "\n",
+                       bt_entry[1].uintptr);
+    }
+}
+
+//--------------------------------------------------
+// Tools for interactive debugging in gdb
+JL_DLLEXPORT void jl_gdblookup(void* ip)
+{
+    jl_print_native_codeloc((uintptr_t)ip);
+}
+
+// Print backtrace for current exception in catch block
 JL_DLLEXPORT void jlbacktrace(void) JL_NOTSAFEPOINT
 {
     jl_excstack_t *s = jl_get_ptls_states()->current_task->excstack;
     if (!s)
         return;
     size_t bt_size = jl_excstack_bt_size(s, s->top);
-    uintptr_t *bt_data = jl_excstack_bt_data(s, s->top);
-    for (size_t i = 0; i < bt_size; ) {
-        if (bt_data[i] == JL_BT_INTERP_FRAME) {
-            jl_safe_printf("Interpreter frame (ip: %d)\n", (int)bt_data[i+2]);
-            jl_static_show(JL_STDERR, (jl_value_t*)bt_data[i+1]);
-            i += 3;
-        } else {
-            jl_gdblookup(bt_data[i] - 1);
-            i += 1;
-        }
+    jl_bt_element_t *bt_data = jl_excstack_bt_data(s, s->top);
+    for (size_t i = 0; i < bt_size; i += jl_bt_entry_size(bt_data + i)) {
+        jl_print_bt_entry_codeloc(bt_data + i);
     }
 }
 
diff -pruN 1.3.1+dfsg-1/src/staticdata.c 1.4.0+dfsg-1/src/staticdata.c
--- 1.3.1+dfsg-1/src/staticdata.c	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/src/staticdata.c	2020-03-21 16:36:32.000000000 +0000
@@ -76,6 +76,7 @@ static void *const _tags[] = {
          // some Core.Builtin Functions that we want to be able to reference:
          &jl_builtin_throw, &jl_builtin_is, &jl_builtin_typeof, &jl_builtin_sizeof,
          &jl_builtin_issubtype, &jl_builtin_isa, &jl_builtin_typeassert, &jl_builtin__apply,
+         &jl_builtin__apply_iterate,
          &jl_builtin_isdefined, &jl_builtin_nfields, &jl_builtin_tuple, &jl_builtin_svec,
          &jl_builtin_getfield, &jl_builtin_setfield, &jl_builtin_fieldtype, &jl_builtin_arrayref,
          &jl_builtin_const_arrayref, &jl_builtin_arrayset, &jl_builtin_arraysize,
@@ -109,7 +110,7 @@ static htable_t fptr_to_id;
 // This is a manually constructed dual of the fvars array, which would be produced by codegen for Julia code, for C.
 static const jl_fptr_args_t id_to_fptrs[] = {
     &jl_f_throw, &jl_f_is, &jl_f_typeof, &jl_f_issubtype, &jl_f_isa,
-    &jl_f_typeassert, &jl_f__apply, &jl_f__apply_pure, &jl_f__apply_latest, &jl_f_isdefined,
+    &jl_f_typeassert, &jl_f__apply, &jl_f__apply_iterate, &jl_f__apply_pure, &jl_f__apply_latest, &jl_f_isdefined,
     &jl_f_tuple, &jl_f_svec, &jl_f_intrinsic_call, &jl_f_invoke_kwsorter,
     &jl_f_getfield, &jl_f_setfield, &jl_f_fieldtype, &jl_f_nfields,
     &jl_f_arrayref, &jl_f_const_arrayref, &jl_f_arrayset, &jl_f_arraysize, &jl_f_apply_type,
@@ -339,19 +340,33 @@ static void jl_serialize_value_(jl_seria
                 jl_serialize_value(s, jl_array_ptr_ref(ar, i));
             }
         }
+        else if (ar->flags.hasptr) {
+            const char *data = (const char*)jl_array_data(ar);
+            uint16_t elsz = ar->elsize;
+            size_t i, l = jl_array_len(ar);
+            jl_datatype_t *et = (jl_datatype_t*)jl_tparam0(jl_typeof(ar));
+            size_t j, np = et->layout->npointers;
+            for (i = 0; i < l; i++) {
+                for (j = 0; j < np; j++) {
+                    uint32_t ptr = jl_ptr_offset(et, j);
+                    jl_value_t *fld = ((jl_value_t**)data)[ptr];
+                    JL_GC_PROMISE_ROOTED(fld);
+                    jl_serialize_value(s, fld);
+                }
+                data += elsz;
+            }
+        }
     }
     else if (jl_typeis(v, jl_module_type)) {
         jl_serialize_module(s, (jl_module_t*)v);
     }
-    else {
+    else if (t->layout->nfields > 0) {
         char *data = (char*)jl_data_ptr(v);
-        size_t i, nf = jl_datatype_nfields(t);
-        for (i = 0; i < nf; i++) {
-            if (jl_field_isptr(t, i)) {
-                char *slot = data + jl_field_offset(t, i);
-                jl_value_t *fld = *(jl_value_t**)slot;
-                jl_serialize_value(s, fld);
-            }
+        size_t i, np = t->layout->npointers;
+        for (i = 0; i < np; i++) {
+            uint32_t ptr = jl_ptr_offset(t, i);
+            jl_value_t *fld = ((jl_value_t* const*)data)[ptr];
+            jl_serialize_value(s, fld);
         }
     }
 }
@@ -606,6 +621,7 @@ static void jl_write_values(jl_serialize
 
     for (i = 0, len = backref_table_numel * 2; i < len; i += 2) {
         jl_value_t *v = (jl_value_t*)objects_list.items[i];
+        JL_GC_PROMISE_ROOTED(v);
         uintptr_t item = (uintptr_t)objects_list.items[i + 1];
         jl_datatype_t *t = (jl_datatype_t*)jl_typeof(v);
         assert((t->instance == NULL || t->instance == v) && "detected singleton construction corruption");
@@ -626,6 +642,7 @@ static void jl_write_values(jl_serialize
         else if (jl_is_array(v)) {
 #define JL_ARRAY_ALIGN(jl_value, nbytes) LLT_ALIGN(jl_value, nbytes)
             jl_array_t *ar = (jl_array_t*)v;
+            jl_value_t *et = jl_tparam0(jl_typeof(v));
             int ndimwords = jl_array_ndimwords(ar->flags.ndims);
             size_t tsz = JL_ARRAY_ALIGN(sizeof(jl_array_t) + ndimwords * sizeof(size_t), JL_CACHE_BYTE_ALIGNMENT);
             // copy header
@@ -642,7 +659,7 @@ static void jl_write_values(jl_serialize
             newa->flags.isshared = 0;
 
             // write data
-            if (!ar->flags.ptrarray) {
+            if (!ar->flags.ptrarray && !ar->flags.hasptr) {
                 uintptr_t data = LLT_ALIGN(ios_pos(s->const_data), 16);
                 // realign stream to max(data-align(array), sizeof(void*))
                 write_padding(s->const_data, data - ios_pos(s->const_data));
@@ -652,20 +669,54 @@ static void jl_write_values(jl_serialize
                 assert(data < ((uintptr_t)1 << RELOC_TAG_OFFSET) && "offset to constant data too large");
                 arraylist_push(&s->relocs_list, (void*)(reloc_offset + offsetof(jl_array_t, data))); // relocation location
                 arraylist_push(&s->relocs_list, (void*)(((uintptr_t)ConstDataRef << RELOC_TAG_OFFSET) + data)); // relocation target
-                int isbitsunion = jl_array_isbitsunion(ar);
-                if (ar->elsize == 1 && !isbitsunion)
-                    tot += 1;
-                ios_write(s->const_data, (char*)jl_array_data(ar), tot);
-                if (isbitsunion)
-                    ios_write(s->const_data, jl_array_typetagdata(ar), alen);
+                if (jl_is_cpointer_type(et)) {
+                    // reset Ptr elements to C_NULL
+                    size_t i;
+                    for (i = 0; i < alen; i++)
+                        write_pointer(s->const_data);
+                }
+                else {
+                    int isbitsunion = jl_array_isbitsunion(ar);
+                    if (ar->elsize == 1 && !isbitsunion)
+                        tot += 1;
+                    ios_write(s->const_data, (char*)jl_array_data(ar), tot);
+                    if (isbitsunion)
+                        ios_write(s->const_data, jl_array_typetagdata(ar), alen);
+                }
             }
             else {
                 newa->data = (void*)tsz; // relocation offset
                 arraylist_push(&s->relocs_list, (void*)(reloc_offset + offsetof(jl_array_t, data))); // relocation location
                 arraylist_push(&s->relocs_list, (void*)(((uintptr_t)DataRef << RELOC_TAG_OFFSET) + item)); // relocation target
-                size_t i;
-                for (i = 0; i < alen; i++) {
-                    write_pointerfield(s, jl_array_ptr_ref(v, i));
+                if (ar->flags.hasptr) {
+                    // copy all of the data first
+                    const char *data = (const char*)jl_array_data(ar);
+                    ios_write(s->s, data, tot);
+                    // the rewrite all of the embedded pointers to null+relocation
+                    uint16_t elsz = ar->elsize;
+                    size_t j, np = ((jl_datatype_t*)et)->layout->npointers;
+                    size_t i;
+                    for (i = 0; i < alen; i++) {
+                        for (j = 0; j < np; j++) {
+                            size_t offset = i * elsz + jl_ptr_offset(((jl_datatype_t*)et), j) * sizeof(jl_value_t*);
+                            jl_value_t *fld = *(jl_value_t**)&data[offset];
+                            if (fld != NULL) {
+                                arraylist_push(&s->relocs_list, (void*)(uintptr_t)(reloc_offset + tsz + offset)); // relocation location
+                                arraylist_push(&s->relocs_list, (void*)backref_id(s, fld)); // relocation target
+                                memset(&s->s->buf[reloc_offset + tsz + offset], 0, sizeof(fld)); // relocation offset (none)
+                            }
+                            else {
+                                assert(*(jl_value_t**)&s->s->buf[reloc_offset + tsz + offset] == NULL);
+                            }
+                        }
+                    }
+                }
+                else {
+                    size_t i;
+                    for (i = 0; i < alen; i++) {
+                        jl_value_t *e = jl_array_ptr_ref(v, i);
+                        write_pointerfield(s, e);
+                    }
                 }
             }
         }
@@ -687,8 +738,7 @@ static void jl_write_values(jl_serialize
             }
         }
         else if (jl_is_string(v)) {
-            ios_write(s->s, (char*)v, sizeof(void*));
-            ios_write(s->s, jl_string_data(v), jl_string_len(v));
+            ios_write(s->s, (char*)v, sizeof(void*) + jl_string_len(v));
             write_uint8(s->s, '\0'); // null-terminated strings for easier C-compatibility
         }
         else if (jl_datatype_nfields(t) == 0) {
@@ -714,18 +764,18 @@ static void jl_write_values(jl_serialize
             write_pointer(s->s);
         }
         else {
+            const char *data = (const char*)v;
             size_t i, nf = jl_datatype_nfields(t);
             size_t tot = 0;
             for (i = 0; i < nf; i++) {
                 size_t offset = jl_field_offset(t, i);
-                char *slot = (char*)v + offset;
+                const char *slot = data + offset;
                 write_padding(s->s, offset - tot);
                 tot = offset;
                 size_t fsz = jl_field_size(t, i);
-                if (jl_field_isptr(t, i) > 0) {
-                    write_pointerfield(s, *(jl_value_t**)slot);
-                }
-                else if (t->mutabl && jl_is_cpointer_type(jl_field_type(t, i))) {
+                if (t->mutabl && jl_is_cpointer_type(jl_field_type(t, i))) {
+                    // reset Ptr fields to C_NULL
+                    assert(!jl_field_isptr(t, i));
                     write_pointer(s->s);
                 }
                 else if (fsz > 0) {
@@ -734,6 +784,17 @@ static void jl_write_values(jl_serialize
                 tot += fsz;
             }
 
+            size_t np = t->layout->npointers;
+            for (i = 0; i < np; i++) {
+                size_t offset = jl_ptr_offset(t, i) * sizeof(jl_value_t*);
+                jl_value_t *fld = *(jl_value_t**)&data[offset];
+                if (fld != NULL) {
+                    arraylist_push(&s->relocs_list, (void*)(uintptr_t)(offset + reloc_offset)); // relocation location
+                    arraylist_push(&s->relocs_list, (void*)backref_id(s, fld)); // relocation target
+                    memset(&s->s->buf[offset + reloc_offset], 0, sizeof(fld)); // relocation offset (none)
+                }
+            }
+
             if (jl_is_method(v)) {
                 write_padding(s->s, sizeof(jl_method_t) - tot);
             }
@@ -807,24 +868,14 @@ static void jl_write_values(jl_serialize
                 newdt->ditype = NULL;
                 if (dt->layout != NULL) {
                     size_t nf = dt->layout->nfields;
+                    size_t np = dt->layout->npointers;
                     size_t fieldsize = jl_fielddesc_size(dt->layout->fielddesc_type);
-                    int has_padding = dt->layout->npointers && nf;
                     char *flddesc = (char*)dt->layout;
                     size_t fldsize = sizeof(jl_datatype_layout_t) + nf * fieldsize;
-                    uintptr_t layout_unaligned = LLT_ALIGN(ios_pos(s->const_data), sizeof(uint32_t));
+                    if (dt->layout->first_ptr != -1)
+                        fldsize += np << dt->layout->fielddesc_type;
                     uintptr_t layout = LLT_ALIGN(ios_pos(s->const_data), sizeof(void*));
-                    if (has_padding) {
-                        if (layout == layout_unaligned) {
-                            layout += sizeof(void*);
-                            layout_unaligned = layout - sizeof(uint32_t);
-                        }
-                        flddesc -= sizeof(uint32_t);
-                        fldsize += sizeof(uint32_t);
-                        write_padding(s->const_data, layout_unaligned - ios_pos(s->const_data)); // realign stream
-                    }
-                    else {
-                        write_padding(s->const_data, layout - ios_pos(s->const_data)); // realign stream
-                    }
+                    write_padding(s->const_data, layout - ios_pos(s->const_data)); // realign stream
                     newdt->layout = NULL; // relocation offset
                     layout /= sizeof(void*);
                     arraylist_push(&s->relocs_list, (void*)(reloc_offset + offsetof(jl_datatype_t, layout))); // relocation location
@@ -1269,8 +1320,8 @@ static void jl_cleanup_serializer2(void)
 
 static void jl_save_system_image_to_stream(ios_t *f)
 {
-    jl_gc_collect(1); // full
-    jl_gc_collect(0); // incremental (sweep finalizers)
+    jl_gc_collect(JL_GC_FULL);
+    jl_gc_collect(JL_GC_INCREMENTAL);   // sweep finalizers
     JL_TIMING(SYSIMG_DUMP);
     int en = jl_gc_enable(0);
     jl_init_serializer2(1);
@@ -1396,7 +1447,7 @@ static void jl_save_system_image_to_stre
 
 JL_DLLEXPORT ios_t *jl_create_system_image(void)
 {
-    ios_t *f = (ios_t*)malloc(sizeof(ios_t));
+    ios_t *f = (ios_t*)malloc_s(sizeof(ios_t));
     ios_mem(f, 0);
     jl_save_system_image_to_stream(f);
     return f;
diff -pruN 1.3.1+dfsg-1/src/subtype.c 1.4.0+dfsg-1/src/subtype.c
--- 1.3.1+dfsg-1/src/subtype.c	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/src/subtype.c	2020-03-21 16:36:32.000000000 +0000
@@ -79,6 +79,7 @@ typedef struct jl_varbinding_t {
     // array of typevars that our bounds depend on, whose UnionAlls need to be
     // moved outside ours.
     jl_array_t *innervars;
+    int intvalued;      // must be integer-valued; i.e. occurs as N in Vararg{_,N}
     struct jl_varbinding_t *prev;
 } jl_varbinding_t;
 
@@ -145,11 +146,11 @@ static void save_env(jl_stenv_t *e, jl_v
         len++;
         v = v->prev;
     }
-    *root = (jl_value_t*)jl_alloc_svec(len*3);
-    se->buf = (int8_t*)(len ? malloc(len*2) : NULL);
+    *root = (jl_value_t*)jl_alloc_svec(len * 3);
+    se->buf = (int8_t*)(len ? malloc_s(len * 2) : NULL);
 #ifdef __clang_analyzer__
     if (len)
-        memset(se->buf, 0, len*2);
+        memset(se->buf, 0, len * 2);
 #endif
     int i=0, j=0; v = e->vars;
     while (v != NULL) {
@@ -294,7 +295,7 @@ int jl_obviously_unequal(jl_value_t *a,
     return obviously_unequal(a, b);
 }
 
-static int in_union(jl_value_t *u, jl_value_t *x)
+static int in_union(jl_value_t *u, jl_value_t *x) JL_NOTSAFEPOINT
 {
     if (u == x) return 1;
     if (!jl_is_uniontype(u)) return 0;
@@ -692,7 +693,7 @@ typedef int (*tvar_callback)(void*, int8
 static int with_tvar(tvar_callback callback, void *context, jl_unionall_t *u, int8_t R, jl_stenv_t *e, int param)
 {
     jl_varbinding_t vb = { u->var, u->var->lb, u->var->ub, R, NULL, 0, 0, 0, 0,
-                           R ? e->Rinvdepth : e->invdepth, 0, NULL, e->vars };
+                           R ? e->Rinvdepth : e->invdepth, 0, NULL, 0, e->vars };
     JL_GC_PUSH4(&u, &vb.lb, &vb.ub, &vb.innervars);
     e->vars = &vb;
     int ans;
@@ -800,6 +801,7 @@ static jl_unionall_t *unalias_unionall(j
     jl_varbinding_t *btemp = e->vars;
     // if the var for this unionall (based on identity) already appears somewhere
     // in the environment, rename to get a fresh var.
+    JL_GC_PUSH1(&u);
     while (btemp != NULL) {
         if (btemp->var == u->var ||
             // outer var can only refer to inner var if bounds changed
@@ -810,6 +812,7 @@ static jl_unionall_t *unalias_unionall(j
         }
         btemp = btemp->prev;
     }
+    JL_GC_POP();
     return u;
 }
 
@@ -819,7 +822,8 @@ struct subtype_unionall_env {
 };
 
 static int subtype_unionall_callback(struct subtype_unionall_env *env, int8_t R, jl_stenv_t *s, int param) {
-    JL_GC_PROMISE_ROOTED(env->t); JL_GC_PROMISE_ROOTED(env->ubody);
+    JL_GC_PROMISE_ROOTED(env->t);
+    JL_GC_PROMISE_ROOTED(env->ubody);
     if (R) {
         return subtype(env->t, env->ubody, s, param);
     }
@@ -833,7 +837,10 @@ static int subtype_unionall(jl_value_t *
 {
     u = unalias_unionall(u, e);
     struct subtype_unionall_env env = {t, u->body};
-    return with_tvar((tvar_callback)subtype_unionall_callback, (void*)&env, u, R, e, param);
+    JL_GC_PUSH1(&u);
+    int res = with_tvar((tvar_callback)subtype_unionall_callback, (void*)&env, u, R, e, param);
+    JL_GC_POP();
+    return res;
 }
 
 // unwrap <=1 layers of UnionAlls, leaving the var in *p1 the body
@@ -998,7 +1005,10 @@ loop: // while (i <= lx) {
                     u = unalias_unionall(u, e);
                     env->vtx = (jl_value_t*)u;
                     // goto loop, but with the tvar introduced
-                    return with_tvar((tvar_callback)subtype_tuple_tail, env, u, 0, e, param);
+                    JL_GC_PUSH1(&u);
+                    int res = with_tvar((tvar_callback)subtype_tuple_tail, env, u, 0, e, param);
+                    JL_GC_POP();
+                    return res;
                 }
                 env->vtx = xi;
             }
@@ -1018,7 +1028,10 @@ loop: // while (i <= lx) {
                         u = unalias_unionall(u, e);
                         env->vty = (jl_value_t*)u;
                         // goto loop, but with the tvar introduced
-                        return with_tvar((tvar_callback)subtype_tuple_tail, env, u, 1, e, param);
+                        JL_GC_PUSH1(&u);
+                        int res = with_tvar((tvar_callback)subtype_tuple_tail, env, u, 1, e, param);
+                        JL_GC_POP();
+                        return res;
                     }
                     env->vty = yi;
                 }
@@ -2123,7 +2136,7 @@ static int try_subtype_in_env(jl_value_t
     return ret;
 }
 
-static void set_bound(jl_value_t **bound, jl_value_t *val, jl_tvar_t *v, jl_stenv_t *e)
+static void set_bound(jl_value_t **bound, jl_value_t *val, jl_tvar_t *v, jl_stenv_t *e) JL_NOTSAFEPOINT
 {
     if (in_union(val, (jl_value_t*)v))
         return;
@@ -2148,7 +2161,7 @@ static int subtype_in_env_existential(jl
         len++;
         v = v->prev;
     }
-    int8_t *rs = (int8_t*)malloc(len);
+    int8_t *rs = (int8_t*)malloc_s(len);
     int n = 0;
     v = e->vars;
     while (n < len) {
@@ -2229,15 +2242,16 @@ static jl_value_t *intersect_var(jl_tvar
     }
     else if (bb->concrete || bb->constraintkind == 1) {
         jl_value_t *ub = R ? intersect_aside(a, bb->ub, e, 1, d) : intersect_aside(bb->ub, a, e, 0, d);
+        if (ub == jl_bottom_type)
+            return jl_bottom_type;
         JL_GC_PUSH1(&ub);
-        if (ub == jl_bottom_type ||
+        if (!R && !subtype_bounds_in_env(bb->lb, a, e, 0, d)) {
             // this fixes issue #30122. TODO: better fix for R flag.
-            (!R && !subtype_bounds_in_env(bb->lb, a, e, 0, d))) {
             JL_GC_POP();
             return jl_bottom_type;
         }
-        set_bound(&bb->ub, ub, b, e);
         JL_GC_POP();
+        set_bound(&bb->ub, ub, b, e);
         return (jl_value_t*)b;
     }
     else if (bb->constraintkind == 2) {
@@ -2260,7 +2274,7 @@ static jl_value_t *intersect_var(jl_tvar
         return (jl_value_t*)b;
     if (ub == a) {
         if (bb->lb == jl_bottom_type) {
-            set_bound(&bb->ub, ub, b, e);
+            set_bound(&bb->ub, a, b, e);
             return (jl_value_t*)b;
         }
         return ub;
@@ -2332,6 +2346,19 @@ static jl_value_t *finish_unionall(jl_va
         varval = vb->ub;
     }
 
+    if (vb->intvalued) {
+        if ((varval && jl_is_long(varval)) ||
+            (vb->lb == jl_bottom_type && vb->ub == (jl_value_t*)jl_any_type) ||
+            (jl_is_typevar(vb->lb) && vb->ub == vb->lb)) {
+            // int-valued typevar must either be an Int, or have Bottom-Any bounds,
+            // or be set equal to another typevar.
+        }
+        else {
+            JL_GC_POP();
+            return jl_bottom_type;
+        }
+    }
+
     if (!varval && (vb->lb != vb->var->lb || vb->ub != vb->var->ub))
         newvar = jl_new_typevar(vb->var->name, vb->lb, vb->ub);
 
@@ -2506,7 +2533,7 @@ static jl_value_t *intersect_unionall(jl
     jl_value_t *res=NULL, *res2=NULL, *save=NULL, *save2=NULL;
     jl_savedenv_t se, se2;
     jl_varbinding_t vb = { u->var, u->var->lb, u->var->ub, R, NULL, 0, 0, 0, 0,
-                           R ? e->Rinvdepth : e->invdepth, 0, NULL, e->vars };
+                           R ? e->Rinvdepth : e->invdepth, 0, NULL, 0, e->vars };
     JL_GC_PUSH6(&res, &save2, &vb.lb, &vb.ub, &save, &vb.innervars);
     save_env(e, &save, &se);
     res = intersect_unionall_(t, u, e, R, param, &vb);
@@ -2939,6 +2966,7 @@ static jl_value_t *intersect(jl_value_t
                     return jl_bottom_type;
                 jl_value_t *i2=NULL, *ii = intersect(xp1, yp1, e, 1);
                 if (ii == jl_bottom_type) return jl_bottom_type;
+                JL_GC_PUSH2(&ii, &i2);
                 if (jl_is_typevar(xp1)) {
                     jl_varbinding_t *xb = lookup(e, (jl_tvar_t*)xp1);
                     if (xb && is_leaf_typevar(xb->var)) xb->concrete = 1;
@@ -2947,10 +2975,19 @@ static jl_value_t *intersect(jl_value_t
                     jl_varbinding_t *yb = lookup(e, (jl_tvar_t*)yp1);
                     if (yb && is_leaf_typevar(yb->var)) yb->concrete = 1;
                 }
-                JL_GC_PUSH2(&ii, &i2);
+                if (jl_is_typevar(xp2)) {
+                    jl_varbinding_t *xb = lookup(e, (jl_tvar_t*)xp2);
+                    if (xb) xb->intvalued = 1;
+                }
+                if (jl_is_typevar(yp2)) {
+                    jl_varbinding_t *yb = lookup(e, (jl_tvar_t*)yp2);
+                    if (yb) yb->intvalued = 1;
+                }
                 // Vararg{T,N} <: Vararg{T2,N2}; equate N and N2
                 i2 = intersect_invariant(xp2, yp2, e);
-                if (i2 == NULL || i2 == jl_bottom_type || (jl_is_long(i2) && jl_unbox_long(i2) < 0))
+                if (i2 == NULL || i2 == jl_bottom_type || (jl_is_long(i2) && jl_unbox_long(i2) < 0) ||
+                    !((jl_is_typevar(i2) && ((jl_tvar_t*)i2)->lb == jl_bottom_type &&
+                       ((jl_tvar_t*)i2)->ub == (jl_value_t*)jl_any_type) || jl_is_long(i2)))
                     ii = jl_bottom_type;
                 else
                     ii = jl_apply_type2((jl_value_t*)jl_vararg_type, ii, i2);
diff -pruN 1.3.1+dfsg-1/src/support/dtypes.h 1.4.0+dfsg-1/src/support/dtypes.h
--- 1.3.1+dfsg-1/src/support/dtypes.h	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/src/support/dtypes.h	2020-03-21 16:36:32.000000000 +0000
@@ -7,6 +7,9 @@
 #include <stddef.h> // double include of stddef.h fixes #3421
 #include <stdint.h>
 #include <string.h> // memcpy
+#include <errno.h>
+#include <stdlib.h>
+#include <stdio.h>
 #if defined(_COMPILER_INTEL_)
 #include <mathimf.h>
 #else
@@ -227,7 +230,7 @@ STATIC_INLINE unsigned int next_power_of
     return val;
 }
 
-#define LLT_ALIGN(x, sz) (((x) + (sz)-1) & -(sz))
+#define LLT_ALIGN(x, sz) (((x) + (sz)-1) & ~((sz)-1))
 
 // branch prediction annotations
 #ifdef __GNUC__
@@ -344,5 +347,42 @@ STATIC_INLINE void jl_store_unaligned_i1
     memcpy(ptr, &val, 2);
 }
 
+#ifdef _OS_WINDOWS_
+#include <errhandlingapi.h>
+#endif
+
+STATIC_INLINE void *malloc_s(size_t sz) JL_NOTSAFEPOINT {
+    int last_errno = errno;
+#ifdef _OS_WINDOWS_
+    DWORD last_error = GetLastError();
+#endif
+    void *p = malloc(sz);
+    if (p == NULL) {
+        perror("(julia) malloc");
+        abort();
+    }
+#ifdef _OS_WINDOWS_
+    SetLastError(last_error);
+#endif
+    errno = last_errno;
+    return p;
+}
+
+STATIC_INLINE void *realloc_s(void *p, size_t sz) JL_NOTSAFEPOINT {
+    int last_errno = errno;
+#ifdef _OS_WINDOWS_
+    DWORD last_error = GetLastError();
+#endif
+    p = realloc(p, sz);
+    if (p == NULL) {
+        perror("(julia) realloc");
+        abort();
+    }
+#ifdef _OS_WINDOWS_
+    SetLastError(last_error);
+#endif
+    errno = last_errno;
+    return p;
+}
 
 #endif /* DTYPES_H */
diff -pruN 1.3.1+dfsg-1/src/support/ios.c 1.4.0+dfsg-1/src/support/ios.c
--- 1.3.1+dfsg-1/src/support/ios.c	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/src/support/ios.c	2020-03-21 16:36:32.000000000 +0000
@@ -537,10 +537,6 @@ int64_t ios_pos(ios_t *s)
     return fdpos;
 }
 
-#if defined(_OS_WINDOWS)
-#include <io.h>
-#endif /* _OS_WINDOWS_ */
-
 int ios_trunc(ios_t *s, size_t size)
 {
     if (s->bm == bm_mem) {
@@ -1022,14 +1018,14 @@ ios_t *ios_stderr = NULL;
 
 void ios_init_stdstreams(void)
 {
-    ios_stdin = (ios_t*)malloc(sizeof(ios_t));
+    ios_stdin = (ios_t*)malloc_s(sizeof(ios_t));
     ios_fd(ios_stdin, STDIN_FILENO, 0, 0);
 
-    ios_stdout = (ios_t*)malloc(sizeof(ios_t));
+    ios_stdout = (ios_t*)malloc_s(sizeof(ios_t));
     ios_fd(ios_stdout, STDOUT_FILENO, 0, 0);
     ios_stdout->bm = bm_line;
 
-    ios_stderr = (ios_t*)malloc(sizeof(ios_t));
+    ios_stderr = (ios_t*)malloc_s(sizeof(ios_t));
     ios_fd(ios_stderr, STDERR_FILENO, 0, 0);
     ios_stderr->bm = bm_none;
 }
diff -pruN 1.3.1+dfsg-1/src/support/platform.h 1.4.0+dfsg-1/src/support/platform.h
--- 1.3.1+dfsg-1/src/support/platform.h	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/src/support/platform.h	2020-03-21 16:36:32.000000000 +0000
@@ -27,6 +27,7 @@
  *      CPU/Architecture:
  *          _CPU_X86_
  *          _CPU_X86_64_
+ *          _CPU_AARCH64_
  *          _CPU_ARM_
  *          _CPU_WASM_
  */
diff -pruN 1.3.1+dfsg-1/src/support/strtod.c 1.4.0+dfsg-1/src/support/strtod.c
--- 1.3.1+dfsg-1/src/support/strtod.c	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/src/support/strtod.c	2020-03-21 16:36:32.000000000 +0000
@@ -223,12 +223,11 @@ JL_DLLEXPORT double jl_strtod_c(const ch
         char *copy, *c;
         /* Create a copy of the input, with the '.' converted to the
            locale-specific decimal point */
-        copy = (char *)malloc(end - digits_pos +
-                                    1 + decimal_point_len);
+        copy = (char *)malloc(end - digits_pos + 1 + decimal_point_len);
         if (copy == NULL) {
             *endptr = (char *)nptr;
             errno = ENOMEM;
-            return val;
+            return -1.0;
         }
 
         c = copy;
diff -pruN 1.3.1+dfsg-1/src/support/utf8.c 1.4.0+dfsg-1/src/support/utf8.c
--- 1.3.1+dfsg-1/src/support/utf8.c	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/src/support/utf8.c	2020-03-21 16:36:32.000000000 +0000
@@ -509,7 +509,7 @@ size_t u8_vprintf(const char *fmt, va_li
     if ((intptr_t)cnt < 0)
         return 0;
     if (cnt >= sz) {
-        buf = (char*)malloc(cnt + 1);
+        buf = (char*)malloc_s(cnt+1);
         needfree = 1;
         vsnprintf(buf, cnt+1, fmt, ap);
     }
@@ -517,7 +517,8 @@ size_t u8_vprintf(const char *fmt, va_li
     nc = u8_toucs(wcs, cnt+1, buf, cnt);
     wcs[nc] = 0;
     printf("%ls", (wchar_t*)wcs);
-    if (needfree) free(buf);
+    if (needfree)
+        free(buf);
     return nc;
 }
 
diff -pruN 1.3.1+dfsg-1/src/symbol.c 1.4.0+dfsg-1/src/symbol.c
--- 1.3.1+dfsg-1/src/symbol.c	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/src/symbol.c	2020-03-21 16:36:32.000000000 +0000
@@ -130,16 +130,19 @@ JL_DLLEXPORT jl_sym_t *jl_tagged_gensym(
     char gs_name[14];
     if (memchr(str, 0, len))
         jl_exceptionf(jl_argumenterror_type, "Symbol name may not contain \\0");
-    char *name = (char*) (len >= 256 ? malloc(sizeof(gs_name)+len+3) :
-                          alloca(sizeof(gs_name)+len+3));
+    char *name = (char*) (len >= 256 ? malloc_s(sizeof(gs_name) + len + 3) :
+                                         alloca(sizeof(gs_name) + len + 3));
     char *n;
-    name[0] = '#'; name[1] = '#'; name[2+len] = '#';
-    memcpy(name+2, str, len);
+    name[0] = '#';
+    name[1] = '#';
+    name[2 + len] = '#';
+    memcpy(name + 2, str, len);
     uint32_t ctr = jl_atomic_fetch_add(&gs_ctr, 1);
     n = uint2str(gs_name, sizeof(gs_name), ctr, 10);
-    memcpy(name+3+len, n, sizeof(gs_name)-(n-gs_name));
-    jl_sym_t *sym = _jl_symbol(name, len+3+sizeof(gs_name)-(n-gs_name)-1);
-    if (len >= 256) free(name);
+    memcpy(name + 3 + len, n, sizeof(gs_name) - (n - gs_name));
+    jl_sym_t *sym = _jl_symbol(name, len + 3 + sizeof(gs_name) - (n - gs_name)- 1);
+    if (len >= 256)
+        free(name);
     return sym;
 }
 
diff -pruN 1.3.1+dfsg-1/src/sys.c 1.4.0+dfsg-1/src/sys.c
--- 1.3.1+dfsg-1/src/sys.c	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/src/sys.c	2020-03-21 16:36:32.000000000 +0000
@@ -549,7 +549,7 @@ JL_DLLEXPORT const char *jl_pathname_for
 
 #elif defined(_OS_WINDOWS_)
 
-    wchar_t *pth16 = (wchar_t*)malloc(32768 * sizeof(*pth16)); // max long path length
+    wchar_t *pth16 = (wchar_t*)malloc_s(32768 * sizeof(*pth16)); // max long path length
     DWORD n16 = GetModuleFileNameW((HMODULE)handle,pth16,32768);
     if (n16 <= 0) {
         free(pth16);
@@ -561,7 +561,7 @@ JL_DLLEXPORT const char *jl_pathname_for
         free(pth16);
         return NULL;
     }
-    char *filepath = (char*)malloc(++n8);
+    char *filepath = (char*)malloc_s(++n8);
     if (!WideCharToMultiByte(CP_UTF8, 0, pth16, -1, filepath, n8, NULL, NULL)) {
         free(pth16);
         free(filepath);
diff -pruN 1.3.1+dfsg-1/src/task.c 1.4.0+dfsg-1/src/task.c
--- 1.3.1+dfsg-1/src/task.c	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/src/task.c	2020-03-21 16:36:32.000000000 +0000
@@ -40,10 +40,21 @@
 extern "C" {
 #endif
 
+#ifdef JL_ASAN_ENABLED
+static inline void sanitizer_start_switch_fiber(const void* bottom, size_t size) {
+    __sanitizer_start_switch_fiber(NULL, bottom, size);
+}
+static inline void sanitizer_finish_switch_fiber(void) {
+    __sanitizer_finish_switch_fiber(NULL, NULL, NULL);
+}
+#else
+static inline void sanitizer_start_switch_fiber(const void* bottom, size_t size) {}
+static inline void sanitizer_finish_switch_fiber(void) {}
+#endif
+
 #if defined(_OS_WINDOWS_)
 volatile int jl_in_stackwalk = 0;
 #else
-#include <sys/mman.h> // mmap
 #ifdef JL_HAVE_UCONTEXT
 #include <ucontext.h>
 #endif
@@ -136,8 +147,11 @@ static void NOINLINE JL_NORETURN restore
         }
         restore_stack(t, ptls, p); // pass p to ensure the compiler can't tailcall this or avoid the alloca
     }
-    assert(t->stkbuf != NULL);
-    memcpy_a16((uint64_t*)_x, (uint64_t*)t->stkbuf, nb); // destroys all but the current stackframe
+    void *_y = t->stkbuf;
+    assert(_x != NULL && _y != NULL);
+    memcpy_a16((uint64_t*)_x, (uint64_t*)_y, nb); // destroys all but the current stackframe
+
+    sanitizer_start_switch_fiber(t->stkbuf, t->bufsz);
     jl_set_fiber(&t->ctx);
     abort(); // unreachable
 }
@@ -145,9 +159,12 @@ static void restore_stack2(jl_task_t *t,
 {
     size_t nb = t->copy_stack;
     char *_x = (char*)ptls->stackbase - nb;
-    assert(t->stkbuf != NULL);
-    memcpy_a16((uint64_t*)_x, (uint64_t*)t->stkbuf, nb); // destroys all but the current stackframe
+    void *_y = t->stkbuf;
+    assert(_x != NULL && _y != NULL);
+    memcpy_a16((uint64_t*)_x, (uint64_t*)_y, nb); // destroys all but the current stackframe
+    sanitizer_start_switch_fiber(t->stkbuf, t->bufsz);
     jl_swap_fiber(&lastt->ctx, &t->ctx);
+    sanitizer_finish_switch_fiber();
 }
 #endif
 
@@ -218,10 +235,12 @@ JL_DLLEXPORT void *jl_task_stack_buffer(
     return (void *)((char *)task->stkbuf + off);
 }
 
-static void record_backtrace(jl_ptls_t ptls) JL_NOTSAFEPOINT
+// Marked noinline so we can consistently skip the associated frame.
+// `skip` is number of additional frames to skip.
+NOINLINE static void record_backtrace(jl_ptls_t ptls, int skip) JL_NOTSAFEPOINT
 {
     // storing bt_size in ptls ensures roots in bt_data will be found
-    ptls->bt_size = rec_backtrace(ptls->bt_data, JL_MAX_BT_SIZE);
+    ptls->bt_size = rec_backtrace(ptls->bt_data, JL_MAX_BT_SIZE, skip + 1);
 }
 
 JL_DLLEXPORT void julia_init(JL_IMAGE_SEARCH rel)
@@ -244,9 +263,8 @@ static void ctx_switch(jl_ptls_t ptls, j
         arraylist_new(locks, 0);
     }
 
-    int started = t->started;
     int killed = (lastt->state == done_sym || lastt->state == failed_sym);
-    if (!started && !t->copy_stack) {
+    if (!t->started && !t->copy_stack) {
         // may need to allocate the stack
         if (t->stkbuf == NULL) {
             t->stkbuf = jl_alloc_fiber(&t->ctx, &t->bufsz, t);
@@ -277,6 +295,7 @@ static void ctx_switch(jl_ptls_t ptls, j
         if (lastt->copy_stack) { // save the old copy-stack
             save_stack(ptls, lastt, pt); // allocates (gc-safepoint, and can also fail)
             if (jl_setjmp(lastt->ctx.uc_mcontext, 0)) {
+                sanitizer_finish_switch_fiber();
                 // TODO: mutex unlock the thread we just switched from
                 return;
             }
@@ -306,7 +325,7 @@ static void ctx_switch(jl_ptls_t ptls, j
         // after restoring the stack
         lastt_ctx = NULL;
 #endif
-    if (started) {
+    if (t->started) {
 #ifdef COPY_STACKS
         if (t->copy_stack) {
             if (lastt_ctx)
@@ -318,18 +337,27 @@ static void ctx_switch(jl_ptls_t ptls, j
         }
         else
 #endif
-        if (!lastt_ctx)
-            jl_set_fiber(&t->ctx);
-        else
+        if (!lastt_ctx) {
+            sanitizer_start_switch_fiber(t->stkbuf, t->bufsz);
+            jl_set_fiber(&t->ctx); // (doesn't return)
+            abort(); // unreachable
+        } else {
+            sanitizer_start_switch_fiber(t->stkbuf, t->bufsz);
             jl_swap_fiber(lastt_ctx, &t->ctx);
+            sanitizer_finish_switch_fiber();
+        }
     }
     else {
+        sanitizer_start_switch_fiber(t->stkbuf, t->bufsz);
+        if (always_copy_stacks) {
 #ifdef COPY_STACKS
-        if (always_copy_stacks)
             jl_longjmp(ptls->base_ctx.uc_mcontext, 1);
-        else
+            abort(); // unreachable
 #endif
+        } else {
             jl_start_fiber(lastt_ctx, &t->ctx);
+            sanitizer_finish_switch_fiber();
+        }
     }
 }
 
@@ -458,7 +486,7 @@ JL_DLLEXPORT void jl_throw(jl_value_t *e
     assert(e != NULL);
     if (ptls->safe_restore)
         throw_internal(NULL);
-    record_backtrace(ptls);
+    record_backtrace(ptls, 1);
     throw_internal(e);
 }
 
@@ -478,7 +506,6 @@ JL_DLLEXPORT void jl_sig_throw(void)
 {
     jl_ptls_t ptls = jl_get_ptls_states();
     jl_value_t *e = ptls->sig_exception;
-    assert(e && ptls->bt_size != 0);
     ptls->sig_exception = NULL;
     throw_internal(e);
 }
@@ -491,7 +518,7 @@ JL_DLLEXPORT void jl_rethrow_other(jl_va
     if (!excstack || excstack->top == 0)
         jl_error("rethrow(exc) not allowed outside a catch block");
     // overwrite exception on top of stack. see jl_excstack_exception
-    jl_excstack_raw(excstack)[excstack->top-1] = (uintptr_t)e;
+    jl_excstack_raw(excstack)[excstack->top-1].jlvalue = e;
     JL_GC_PROMISE_ROOTED(e);
     throw_internal(NULL);
 }
@@ -631,6 +658,7 @@ STATIC_OR_JS void NOINLINE JL_NORETURN s
 #endif
 
     // this runs the first time we switch to a task
+    sanitizer_finish_switch_fiber();
     jl_ptls_t ptls = jl_get_ptls_states();
     jl_task_t *t = ptls->current_task;
     jl_value_t *res;
@@ -643,9 +671,9 @@ STATIC_OR_JS void NOINLINE JL_NORETURN s
 
     t->started = 1;
     if (t->exception != jl_nothing) {
-        record_backtrace(ptls);
+        record_backtrace(ptls, 0);
         jl_push_excstack(&t->excstack, t->exception,
-                          ptls->bt_data, ptls->bt_size);
+                         ptls->bt_data, ptls->bt_size);
         res = t->exception;
     }
     else {
@@ -728,8 +756,10 @@ static void start_basefiber(void)
 {
     jl_ptls_t ptls = jl_get_ptls_states();
     if (jl_setjmp(ptls->base_ctx.uc_mcontext, 0))
-        start_task();
+        start_task(); // sanitizer_finish_switch_fiber is part of start_task
+    sanitizer_start_switch_fiber(jl_root_task->stkbuf, jl_root_task->bufsz);
     jl_longjmp(jl_root_task->ctx.uc_mcontext, 1);
+    abort(); // unreachable
 }
 #if defined(_CPU_X86_) || defined(_CPU_X86_64_)
 #define PUSH_RET(ctx, stk) \
@@ -795,7 +825,9 @@ static void jl_init_basefiber(size_t ssi
     char *stkbuf = jl_alloc_fiber(&ptls->base_ctx, &ssize, NULL);
     ptls->stackbase = stkbuf + ssize;
     ptls->stacksize = ssize;
+    sanitizer_start_switch_fiber(stkbuf, sksize);
     jl_start_fiber(jl_root_task, &ptls->base_ctx); // finishes initializing jl_basectx
+    sanitizer_finish_switch_fiber();
 #endif
 }
 #endif
@@ -910,7 +942,7 @@ static void start_basefiber(void)
 {
     jl_ptls_t ptls = jl_get_ptls_states();
     if (jl_setjmp(ptls->base_ctx.uc_mcontext, 0))
-        start_task();
+        start_task(); // sanitizer_finish_switch_fiber is part of start_task
 }
 static char *jl_alloc_fiber(jl_ucontext_t *t, size_t *ssize, jl_task_t *owner)
 {
@@ -1060,7 +1092,7 @@ void jl_init_root_task(void *stack_lo, v
         ptls->stackbase = stack_hi;
         ptls->stacksize = ssize;
         if (jl_setjmp(ptls->base_ctx.uc_mcontext, 0))
-            start_task();
+            start_task(); // sanitizer_finish_switch_fiber is part of start_task
         return;
     }
 #endif
diff -pruN 1.3.1+dfsg-1/src/threading.c 1.4.0+dfsg-1/src/threading.c
--- 1.3.1+dfsg-1/src/threading.c	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/src/threading.c	2020-03-21 16:36:32.000000000 +0000
@@ -71,7 +71,7 @@ JL_DLLEXPORT JL_CONST_FUNC jl_ptls_t (jl
 }
 
 // This is only used after the tls is already initialized on the thread
-static JL_CONST_FUNC jl_ptls_t jl_get_ptls_states_fast(void)
+static JL_CONST_FUNC jl_ptls_t jl_get_ptls_states_fast(void) JL_NOTSAFEPOINT
 {
     return (jl_ptls_t)pthread_getspecific(jl_tls_key);
 }
@@ -113,7 +113,24 @@ BOOLEAN WINAPI DllMain(IN HINSTANCE hDll
 
 JL_DLLEXPORT JL_CONST_FUNC jl_ptls_t (jl_get_ptls_states)(void) JL_GLOBALLY_ROOTED
 {
-    return (jl_ptls_t)TlsGetValue(jl_tls_key);
+#if defined(_CPU_X86_64_)
+    DWORD *plast_error = (DWORD*)(__readgsqword(0x30) + 0x68);
+    DWORD last_error = *plast_error;
+#elif defined(_CPU_X86_)
+    DWORD *plast_error = (DWORD*)(__readfsdword(0x18) + 0x34);
+    DWORD last_error = *plast_error;
+#else
+    DWORD last_error = GetLastError();
+#endif
+    jl_ptls_t state = (jl_ptls_t)TlsGetValue(jl_tls_key);
+#if defined(_CPU_X86_64_)
+    *plast_error = last_error;
+#elif defined(_CPU_X86_)
+    *plast_error = last_error;
+#else
+    SetLastError(last_error);
+#endif
+    return state;
 }
 
 jl_get_ptls_states_func jl_get_ptls_states_getter(void)
@@ -262,14 +279,10 @@ void jl_init_threadtls(int16_t tid)
                                     sizeof(size_t));
     }
     ptls->defer_signal = 0;
-    void *bt_data = malloc(sizeof(uintptr_t) * (JL_MAX_BT_SIZE + 1));
-    if (bt_data == NULL) {
-        jl_printf(JL_STDERR, "could not allocate backtrace buffer\n");
-        gc_debug_critical_error();
-        abort();
-    }
-    memset(bt_data, 0, sizeof(uintptr_t) * (JL_MAX_BT_SIZE + 1));
-    ptls->bt_data = (uintptr_t*)bt_data;
+    jl_bt_element_t *bt_data = (jl_bt_element_t*)
+        malloc_s(sizeof(jl_bt_element_t) * (JL_MAX_BT_SIZE + 1));
+    memset(bt_data, 0, sizeof(jl_bt_element_t) * (JL_MAX_BT_SIZE + 1));
+    ptls->bt_data = bt_data;
     ptls->sig_exception = NULL;
     ptls->previous_exception = NULL;
 #ifdef _OS_WINDOWS_
@@ -447,7 +460,7 @@ void jl_start_threads(void)
     uv_barrier_init(&thread_init_done, nthreads);
 
     for (i = 1; i < nthreads; ++i) {
-        jl_threadarg_t *t = (jl_threadarg_t*)malloc(sizeof(jl_threadarg_t)); // ownership will be passed to the thread
+        jl_threadarg_t *t = (jl_threadarg_t*)malloc_s(sizeof(jl_threadarg_t)); // ownership will be passed to the thread
         t->tid = i;
         t->barrier = &thread_init_done;
         uv_thread_create(&uvtid, jl_threadfun, t);
diff -pruN 1.3.1+dfsg-1/src/timing.c 1.4.0+dfsg-1/src/timing.c
--- 1.3.1+dfsg-1/src/timing.c	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/src/timing.c	2020-03-21 16:36:32.000000000 +0000
@@ -36,7 +36,7 @@ void jl_print_timings(void)
 
 void jl_init_timing(void)
 {
-    jl_root_timing = (jl_timing_block_t*)malloc(sizeof(jl_timing_block_t));
+    jl_root_timing = (jl_timing_block_t*)malloc_s(sizeof(jl_timing_block_t));
     _jl_timing_block_init(jl_root_timing, JL_TIMING_ROOT);
     jl_root_timing->prev = NULL;
 }
diff -pruN 1.3.1+dfsg-1/src/toplevel.c 1.4.0+dfsg-1/src/toplevel.c
--- 1.3.1+dfsg-1/src/toplevel.c	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/src/toplevel.c	2020-03-21 16:36:32.000000000 +0000
@@ -621,7 +621,7 @@ jl_value_t *jl_toplevel_eval_flex(jl_mod
     }
 
     if (ptls->in_pure_callback) {
-        jl_eval_errorf(m, "eval cannot be used in a generated function");
+        jl_error("eval cannot be used in a generated function");
     }
 
     jl_method_instance_t *mfunc = NULL;
@@ -865,12 +865,6 @@ JL_DLLEXPORT jl_value_t *jl_infer_thunk(
 
 JL_DLLEXPORT jl_value_t *jl_load(jl_module_t *module, const char *fname)
 {
-    if (module->istopmod) {
-        jl_printf(JL_STDOUT, "%s\r\n", fname);
-#ifdef _OS_WINDOWS_
-        jl_uv_flush(JL_STDOUT);
-#endif
-    }
     uv_stat_t stbuf;
     if (jl_stat(fname, (char*)&stbuf) != 0 || (stbuf.st_mode & S_IFMT) != S_IFREG) {
         jl_errorf("could not open file %s", fname);
diff -pruN 1.3.1+dfsg-1/stdlib/Dates/src/periods.jl 1.4.0+dfsg-1/stdlib/Dates/src/periods.jl
--- 1.3.1+dfsg-1/stdlib/Dates/src/periods.jl	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/stdlib/Dates/src/periods.jl	2020-03-21 16:36:32.000000000 +0000
@@ -75,12 +75,10 @@ for op in (:+, :-, :lcm, :gcd)
     @eval ($op)(x::P, y::P) where {P<:Period} = P(($op)(value(x), value(y)))
 end
 
-for op in (:/, :div, :fld)
-    @eval begin
-        ($op)(x::P, y::P) where {P<:Period} = ($op)(value(x), value(y))
-        ($op)(x::P, y::Real) where {P<:Period} = P(($op)(value(x), Int64(y)))
-    end
-end
+/(x::P, y::P) where {P<:Period} = /(value(x), value(y))
+/(x::P, y::Real) where {P<:Period} = P(/(value(x), Int64(y)))
+div(x::P, y::P, r::RoundingMode) where {P<:Period} = div(value(x), value(y), r)
+div(x::P, y::Real, r::RoundingMode) where {P<:Period} = P(div(value(x), Int64(y), r))
 
 for op in (:rem, :mod)
     @eval begin
diff -pruN 1.3.1+dfsg-1/stdlib/Dates/src/types.jl 1.4.0+dfsg-1/stdlib/Dates/src/types.jl
--- 1.3.1+dfsg-1/stdlib/Dates/src/types.jl	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/stdlib/Dates/src/types.jl	2020-03-21 16:36:32.000000000 +0000
@@ -124,7 +124,7 @@ end
 """
 struct Time <: TimeType
     instant::Nanosecond
-    Time(instant::Nanosecond) = new(instant)
+    Time(instant::Nanosecond) = new(mod(instant, 86400000000000))
 end
 
 # Convert y,m,d to # of Rata Die days
@@ -397,11 +397,6 @@ Base.promote_rule(::Type{Date}, x::Type{
 Base.isless(x::T, y::T) where {T<:TimeType} = isless(value(x), value(y))
 Base.isless(x::TimeType, y::TimeType) = isless(promote(x, y)...)
 (==)(x::T, y::T) where {T<:TimeType} = (==)(value(x), value(y))
-function ==(a::Time, b::Time)
-    return hour(a) == hour(b) && minute(a) == minute(b) &&
-        second(a) == second(b) && millisecond(a) == millisecond(b) &&
-        microsecond(a) == microsecond(b) && nanosecond(a) == nanosecond(b)
-end
 (==)(x::TimeType, y::TimeType) = (===)(promote(x, y)...)
 Base.min(x::AbstractTime) = x
 Base.max(x::AbstractTime) = x
diff -pruN 1.3.1+dfsg-1/stdlib/Dates/test/arithmetic.jl 1.4.0+dfsg-1/stdlib/Dates/test/arithmetic.jl
--- 1.3.1+dfsg-1/stdlib/Dates/test/arithmetic.jl	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/stdlib/Dates/test/arithmetic.jl	2020-03-21 16:36:32.000000000 +0000
@@ -325,6 +325,15 @@ end
     @test t + Dates.Millisecond(1) == Dates.Time(0, 0, 0, 1)
     @test t + Dates.Microsecond(1) == Dates.Time(0, 0, 0, 0, 1)
     @test_throws MethodError t + Dates.Day(1)
+    @testset "Time-TimePeriod arithmetic inequalities" begin
+        t = Dates.Time(4, 20)
+        @test t - Dates.Nanosecond(1) < t
+        @test t + Dates.Nanosecond(1) > t
+        @test t + Dates.Hour(24) < typemax(Dates.Time)
+        @test t - Dates.Hour(24) > typemin(Dates.Time)
+        @test t + Dates.Hour(23) < t
+        @test t + Dates.Hour(25) > t
+    end
 end
 @testset "Month arithmetic and non-associativity" begin
     # Month arithmetic minimizes "edit distance", or number of changes
diff -pruN 1.3.1+dfsg-1/stdlib/DelimitedFiles/src/DelimitedFiles.jl 1.4.0+dfsg-1/stdlib/DelimitedFiles/src/DelimitedFiles.jl
--- 1.3.1+dfsg-1/stdlib/DelimitedFiles/src/DelimitedFiles.jl	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/stdlib/DelimitedFiles/src/DelimitedFiles.jl	2020-03-21 16:36:32.000000000 +0000
@@ -143,8 +143,6 @@ julia> readdlm("delim_file.txt", ',')
  3.0  3.3
  4.0  4.4
 
-julia> rm("delim_file.txt")
-
 julia> z = ["a"; "b"; "c"; "d"];
 
 julia> open("delim_file.txt", "w") do io
@@ -220,6 +218,8 @@ julia> readdlm("delim_file.txt", '\\t',
  2  6
  3  7
  4  8
+
+julia> rm("delim_file.txt")
 ```
 """
 readdlm(input, dlm::AbstractChar, T::Type, eol::AbstractChar; opts...) =
diff -pruN 1.3.1+dfsg-1/stdlib/Distributed/src/Distributed.jl 1.4.0+dfsg-1/stdlib/Distributed/src/Distributed.jl
--- 1.3.1+dfsg-1/stdlib/Distributed/src/Distributed.jl	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/stdlib/Distributed/src/Distributed.jl	2020-03-21 16:36:32.000000000 +0000
@@ -91,7 +91,6 @@ include("macros.jl")      # @spawn and f
 include("workerpool.jl")
 include("pmap.jl")
 include("managers.jl")    # LocalManager and SSHManager
-include("precompile.jl")
 
 function __init__()
     init_parallel()
diff -pruN 1.3.1+dfsg-1/stdlib/Distributed/src/macros.jl 1.4.0+dfsg-1/stdlib/Distributed/src/macros.jl
--- 1.3.1+dfsg-1/stdlib/Distributed/src/macros.jl	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/stdlib/Distributed/src/macros.jl	2020-03-21 16:36:32.000000000 +0000
@@ -48,7 +48,7 @@ macro spawn(expr)
     var = esc(Base.sync_varname)
     quote
         local ref = spawn_somewhere($thunk)
-        if $(Expr(:isdefined, var))
+        if $(Expr(:islocal, var))
             push!($var, ref)
         end
         ref
@@ -93,7 +93,7 @@ macro spawnat(p, expr)
     end
     quote
         local ref = $spawncall
-        if $(Expr(:isdefined, var))
+        if $(Expr(:islocal, var))
             push!($var, ref)
         end
         ref
@@ -171,7 +171,7 @@ extract_imports(x) = extract_imports!(An
 
 Execute an expression under `Main` on all `procs`.
 Errors on any of the processes are collected into a
-`CompositeException` and thrown. For example:
+[`CompositeException`](@ref) and thrown. For example:
 
     @everywhere bar = 1
 
@@ -209,9 +209,9 @@ end
 Execute an expression under module `m` on the processes
 specified in `procs`.
 Errors on any of the processes are collected into a
-`CompositeException` and thrown.
+[`CompositeException`](@ref) and thrown.
 
-See also `@everywhere`.
+See also [`@everywhere`](@ref).
 """
 function remotecall_eval(m::Module, procs, ex)
     @sync begin
@@ -346,7 +346,7 @@ macro distributed(args...)
         syncvar = esc(Base.sync_varname)
         return quote
             local ref = pfor($(make_pfor_body(var, body)), $(esc(r)))
-            if $(Expr(:isdefined, syncvar))
+            if $(Expr(:islocal, syncvar))
                 push!($syncvar, ref)
             end
             ref
diff -pruN 1.3.1+dfsg-1/stdlib/Distributed/src/pmap.jl 1.4.0+dfsg-1/stdlib/Distributed/src/pmap.jl
--- 1.3.1+dfsg-1/stdlib/Distributed/src/pmap.jl	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/stdlib/Distributed/src/pmap.jl	2020-03-21 16:36:32.000000000 +0000
@@ -90,7 +90,7 @@ Example: On errors, retry `f` on an elem
 pmap(f, c; retry_delays = zeros(3))
 ```
 
-Example: Retry `f` only if the exception is not of type `InexactError`, with exponentially increasing
+Example: Retry `f` only if the exception is not of type [`InexactError`](@ref), with exponentially increasing
 delays up to 3 times. Return a `NaN` in place for all `InexactError` occurrences.
 ```julia
 pmap(f, c; on_error = e->(isa(e, InexactError) ? NaN : rethrow()), retry_delays = ExponentialBackOff(n = 3))
diff -pruN 1.3.1+dfsg-1/stdlib/Distributed/src/precompile.jl 1.4.0+dfsg-1/stdlib/Distributed/src/precompile.jl
--- 1.3.1+dfsg-1/stdlib/Distributed/src/precompile.jl	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/stdlib/Distributed/src/precompile.jl	1970-01-01 00:00:00.000000000 +0000
@@ -1,212 +0,0 @@
-# This file is a part of Julia. License is MIT: https://julialang.org/license
-
-precompile(Tuple{typeof(Base.empty!), Base.Dict{Int64, Union{Distributed.Worker, Distributed.LocalProcess}}})
-precompile(Tuple{typeof(Core.Compiler.isbits), Distributed.DefaultClusterManager})
-precompile(Tuple{typeof(Distributed.init_worker), String, Distributed.DefaultClusterManager})
-precompile(Tuple{typeof(Distributed.local_remotecall_thunk), typeof(Distributed.set_valid_processes), Tuple{Array{Int64, 1}}, Array{Any, 1}})
-precompile(Tuple{typeof(Distributed.remote_do), typeof(Distributed.set_valid_processes), Distributed.Worker, Array{Int64, 1}})
-precompile(Tuple{typeof(Distributed.remote_do), typeof(Distributed.set_valid_processes), Distributed.LocalProcess, Array{Int64, 1}})
-precompile(Tuple{getfield(Distributed, Symbol("#kw##remote_do")), Array{Any, 1}, typeof(Distributed.remote_do), typeof(Distributed.set_valid_processes), Distributed.Worker, Array{Int64, 1}})
-precompile(Tuple{getfield(Distributed, Symbol("#kw##remote_do")), Array{Any, 1}, typeof(Distributed.remote_do), typeof(Distributed.set_valid_processes), Distributed.LocalProcess, Array{Int64, 1}})
-precompile(Tuple{typeof(Distributed.default_addprocs_params)})
-precompile(Tuple{typeof(Distributed.topology), Symbol})
-precompile(Tuple{typeof(Base.popfirst!), Array{Distributed.WorkerConfig, 1}})
-precompile(Tuple{typeof(Distributed.workers)})
-precompile(Tuple{getfield(Distributed, Symbol("#kw##addprocs_locked")), Array{Any, 1}, typeof(Distributed.addprocs_locked), Distributed.SSHManager})
-precompile(Tuple{typeof(Distributed.check_addprocs_args), Array{Any, 1}})
-precompile(Tuple{Type{Distributed.SSHManager}, Array{Any, 1}})
-precompile(Tuple{getfield(Distributed, Symbol("#kw##addprocs")), Array{Any, 1}, typeof(Distributed.addprocs), Distributed.SSHManager})
-precompile(Tuple{getfield(Distributed, Symbol("#kw##addprocs_locked")), Array{Any, 1}, typeof(Distributed.addprocs_locked), Distributed.LocalManager})
-precompile(Tuple{getfield(Distributed, Symbol("#kw##addprocs")), Array{Any, 1}, typeof(Distributed.addprocs), Distributed.LocalManager})
-precompile(Tuple{typeof(Distributed.check_master_connect)})
-precompile(Tuple{typeof(Distributed.terminate_all_workers)})
-precompile(Tuple{typeof(Distributed.local_remotecall_thunk), typeof(Base.exit), Tuple{}, Array{Any, 1}})
-precompile(Tuple{typeof(Distributed.remote_do), typeof(Base.exit), Distributed.Worker})
-precompile(Tuple{typeof(Distributed.remote_do), typeof(Base.exit), Distributed.LocalProcess})
-precompile(Tuple{getfield(Distributed, Symbol("#kw##remote_do")), Array{Any, 1}, typeof(Distributed.remote_do), typeof(Base.exit), Distributed.Worker})
-precompile(Tuple{getfield(Distributed, Symbol("#kw##remote_do")), Array{Any, 1}, typeof(Distributed.remote_do), typeof(Base.exit), Distributed.LocalProcess})
-precompile(Tuple{typeof(Distributed.set_worker_state), Distributed.Worker, Distributed.WorkerState})
-precompile(Tuple{typeof(Distributed.set_worker_state), Distributed.LocalProcess, Distributed.WorkerState})
-precompile(Tuple{getfield(Distributed, Symbol("#kw##rmprocs")), Array{Any, 1}, typeof(Distributed.rmprocs), Array{Int64, 1}})
-precompile(Tuple{typeof(Distributed.interrupt), Array{Int64, 1}})
-precompile(Tuple{typeof(Distributed.flush_gc_msgs)})
-precompile(Tuple{typeof(Distributed.addprocs), Int64})
-precompile(Tuple{Type{Distributed.WorkerConfig}})
-precompile(Tuple{typeof(Distributed.launch), Distributed.LocalManager, Base.Dict{Any, Any}, Array{Distributed.WorkerConfig, 1}, Base.Condition})
-precompile(Tuple{typeof(Distributed.start_worker), Base.PipeEndpoint, String})
-precompile(Tuple{typeof(Distributed.socket_reuse_port)})
-precompile(Tuple{typeof(Distributed.flush_gc_msgs)})
-precompile(Tuple{typeof(Sockets.nagle), Sockets.TCPServer, Bool})
-precompile(Tuple{typeof(Sockets.quickack), Sockets.TCPServer, Bool})
-precompile(Tuple{typeof(Distributed.next_tunnel_port)})
-precompile(Tuple{typeof(Base._delete!), Base.Dict{Int64, Union{Distributed.Worker, Distributed.LocalProcess}}, Int64})
-precompile(Tuple{typeof(Distributed.send_msg_), Distributed.Worker, Distributed.MsgHeader, Distributed.JoinPGRPMsg, Bool})
-precompile(Tuple{typeof(Distributed.send_msg_now), Distributed.Worker, Distributed.MsgHeader, Distributed.JoinPGRPMsg})
-precompile(Tuple{typeof(Distributed.connect_w2w), Int64, Distributed.WorkerConfig})
-precompile(Tuple{typeof(Distributed.create_worker), Distributed.LocalManager, Distributed.WorkerConfig})
-precompile(Tuple{typeof(Distributed.setup_launched_worker), Distributed.LocalManager, Distributed.WorkerConfig, Array{Int64, 1}})
-precompile(Tuple{typeof(Sockets.connect), Distributed.LocalManager, Int64, Distributed.WorkerConfig})
-precompile(Tuple{typeof(Distributed.read_worker_host_port), Base.Pipe})
-precompile(Tuple{typeof(Distributed.parse_connection_info), String})
-precompile(Tuple{typeof(Distributed.connect_to_worker), Base.SubString{String}, Int16})
-precompile(Tuple{typeof(Distributed.process_messages), Sockets.TCPSocket, Sockets.TCPSocket, Bool})
-precompile(Tuple{getfield(Core, Symbol("#kw#Type")), Array{Any, 1}, Type{Distributed.Worker}, Int64, Sockets.TCPSocket, Sockets.TCPSocket, Distributed.LocalManager})
-precompile(Tuple{typeof(Distributed.worker_id_from_socket), Sockets.TCPSocket})
-precompile(Tuple{Type{Distributed.ClusterSerializer{Sockets.TCPSocket}}, Sockets.TCPSocket})
-precompile(Tuple{typeof(Distributed.send_msg_), Distributed.Worker, Distributed.MsgHeader, Distributed.ResultMsg, Bool})
-precompile(Tuple{typeof(Distributed.send_msg_now), Distributed.Worker, Distributed.MsgHeader, Distributed.ResultMsg})
-precompile(Tuple{typeof(Distributed.register_worker_streams), Distributed.Worker})
-precompile(Tuple{typeof(Distributed.register_worker_streams), Distributed.LocalProcess})
-precompile(Tuple{Type{Distributed.ClusterSerializer{Sockets.TCPSocket}}, Sockets.TCPSocket})
-precompile(Tuple{typeof(Distributed.worker_id_from_socket), Sockets.TCPSocket})
-precompile(Tuple{typeof(Base.convert), Type{Distributed.ClusterSerializer{I} where I<:IO}, Distributed.ClusterSerializer{Sockets.TCPSocket}})
-precompile(Tuple{typeof(Base.convert), Type{Distributed.ClusterManager}, Distributed.LocalManager})
-precompile(Tuple{typeof(Base.convert), Type{Distributed.WorkerConfig}, Distributed.WorkerConfig})
-precompile(Tuple{typeof(Base.get), Base.Dict{Any, Any}, Distributed.RRID, Bool})
-precompile(Tuple{typeof(Base.ht_keyindex), Base.Dict{Any, Any}, Distributed.RRID})
-precompile(Tuple{typeof(Distributed.local_remotecall_thunk), typeof(Distributed.rmprocs), Tuple{Int64}, Array{Any, 1}})
-precompile(Tuple{typeof(Distributed.remote_do), typeof(Distributed.rmprocs), Distributed.Worker, Int64})
-precompile(Tuple{typeof(Distributed.remote_do), typeof(Distributed.rmprocs), Distributed.LocalProcess, Int64})
-precompile(Tuple{getfield(Distributed, Symbol("#kw##remote_do")), Array{Any, 1}, typeof(Distributed.remote_do), typeof(Distributed.rmprocs), Distributed.Worker, Int64})
-precompile(Tuple{getfield(Distributed, Symbol("#kw##remote_do")), Array{Any, 1}, typeof(Distributed.remote_do), typeof(Distributed.rmprocs), Distributed.LocalProcess, Int64})
-precompile(Tuple{Type{Distributed.ResultMsg}, Distributed.RemoteException})
-precompile(Tuple{Type{Distributed.ResultMsg}, Symbol})
-precompile(Tuple{typeof(Distributed.send_msg_now), Sockets.TCPSocket, Distributed.MsgHeader, Distributed.ResultMsg})
-precompile(Tuple{typeof(Base._delete!), Base.Dict{Int64, Union{Distributed.Worker, Distributed.LocalProcess}}, Int64})
-precompile(Tuple{typeof(Distributed.def_rv_channel)})
-precompile(Tuple{typeof(Base.setindex!), Base.Dict{Any, Any}, Distributed.RemoteValue, Distributed.RRID})
-precompile(Tuple{typeof(Base.ht_keyindex2!), Base.Dict{Any, Any}, Distributed.RRID})
-precompile(Tuple{typeof(Base._setindex!), Base.Dict{Any, Any}, Distributed.RemoteValue, Distributed.RRID, Int64})
-precompile(Tuple{typeof(Base.notify), Base.Condition, Distributed.ProcessExitedException, Bool, Bool})
-precompile(Tuple{typeof(Distributed.process_messages), Sockets.TCPSocket, Sockets.TCPSocket, Bool})
-precompile(Tuple{typeof(Base.pop!), Base.Dict{Int64, Union{Distributed.Worker, Distributed.LocalProcess}}, Int64, Nothing})
-precompile(Tuple{typeof(Distributed.send_connection_hdr), Distributed.Worker, Bool})
-precompile(Tuple{typeof(Distributed.deregister_worker), Distributed.ProcessGroup, Int64})
-precompile(Tuple{typeof(Distributed.process_hdr), Sockets.TCPSocket, Bool})
-precompile(Tuple{typeof(Distributed.deserialize_msg), Distributed.ClusterSerializer{Sockets.TCPSocket}})
-precompile(Tuple{typeof(Distributed.null_id), Distributed.RRID})
-precompile(Tuple{typeof(Distributed.deliver_result), Sockets.TCPSocket, Symbol, Distributed.RRID, Distributed.RemoteException})
-precompile(Tuple{typeof(Sockets.nagle), Sockets.TCPSocket, Bool})
-precompile(Tuple{typeof(Sockets.quickack), Sockets.TCPSocket, Bool})
-precompile(Tuple{typeof(Distributed.message_handler_loop), Sockets.TCPSocket, Sockets.TCPSocket, Bool})
-precompile(Tuple{typeof(Distributed.process_tcp_streams), Sockets.TCPSocket, Sockets.TCPSocket, Bool})
-precompile(Tuple{Type{Distributed.JoinPGRPMsg}, Int64, Array{Union{Tuple{Any, Int64}, Tuple{Tuple{}, Any, Bool}}, 1}, Symbol, Bool})
-precompile(Tuple{typeof(Serialization.serialize), Distributed.ClusterSerializer{Sockets.TCPSocket}, Distributed.JoinPGRPMsg})
-precompile(Tuple{typeof(Serialization.serialize), Distributed.ClusterSerializer{Sockets.TCPSocket}, Int64})
-precompile(Tuple{typeof(Serialization.serialize), Distributed.ClusterSerializer{Sockets.TCPSocket}, Array{Union{Tuple{Any, Int64}, Tuple{Tuple{}, Any, Bool}}, 1}})
-precompile(Tuple{typeof(Serialization.should_send_whole_type), Distributed.ClusterSerializer{Sockets.TCPSocket}, Type{Any}})
-precompile(Tuple{typeof(Serialization.serialize), Distributed.ClusterSerializer{Sockets.TCPSocket}, Core.SimpleVector})
-precompile(Tuple{typeof(Serialization.serialize_type_data), Distributed.ClusterSerializer{Sockets.TCPSocket}, Type{Any}, Bool})
-precompile(Tuple{typeof(Serialization.serialize), Distributed.ClusterSerializer{Sockets.TCPSocket}, Type{Any}})
-precompile(Tuple{typeof(Serialization.serialize), Distributed.ClusterSerializer{Sockets.TCPSocket}, Tuple{Int64}})
-precompile(Tuple{typeof(Serialization.serialize_cycle), Distributed.ClusterSerializer{Sockets.TCPSocket}, Type{Union{Tuple{Any, Int64}, Tuple{Tuple{}, Any, Bool}}}})
-precompile(Tuple{typeof(Serialization.serialize_type), Distributed.ClusterSerializer{Sockets.TCPSocket}, DataType})
-precompile(Tuple{typeof(Serialization.serialize), Distributed.ClusterSerializer{Sockets.TCPSocket}, Bool})
-precompile(Tuple{typeof(Distributed.serialize_global_from_main), Distributed.ClusterSerializer{Sockets.TCPSocket}, Symbol})
-precompile(Tuple{typeof(Serialization.serialize_mod_names), Distributed.ClusterSerializer{Sockets.TCPSocket}, Module})
-precompile(Tuple{typeof(Serialization.serialize), Distributed.ClusterSerializer{Sockets.TCPSocket}, Symbol})
-precompile(Tuple{typeof(Serialization.serialize), Distributed.ClusterSerializer{Sockets.TCPSocket}, Module})
-precompile(Tuple{typeof(Serialization.serialize), Distributed.ClusterSerializer{Sockets.TCPSocket}, Array{Any, 1}})
-precompile(Tuple{typeof(Serialization.serialize_cycle), Distributed.ClusterSerializer{Sockets.TCPSocket}, Core.TypeName})
-precompile(Tuple{typeof(Serialization.serialize_typename), Distributed.ClusterSerializer{Sockets.TCPSocket}, Core.TypeName})
-precompile(Tuple{typeof(Serialization.serialize), Distributed.ClusterSerializer{Sockets.TCPSocket}, Array{Symbol, 1}})
-precompile(Tuple{typeof(Serialization.serialize), Distributed.ClusterSerializer{Sockets.TCPSocket}, Core.TypeName})
-precompile(Tuple{typeof(Serialization.serialize_cycle_header), Distributed.ClusterSerializer{Sockets.TCPSocket}, Type{Union{Tuple{Any, Int64}, Tuple{Tuple{}, Any, Bool}}}})
-precompile(Tuple{typeof(Serialization.serialize_any), Distributed.ClusterSerializer{Sockets.TCPSocket}, Type{Union{Tuple{Any, Int64}, Tuple{Tuple{}, Any, Bool}}}})
-precompile(Tuple{typeof(Distributed.send_msg_), Distributed.Worker, Distributed.MsgHeader, Distributed.ResultMsg, Bool})
-precompile(Tuple{typeof(Distributed.send_msg_now), Distributed.Worker, Distributed.MsgHeader, Distributed.ResultMsg})
-precompile(Tuple{typeof(Distributed.local_remotecall_thunk), typeof(Distributed.rmprocs), Tuple{Int64}, Array{Any, 1}})
-precompile(Tuple{typeof(Distributed.remote_do), typeof(Distributed.rmprocs), Distributed.Worker, Int64})
-precompile(Tuple{typeof(Distributed.remote_do), typeof(Distributed.rmprocs), Distributed.LocalProcess, Int64})
-precompile(Tuple{getfield(Distributed, Symbol("#kw##remote_do")), Array{Any, 1}, typeof(Distributed.remote_do), typeof(Distributed.rmprocs), Distributed.Worker, Int64})
-precompile(Tuple{getfield(Distributed, Symbol("#kw##remote_do")), Array{Any, 1}, typeof(Distributed.remote_do), typeof(Distributed.rmprocs), Distributed.LocalProcess, Int64})
-precompile(Tuple{Type{Distributed.ResultMsg}, Distributed.RemoteException})
-precompile(Tuple{Type{Distributed.ResultMsg}, Symbol})
-precompile(Tuple{typeof(Distributed.send_msg_now), Sockets.TCPSocket, Distributed.MsgHeader, Distributed.ResultMsg})
-precompile(Tuple{typeof(Base.pop!), Base.Dict{Int64, Union{Distributed.Worker, Distributed.LocalProcess}}, Int64, Nothing})
-precompile(Tuple{typeof(Distributed.deregister_worker), Distributed.ProcessGroup, Int64})
-precompile(Tuple{typeof(Distributed.process_hdr), Sockets.TCPSocket, Bool})
-precompile(Tuple{typeof(Distributed.null_id), Distributed.RRID})
-precompile(Tuple{typeof(Distributed.deliver_result), Sockets.TCPSocket, Symbol, Distributed.RRID, Distributed.RemoteException})
-precompile(Tuple{typeof(Distributed.message_handler_loop), Sockets.TCPSocket, Sockets.TCPSocket, Bool})
-precompile(Tuple{typeof(Distributed.process_tcp_streams), Sockets.TCPSocket, Sockets.TCPSocket, Bool})
-precompile(Tuple{typeof(Serialization.deserialize), Distributed.ClusterSerializer{Sockets.TCPSocket}, Type{Union}})
-precompile(Tuple{typeof(Serialization.deserialize), Distributed.ClusterSerializer{Sockets.TCPSocket}, Type{Module}})
-precompile(Tuple{typeof(Serialization.deserialize), Distributed.ClusterSerializer{Sockets.TCPSocket}, Type{Core.SimpleVector}})
-precompile(Tuple{Type{Distributed.JoinPGRPMsg}, Int64, Array{Union{Tuple{Any, Int64}, Tuple{Tuple{}, Any, Bool}}, 1}, Symbol, Bool})
-precompile(Tuple{typeof(Distributed.handle_msg), Distributed.JoinPGRPMsg, Distributed.MsgHeader, Sockets.TCPSocket, Sockets.TCPSocket, Base.VersionNumber})
-precompile(Tuple{Type{Distributed.WorkerConfig}})
-precompile(Tuple{typeof(Distributed.send_msg_), Distributed.Worker, Distributed.MsgHeader, Distributed.JoinCompleteMsg, Bool})
-precompile(Tuple{typeof(Distributed.send_msg_now), Distributed.Worker, Distributed.MsgHeader, Distributed.JoinCompleteMsg})
-precompile(Tuple{getfield(Core, Symbol("#kw#Type")), Array{Any, 1}, Type{Distributed.Worker}, Int64, Sockets.TCPSocket, Sockets.TCPSocket, Distributed.DefaultClusterManager})
-precompile(Tuple{typeof(Distributed.register_worker_streams), Distributed.Worker})
-precompile(Tuple{typeof(Distributed.register_worker_streams), Distributed.LocalProcess})
-precompile(Tuple{typeof(Base.convert), Type{Distributed.ClusterSerializer{I} where I<:IO}, Distributed.ClusterSerializer{Sockets.TCPSocket}})
-precompile(Tuple{typeof(Base.convert), Type{Distributed.ClusterManager}, Distributed.DefaultClusterManager})
-precompile(Tuple{typeof(Base.convert), Type{Distributed.WorkerConfig}, Distributed.WorkerConfig})
-precompile(Tuple{typeof(Distributed.send_connection_hdr), Distributed.Worker, Bool})
-precompile(Tuple{typeof(Distributed.manage), Distributed.LocalManager, Int64, Distributed.WorkerConfig, Symbol})
-precompile(Tuple{typeof(Serialization.serialize), Distributed.ClusterSerializer{Sockets.TCPSocket}, Distributed.JoinCompleteMsg})
-precompile(Tuple{typeof(Serialization.serialize), Distributed.ClusterSerializer{Sockets.TCPSocket}, Int64})
-precompile(Tuple{typeof(Serialization.deserialize), Distributed.ClusterSerializer{Sockets.TCPSocket}})
-precompile(Tuple{typeof(Serialization.deserialize_cycle), Distributed.ClusterSerializer{Sockets.TCPSocket}, Expr})
-precompile(Tuple{typeof(Serialization.handle_deserialize), Distributed.ClusterSerializer{Sockets.TCPSocket}, Int32})
-precompile(Tuple{typeof(Serialization.deserialize_array), Distributed.ClusterSerializer{Sockets.TCPSocket}})
-precompile(Tuple{typeof(Serialization.deserialize_datatype), Distributed.ClusterSerializer{Sockets.TCPSocket}})
-precompile(Tuple{typeof(Serialization.deserialize_expr), Distributed.ClusterSerializer{Sockets.TCPSocket}, Int64})
-precompile(Tuple{typeof(Serialization.deserialize), Distributed.ClusterSerializer{Sockets.TCPSocket}, Type{Int64}})
-precompile(Tuple{Type{Distributed.JoinCompleteMsg}, Int64, Int64})
-precompile(Tuple{typeof(Distributed.handle_msg), Distributed.JoinCompleteMsg, Distributed.MsgHeader, Sockets.TCPSocket, Sockets.TCPSocket, Base.VersionNumber})
-precompile(Tuple{typeof(Base.hash), Distributed.RemoteChannel{Base.Channel{Any}}, UInt64})
-precompile(Tuple{typeof(Base.ht_keyindex), Base.Dict{WeakRef, Nothing}, Distributed.RemoteChannel{Base.Channel{Any}}})
-precompile(Tuple{typeof(Distributed.remotecall_fetch), typeof(Distributed.put_ref), Distributed.Worker, Distributed.RRID, Distributed.WorkerPool})
-precompile(Tuple{typeof(Distributed.remotecall_fetch), typeof(Distributed.put_ref), Distributed.LocalProcess, Distributed.RRID, Distributed.WorkerPool})
-precompile(Tuple{getfield(Distributed, Symbol("#kw##remotecall_fetch")), Array{Any, 1}, typeof(Distributed.remotecall_fetch), typeof(Distributed.put_ref), Distributed.Worker, Distributed.RRID, Distributed.WorkerPool})
-precompile(Tuple{getfield(Distributed, Symbol("#kw##remotecall_fetch")), Array{Any, 1}, typeof(Distributed.remotecall_fetch), typeof(Distributed.put_ref), Distributed.LocalProcess, Distributed.RRID, Distributed.WorkerPool})
-precompile(Tuple{typeof(Base.finalizer), Distributed.RemoteChannel{Base.Channel{Any}}, typeof(Distributed.finalize_ref)})
-precompile(Tuple{typeof(Distributed.test_existing_ref), Distributed.RemoteChannel{Base.Channel{Any}}})
-precompile(Tuple{Type{Distributed.RemoteChannel{T} where T<:Base.AbstractChannel}, Int64})
-precompile(Tuple{Type{Distributed.WorkerPool}})
-precompile(Tuple{typeof(Distributed.default_worker_pool)})
-precompile(Tuple{typeof(Distributed.call_on_owner), typeof(Distributed.put_ref), Distributed.RemoteChannel{Base.Channel{Any}}, Distributed.WorkerPool})
-precompile(Tuple{typeof(Distributed.put_ref), Distributed.RRID, Distributed.WorkerPool})
-precompile(Tuple{typeof(Base.put!), Distributed.RemoteValue, Distributed.WorkerPool})
-precompile(Tuple{typeof(Base.put!), Base.Channel{Any}, Distributed.WorkerPool})
-precompile(Tuple{typeof(Base.put_buffered), Base.Channel{Any}, Distributed.WorkerPool})
-precompile(Tuple{typeof(Base.put_unbuffered), Base.Channel{Any}, Distributed.WorkerPool})
-precompile(Tuple{typeof(Base.push!), Distributed.WorkerPool, Int64})
-precompile(Tuple{typeof(Serialization.serialize), Distributed.ClusterSerializer{Sockets.TCPSocket}, Distributed.RemoteDoMsg})
-precompile(Tuple{typeof(Serialization.serialize), Distributed.ClusterSerializer{Sockets.TCPSocket}, typeof(Distributed.set_valid_processes)})
-precompile(Tuple{typeof(Serialization.serialize), Distributed.ClusterSerializer{Sockets.TCPSocket}, Tuple{Array{Int64, 1}}})
-precompile(Tuple{typeof(Serialization.serialize), Distributed.ClusterSerializer{Sockets.TCPSocket}, Array{Int64, 1}})
-precompile(Tuple{typeof(Serialization.deserialize), Distributed.ClusterSerializer{Sockets.TCPSocket}, Type{typeof(Distributed.set_valid_processes)}})
-precompile(Tuple{typeof(Distributed.handle_msg), Distributed.RemoteDoMsg, Distributed.MsgHeader, Sockets.TCPSocket, Sockets.TCPSocket, Base.VersionNumber})
-precompile(Tuple{typeof(Distributed.set_valid_processes), Array{Int64, 1}})
-precompile(Tuple{typeof(Distributed._rmprocs), Array{Int64, 1}, Float64})
-precompile(Tuple{typeof(Base.kill), Distributed.LocalManager, Int64, Distributed.WorkerConfig})
-precompile(Tuple{typeof(Serialization.serialize), Distributed.ClusterSerializer{Sockets.TCPSocket}, typeof(Base.exit)})
-precompile(Tuple{typeof(Serialization.serialize), Distributed.ClusterSerializer{Sockets.TCPSocket}, Tuple{}})
-precompile(Tuple{typeof(Serialization.deserialize), Distributed.ClusterSerializer{Sockets.TCPSocket}, Type{typeof(Base.exit)}})
-precompile(Tuple{typeof(Distributed.finalize_ref), Distributed.RemoteChannel{Base.Channel{Any}}})
-precompile(Tuple{typeof(Distributed.send_del_client), Distributed.RemoteChannel{Base.Channel{Any}}})
-precompile(Tuple{typeof(Base.:(==)), Distributed.RemoteChannel{Base.Channel{Any}}, Distributed.RemoteChannel{Base.Channel{Any}}})
-precompile(Tuple{getfield(Distributed, Symbol("#kw##remotecall_fetch")), Array{Any, 1}, typeof(Distributed.remotecall_fetch), typeof(Base.open), Distributed.LocalProcess, typeof(Base.read), String})
-precompile(Tuple{getfield(Distributed, Symbol("#kw##remotecall_fetch")), Array{Any, 1}, typeof(Distributed.remotecall_fetch), typeof(Base.open), Distributed.Worker, typeof(Base.read), String})
-precompile(Tuple{getfield(Distributed, Symbol("#kw##remote_do")), Array{Any, 1}, typeof(Distributed.remote_do), typeof(Base.exit), Distributed.Worker})
-precompile(Tuple{getfield(Distributed, Symbol("#kw##rmprocs")), Array{Any, 1}, typeof(Distributed.rmprocs), Array{Int64, 1}})
-precompile(Tuple{Type{Distributed.Future}, Int64})
-precompile(Tuple{typeof(Distributed.flush_gc_msgs), Distributed.Worker})
-precompile(Tuple{typeof(Distributed.remote_do), typeof(Base.exit), Distributed.Worker})
-precompile(Tuple{typeof(Distributed.send_del_client), Distributed.Future})
-precompile(Tuple{typeof(Distributed.send_msg), Distributed.Worker, Distributed.MsgHeader, Distributed.CallMsg{:call}})
-precompile(Tuple{typeof(Distributed.send_msg_), Distributed.Worker, Distributed.MsgHeader, Distributed.CallMsg{:call}, Bool})
-precompile(Tuple{typeof(Distributed.send_msg), Distributed.Worker, Distributed.MsgHeader, Distributed.CallMsg{:call_fetch}})
-precompile(Tuple{typeof(Distributed.send_msg_), Distributed.Worker, Distributed.MsgHeader, Distributed.CallMsg{:call_fetch}, Bool})
-precompile(Tuple{typeof(Distributed.send_msg), Distributed.Worker, Distributed.MsgHeader, Distributed.RemoteDoMsg})
-precompile(Tuple{typeof(Distributed.send_msg_), Distributed.Worker, Distributed.MsgHeader, Distributed.RemoteDoMsg, Bool})
-precompile(Tuple{typeof(Distributed.terminate_all_workers)})
-precompile(Tuple{typeof(Distributed.test_existing_ref), Distributed.Future})
-precompile(Tuple{typeof(Base.finalizer), Distributed.Future, typeof(Distributed.finalize_ref)})
-precompile(Tuple{typeof(Base.hash), Distributed.Future, UInt64})
-precompile(Tuple{typeof(Base.ht_keyindex), Base.Dict{WeakRef, Nothing}, Distributed.Future})
-precompile(Tuple{Type{Union{}}, Distributed.RRID})
diff -pruN 1.3.1+dfsg-1/stdlib/Distributed/src/remotecall.jl 1.4.0+dfsg-1/stdlib/Distributed/src/remotecall.jl
--- 1.3.1+dfsg-1/stdlib/Distributed/src/remotecall.jl	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/stdlib/Distributed/src/remotecall.jl	2020-03-21 16:36:32.000000000 +0000
@@ -538,7 +538,7 @@ fetch_ref(rid, args...) = fetch(lookup_r
     fetch(c::RemoteChannel)
 
 Wait for and get a value from a [`RemoteChannel`](@ref). Exceptions raised are the
-same as for a `Future`. Does not remove the item fetched.
+same as for a [`Future`](@ref). Does not remove the item fetched.
 """
 fetch(r::RemoteChannel, args...) = call_on_owner(fetch_ref, r, args...)
 
diff -pruN 1.3.1+dfsg-1/stdlib/Distributed/src/workerpool.jl 1.4.0+dfsg-1/stdlib/Distributed/src/workerpool.jl
--- 1.3.1+dfsg-1/stdlib/Distributed/src/workerpool.jl	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/stdlib/Distributed/src/workerpool.jl	2020-03-21 16:36:32.000000000 +0000
@@ -12,8 +12,8 @@ An `AbstractWorkerPool` should implement
   - [`isready`](@ref) - return false if a `take!` on the pool would block, else true
 
 The default implementations of the above (on a `AbstractWorkerPool`) require fields
-    channel::Channel{Int}
-    workers::Set{Int}
+  - `channel::Channel{Int}`
+  - `workers::Set{Int}`
 where `channel` contains free worker pids and `workers` is the set of all workers associated with this pool.
 """
 abstract type AbstractWorkerPool end
diff -pruN 1.3.1+dfsg-1/stdlib/FileWatching/src/FileWatching.jl 1.4.0+dfsg-1/stdlib/FileWatching/src/FileWatching.jl
--- 1.3.1+dfsg-1/stdlib/FileWatching/src/FileWatching.jl	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/stdlib/FileWatching/src/FileWatching.jl	2020-03-21 16:36:32.000000000 +0000
@@ -719,7 +719,7 @@ function watch_folder(s::String, timeout
     end
     if timeout_s >= 0 && !isready(fm.notify)
         if timeout_s <= 0.010
-            # for very small timeouts, we can just sleep for the timeout-interval
+            # for very small timeouts, we can just sleep for the whole timeout-interval
             (timeout_s == 0) ? yield() : sleep(timeout_s)
             if !isready(fm.notify)
                 return "" => FileEvent() # timeout
diff -pruN 1.3.1+dfsg-1/stdlib/FileWatching/test/runtests.jl 1.4.0+dfsg-1/stdlib/FileWatching/test/runtests.jl
--- 1.3.1+dfsg-1/stdlib/FileWatching/test/runtests.jl	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/stdlib/FileWatching/test/runtests.jl	2020-03-21 16:36:32.000000000 +0000
@@ -30,21 +30,15 @@ end
 function pfd_tst_reads(idx, intvl)
     global ready += 1
     wait(ready_c)
-    t_elapsed = @elapsed begin
-        start_evt2 = Condition()
-        evt2 = @async (notify(start_evt2); poll_fd(pipe_fds[idx][1], intvl; readable=true, writable=false))
-        wait(start_evt2); yield() # make sure the async poll_fd is pumping events
-        evt = poll_fd(pipe_fds[idx][1], intvl; readable=true, writable=false)
-    end
+    start_evt2 = Condition()
+    evt2 = @async (notify(start_evt2); poll_fd(pipe_fds[idx][1], intvl; readable=true, writable=false))
+    wait(start_evt2); yield() # make sure the async poll_fd is pumping events
+    evt = poll_fd(pipe_fds[idx][1], intvl; readable=true, writable=false)
     @test !evt.timedout
     @test evt.readable
     @test !evt.writable
     @test evt === fetch(evt2)
 
-    # println("Expected ", intvl, ", actual ", t_elapsed, ", diff ", t_elapsed - intvl)
-    # Disabled since this assertion fails randomly, notably on build VMs (issue #12824)
-    # @test t_elapsed <= (intvl + 1)
-
     dout = zeros(UInt8, 1)
     @static if Sys.iswindows()
         1 == ccall(:recv, stdcall, Cint, (Ptr{Cvoid}, Ptr{UInt8}, Cint, Cint), pipe_fds[idx][1], dout, 1, 0) || error(Libc.FormatMessage())
@@ -58,23 +52,16 @@ end
 function pfd_tst_timeout(idx, intvl)
     global ready += 1
     wait(ready_c)
-    t_elapsed = @elapsed begin
-        start_evt2 = Condition()
-        evt2 = @async (notify(start_evt2); poll_fd(pipe_fds[idx][1], intvl; readable=true, writable=false))
-        wait(start_evt2); yield() # make sure the async poll_fd is pumping events
-        evt = poll_fd(pipe_fds[idx][1], intvl; readable=true, writable=false)
-        @test evt.timedout
-        @test !evt.readable
-        @test !evt.writable
-        @test evt === fetch(evt2)
-    end
-
-    # Disabled since these assertions fail randomly, notably on build VMs (issue #12824)
-    # @test intvl <= t_elapsed
-    # @test t_elapsed <= (intvl + 1)
+    start_evt2 = Condition()
+    evt2 = @async (notify(start_evt2); poll_fd(pipe_fds[idx][1], intvl; readable=true, writable=false))
+    wait(start_evt2); yield() # make sure the async poll_fd is pumping events
+    evt = poll_fd(pipe_fds[idx][1], intvl; readable=true, writable=false)
+    @test evt.timedout
+    @test !evt.readable
+    @test !evt.writable
+    @test evt === fetch(evt2)
 end
 
-
 # Odd numbers trigger reads, even numbers timeout
 for (i, intvl) in enumerate(intvls)
     @sync begin
@@ -176,24 +163,24 @@ file = joinpath(dir, "afile.txt")
 # initialize a watch_folder instance and create afile.txt
 function test_init_afile()
     @test isempty(FileWatching.watched_folders)
-    @test @elapsed(@test(watch_folder(dir, 0) == ("" => FileWatching.FileEvent()))) <= 2
+    @test(watch_folder(dir, 0) == ("" => FileWatching.FileEvent()))
     @test @elapsed(@test(watch_folder(dir, 0) == ("" => FileWatching.FileEvent()))) <= 0.5
     @test length(FileWatching.watched_folders) == 1
     @test unwatch_folder(dir) === nothing
     @test isempty(FileWatching.watched_folders)
-    @test 0.001 <= @elapsed(@test(watch_folder(dir, 0.004) == ("" => FileWatching.FileEvent()))) <= 2
-    @test 0.001 <= @elapsed(@test(watch_folder(dir, 0.004) == ("" => FileWatching.FileEvent()))) <= 0.5
+    @test 0.002 <= @elapsed(@test(watch_folder(dir, 0.004) == ("" => FileWatching.FileEvent())))
+    @test 0.002 <= @elapsed(@test(watch_folder(dir, 0.004) == ("" => FileWatching.FileEvent()))) <= 0.5
     @test unwatch_folder(dir) === nothing
-    @test 0.9 <= @elapsed(@test(watch_folder(dir, 1) == ("" => FileWatching.FileEvent()))) <= 4
-    @test 0.9 <= @elapsed(@test(watch_folder(dir, 1) == ("" => FileWatching.FileEvent()))) <= 1.5
+    @test 0.99 <= @elapsed(@test(watch_folder(dir, 1) == ("" => FileWatching.FileEvent())))
+    @test 0.99 <= @elapsed(@test(watch_folder(dir, 1) == ("" => FileWatching.FileEvent())))
     # like touch, but lets the operating system update the timestamp
     # for greater precision on some platforms (windows)
     @test close(open(file, "w")) === nothing
-    @test @elapsed(@test(watch_folder(dir) == (F_PATH => FileWatching.FileEvent(FileWatching.UV_RENAME)))) <= 0.5
+    @test(watch_folder(dir) == (F_PATH => FileWatching.FileEvent(FileWatching.UV_RENAME)))
     @test close(open(file, "w")) === nothing
     sleep(3)
     let c
-        @test @elapsed(c = watch_folder(dir, 0)) <= 0.5
+        c = watch_folder(dir, 0)
         if F_GETPATH
             @test c.first == F_PATH
             @test c.second.changed ⊻ c.second.renamed
@@ -205,8 +192,8 @@ function test_init_afile()
         end
     end
     @test unwatch_folder(dir) === nothing
-    @test @elapsed(@test(watch_folder(dir, 0) == ("" => FileWatching.FileEvent()))) <= 0.5
-    @test 0.9 <= @elapsed(@test(watch_folder(dir, 1) == ("" => FileWatching.FileEvent()))) <= 1.5
+    @test(watch_folder(dir, 0) == ("" => FileWatching.FileEvent()))
+    @test 0.9 <= @elapsed(@test(watch_folder(dir, 1) == ("" => FileWatching.FileEvent())))
     @test length(FileWatching.watched_folders) == 1
     nothing
 end
@@ -384,8 +371,8 @@ mv(file * "~", file)
 let changes = []
     while true
         let c
-            timeout = Sys.iswindows() ? 0.1 : 0.0
-            @test @elapsed(c = watch_folder(dir, timeout)) < 0.5
+            Sys.iswindows() && sleep(0.1)
+            @test @elapsed(c = watch_folder(dir, 0.0)) < 0.5
             push!(changes, c)
             (c.second::FileWatching.FileEvent).timedout && break
         end
diff -pruN 1.3.1+dfsg-1/stdlib/.gitignore 1.4.0+dfsg-1/stdlib/.gitignore
--- 1.3.1+dfsg-1/stdlib/.gitignore	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/stdlib/.gitignore	2020-03-21 16:36:32.000000000 +0000
@@ -1,3 +1,5 @@
 /srccache
 /Pkg-*
 /Pkg
+/Statistics-*
+/Statistics
diff -pruN 1.3.1+dfsg-1/stdlib/InteractiveUtils/docs/src/index.md 1.4.0+dfsg-1/stdlib/InteractiveUtils/docs/src/index.md
--- 1.3.1+dfsg-1/stdlib/InteractiveUtils/docs/src/index.md	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/stdlib/InteractiveUtils/docs/src/index.md	2020-03-21 16:36:32.000000000 +0000
@@ -9,6 +9,7 @@ InteractiveUtils.subtypes
 InteractiveUtils.edit(::AbstractString, ::Integer)
 InteractiveUtils.edit(::Any)
 InteractiveUtils.@edit
+InteractiveUtils.define_editor
 InteractiveUtils.less(::AbstractString)
 InteractiveUtils.less(::Any)
 InteractiveUtils.@less
diff -pruN 1.3.1+dfsg-1/stdlib/InteractiveUtils/src/clipboard.jl 1.4.0+dfsg-1/stdlib/InteractiveUtils/src/clipboard.jl
--- 1.3.1+dfsg-1/stdlib/InteractiveUtils/src/clipboard.jl	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/stdlib/InteractiveUtils/src/clipboard.jl	2020-03-21 16:36:32.000000000 +0000
@@ -18,6 +18,7 @@ if Sys.isapple()
         open(pipeline(pbcopy_cmd, stderr=stderr), "w") do io
             print(io, x)
         end
+        nothing
     end
     function clipboard()
         pbpaste_cmd = `pbpaste`
@@ -26,89 +27,113 @@ if Sys.isapple()
         if Sys.which("reattach-to-user-namespace") !== nothing
             pbcopy_cmd = `reattach-to-user-namespace pbpaste`
         end
-        read(pbpaste_cmd, String)
+        return read(pbpaste_cmd, String)
     end
 
 elseif Sys.islinux() || Sys.KERNEL === :FreeBSD
     _clipboardcmd = nothing
-    const _clipboardcmds = Dict(
-        :copy => Dict(
+    const _clipboard_copy = Dict(
             :xsel  => Sys.islinux() ?
-                `xsel --nodetach --input --clipboard` : `xsel -c`,
+                `xsel --nodetach --input --clipboard` :
+                `xsel -c`,
             :xclip => `xclip -silent -in -selection clipboard`,
-        ),
-        :paste => Dict(
+        )
+    const _clipboard_paste = Dict(
             :xsel  => Sys.islinux() ?
-                `xsel --nodetach --output --clipboard` : `xsel -p`,
+                `xsel --nodetach --output --clipboard` :
+                `xsel -p`,
             :xclip => `xclip -quiet -out -selection clipboard`,
         )
-    )
     function clipboardcmd()
         global _clipboardcmd
         _clipboardcmd !== nothing && return _clipboardcmd
         for cmd in (:xclip, :xsel)
             success(pipeline(`which $cmd`, devnull)) && return _clipboardcmd = cmd
         end
-        pkgs = @static if Sys.islinux()
-            "xsel or xclip"
-        elseif Sys.KERNEL === :FreeBSD
+        pkgs = @static if Sys.KERNEL === :FreeBSD
             "x11/xsel or x11/xclip"
+        else
+            "xsel or xclip"
         end
         error("no clipboard command found, please install $pkgs")
     end
     function clipboard(x)
         c = clipboardcmd()
-        cmd = get(_clipboardcmds[:copy], c, nothing)
-        if cmd === nothing
-            error("unexpected clipboard command: $c")
-        end
+        cmd = _clipboard_copy[c]
         open(pipeline(cmd, stderr=stderr), "w") do io
             print(io, x)
         end
+        nothing
     end
     function clipboard()
         c = clipboardcmd()
-        cmd = get(_clipboardcmds[:paste], c, nothing)
-        if cmd === nothing
-            error("unexpected clipboard command: $c")
-        end
-        read(pipeline(cmd, stderr=stderr), String)
+        cmd = _clipboardcmds_paste[c]
+        return read(pipeline(cmd, stderr=stderr), String)
     end
 
 elseif Sys.iswindows()
-    # TODO: these functions leak memory and memory locks if they throw an error
     function clipboard(x::AbstractString)
         if Base.containsnul(x)
             throw(ArgumentError("Windows clipboard strings cannot contain NUL character"))
         end
-        Base.windowserror(:OpenClipboard, 0==ccall((:OpenClipboard, "user32"), stdcall, Cint, (Ptr{Cvoid},), C_NULL))
-        Base.windowserror(:EmptyClipboard, 0==ccall((:EmptyClipboard, "user32"), stdcall, Cint, ()))
         x_u16 = Base.cwstring(x)
+        pdata = Ptr{UInt16}(C_NULL)
+        function cleanup(cause)
+            errno = cause == :success ? UInt32(0) : Libc.GetLastError()
+            if cause !== :OpenClipboard
+                if cause !== :success && pdata != C_NULL
+                    ccall((:GlobalFree, "kernel32"), stdcall, Cint, (Ptr{UInt16},), pdata)
+                end
+                ccall((:CloseClipboard, "user32"), stdcall, Cint, ()) == 0 && Base.windowserror(:CloseClipboard) # this should never fail
+            end
+            cause == :success || Base.windowserror(cause, errno)
+            nothing
+        end
+        ccall((:OpenClipboard, "user32"), stdcall, Cint, (Ptr{Cvoid},), C_NULL) == 0 && return Base.windowserror(:OpenClipboard)
+        ccall((:EmptyClipboard, "user32"), stdcall, Cint, ()) == 0 && return cleanup(:EmptyClipboard)
         # copy data to locked, allocated space
-        p = ccall((:GlobalAlloc, "kernel32"), stdcall, Ptr{UInt16}, (UInt16, Int32), 2, sizeof(x_u16))
-        Base.windowserror(:GlobalAlloc, p==C_NULL)
-        plock = ccall((:GlobalLock, "kernel32"), stdcall, Ptr{UInt16}, (Ptr{UInt16},), p)
-        Base.windowserror(:GlobalLock, plock==C_NULL)
-        ccall(:memcpy, Ptr{UInt16}, (Ptr{UInt16},Ptr{UInt16},Int), plock, x_u16, sizeof(x_u16))
-        Base.windowserror(:GlobalUnlock, 0==ccall((:GlobalUnlock, "kernel32"), stdcall, Cint, (Ptr{Cvoid},), plock))
-        pdata = ccall((:SetClipboardData, "user32"), stdcall, Ptr{UInt16}, (UInt32, Ptr{UInt16}), 13, p)
-        Base.windowserror(:SetClipboardData, pdata!=p)
-        ccall((:CloseClipboard, "user32"), stdcall, Cvoid, ())
+        pdata = ccall((:GlobalAlloc, "kernel32"), stdcall, Ptr{UInt16}, (Cuint, Csize_t), 2 #=GMEM_MOVEABLE=#, sizeof(x_u16))
+        pdata == C_NULL && return cleanup(:GlobalAlloc)
+        plock = ccall((:GlobalLock, "kernel32"), stdcall, Ptr{UInt16}, (Ptr{UInt16},), pdata)
+        plock == C_NULL && return cleanup(:GlobalLock)
+        ccall(:memcpy, Ptr{UInt16}, (Ptr{UInt16}, Ptr{UInt16}, Csize_t), plock, x_u16, sizeof(x_u16))
+        unlock = ccall((:GlobalUnlock, "kernel32"), stdcall, Cint, (Ptr{UInt16},), pdata)
+        (unlock == 0 && Libc.GetLastError() == 0) || return cleanup(:GlobalUnlock) # this should never fail
+        pset = ccall((:SetClipboardData, "user32"), stdcall, Ptr{UInt16}, (Cuint, Ptr{UInt16}), 13, pdata)
+        pdata != pset && return cleanup(:SetClipboardData)
+        cleanup(:success)
     end
     clipboard(x) = clipboard(sprint(print, x)::String)
     function clipboard()
-        Base.windowserror(:OpenClipboard, 0==ccall((:OpenClipboard, "user32"), stdcall, Cint, (Ptr{Cvoid},), C_NULL))
-        pdata = ccall((:GetClipboardData, "user32"), stdcall, Ptr{UInt16}, (UInt32,), 13)
-        Base.windowserror(:GetClipboardData, pdata==C_NULL)
-        Base.windowserror(:CloseClipboard, 0==ccall((:CloseClipboard, "user32"), stdcall, Cint, ()))
+        function cleanup(cause)
+            errno = cause == :success ? UInt32(0) : Libc.GetLastError()
+            if cause !== :OpenClipboard
+                ccall((:CloseClipboard, "user32"), stdcall, Cint, ()) == 0 && Base.windowserror(:CloseClipboard) # this should never fail
+            end
+            if cause !== :success && (cause !== :GetClipboardData || errno != 0)
+                Base.windowserror(cause, errno)
+            end
+            ""
+        end
+        ccall((:OpenClipboard, "user32"), stdcall, Cint, (Ptr{Cvoid},), C_NULL) == 0 && return Base.windowserror(:OpenClipboard)
+        ccall(:SetLastError, stdcall, Cvoid, (UInt32,), 0) # allow distinguishing if the clipboard simply didn't have text
+        pdata = ccall((:GetClipboardData, "user32"), stdcall, Ptr{UInt16}, (Cuint,), 13)
+        pdata == C_NULL && return cleanup(:GetClipboardData)
         plock = ccall((:GlobalLock, "kernel32"), stdcall, Ptr{UInt16}, (Ptr{UInt16},), pdata)
-        Base.windowserror(:GlobalLock, plock==C_NULL)
-        # find NUL terminator (0x0000 16-bit code unit)
-        len = 0
-        while unsafe_load(plock, len+1) != 0; len += 1; end
-        # get Vector{UInt16}, transcode data to UTF-8, make a String of it
-        s = transcode(String, unsafe_wrap(Array, plock, len))
-        Base.windowserror(:GlobalUnlock, 0==ccall((:GlobalUnlock, "kernel32"), stdcall, Cint, (Ptr{UInt16},), plock))
+        plock == C_NULL && return cleanup(:GlobalLock)
+        s = try
+            # find NUL terminator (0x0000 16-bit code unit)
+            len = 0
+            while unsafe_load(plock, len + 1) != 0
+                len += 1
+            end
+            # get Vector{UInt16}, transcode data to UTF-8, make a String of it
+            transcode(String, unsafe_wrap(Array, plock, len))
+        finally
+           unlock = ccall((:GlobalUnlock, "kernel32"), stdcall, Cint, (Ptr{UInt16},), pdata)
+           (unlock != 0 || Libc.GetLastError() == 0) || return cleanup(:GlobalUnlock) # this should never fail
+           cleanup(:success)
+        end
         return s
     end
 
diff -pruN 1.3.1+dfsg-1/stdlib/InteractiveUtils/src/editless.jl 1.4.0+dfsg-1/stdlib/InteractiveUtils/src/editless.jl
--- 1.3.1+dfsg-1/stdlib/InteractiveUtils/src/editless.jl	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/stdlib/InteractiveUtils/src/editless.jl	2020-03-21 16:36:32.000000000 +0000
@@ -2,28 +2,180 @@
 
 # editing and paging files
 
-import Base.shell_split
-using Base: find_source_file
+using Base: shell_split, shell_escape, find_source_file
+
+"""
+    EDITOR_CALLBACKS :: Vector{Function}
+
+A vector of editor callback functions, which take as arguments `cmd`, `path` and
+`line` and which is then expected to either open an editor and return `true` to
+indicate that it has handled the request, or return `false` to decline the
+editing request.
+"""
+const EDITOR_CALLBACKS = Function[]
+
+"""
+    define_editor(fn, pattern; wait=false)
+
+Define a new editor matching `pattern` that can be used to open a file (possibly
+at a given line number) using `fn`.
+
+The `fn` argument is a function that determines how to open a file with the
+given editor. It should take three arguments, as follows:
+
+* `cmd` - a base command object for the editor
+* `path` - the path to the source file to open
+* `line` - the line number to open the editor at
+
+Editors which cannot open to a specific line with a command may ignore the
+`line` argument. The `fn` callback must return either an appropriate `Cmd`
+object to open a file or `nothing` to indicate that they cannot edit this file.
+Use `nothing` to indicate that this editor is not appropriate for the current
+environment and another editor should be attempted. It is possible to add more
+general editing hooks that need not spawn external commands by pushing a
+callback directly to the vector `EDITOR_CALLBACKS`.
+
+The `pattern` argument is a string, regular expression, or an array of strings
+and regular expressions. For the `fn` to be called, one of the patterns must
+match the value of `EDITOR`, `VISUAL` or `JULIA_EDITOR`. For strings, the string
+must equal the [`basename`](@ref) of the first word of the editor command, with
+its extension, if any, removed. E.g. "vi" doesn't match "vim -g" but matches
+"/usr/bin/vi -m"; it also matches `vi.exe`. If `pattern` is a regex it is
+matched against all of the editor command as a shell-escaped string. An array
+pattern matches if any of its items match. If multiple editors match, the one
+added most recently is used.
+
+By default julia does not wait for the editor to close, running it in the
+background. However, if the editor is terminal based, you will probably want to
+set `wait=true` and julia will wait for the editor to close before resuming.
+
+If one of the editor environment variables is set, but no editor entry matches it,
+the default editor entry is invoked:
+
+    (cmd, path, line) -> `\$cmd \$path`
+
+Note that many editors are already defined. All of the following commands should
+already work:
+
+- emacs
+- vim
+- nvim
+- nano
+- textmate
+- mate
+- kate
+- subl
+- atom
+- notepad++
+- Visual Studio Code
+- open
+- pycharm
+
+# Example:
+
+The following defines the usage of terminal-based `emacs`:
+
+    define_editor(
+        r"\\bemacs\\b.*\\s(-nw|--no-window-system)\\b", wait=true) do cmd, path, line
+        `\$cmd +\$line \$path`
+    end
+
+!!! compat "Julia 1.4"
+    `define_editor` was introduced in Julia 1.4.
+"""
+function define_editor(fn::Function, pattern; wait::Bool=false)
+    callback = function (cmd::Cmd, path::AbstractString, line::Integer)
+        editor_matches(pattern, cmd) || return false
+        editor = fn(cmd, path, line)
+        if editor isa Cmd
+            if wait
+                run(editor) # blocks while editor runs
+            else
+                run(pipeline(editor, stderr=stderr), wait=false)
+            end
+            return true
+        elseif editor isa Nothing
+            return false
+        end
+        @warn "invalid editor value returned" pattern=pattern editor=editor
+        return false
+    end
+    pushfirst!(EDITOR_CALLBACKS, callback)
+end
+
+editor_matches(p::Regex, cmd::Cmd) = occursin(p, shell_escape(cmd))
+editor_matches(p::String, cmd::Cmd) = p == splitext(basename(first(cmd)))[1]
+editor_matches(ps::AbstractArray, cmd::Cmd) = any(editor_matches(p, cmd) for p in ps)
+
+function define_default_editors()
+    # fallback: just call the editor with the path as argument
+    define_editor(r".*") do cmd, path, line
+        `$cmd $path`
+    end
+    define_editor([
+        "vim", "vi", "nvim", "mvim", "nano",
+        r"\bemacs\b.*\s(-nw|--no-window-system)\b",
+        r"\bemacsclient\b.\s*-(-?nw|t|-?tty)\b"], wait=true) do cmd, path, line
+        `$cmd +$line $path`
+    end
+    define_editor([r"\bemacs", "gedit", r"\bgvim"]) do cmd, path, line
+        `$cmd +$line $path`
+    end
+    define_editor(["textmate", "mate", "kate"]) do cmd, path, line
+        `$cmd $path -l $line`
+    end
+    define_editor([r"\bsubl", r"\batom", "pycharm"]) do cmd, path, line
+        `$cmd $path:$line`
+    end
+    define_editor("code") do cmd, path, line
+        `$cmd -g $path:$line`
+    end
+    define_editor(r"\bnotepad++") do cmd, path, line
+        `$cmd $path -n$line`
+    end
+    if Sys.iswindows()
+        define_editor(r"\bCODE\.EXE\b"i) do cmd, path, line
+            `$cmd -g $path:$line`
+        end
+        callback = function (cmd::Cmd, path::AbstractString, line::Integer)
+            cmd == `open` || return false
+            # don't emit this ccall on other platforms
+            @static if Sys.iswindows()
+                result = ccall((:ShellExecuteW, "shell32"), stdcall,
+                               Int, (Ptr{Cvoid}, Cwstring, Cwstring,
+                                     Ptr{Cvoid}, Ptr{Cvoid}, Cint),
+                               C_NULL, "open", path, C_NULL, C_NULL, 10)
+                systemerror(:edit, result ≤ 32)
+            end
+            return true
+        end
+        pushfirst!(EDITOR_CALLBACKS, callback)
+    elseif Sys.isapple()
+        define_editor("open") do cmd, path, line
+            `open -t $path`
+        end
+    end
+end
 
 """
     editor()
 
-Determine the editor to use when running functions like `edit`. Return an `Array` compatible
-for use within backticks. You can change the editor by setting `JULIA_EDITOR`, `VISUAL` or
-`EDITOR` as an environment variable.
+Determine the editor to use when running functions like `edit`. Returns a `Cmd`
+object. Change editor by setting `JULIA_EDITOR`, `VISUAL` or `EDITOR`
+environment variables.
 """
 function editor()
-    if Sys.iswindows() || Sys.isapple()
-        default_editor = "open"
-    elseif isfile("/etc/alternatives/editor")
-        default_editor = realpath("/etc/alternatives/editor")
-    else
-        default_editor = "emacs"
-    end
     # Note: the editor path can include spaces (if escaped) and flags.
-    args = shell_split(get(ENV,"JULIA_EDITOR", get(ENV,"VISUAL", get(ENV,"EDITOR", default_editor))))
-    isempty(args) && error("editor is empty")
-    return args
+    for var in ["JULIA_EDITOR", "VISUAL", "EDITOR"]
+        str = get(ENV, var, nothing)
+        str === nothing && continue
+        isempty(str) && error("invalid editor \$$var: $(repr(str))")
+        return Cmd(shell_split(str))
+    end
+    editor_file = "/etc/alternatives/editor"
+    editor = (Sys.iswindows() || Sys.isapple()) ? "open" :
+        isfile(editor_file) ? realpath(editor_file) : "emacs"
+    return Cmd([editor])
 end
 
 """
@@ -32,56 +184,22 @@ end
 Edit a file or directory optionally providing a line number to edit the file at.
 Return to the `julia` prompt when you quit the editor. The editor can be changed
 by setting `JULIA_EDITOR`, `VISUAL` or `EDITOR` as an environment variable.
+
+See also: (`define_editor`)[@ref]
 """
 function edit(path::AbstractString, line::Integer=0)
-    command = editor()
-    name = basename(first(command))
+    isempty(EDITOR_CALLBACKS) && define_default_editors()
+    path isa String || (path = convert(String, path))
     if endswith(path, ".jl")
-        f = find_source_file(path)
-        f !== nothing && (path = f)
+        p = find_source_file(path)
+        p !== nothing && (path = p)
     end
-    background = true
-    line_unsupported = false
-    if startswith(name, "vim.") || name == "vi" || name == "vim" || name == "nvim" ||
-            name == "mvim" || name == "nano" ||
-            name == "emacs" && any(c -> c in ["-nw", "--no-window-system" ], command) ||
-            name == "emacsclient" && any(c -> c in ["-nw", "-t", "-tty"], command)
-        cmd = line != 0 ? `$command +$line $path` : `$command $path`
-        background = false
-    elseif startswith(name, "emacs") || name == "gedit" || startswith(name, "gvim")
-        cmd = line != 0 ? `$command +$line $path` : `$command $path`
-    elseif name == "textmate" || name == "mate" || name == "kate"
-        cmd = line != 0 ? `$command $path -l $line` : `$command $path`
-    elseif name == "rmate"
-        cmd = line != 0 ? `$command $path -l $line -f` : `$command $path -f`
-    elseif startswith(name, "subl") || startswith(name, "atom")
-        cmd = line != 0 ? `$command $path:$line` : `$command $path`
-    elseif name == "code" || (Sys.iswindows() && (uppercase(name) == "CODE.EXE" || uppercase(name) == "CODE.CMD"))
-        cmd = line != 0 ? `$command -g $path:$line` : `$command -g $path`
-    elseif startswith(name, "notepad++")
-        cmd = line != 0 ? `$command $path -n$line` : `$command $path`
-    elseif Sys.isapple() && name == "open"
-        cmd = `open -t $path`
-        line_unsupported = true
-    else
-        cmd = `$command $path`
-        background = false
-        line_unsupported = true
-    end
-
-    if Sys.iswindows() && name == "open"
-        @static Sys.iswindows() && # don't emit this ccall on other platforms
-            systemerror(:edit, ccall((:ShellExecuteW, "shell32"), stdcall, Int,
-                                     (Ptr{Cvoid}, Cwstring, Cwstring, Ptr{Cvoid}, Ptr{Cvoid}, Cint),
-                                     C_NULL, "open", path, C_NULL, C_NULL, 10) ≤ 32)
-    elseif background
-        run(pipeline(cmd, stderr=stderr), wait=false)
-    else
-        run(cmd)
+    cmd = editor()
+    for callback in EDITOR_CALLBACKS
+        callback(cmd, path, line) && return
     end
-    line != 0 && line_unsupported && println("Unknown editor: no line number information passed.\nThe method is defined at line $line.")
-
-    nothing
+    # shouldn't happen unless someone has removed fallback entry
+    error("no editor found")
 end
 
 """
@@ -95,8 +213,8 @@ method to edit. For modules, open the ma
 !!! compat "Julia 1.1"
     `edit` on modules requires at least Julia 1.1.
 
-The editor can be changed by setting `JULIA_EDITOR`, `VISUAL` or `EDITOR` as an environment
-variable.
+To ensure that the file can be opened at the given line, you may need to call
+`define_editor` first.
 """
 edit(f)                   = edit(functionloc(f)...)
 edit(f, @nospecialize t)  = edit(functionloc(f,t)...)
diff -pruN 1.3.1+dfsg-1/stdlib/InteractiveUtils/test/runtests.jl 1.4.0+dfsg-1/stdlib/InteractiveUtils/test/runtests.jl
--- 1.3.1+dfsg-1/stdlib/InteractiveUtils/test/runtests.jl	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/stdlib/InteractiveUtils/test/runtests.jl	2020-03-21 16:36:32.000000000 +0000
@@ -251,12 +251,25 @@ end
 @which get_A18434()(1, y=2)
 @test counter18434 == 2
 
+@eval function f_invalid(x)
+    Base.@_noinline_meta
+    $(Expr(:loopinfo, 1.0f0)) # some expression that throws an error in codegen
+    x
+end
+
+let _true = Ref(true), g, h
+    @noinline g() = _true[] ? 0 : h()
+    @noinline h() = (g(); f_invalid(_true[]))
+    @test_throws ErrorException @code_native h() # due to a failure to compile f()
+    @test g() == 0
+end
+
 let _true = Ref(true), f, g, h
-    @noinline f() = ccall((:time, "error_library_doesnt_exist\0"), Cvoid, ()) # some expression that throws an error in codegen
+    @noinline f() = ccall((:time, "error_library_doesnt_exist\0"), Cvoid, ()) # should throw error during runtime
     @noinline g() = _true[] ? 0 : h()
     @noinline h() = (g(); f())
-    @test_throws ErrorException @code_native h() # due to a failure to compile f()
     @test g() == 0
+    @test_throws ErrorException h()
 end
 
 module ReflectionTest
@@ -346,7 +359,7 @@ using InteractiveUtils: editor
 # Issue #13032
 withenv("JULIA_EDITOR" => nothing, "VISUAL" => nothing, "EDITOR" => nothing) do
     # Make sure editor doesn't error when no ENV editor is set.
-    @test isa(editor(), Array)
+    @test isa(editor(), Cmd)
 
     # Invalid editor
     ENV["JULIA_EDITOR"] = ""
@@ -357,35 +370,72 @@ withenv("JULIA_EDITOR" => nothing, "VISU
 
     # Editor on the path.
     ENV["JULIA_EDITOR"] = "vim"
-    @test editor() == ["vim"]
+    @test editor() == `vim`
 
     # Absolute path to editor.
     ENV["JULIA_EDITOR"] = "/usr/bin/vim"
-    @test editor() == ["/usr/bin/vim"]
+    @test editor() == `/usr/bin/vim`
 
     # Editor on the path using arguments.
     ENV["JULIA_EDITOR"] = "subl -w"
-    @test editor() == ["subl", "-w"]
+    @test editor() == `subl -w`
 
     # Absolute path to editor with spaces.
     ENV["JULIA_EDITOR"] = "/Applications/Sublime\\ Text.app/Contents/SharedSupport/bin/subl"
-    @test editor() == ["/Applications/Sublime Text.app/Contents/SharedSupport/bin/subl"]
+    @test editor() == `'/Applications/Sublime Text.app/Contents/SharedSupport/bin/subl'`
 
     # Paths with spaces and arguments (#13032).
     ENV["JULIA_EDITOR"] = "/Applications/Sublime\\ Text.app/Contents/SharedSupport/bin/subl -w"
-    @test editor() == ["/Applications/Sublime Text.app/Contents/SharedSupport/bin/subl", "-w"]
+    @test editor() == `'/Applications/Sublime Text.app/Contents/SharedSupport/bin/subl' -w`
 
     ENV["JULIA_EDITOR"] = "'/Applications/Sublime Text.app/Contents/SharedSupport/bin/subl' -w"
-    @test editor() == ["/Applications/Sublime Text.app/Contents/SharedSupport/bin/subl", "-w"]
+    @test editor() == `'/Applications/Sublime Text.app/Contents/SharedSupport/bin/subl' -w`
 
     ENV["JULIA_EDITOR"] = "\"/Applications/Sublime Text.app/Contents/SharedSupport/bin/subl\" -w"
-    @test editor() == ["/Applications/Sublime Text.app/Contents/SharedSupport/bin/subl", "-w"]
+    @test editor() == `'/Applications/Sublime Text.app/Contents/SharedSupport/bin/subl' -w`
 end
 
 # clipboard functionality
+if Sys.isapple()
+    let str = "abc\0def"
+        clipboard(str)
+        @test clipboard() == str
+    end
+end
 if Sys.iswindows() || Sys.isapple()
     for str in ("Hello, world.", "∀ x ∃ y", "")
         clipboard(str)
         @test clipboard() == str
     end
 end
+@static if Sys.iswindows()
+    @test_broken false # CI has trouble with this test
+    ## concurrent access error
+    #hDesktop = ccall((:GetDesktopWindow, "user32"), stdcall, Ptr{Cvoid}, ())
+    #ccall((:OpenClipboard, "user32"), stdcall, Cint, (Ptr{Cvoid},), hDesktop) == 0 && Base.windowserror("OpenClipboard")
+    #try
+    #    @test_throws Base.SystemError("OpenClipboard", 0, Base.WindowsErrorInfo(0x00000005, nothing)) clipboard() # ACCESS_DENIED
+    #finally
+    #    ccall((:CloseClipboard, "user32"), stdcall, Cint, ()) == 0 && Base.windowserror("CloseClipboard")
+    #end
+    # empty clipboard failure
+    ccall((:OpenClipboard, "user32"), stdcall, Cint, (Ptr{Cvoid},), C_NULL) == 0 && Base.windowserror("OpenClipboard")
+    try
+        ccall((:EmptyClipboard, "user32"), stdcall, Cint, ()) == 0 && Base.windowserror("EmptyClipboard")
+    finally
+        ccall((:CloseClipboard, "user32"), stdcall, Cint, ()) == 0 && Base.windowserror("CloseClipboard")
+    end
+    @test clipboard() == ""
+    # nul error (unsupported data)
+    @test_throws ArgumentError("Windows clipboard strings cannot contain NUL character") clipboard("abc\0")
+end
+
+# buildbot path updating
+file, ln = functionloc(versioninfo, Tuple{})
+@test isfile(file)
+
+@testset "Issue #34434" begin
+    io = IOBuffer()
+    code_native(io, eltype, Tuple{Int})
+    @test occursin("eltype", String(take!(io)))
+end
diff -pruN 1.3.1+dfsg-1/stdlib/LibGit2/Project.toml 1.4.0+dfsg-1/stdlib/LibGit2/Project.toml
--- 1.3.1+dfsg-1/stdlib/LibGit2/Project.toml	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/stdlib/LibGit2/Project.toml	2020-03-21 16:36:32.000000000 +0000
@@ -1,6 +1,9 @@
 name = "LibGit2"
 uuid = "76f85450-5226-5b5a-8eaa-529ad045b433"
 
+[deps]
+Printf = "de0858da-6303-5e67-8744-51eddeeeb8d7"
+
 [extras]
 Test = "8dfed614-e22c-5e08-85e1-65c5234f0b40"
 Random = "9a3f8284-a2c9-5f02-9a11-845980a1fd5c"
diff -pruN 1.3.1+dfsg-1/stdlib/LibGit2/src/LibGit2.jl 1.4.0+dfsg-1/stdlib/LibGit2/src/LibGit2.jl
--- 1.3.1+dfsg-1/stdlib/LibGit2/src/LibGit2.jl	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/stdlib/LibGit2/src/LibGit2.jl	2020-03-21 16:36:32.000000000 +0000
@@ -7,7 +7,7 @@ module LibGit2
 
 import Base: ==
 using Base: something, notnothing
-using Base.Printf: @printf
+using Printf: @printf
 
 export with, GitRepo, GitConfig
 
diff -pruN 1.3.1+dfsg-1/stdlib/LibGit2/test/libgit2.jl 1.4.0+dfsg-1/stdlib/LibGit2/test/libgit2.jl
--- 1.3.1+dfsg-1/stdlib/LibGit2/test/libgit2.jl	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/stdlib/LibGit2/test/libgit2.jl	2020-03-21 16:36:32.000000000 +0000
@@ -600,6 +600,7 @@ end
 end
 
 mktempdir() do dir
+    dir = realpath(dir)
     # test parameters
     repo_url = "https://github.com/JuliaLang/Example.jl"
     cache_repo = joinpath(dir, "Example")
diff -pruN 1.3.1+dfsg-1/stdlib/LinearAlgebra/docs/src/index.md 1.4.0+dfsg-1/stdlib/LinearAlgebra/docs/src/index.md
--- 1.3.1+dfsg-1/stdlib/LinearAlgebra/docs/src/index.md	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/stdlib/LinearAlgebra/docs/src/index.md	2020-03-21 16:36:32.000000000 +0000
@@ -284,7 +284,7 @@ compute the factorization of a matrix in
 in linear algebra.
 
 The following table summarizes the types of matrix factorizations that have been implemented in
-Julia. Details of their associated methods can be found in the [Standard Functions](@ref) section
+Julia. Details of their associated methods can be found in the [Standard functions](@ref) section
 of the Linear Algebra documentation.
 
 | Type               | Description                                                                                                    |
@@ -308,7 +308,7 @@ of the Linear Algebra documentation.
 
 
 
-## Standard Functions
+## Standard functions
 
 Linear algebra functions in Julia are largely implemented by calling functions from [LAPACK](http://www.netlib.org/lapack/).
  Sparse factorizations call functions from [SuiteSparse](http://faculty.cse.tamu.edu/davis/suitesparse.html).
@@ -318,6 +318,7 @@ Base.:*(::AbstractMatrix, ::AbstractMatr
 Base.:\(::AbstractMatrix, ::AbstractVecOrMat)
 LinearAlgebra.SingularException
 LinearAlgebra.PosDefException
+LinearAlgebra.ZeroPivotException
 LinearAlgebra.dot
 LinearAlgebra.cross
 LinearAlgebra.factorize
@@ -333,6 +334,7 @@ LinearAlgebra.UnitLowerTriangular
 LinearAlgebra.UnitUpperTriangular
 LinearAlgebra.UpperHessenberg
 LinearAlgebra.UniformScaling
+LinearAlgebra.I
 LinearAlgebra.Factorization
 LinearAlgebra.LU
 LinearAlgebra.lu
@@ -474,7 +476,7 @@ LinearAlgebra.ldiv!
 LinearAlgebra.rdiv!
 ```
 
-## BLAS Functions
+## BLAS functions
 
 In Julia (as in much of scientific computation), dense linear-algebra operations are based on
 the [LAPACK library](http://www.netlib.org/lapack/), which in turn is built on top of basic linear-algebra
@@ -486,33 +488,33 @@ linear algebra routines it is useful to
 that overwrite one of the input arrays have names ending in `'!'`.  Usually, a BLAS function has
 four methods defined, for [`Float64`](@ref), [`Float32`](@ref), `ComplexF64`, and `ComplexF32` arrays.
 
-### [BLAS Character Arguments](@id stdlib-blas-chars)
+### [BLAS character arguments](@id stdlib-blas-chars)
 Many BLAS functions accept arguments that determine whether to transpose an argument (`trans`),
 which triangle of a matrix to reference (`uplo` or `ul`),
 whether the diagonal of a triangular matrix can be assumed to
 be all ones (`dA`) or which side of a matrix multiplication
 the input argument belongs on (`side`). The possibilities are:
 
-#### [Multplication Order](@id stdlib-blas-side)
+#### [Multiplication order](@id stdlib-blas-side)
 | `side` | Meaning                                                             |
 |:-------|:--------------------------------------------------------------------|
 | `'L'`  | The argument goes on the *left* side of a matrix-matrix operation.  |
 | `'R'`  | The argument goes on the *right* side of a matrix-matrix operation. |
 
-#### [Triangle Referencing](@id stdlib-blas-uplo)
+#### [Triangle referencing](@id stdlib-blas-uplo)
 | `uplo`/`ul` | Meaning                                               |
 |:------------|:------------------------------------------------------|
 | `'U'`       | Only the *upper* triangle of the matrix will be used. |
 | `'L'`       | Only the *lower* triangle of the matrix will be used. |
 
-#### [Transposition Operation](@id stdlib-blas-trans)
+#### [Transposition operation](@id stdlib-blas-trans)
 | `trans`/`tX` | Meaning                                                 |
 |:-------------|:--------------------------------------------------------|
 | `'N'`        | The input matrix `X` is not transposed or conjugated.   |
 | `'T'`        | The input matrix `X` will be transposed.                |
 | `'C'`        | The input matrix `X` will be conjugated and transposed. |
 
-#### [Unit Diagonal](@id stdlib-blas-diag)
+#### [Unit diagonal](@id stdlib-blas-diag)
 | `diag`/`dX` | Meaning                                                   |
 |:------------|:----------------------------------------------------------|
 | `'N'`       | The diagonal values of the matrix `X` will be read.       |
@@ -535,9 +537,13 @@ LinearAlgebra.BLAS.ger!
 LinearAlgebra.BLAS.syr!
 LinearAlgebra.BLAS.syrk!
 LinearAlgebra.BLAS.syrk
+LinearAlgebra.BLAS.syr2k!
+LinearAlgebra.BLAS.syr2k
 LinearAlgebra.BLAS.her!
 LinearAlgebra.BLAS.herk!
 LinearAlgebra.BLAS.herk
+LinearAlgebra.BLAS.her2k!
+LinearAlgebra.BLAS.her2k
 LinearAlgebra.BLAS.gbmv!
 LinearAlgebra.BLAS.gbmv
 LinearAlgebra.BLAS.sbmv!
@@ -555,6 +561,12 @@ LinearAlgebra.BLAS.symm(::Any, ::Any, ::
 LinearAlgebra.BLAS.symv!
 LinearAlgebra.BLAS.symv(::Any, ::Any, ::Any, ::Any)
 LinearAlgebra.BLAS.symv(::Any, ::Any, ::Any)
+LinearAlgebra.BLAS.hemm!
+LinearAlgebra.BLAS.hemm(::Any, ::Any, ::Any, ::Any, ::Any)
+LinearAlgebra.BLAS.hemm(::Any, ::Any, ::Any, ::Any)
+LinearAlgebra.BLAS.hemv!
+LinearAlgebra.BLAS.hemv(::Any, ::Any, ::Any, ::Any)
+LinearAlgebra.BLAS.hemv(::Any, ::Any, ::Any)
 LinearAlgebra.BLAS.trmm!
 LinearAlgebra.BLAS.trmm
 LinearAlgebra.BLAS.trsm!
@@ -564,10 +576,9 @@ LinearAlgebra.BLAS.trmv
 LinearAlgebra.BLAS.trsv!
 LinearAlgebra.BLAS.trsv
 LinearAlgebra.BLAS.set_num_threads
-LinearAlgebra.I
 ```
 
-## LAPACK Functions
+## LAPACK functions
 
 `LinearAlgebra.LAPACK` provides wrappers for some of the LAPACK functions for linear algebra.
  Those functions that overwrite one of the input arrays have names ending in `'!'`.
diff -pruN 1.3.1+dfsg-1/stdlib/LinearAlgebra/src/adjtrans.jl 1.4.0+dfsg-1/stdlib/LinearAlgebra/src/adjtrans.jl
--- 1.3.1+dfsg-1/stdlib/LinearAlgebra/src/adjtrans.jl	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/stdlib/LinearAlgebra/src/adjtrans.jl	2020-03-21 16:36:32.000000000 +0000
@@ -281,3 +281,7 @@ pinv(v::TransposeAbsVec, tol::Real = 0)
 /(u::TransposeAbsVec, A::AbstractMatrix) = transpose(transpose(A) \ u.parent)
 /(u::AdjointAbsVec, A::Transpose{<:Any,<:AbstractMatrix}) = adjoint(conj(A.parent) \ u.parent) # technically should be adjoint(copy(adjoint(copy(A))) \ u.parent)
 /(u::TransposeAbsVec, A::Adjoint{<:Any,<:AbstractMatrix}) = transpose(conj(A.parent) \ u.parent) # technically should be transpose(copy(transpose(copy(A))) \ u.parent)
+
+## complex conjugate
+conj(A::Transpose) = adjoint(A.parent)
+conj(A::Adjoint) = transpose(A.parent)
diff -pruN 1.3.1+dfsg-1/stdlib/LinearAlgebra/src/bidiag.jl 1.4.0+dfsg-1/stdlib/LinearAlgebra/src/bidiag.jl
--- 1.3.1+dfsg-1/stdlib/LinearAlgebra/src/bidiag.jl	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/stdlib/LinearAlgebra/src/bidiag.jl	2020-03-21 16:36:32.000000000 +0000
@@ -586,7 +586,12 @@ function *(A::AbstractTriangular, B::Uni
     A_mul_B_td!(zeros(TS, size(A)...), A, B)
 end
 
-function *(A::UpperTriangular, B::Bidiagonal)
+const UpperOrUnitUpperTriangular = Union{UpperTriangular, UnitUpperTriangular}
+const LowerOrUnitLowerTriangular = Union{LowerTriangular, UnitLowerTriangular}
+const AdjOrTransUpperOrUnitUpperTriangular = Union{Adjoint{<:Any, <:UpperOrUnitUpperTriangular}, Transpose{<:Any, <:UpperOrUnitUpperTriangular}}
+const AdjOrTransLowerOrUnitLowerTriangular = Union{Adjoint{<:Any, <:LowerOrUnitLowerTriangular}, Transpose{<:Any, <:LowerOrUnitLowerTriangular}}
+
+function *(A::UpperOrUnitUpperTriangular, B::Bidiagonal)
     TS = promote_op(matprod, eltype(A), eltype(B))
     if B.uplo == 'U'
         A_mul_B_td!(UpperTriangular(zeros(TS, size(A)...)), A, B)
@@ -595,7 +600,16 @@ function *(A::UpperTriangular, B::Bidiag
     end
 end
 
-function *(A::LowerTriangular, B::Bidiagonal)
+function *(A::AdjOrTransUpperOrUnitUpperTriangular, B::Bidiagonal)
+    TS = promote_op(matprod, eltype(A), eltype(B))
+    if B.uplo == 'L'
+        A_mul_B_td!(LowerTriangular(zeros(TS, size(A)...)), A, B)
+    else
+        A_mul_B_td!(zeros(TS, size(A)...), A, B)
+    end
+end
+
+function *(A::LowerOrUnitLowerTriangular, B::Bidiagonal)
     TS = promote_op(matprod, eltype(A), eltype(B))
     if B.uplo == 'L'
         A_mul_B_td!(LowerTriangular(zeros(TS, size(A)...)), A, B)
@@ -604,12 +618,21 @@ function *(A::LowerTriangular, B::Bidiag
     end
 end
 
+function *(A::AdjOrTransLowerOrUnitLowerTriangular, B::Bidiagonal)
+    TS = promote_op(matprod, eltype(A), eltype(B))
+    if B.uplo == 'U'
+        A_mul_B_td!(UpperTriangular(zeros(TS, size(A)...)), A, B)
+    else
+        A_mul_B_td!(zeros(TS, size(A)...), A, B)
+    end
+end
+
 function *(A::Union{SymTridiagonal, Tridiagonal}, B::AbstractTriangular)
     TS = promote_op(matprod, eltype(A), eltype(B))
     A_mul_B_td!(zeros(TS, size(A)...), A, B)
 end
 
-function *(A::Bidiagonal, B::UpperTriangular)
+function *(A::Bidiagonal, B::UpperOrUnitUpperTriangular)
     TS = promote_op(matprod, eltype(A), eltype(B))
     if A.uplo == 'U'
         A_mul_B_td!(UpperTriangular(zeros(TS, size(A)...)), A, B)
@@ -618,7 +641,16 @@ function *(A::Bidiagonal, B::UpperTriang
     end
 end
 
-function *(A::Bidiagonal, B::LowerTriangular)
+function *(A::Bidiagonal, B::AdjOrTransUpperOrUnitUpperTriangular)
+    TS = promote_op(matprod, eltype(A), eltype(B))
+    if A.uplo == 'L'
+        A_mul_B_td!(LowerTriangular(zeros(TS, size(A)...)), A, B)
+    else
+        A_mul_B_td!(zeros(TS, size(A)...), A, B)
+    end
+end
+
+function *(A::Bidiagonal, B::LowerOrUnitLowerTriangular)
     TS = promote_op(matprod, eltype(A), eltype(B))
     if A.uplo == 'L'
         A_mul_B_td!(LowerTriangular(zeros(TS, size(A)...)), A, B)
@@ -627,6 +659,15 @@ function *(A::Bidiagonal, B::LowerTriang
     end
 end
 
+function *(A::Bidiagonal, B::AdjOrTransLowerOrUnitLowerTriangular)
+    TS = promote_op(matprod, eltype(A), eltype(B))
+    if A.uplo == 'U'
+        A_mul_B_td!(UpperTriangular(zeros(TS, size(A)...)), A, B)
+    else
+        A_mul_B_td!(zeros(TS, size(A)...), A, B)
+    end
+end
+
 function *(A::BiTri, B::Diagonal)
     TS = promote_op(matprod, eltype(A), eltype(B))
     A_mul_B_td!(similar(A, TS), A, B)
@@ -647,6 +688,36 @@ function *(A::SymTridiagonal, B::Diagona
     A_mul_B_td!(Tridiagonal(zeros(TS, size(A, 1)-1), zeros(TS, size(A, 1)), zeros(TS, size(A, 1)-1)), A, B)
 end
 
+function dot(x::AbstractVector, B::Bidiagonal, y::AbstractVector)
+    require_one_based_indexing(x, y)
+    nx, ny = length(x), length(y)
+    (nx == size(B, 1) == ny) || throw(DimensionMismatch())
+    if iszero(nx)
+        return dot(zero(eltype(x)), zero(eltype(B)), zero(eltype(y)))
+    end
+    ev, dv = B.ev, B.dv
+    if B.uplo == 'U'
+        x₀ = x[1]
+        r = dot(x[1], dv[1], y[1])
+        @inbounds for j in 2:nx-1
+            x₋, x₀ = x₀, x[j]
+            r += dot(adjoint(ev[j-1])*x₋ + adjoint(dv[j])*x₀, y[j])
+        end
+        r += dot(adjoint(ev[nx-1])*x₀ + adjoint(dv[nx])*x[nx], y[nx])
+        return r
+    else # B.uplo == 'L'
+        x₀ = x[1]
+        x₊ = x[2]
+        r = dot(adjoint(dv[1])*x₀ + adjoint(ev[1])*x₊, y[1])
+        @inbounds for j in 2:nx-1
+            x₀, x₊ = x₊, x[j+1]
+            r += dot(adjoint(dv[j])*x₀ + adjoint(ev[j])*x₊, y[j])
+        end
+        r += dot(x₊, dv[nx], y[nx])
+        return r
+    end
+end
+
 #Linear solvers
 ldiv!(A::Union{Bidiagonal, AbstractTriangular}, b::AbstractVector) = naivesub!(A, b)
 ldiv!(A::Transpose{<:Any,<:Bidiagonal}, b::AbstractVector) = ldiv!(copy(A), b)
diff -pruN 1.3.1+dfsg-1/stdlib/LinearAlgebra/src/blas.jl 1.4.0+dfsg-1/stdlib/LinearAlgebra/src/blas.jl
--- 1.3.1+dfsg-1/stdlib/LinearAlgebra/src/blas.jl	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/stdlib/LinearAlgebra/src/blas.jl	2020-03-21 16:36:32.000000000 +0000
@@ -422,7 +422,7 @@ asum(x::Union{AbstractVector,DenseArray}
 """
     axpy!(a, X, Y)
 
-Overwrite `Y` with `a*X + Y`, where `a` is a scalar. Return `Y`.
+Overwrite `Y` with `X*a + Y`, where `a` is a scalar. Return `Y`.
 
 # Examples
 ```jldoctest
@@ -760,6 +760,15 @@ Only the [`ul`](@ref stdlib-blas-uplo) t
 symv(ul, A, x)
 
 ### hemv
+"""
+    hemv!(ul, alpha, A, x, beta, y)
+
+Update the vector `y` as `alpha*A*x + beta*y`. `A` is assumed to be Hermitian.
+Only the [`ul`](@ref stdlib-blas-uplo) triangle of `A` is used.
+`alpha` and `beta` are scalars. Return the updated `y`.
+"""
+function hemv! end
+
 for (fname, elty) in ((:zhemv_,:ComplexF64),
                       (:chemv_,:ComplexF32))
     @eval begin
@@ -797,6 +806,23 @@ for (fname, elty) in ((:zhemv_,:ComplexF
     end
 end
 
+"""
+    hemv(ul, alpha, A, x)
+
+Return `alpha*A*x`. `A` is assumed to be Hermitian.
+Only the [`ul`](@ref stdlib-blas-uplo) triangle of `A` is used.
+`alpha` is a scalar.
+"""
+hemv(ul, alpha, A, x)
+
+"""
+    hemv(ul, A, x)
+
+Return `A*x`. `A` is assumed to be Hermitian.
+Only the [`ul`](@ref stdlib-blas-uplo) triangle of `A` is used.
+"""
+hemv(ul, A, x)
+
 ### sbmv, (SB) symmetric banded matrix-vector multiplication
 for (fname, elty) in ((:dsbmv_,:Float64),
                       (:ssbmv_,:Float32))
@@ -1290,13 +1316,39 @@ for (mfname, elty) in ((:zhemm_,:Complex
     end
 end
 
+"""
+    hemm(side, ul, alpha, A, B)
+
+Return `alpha*A*B` or `alpha*B*A` according to [`side`](@ref stdlib-blas-side).
+`A` is assumed to be Hermitian. Only the [`ul`](@ref stdlib-blas-uplo) triangle
+of `A` is used.
+"""
+hemm(side, ul, alpha, A, B)
+
+"""
+    hemm(side, ul, A, B)
+
+Return `A*B` or `B*A` according to [`side`](@ref stdlib-blas-side). `A` is assumed
+to be Hermitian. Only the [`ul`](@ref stdlib-blas-uplo) triangle of `A` is used.
+"""
+hemm(side, ul, A, B)
+
+"""
+    hemm!(side, ul, alpha, A, B, beta, C)
+
+Update `C` as `alpha*A*B + beta*C` or `alpha*B*A + beta*C` according to
+[`side`](@ref stdlib-blas-side). `A` is assumed to be Hermitian. Only the
+[`ul`](@ref stdlib-blas-uplo) triangle of `A` is used. Return the updated `C`.
+"""
+hemm!
+
 ## syrk
 
 """
     syrk!(uplo, trans, alpha, A, beta, C)
 
-Rank-k update of the symmetric matrix `C` as `alpha*A*transpose(A) + beta*C` or `alpha*transpose(A)*A +
-beta*C` according to [`trans`](@ref stdlib-blas-trans).
+Rank-k update of the symmetric matrix `C` as `alpha*A*transpose(A) + beta*C` or
+`alpha*transpose(A)*A + beta*C` according to [`trans`](@ref stdlib-blas-trans).
 Only the [`uplo`](@ref stdlib-blas-uplo) triangle of `C` is used. Returns `C`.
 """
 function syrk! end
@@ -1354,19 +1406,17 @@ syrk(uplo::AbstractChar, trans::Abstract
 """
     herk!(uplo, trans, alpha, A, beta, C)
 
-Methods for complex arrays only. Rank-k update of the Hermitian matrix `C` as `alpha*A*A' +
-beta*C` or `alpha*A'*A + beta*C` according to [`trans`](@ref stdlib-blas-trans).
-Only the [`uplo`](@ref stdlib-blas-uplo) triangle of `C` is updated.
-Returns `C`.
+Methods for complex arrays only. Rank-k update of the Hermitian matrix `C` as
+`alpha*A*A' + beta*C` or `alpha*A'*A + beta*C` according to [`trans`](@ref stdlib-blas-trans).
+Only the [`uplo`](@ref stdlib-blas-uplo) triangle of `C` is updated. Returns `C`.
 """
 function herk! end
 
 """
     herk(uplo, trans, alpha, A)
 
-Methods for complex arrays only.
-Returns the [`uplo`](@ref stdlib-blas-uplo) triangle of `alpha*A*A'` or `alpha*A'*A`,
-according to [`trans`](@ref stdlib-blas-trans).
+Methods for complex arrays only. Returns the [`uplo`](@ref stdlib-blas-uplo)
+triangle of `alpha*A*A'` or `alpha*A'*A`, according to [`trans`](@ref stdlib-blas-trans).
 """
 function herk end
 
@@ -1447,11 +1497,37 @@ for (fname, elty) in ((:dsyr2k_,:Float64
         end
     end
 end
+
+"""
+    syr2k!(uplo, trans, alpha, A, B, beta, C)
+
+Rank-2k update of the symmetric matrix `C` as
+`alpha*A*transpose(B) + alpha*B*transpose(A) + beta*C` or
+`alpha*transpose(A)*B + alpha*transpose(B)*A + beta*C`
+according to [`trans`](@ref stdlib-blas-trans).
+Only the [`uplo`](@ref stdlib-blas-uplo) triangle of `C` is used. Returns `C`.
+"""
+function syr2k! end
+
+"""
+    syr2k(uplo, trans, alpha, A, B)
+
+Returns the [`uplo`](@ref stdlib-blas-uplo) triangle of
+`alpha*A*transpose(B) + alpha*B*transpose(A)` or
+`alpha*transpose(A)*B + alpha*transpose(B)*A`,
+according to [`trans`](@ref stdlib-blas-trans).
+"""
 function syr2k(uplo::AbstractChar, trans::AbstractChar, alpha::Number, A::AbstractVecOrMat, B::AbstractVecOrMat)
     T = eltype(A)
     n = size(A, trans == 'N' ? 1 : 2)
     syr2k!(uplo, trans, convert(T,alpha), A, B, zero(T), similar(A, T, (n, n)))
 end
+"""
+    syr2k(uplo, trans, A, B)
+
+Returns the [`uplo`](@ref stdlib-blas-uplo) triangle of `A*transpose(B) + B*transpose(A)`
+or `transpose(A)*B + transpose(B)*A`, according to [`trans`](@ref stdlib-blas-trans).
+"""
 syr2k(uplo::AbstractChar, trans::AbstractChar, A::AbstractVecOrMat, B::AbstractVecOrMat) = syr2k(uplo, trans, one(eltype(A)), A, B)
 
 for (fname, elty1, elty2) in ((:zher2k_,:ComplexF64,:Float64), (:cher2k_,:ComplexF32,:Float32))
@@ -1494,6 +1570,32 @@ for (fname, elty1, elty2) in ((:zher2k_,
    end
 end
 
+"""
+    her2k!(uplo, trans, alpha, A, B, beta, C)
+
+Rank-2k update of the Hermitian matrix `C` as
+`alpha*A*B' + alpha*B*A' + beta*C` or `alpha*A'*B + alpha*B'*A + beta*C`
+according to [`trans`](@ref stdlib-blas-trans). The scalar `beta` has to be real.
+Only the [`uplo`](@ref stdlib-blas-uplo) triangle of `C` is used. Returns `C`.
+"""
+function her2k! end
+
+"""
+    her2k(uplo, trans, alpha, A, B)
+
+Returns the [`uplo`](@ref stdlib-blas-uplo) triangle of `alpha*A*B' + alpha*B*A'`
+or `alpha*A'*B + alpha*B'*A`, according to [`trans`](@ref stdlib-blas-trans).
+"""
+her2k(uplo, trans, alpha, A, B)
+
+"""
+    her2k(uplo, trans, A, B)
+
+Returns the [`uplo`](@ref stdlib-blas-uplo) triangle of `A*B' + B*A'`
+or `A'*B + B'*A`, according to [`trans`](@ref stdlib-blas-trans).
+"""
+her2k(uplo, trans, A, B)
+
 ## (TR) Triangular matrix and vector multiplication and solution
 
 """
diff -pruN 1.3.1+dfsg-1/stdlib/LinearAlgebra/src/cholesky.jl 1.4.0+dfsg-1/stdlib/LinearAlgebra/src/cholesky.jl
--- 1.3.1+dfsg-1/stdlib/LinearAlgebra/src/cholesky.jl	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/stdlib/LinearAlgebra/src/cholesky.jl	2020-03-21 16:36:32.000000000 +0000
@@ -396,7 +396,8 @@ Array(C::Cholesky) = Matrix(C)
 
 function AbstractMatrix(F::CholeskyPivoted)
     ip = invperm(F.p)
-    (F.L * F.U)[ip,ip]
+    U = F.U[1:F.rank,ip]
+    U'U
 end
 AbstractArray(F::CholeskyPivoted) = AbstractMatrix(F)
 Matrix(F::CholeskyPivoted) = Array(AbstractArray(F))
@@ -411,7 +412,6 @@ size(C::Union{Cholesky, CholeskyPivoted}
 function getproperty(C::Cholesky, d::Symbol)
     Cfactors = getfield(C, :factors)
     Cuplo    = getfield(C, :uplo)
-    info     = getfield(C, :info)
     if d === :U
         return UpperTriangular(Cuplo === char_uplo(d) ? Cfactors : copy(Cfactors'))
     elseif d === :L
diff -pruN 1.3.1+dfsg-1/stdlib/LinearAlgebra/src/dense.jl 1.4.0+dfsg-1/stdlib/LinearAlgebra/src/dense.jl
--- 1.3.1+dfsg-1/stdlib/LinearAlgebra/src/dense.jl	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/stdlib/LinearAlgebra/src/dense.jl	2020-03-21 16:36:32.000000000 +0000
@@ -1359,12 +1359,12 @@ end
 ## Basis for null space
 
 """
-    nullspace(M; atol::Real=0, rtol::Rea=atol>0 ? 0 : n*ϵ)
+    nullspace(M; atol::Real=0, rtol::Real=atol>0 ? 0 : n*ϵ)
     nullspace(M, rtol::Real) = nullspace(M; rtol=rtol) # to be deprecated in Julia 2.0
 
 Computes a basis for the nullspace of `M` by including the singular
-vectors of A whose singular have magnitude are greater than `max(atol, rtol*σ₁)`,
-where `σ₁` is `M`'s largest singularvalue.
+vectors of `M` whose singular values have magnitudes greater than `max(atol, rtol*σ₁)`,
+where `σ₁` is `M`'s largest singular value.
 
 By default, the relative tolerance `rtol` is `n*ϵ`, where `n`
 is the size of the smallest dimension of `M`, and `ϵ` is the [`eps`](@ref) of
@@ -1418,15 +1418,22 @@ function cond(A::AbstractMatrix, p::Real
     if p == 2
         v = svdvals(A)
         maxv = maximum(v)
-        return maxv == 0.0 ? oftype(real(A[1,1]),Inf) : maxv / minimum(v)
+        return iszero(maxv) ? oftype(real(maxv), Inf) : maxv / minimum(v)
     elseif p == 1 || p == Inf
         checksquare(A)
-        return _cond1Inf(A, p)
+        try
+            Ainv = inv(A)
+            return opnorm(A, p)*opnorm(Ainv, p)
+        catch e
+            if isa(e, LAPACKException) || isa(e, SingularException)
+                return convert(float(real(eltype(A))), Inf)
+            else
+                rethrow()
+            end
+        end
     end
     throw(ArgumentError("p-norm must be 1, 2 or Inf, got $p"))
 end
-_cond1Inf(A::StridedMatrix{<:BlasFloat}, p::Real) = _cond1Inf(lu(A), p, opnorm(A, p))
-_cond1Inf(A::AbstractMatrix, p::Real)             = opnorm(A, p)*opnorm(inv(A), p)
 
 ## Lyapunov and Sylvester equation
 
diff -pruN 1.3.1+dfsg-1/stdlib/LinearAlgebra/src/diagonal.jl 1.4.0+dfsg-1/stdlib/LinearAlgebra/src/diagonal.jl
--- 1.3.1+dfsg-1/stdlib/LinearAlgebra/src/diagonal.jl	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/stdlib/LinearAlgebra/src/diagonal.jl	2020-03-21 16:36:32.000000000 +0000
@@ -162,8 +162,10 @@ end
 (*)(Da::Diagonal, Db::Diagonal) = Diagonal(Da.diag .* Db.diag)
 (*)(D::Diagonal, V::AbstractVector) = D.diag .* V
 
-(*)(A::AbstractTriangular, D::Diagonal) = rmul!(copy(A), D)
-(*)(D::Diagonal, B::AbstractTriangular) = lmul!(D, copy(B))
+(*)(A::AbstractTriangular, D::Diagonal) =
+    rmul!(copyto!(similar(A, promote_op(*, eltype(A), eltype(D.diag))), A), D)
+(*)(D::Diagonal, B::AbstractTriangular) =
+    lmul!(D, copyto!(similar(B, promote_op(*, eltype(B), eltype(D.diag))), B))
 
 (*)(A::AbstractMatrix, D::Diagonal) =
     rmul!(copyto!(similar(A, promote_op(*, eltype(A), eltype(D.diag)), size(A)), A), D)
@@ -214,7 +216,8 @@ function lmul!(D::Diagonal, B::UnitUpper
 end
 
 *(D::Adjoint{<:Any,<:Diagonal}, B::Diagonal) = Diagonal(adjoint.(D.parent.diag) .* B.diag)
-*(A::Adjoint{<:Any,<:AbstractTriangular}, D::Diagonal) = rmul!(copy(A), D)
+*(A::Adjoint{<:Any,<:AbstractTriangular}, D::Diagonal) =
+    rmul!(copyto!(similar(A, promote_op(*, eltype(A), eltype(D.diag))), A), D)
 function *(adjA::Adjoint{<:Any,<:AbstractMatrix}, D::Diagonal)
     A = adjA.parent
     Ac = similar(A, promote_op(*, eltype(A), eltype(D.diag)), (size(A, 2), size(A, 1)))
@@ -223,7 +226,8 @@ function *(adjA::Adjoint{<:Any,<:Abstrac
 end
 
 *(D::Transpose{<:Any,<:Diagonal}, B::Diagonal) = Diagonal(transpose.(D.parent.diag) .* B.diag)
-*(A::Transpose{<:Any,<:AbstractTriangular}, D::Diagonal) = rmul!(copy(A), D)
+*(A::Transpose{<:Any,<:AbstractTriangular}, D::Diagonal) =
+    rmul!(copyto!(similar(A, promote_op(*, eltype(A), eltype(D.diag))), A), D)
 function *(transA::Transpose{<:Any,<:AbstractMatrix}, D::Diagonal)
     A = transA.parent
     At = similar(A, promote_op(*, eltype(A), eltype(D.diag)), (size(A, 2), size(A, 1)))
@@ -232,7 +236,8 @@ function *(transA::Transpose{<:Any,<:Abs
 end
 
 *(D::Diagonal, B::Adjoint{<:Any,<:Diagonal}) = Diagonal(D.diag .* adjoint.(B.parent.diag))
-*(D::Diagonal, B::Adjoint{<:Any,<:AbstractTriangular}) = lmul!(D, collect(B))
+*(D::Diagonal, B::Adjoint{<:Any,<:AbstractTriangular}) =
+    lmul!(D, copyto!(similar(B, promote_op(*, eltype(B), eltype(D.diag))), B))
 *(D::Diagonal, adjQ::Adjoint{<:Any,<:Union{QRCompactWYQ,QRPackedQ}}) = (Q = adjQ.parent; rmul!(Array(D), adjoint(Q)))
 function *(D::Diagonal, adjA::Adjoint{<:Any,<:AbstractMatrix})
     A = adjA.parent
@@ -242,7 +247,8 @@ function *(D::Diagonal, adjA::Adjoint{<:
 end
 
 *(D::Diagonal, B::Transpose{<:Any,<:Diagonal}) = Diagonal(D.diag .* transpose.(B.parent.diag))
-*(D::Diagonal, B::Transpose{<:Any,<:AbstractTriangular}) = lmul!(D, copy(B))
+*(D::Diagonal, B::Transpose{<:Any,<:AbstractTriangular}) =
+    lmul!(D, copyto!(similar(B, promote_op(*, eltype(B), eltype(D.diag))), B))
 function *(D::Diagonal, transA::Transpose{<:Any,<:AbstractMatrix})
     A = transA.parent
     At = similar(A, promote_op(*, eltype(A), eltype(D.diag)), (size(A, 2), size(A, 1)))
@@ -421,7 +427,7 @@ function ldiv!(D::Diagonal{T}, V::Abstra
     end
     V
 end
-
+ldiv!(x::AbstractArray, A::Diagonal, b::AbstractArray) = (x .= A.diag .\ b)
 
 ldiv!(adjD::Adjoint{<:Any,<:Diagonal{T}}, B::AbstractVecOrMat{T}) where {T} =
     (D = adjD.parent; ldiv!(conj(D), B))
@@ -637,19 +643,20 @@ end
 
 # disambiguation methods: * of Diagonal and Adj/Trans AbsVec
 *(x::Adjoint{<:Any,<:AbstractVector}, D::Diagonal) = Adjoint(map((t,s) -> t'*s, D.diag, parent(x)))
+*(x::Transpose{<:Any,<:AbstractVector}, D::Diagonal) = Transpose(map((t,s) -> transpose(t)*s, D.diag, parent(x)))
 *(x::Adjoint{<:Any,<:AbstractVector}, D::Diagonal, y::AbstractVector) =
     mapreduce(t -> t[1]*t[2]*t[3], +, zip(x, D.diag, y))
-*(x::Transpose{<:Any,<:AbstractVector}, D::Diagonal) = Transpose(map((t,s) -> transpose(t)*s, D.diag, parent(x)))
 *(x::Transpose{<:Any,<:AbstractVector}, D::Diagonal, y::AbstractVector) =
     mapreduce(t -> t[1]*t[2]*t[3], +, zip(x, D.diag, y))
+function dot(x::AbstractVector, D::Diagonal, y::AbstractVector)
+    mapreduce(t -> dot(t[1], t[2], t[3]), +, zip(x, D.diag, y))
+end
 
 function cholesky!(A::Diagonal, ::Val{false} = Val(false); check::Bool = true)
     info = 0
-    diagonal = A.diag
-    for i in axes(diagonal, 1)
-        d = diagonal[i]
-        if !(d == 0 || (isreal(d) && d < 0))
-            diagonal[i] = √d
+    for (i, di) in enumerate(A.diag)
+        if isreal(di) && real(di) > 0
+            A.diag[i] = √di
         elseif check
             throw(PosDefException(i))
         else
@@ -663,4 +670,18 @@ end
 cholesky(A::Diagonal, ::Val{false} = Val(false); check::Bool = true) =
     cholesky!(cholcopy(A), Val(false); check = check)
 
+function getproperty(C::Cholesky{<:Any,<:Diagonal}, d::Symbol)
+    Cfactors = getfield(C, :factors)
+    if d in (:U, :L, :UL)
+        return Cfactors
+    else
+        return getfield(C, d)
+    end
+end
+
 Base._sum(A::Diagonal, ::Colon) = sum(A.diag)
+
+function logabsdet(A::Diagonal)
+     mapreduce(x -> (log(abs(x)), sign(x)), ((d1, s1), (d2, s2)) -> (d1 + d2, s1 * s2),
+               A.diag)
+end
diff -pruN 1.3.1+dfsg-1/stdlib/LinearAlgebra/src/eigen.jl 1.4.0+dfsg-1/stdlib/LinearAlgebra/src/eigen.jl
--- 1.3.1+dfsg-1/stdlib/LinearAlgebra/src/eigen.jl	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/stdlib/LinearAlgebra/src/eigen.jl	2020-03-21 16:36:32.000000000 +0000
@@ -18,12 +18,12 @@ Iterating the decomposition produces the
 ```jldoctest
 julia> F = eigen([1.0 0.0 0.0; 0.0 3.0 0.0; 0.0 0.0 18.0])
 Eigen{Float64,Float64,Array{Float64,2},Array{Float64,1}}
-eigenvalues:
+values:
 3-element Array{Float64,1}:
   1.0
   3.0
  18.0
-eigenvectors:
+vectors:
 3×3 Array{Float64,2}:
  1.0  0.0  0.0
  0.0  1.0  0.0
@@ -84,11 +84,11 @@ julia> B = [0 1; 1 0]
 
 julia> F = eigen(A, B)
 GeneralizedEigen{Complex{Float64},Complex{Float64},Array{Complex{Float64},2},Array{Complex{Float64},1}}
-eigenvalues:
+values:
 2-element Array{Complex{Float64},1}:
  0.0 - 1.0im
  0.0 + 1.0im
-eigenvectors:
+vectors:
 2×2 Array{Complex{Float64},2}:
   0.0+1.0im   0.0-1.0im
  -1.0+0.0im  -1.0-0.0im
@@ -202,12 +202,12 @@ accept a `sortby` keyword.
 ```jldoctest
 julia> F = eigen([1.0 0.0 0.0; 0.0 3.0 0.0; 0.0 0.0 18.0])
 Eigen{Float64,Float64,Array{Float64,2},Array{Float64,1}}
-eigenvalues:
+values:
 3-element Array{Float64,1}:
   1.0
   3.0
  18.0
-eigenvectors:
+vectors:
 3×3 Array{Float64,2}:
  1.0  0.0  0.0
  0.0  1.0  0.0
@@ -608,9 +608,9 @@ eigvecs(A::AbstractMatrix, B::AbstractMa
 
 function show(io::IO, mime::MIME{Symbol("text/plain")}, F::Union{Eigen,GeneralizedEigen})
     summary(io, F); println(io)
-    println(io, "eigenvalues:")
+    println(io, "values:")
     show(io, mime, F.values)
-    println(io, "\neigenvectors:")
+    println(io, "\nvectors:")
     show(io, mime, F.vectors)
 end
 
diff -pruN 1.3.1+dfsg-1/stdlib/LinearAlgebra/src/exceptions.jl 1.4.0+dfsg-1/stdlib/LinearAlgebra/src/exceptions.jl
--- 1.3.1+dfsg-1/stdlib/LinearAlgebra/src/exceptions.jl	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/stdlib/LinearAlgebra/src/exceptions.jl	2020-03-21 16:36:32.000000000 +0000
@@ -3,7 +3,8 @@
 export LAPACKException,
        SingularException,
        PosDefException,
-       RankDeficientException
+       RankDeficientException,
+       ZeroPivotException
 
 struct LAPACKException <: Exception
     info::BlasInt
@@ -43,3 +44,19 @@ end
 struct RankDeficientException <: Exception
     info::BlasInt
 end
+
+"""
+    ZeroPivotException <: Exception
+
+Exception thrown when a matrix factorization/solve encounters a zero in a pivot (diagonal)
+position and cannot proceed.  This may *not* mean that the matrix is singular:
+it may be fruitful to switch to a diffent factorization such as pivoted LU
+that can re-order variables to eliminate spurious zero pivots.
+The `info` field indicates the location of (one of) the zero pivot(s).
+"""
+struct ZeroPivotException <: Exception
+    info::BlasInt
+end
+function Base.showerror(io::IO, ex::ZeroPivotException)
+    print(io, "ZeroPivotException: factorization encountered one or more zero pivots. Consider switching to a pivoted LU factorization.")
+end
\ No newline at end of file
diff -pruN 1.3.1+dfsg-1/stdlib/LinearAlgebra/src/factorization.jl 1.4.0+dfsg-1/stdlib/LinearAlgebra/src/factorization.jl
--- 1.3.1+dfsg-1/stdlib/LinearAlgebra/src/factorization.jl	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/stdlib/LinearAlgebra/src/factorization.jl	2020-03-21 16:36:32.000000000 +0000
@@ -16,7 +16,9 @@ size(F::Adjoint{<:Any,<:Factorization})
 size(F::Transpose{<:Any,<:Factorization}) = reverse(size(parent(F)))
 
 checkpositivedefinite(info) = info == 0 || throw(PosDefException(info))
-checknonsingular(info) = info == 0 || throw(SingularException(info))
+checknonsingular(info, pivoted::Val{true}) = info == 0 || throw(SingularException(info))
+checknonsingular(info, pivoted::Val{false}) = info == 0 || throw(ZeroPivotException(info))
+checknonsingular(info) = checknonsingular(info, Val{true}())
 
 """
     issuccess(F::Factorization)
@@ -138,15 +140,6 @@ function ldiv!(Y::AbstractVecOrMat, A::F
     end
 end
 
-function ldiv!(Y::AbstractVecOrMat, adjA::Adjoint{<:Any,<:Factorization}, B::AbstractVecOrMat)
-    checksquare(adjA)
-    return ldiv!(adjA, copyto!(Y, B))
-end
-function ldiv!(Y::AbstractVecOrMat, transA::Transpose{<:Any,<:Factorization}, B::AbstractVecOrMat)
-    checksquare(transA)
-    return ldiv!(transA, copyto!(Y, B))
-end
-
 # fallback methods for transposed solves
 \(F::Transpose{<:Any,<:Factorization{<:Real}}, B::AbstractVecOrMat) = adjoint(F.parent) \ B
 \(F::Transpose{<:Any,<:Factorization}, B::AbstractVecOrMat) = conj.(adjoint(F.parent) \ conj.(B))
diff -pruN 1.3.1+dfsg-1/stdlib/LinearAlgebra/src/generic.jl 1.4.0+dfsg-1/stdlib/LinearAlgebra/src/generic.jl
--- 1.3.1+dfsg-1/stdlib/LinearAlgebra/src/generic.jl	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/stdlib/LinearAlgebra/src/generic.jl	2020-03-21 16:36:32.000000000 +0000
@@ -25,10 +25,23 @@ struct MulAddMul{ais1, bis0, TA, TB}
     beta::TB
 end
 
-MulAddMul(alpha::TA, beta::TB) where {TA, TB} =
-    MulAddMul{isone(alpha), iszero(beta), TA, TB}(alpha, beta)
+@inline function MulAddMul(alpha::TA, beta::TB) where {TA,TB}
+    if isone(alpha)
+        if iszero(beta)
+            return MulAddMul{true,true,TA,TB}(alpha, beta)
+        else
+            return MulAddMul{true,false,TA,TB}(alpha, beta)
+        end
+    else
+        if iszero(beta)
+            return MulAddMul{false,true,TA,TB}(alpha, beta)
+        else
+            return MulAddMul{false,false,TA,TB}(alpha, beta)
+        end
+    end
+end
 
-MulAddMul() = MulAddMul(true, false)
+MulAddMul() = MulAddMul{true,true,Bool,Bool}(true, false)
 
 @inline (::MulAddMul{true})(x) = x
 @inline (p::MulAddMul{false})(x) = x * p.alpha
@@ -75,6 +88,9 @@ julia> C
 end
 
 @inline function _rmul_or_fill!(C::AbstractArray, beta::Number)
+    if isempty(C)
+        return C
+    end
     if iszero(beta)
         fill!(C, zero(eltype(C)))
     else
@@ -238,6 +254,11 @@ function ldiv!(s::Number, X::AbstractArr
     end
     X
 end
+ldiv!(Y::AbstractArray, s::Number, X::AbstractArray) = Y .= s .\ X
+
+# Generic fallback. This assumes that B and Y have the same sizes.
+ldiv!(Y::AbstractArray, A::AbstractMatrix, B::AbstractArray) = ldiv!(A, copyto!(Y, B))
+
 
 """
     cross(x, y)
@@ -877,6 +898,51 @@ function dot(x::AbstractArray, y::Abstra
     s
 end
 
+"""
+    dot(x, A, y)
+
+Compute the generalized dot product `dot(x, A*y)` between two vectors `x` and `y`,
+without storing the intermediate result of `A*y`. As for the two-argument
+[`dot(_,_)`](@ref), this acts recursively. Moreover, for complex vectors, the
+first vector is conjugated.
+
+!!! compat "Julia 1.4"
+    Three-argument `dot` requires at least Julia 1.4.
+
+# Examples
+```jldoctest
+julia> dot([1; 1], [1 2; 3 4], [2; 3])
+26
+
+julia> dot(1:5, reshape(1:25, 5, 5), 2:6)
+4850
+
+julia> ⋅(1:5, reshape(1:25, 5, 5), 2:6) == dot(1:5, reshape(1:25, 5, 5), 2:6)
+true
+```
+"""
+dot(x, A, y) = dot(x, A*y) # generic fallback for cases that are not covered by specialized methods
+
+function dot(x::AbstractVector, A::AbstractMatrix, y::AbstractVector)
+    (axes(x)..., axes(y)...) == axes(A) || throw(DimensionMismatch())
+    T = typeof(dot(first(x), first(A), first(y)))
+    s = zero(T)
+    i₁ = first(eachindex(x))
+    x₁ = first(x)
+    @inbounds for j in eachindex(y)
+        yj = y[j]
+        if !iszero(yj)
+            temp = zero(adjoint(A[i₁,j]) * x₁)
+            @simd for i in eachindex(x)
+                temp += adjoint(A[i,j]) * x[i]
+            end
+            s += dot(temp, yj)
+        end
+    end
+    return s
+end
+dot(x::AbstractVector, adjA::Adjoint, y::AbstractVector) = adjoint(dot(y, adjA.parent, x))
+dot(x::AbstractVector, transA::Transpose{<:Real}, y::AbstractVector) = adjoint(dot(y, transA.parent, x))
 
 ###########################################################################################
 
diff -pruN 1.3.1+dfsg-1/stdlib/LinearAlgebra/src/hessenberg.jl 1.4.0+dfsg-1/stdlib/LinearAlgebra/src/hessenberg.jl
--- 1.3.1+dfsg-1/stdlib/LinearAlgebra/src/hessenberg.jl	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/stdlib/LinearAlgebra/src/hessenberg.jl	2020-03-21 16:36:32.000000000 +0000
@@ -284,6 +284,37 @@ function logabsdet(F::UpperHessenberg; s
     return (logdeterminant, P)
 end
 
+function dot(x::AbstractVector, H::UpperHessenberg, y::AbstractVector)
+    require_one_based_indexing(x, y)
+    m = size(H, 1)
+    (length(x) == m == length(y)) || throw(DimensionMismatch())
+    if iszero(m)
+        return dot(zero(eltype(x)), zero(eltype(H)), zero(eltype(y)))
+    end
+    x₁ = x[1]
+    r = dot(x₁, H[1,1], y[1])
+    r += dot(x[2], H[2,1], y[1])
+    @inbounds for j in 2:m-1
+        yj = y[j]
+        if !iszero(yj)
+            temp = adjoint(H[1,j]) * x₁
+            @simd for i in 2:j+1
+                temp += adjoint(H[i,j]) * x[i]
+            end
+            r += dot(temp, yj)
+        end
+    end
+    ym = y[m]
+    if !iszero(ym)
+        temp = adjoint(H[1,m]) * x₁
+        @simd for i in 2:m
+            temp += adjoint(H[i,m]) * x[i]
+        end
+        r += dot(temp, ym)
+    end
+    return r
+end
+
 ######################################################################################
 # Hessenberg factorizations Q(H+μI)Q' of A+μI:
 
@@ -362,7 +393,18 @@ julia> A = [4. 9. 7.; 4. 4. 1.; 4. 3. 2.
  4.0  4.0  1.0
  4.0  3.0  2.0
 
-julia> F = hessenberg(A);
+julia> F = hessenberg(A)
+Hessenberg{Float64,UpperHessenberg{Float64,Array{Float64,2}},Array{Float64,2},Array{Float64,1},Bool}
+Q factor:
+3×3 LinearAlgebra.HessenbergQ{Float64,Array{Float64,2},Array{Float64,1},false}:
+ 1.0   0.0        0.0
+ 0.0  -0.707107  -0.707107
+ 0.0  -0.707107   0.707107
+H factor:
+3×3 UpperHessenberg{Float64,Array{Float64,2}}:
+  4.0      -11.3137       -1.41421
+ -5.65685    5.0           2.0
+   ⋅        -8.88178e-16   1.0
 
 julia> F.Q * F.H * F.Q'
 3×3 Array{Float64,2}:
diff -pruN 1.3.1+dfsg-1/stdlib/LinearAlgebra/src/ldlt.jl 1.4.0+dfsg-1/stdlib/LinearAlgebra/src/ldlt.jl
--- 1.3.1+dfsg-1/stdlib/LinearAlgebra/src/ldlt.jl	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/stdlib/LinearAlgebra/src/ldlt.jl	2020-03-21 16:36:32.000000000 +0000
@@ -9,6 +9,15 @@ matrix and `d` is a vector. The main use
 is to solve the linear system of equations `Sx = b` with `F\\b`. This is the
 return type of [`ldlt`](@ref), the corresponding matrix factorization function.
 
+The individual components of the factorization `F::LDLt` can be accessed via `getproperty`:
+
+| Component | Description                                 |
+|:---------:|:--------------------------------------------|
+| `F.L`     | `L` (unit lower triangular) part of `LDLt`  |
+| `F.D`     | `D` (diagonal) part of `LDLt`               |
+| `F.Lt`    | `Lt` (unit upper triangular) part of `LDLt` |
+| `F.d`     | diagonal values of `D` as a `Vector`        |
+
 # Examples
 ```jldoctest
 julia> S = SymTridiagonal([3., 4., 5.], [1., 2.])
@@ -18,7 +27,17 @@ julia> S = SymTridiagonal([3., 4., 5.],
   ⋅   2.0  5.0
 
 julia> F = ldlt(S)
-LDLt{Float64,SymTridiagonal{Float64,Array{Float64,1}}}([3.0 0.3333333333333333 0.0; 0.3333333333333333 3.6666666666666665 0.5454545454545455; 0.0 0.5454545454545455 3.909090909090909])
+LDLt{Float64,SymTridiagonal{Float64,Array{Float64,1}}}
+L factor:
+3×3 UnitLowerTriangular{Float64,SymTridiagonal{Float64,Array{Float64,1}}}:
+ 1.0        ⋅         ⋅
+ 0.333333  1.0        ⋅
+ 0.0       0.545455  1.0
+D factor:
+3×3 Diagonal{Float64,Array{Float64,1}}:
+ 3.0   ⋅        ⋅
+  ⋅   3.66667   ⋅
+  ⋅    ⋅       3.90909
 ```
 """
 struct LDLt{T,S<:AbstractMatrix{T}} <: Factorization{T}
@@ -43,6 +62,29 @@ LDLt{T}(F::LDLt) where {T} = LDLt(conver
 Factorization{T}(F::LDLt{T}) where {T} = F
 Factorization{T}(F::LDLt) where {T} = LDLt{T}(F)
 
+function getproperty(F::LDLt, d::Symbol)
+    Fdata = getfield(F, :data)
+    if d === :d
+        return Fdata.dv
+    elseif d === :D
+        return Diagonal(Fdata.dv)
+    elseif d === :L
+        return UnitLowerTriangular(Fdata)
+    elseif d === :Lt
+        return UnitUpperTriangular(Fdata)
+    else
+        return getfield(F, d)
+    end
+end
+
+function show(io::IO, mime::MIME{Symbol("text/plain")}, F::LDLt)
+    summary(io, F); println(io)
+    println(io, "L factor:")
+    show(io, mime, F.L)
+    println(io, "\nD factor:")
+    show(io, mime, F.D)
+end
+
 # SymTridiagonal
 """
     ldlt!(S::SymTridiagonal) -> LDLt
diff -pruN 1.3.1+dfsg-1/stdlib/LinearAlgebra/src/lq.jl 1.4.0+dfsg-1/stdlib/LinearAlgebra/src/lq.jl
--- 1.3.1+dfsg-1/stdlib/LinearAlgebra/src/lq.jl	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/stdlib/LinearAlgebra/src/lq.jl	2020-03-21 16:36:32.000000000 +0000
@@ -35,6 +35,7 @@ julia> l, q = S; # destructuring via ite
 
 julia> l == S.L &&  q == S.Q
 true
+```
 """
 struct LQ{T,S<:AbstractMatrix{T}} <: Factorization{T}
     factors::S
@@ -333,3 +334,8 @@ function ldiv!(A::LQ{T}, B::StridedVecOr
     lmul!(adjoint(A.Q), ldiv!(LowerTriangular(A.L),B))
     return B
 end
+
+
+# In LQ factorization, `Q` is expressed as the product of the adjoint of the
+# reflectors.  Thus, `det` has to be conjugated.
+det(Q::LQPackedQ) = conj(_det_tau(Q.τ))
diff -pruN 1.3.1+dfsg-1/stdlib/LinearAlgebra/src/lu.jl 1.4.0+dfsg-1/stdlib/LinearAlgebra/src/lu.jl
--- 1.3.1+dfsg-1/stdlib/LinearAlgebra/src/lu.jl	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/stdlib/LinearAlgebra/src/lu.jl	2020-03-21 16:36:32.000000000 +0000
@@ -175,7 +175,7 @@ function generic_lufact!(A::StridedMatri
             end
         end
     end
-    check && checknonsingular(info)
+    check && checknonsingular(info, Val{Pivot}())
     return LU{T,typeof(A)}(A, ipiv, convert(BlasInt, info))
 end
 
@@ -478,13 +478,6 @@ inv!(A::LU{T,<:StridedMatrix}) where {T}
     ldiv!(A.factors, copy(A), Matrix{T}(I, size(A, 1), size(A, 1)))
 inv(A::LU{<:BlasFloat,<:StridedMatrix}) = inv!(copy(A))
 
-function _cond1Inf(A::LU{<:BlasFloat,<:StridedMatrix}, p::Number, normA::Real)
-    if p != 1 && p != Inf
-        throw(ArgumentError("p must be either 1 or Inf"))
-    end
-    return inv(LAPACK.gecon!(p == 1 ? '1' : 'I', A.factors, normA))
-end
-
 # Tridiagonal
 
 # See dgttrf.f
@@ -552,7 +545,7 @@ function lu!(A::Tridiagonal{T,V}, pivot:
         end
     end
     B = Tridiagonal{T,V}(dl, d, du, du2)
-    check && checknonsingular(info)
+    check && checknonsingular(info, pivot)
     return LU{T,Tridiagonal{T,V}}(B, ipiv, convert(BlasInt, info))
 end
 
diff -pruN 1.3.1+dfsg-1/stdlib/LinearAlgebra/src/matmul.jl 1.4.0+dfsg-1/stdlib/LinearAlgebra/src/matmul.jl
--- 1.3.1+dfsg-1/stdlib/LinearAlgebra/src/matmul.jl	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/stdlib/LinearAlgebra/src/matmul.jl	2020-03-21 16:36:32.000000000 +0000
@@ -63,15 +63,15 @@ end
 (*)(a::AbstractVector, B::AbstractMatrix) = reshape(a,length(a),1)*B
 
 @inline mul!(y::StridedVector{T}, A::StridedVecOrMat{T}, x::StridedVector{T},
-             alpha::Union{T, Bool}, beta::Union{T, Bool}) where {T<:BlasFloat} =
+             alpha::Number, beta::Number) where {T<:BlasFloat} =
     gemv!(y, 'N', A, x, alpha, beta)
 # Complex matrix times real vector. Reinterpret the matrix as a real matrix and do real matvec compuation.
 for elty in (Float32,Float64)
     @eval begin
         @inline function mul!(y::StridedVector{Complex{$elty}}, A::StridedVecOrMat{Complex{$elty}}, x::StridedVector{$elty},
-                              alpha::Union{$elty, Bool}, beta::Union{$elty, Bool})
-            Afl = reinterpret($elty,A)
-            yfl = reinterpret($elty,y)
+                              alpha::Real, beta::Real)
+            Afl = reinterpret($elty, A)
+            yfl = reinterpret($elty, y)
             mul!(yfl, Afl, x, alpha, beta)
             return y
         end
@@ -92,7 +92,7 @@ function *(transA::Transpose{<:Any,<:Abs
     mul!(similar(x,TS,size(A,2)), transpose(A), x)
 end
 @inline function mul!(y::StridedVector{T}, transA::Transpose{<:Any,<:StridedVecOrMat{T}}, x::StridedVector{T},
-                      alpha::Union{T, Bool}, beta::Union{T, Bool}) where {T<:BlasFloat}
+                      alpha::Number, beta::Number) where {T<:BlasFloat}
     A = transA.parent
     return gemv!(y, 'T', A, x, alpha, beta)
 end
@@ -114,12 +114,12 @@ function *(adjA::Adjoint{<:Any,<:Abstrac
 end
 
 @inline function mul!(y::StridedVector{T}, adjA::Adjoint{<:Any,<:StridedVecOrMat{T}}, x::StridedVector{T},
-                      alpha::Union{T, Bool}, beta::Union{T, Bool}) where {T<:BlasReal}
+                      alpha::Number, beta::Number) where {T<:BlasReal}
     A = adjA.parent
     return mul!(y, transpose(A), x, alpha, beta)
 end
 @inline function mul!(y::StridedVector{T}, adjA::Adjoint{<:Any,<:StridedVecOrMat{T}}, x::StridedVector{T},
-                      alpha::Union{T, Bool}, beta::Union{T, Bool}) where {T<:BlasComplex}
+                      alpha::Number, beta::Number) where {T<:BlasComplex}
     A = adjA.parent
     return gemv!(y, 'C', A, x, alpha, beta)
 end
@@ -152,17 +152,22 @@ function (*)(A::AbstractMatrix, B::Abstr
     TS = promote_op(matprod, eltype(A), eltype(B))
     mul!(similar(B, TS, (size(A,1), size(B,2))), A, B)
 end
+# optimization for dispatching to BLAS, e.g. *(::Matrix{Float32}, ::Matrix{Float64})
+# but avoiding the case *(::Matrix{<:BlasComplex}, ::Matrix{<:BlasReal})
+# which is better handled by reinterpreting rather than promotion
+function (*)(A::StridedMatrix{<:BlasReal}, B::StridedMatrix{<:BlasFloat})
+    TS = promote_type(eltype(A), eltype(B))
+    mul!(similar(B, TS, (size(A,1), size(B,2))), convert(AbstractArray{TS}, A), convert(AbstractArray{TS}, B))
+end
+function (*)(A::StridedMatrix{<:BlasComplex}, B::StridedMatrix{<:BlasComplex})
+    TS = promote_type(eltype(A), eltype(B))
+    mul!(similar(B, TS, (size(A,1), size(B,2))), convert(AbstractArray{TS}, A), convert(AbstractArray{TS}, B))
+end
 
 @inline function mul!(C::StridedMatrix{T}, A::StridedVecOrMat{T}, B::StridedVecOrMat{T},
-                      α::Number, β::Number) where {T<:BlasFloat}
-    alpha, beta = promote(α, β, zero(T))
-    if alpha isa T && beta isa T
-        return gemm_wrapper!(C, 'N', 'N', A, B, MulAddMul(alpha, beta))
-    else
-        return generic_matmatmul!(C, 'N', 'N', A, B, MulAddMul(α, β))
-    end
+                      alpha::Number, beta::Number) where {T<:BlasFloat}
+    return gemm_wrapper!(C, 'N', 'N', A, B, MulAddMul(alpha, beta))
 end
-
 # Complex Matrix times real matrix: We use that it is generally faster to reinterpret the
 # first matrix as a real matrix and carry out real matrix matrix multiply
 for elty in (Float32,Float64)
@@ -297,10 +302,10 @@ julia> lmul!(F.Q, B)
 lmul!(A, B)
 
 @inline function mul!(C::StridedMatrix{T}, transA::Transpose{<:Any,<:StridedVecOrMat{T}}, B::StridedVecOrMat{T},
-                 alpha::Union{T, Bool}, beta::Union{T, Bool}) where {T<:BlasFloat}
+                 alpha::Number, beta::Number) where {T<:BlasFloat}
     A = transA.parent
     if A===B
-        return syrk_wrapper!(C, 'T', A, MulAddMul(alpha, beta))
+        return syrk_wrapper!(C, 'T', A, alpha, beta)
     else
         return gemm_wrapper!(C, 'T', 'N', A, B, MulAddMul(alpha, beta))
     end
@@ -312,10 +317,10 @@ end
 end
 
 @inline function mul!(C::StridedMatrix{T}, A::StridedVecOrMat{T}, transB::Transpose{<:Any,<:StridedVecOrMat{T}},
-                 alpha::Union{T, Bool}, beta::Union{T, Bool}) where {T<:BlasFloat}
+                 alpha::Number, beta::Number) where {T<:BlasFloat}
     B = transB.parent
     if A===B
-        return syrk_wrapper!(C, 'N', A, MulAddMul(alpha, beta))
+        return syrk_wrapper!(C, 'N', A, alpha, beta)
     else
         return gemm_wrapper!(C, 'N', 'T', A, B, MulAddMul(alpha, beta))
     end
@@ -324,7 +329,7 @@ end
 for elty in (Float32,Float64)
     @eval begin
         @inline function mul!(C::StridedMatrix{Complex{$elty}}, A::StridedVecOrMat{Complex{$elty}}, transB::Transpose{<:Any,<:StridedVecOrMat{$elty}},
-                         alpha::Union{$elty, Bool}, beta::Union{$elty, Bool})
+                         alpha::Real, beta::Real)
             Afl = reinterpret($elty, A)
             Cfl = reinterpret($elty, C)
             mul!(Cfl, Afl, transB, alpha, beta)
@@ -354,7 +359,7 @@ end
 end
 
 @inline function mul!(C::StridedMatrix{T}, transA::Transpose{<:Any,<:StridedVecOrMat{T}}, transB::Adjoint{<:Any,<:StridedVecOrMat{T}},
-                 alpha::Union{T, Bool}, beta::Union{T, Bool}) where {T<:BlasFloat}
+                 alpha::Number, beta::Number) where {T<:BlasFloat}
     A = transA.parent
     B = transB.parent
     return gemm_wrapper!(C, 'T', 'C', A, B, MulAddMul(alpha, beta))
@@ -367,15 +372,15 @@ end
 end
 
 @inline function mul!(C::StridedMatrix{T}, adjA::Adjoint{<:Any,<:StridedVecOrMat{T}}, B::StridedVecOrMat{T},
-                 alpha::Union{T, Bool}, beta::Union{T, Bool}) where {T<:BlasReal}
+                 alpha::Real, beta::Real) where {T<:BlasReal}
     A = adjA.parent
     return mul!(C, transpose(A), B, alpha, beta)
 end
 @inline function mul!(C::StridedMatrix{T}, adjA::Adjoint{<:Any,<:StridedVecOrMat{T}}, B::StridedVecOrMat{T},
-                 alpha::Union{T, Bool}, beta::Union{T, Bool}) where {T<:BlasComplex}
+                 alpha::Number, beta::Number) where {T<:BlasComplex}
     A = adjA.parent
     if A===B
-        return herk_wrapper!(C, 'C', A, MulAddMul(alpha, beta))
+        return herk_wrapper!(C, 'C', A, alpha, beta)
     else
         return gemm_wrapper!(C, 'C', 'N', A, B, MulAddMul(alpha, beta))
     end
@@ -392,10 +397,10 @@ end
     return mul!(C, A, transpose(B), alpha, beta)
 end
 @inline function mul!(C::StridedMatrix{T}, A::StridedVecOrMat{T}, adjB::Adjoint{<:Any,<:StridedVecOrMat{T}},
-                 alpha::Union{T, Bool}, beta::Union{T, Bool}) where {T<:BlasComplex}
+                 alpha::Number, beta::Number) where {T<:BlasComplex}
     B = adjB.parent
     if A === B
-        return herk_wrapper!(C, 'N', A, MulAddMul(alpha, beta))
+        return herk_wrapper!(C, 'N', A, alpha, beta)
     else
         return gemm_wrapper!(C, 'N', 'C', A, B, MulAddMul(alpha, beta))
     end
@@ -407,7 +412,7 @@ end
 end
 
 @inline function mul!(C::StridedMatrix{T}, adjA::Adjoint{<:Any,<:StridedVecOrMat{T}}, adjB::Adjoint{<:Any,<:StridedVecOrMat{T}},
-                 alpha::Union{T, Bool}, beta::Union{T, Bool}) where {T<:BlasFloat}
+                 alpha::Number, beta::Number) where {T<:BlasFloat}
     A = adjA.parent
     B = adjB.parent
     return gemm_wrapper!(C, 'C', 'C', A, B, MulAddMul(alpha, beta))
@@ -445,7 +450,7 @@ end
 end
 
 function gemv!(y::StridedVector{T}, tA::AbstractChar, A::StridedVecOrMat{T}, x::StridedVector{T},
-               alpha::Union{T, Bool} = true, beta::Union{T, Bool} = false) where T<:BlasFloat
+               α::Number=true, β::Number=false) where {T<:BlasFloat}
     mA, nA = lapack_size(tA, A)
     if nA != length(x)
         throw(DimensionMismatch("second dimension of A, $nA, does not match length of x, $(length(x))"))
@@ -457,16 +462,19 @@ function gemv!(y::StridedVector{T}, tA::
         return y
     end
     if nA == 0
-        return _rmul_or_fill!(y, beta)
+        return _rmul_or_fill!(y, β)
     end
-    if stride(A, 1) == 1 && stride(A, 2) >= size(A, 1)
+
+    alpha, beta = promote(α, β, zero(T))
+    if alpha isa Union{Bool,T} && beta isa Union{Bool,T} && stride(A, 1) == 1 && stride(A, 2) >= size(A, 1)
         return BLAS.gemv!(tA, alpha, A, x, beta, y)
+    else
+        return generic_matvecmul!(y, tA, A, x, MulAddMul(α, β))
     end
-    return generic_matvecmul!(y, tA, A, x, MulAddMul(alpha, beta))
 end
 
 function syrk_wrapper!(C::StridedMatrix{T}, tA::AbstractChar, A::StridedVecOrMat{T},
-                       _add::MulAddMul = MulAddMul()) where T<:BlasFloat
+                       α::Number=true, β::Number=false) where {T<:BlasFloat}
     nC = checksquare(C)
     if tA == 'T'
         (nA, mA) = size(A,1), size(A,2)
@@ -478,24 +486,33 @@ function syrk_wrapper!(C::StridedMatrix{
     if nC != mA
         throw(DimensionMismatch("output matrix has size: $(nC), but should have size $(mA)"))
     end
-    if mA == 0 || nA == 0 || iszero(_add.alpha)
-        return _rmul_or_fill!(C, _add.beta)
+    if mA == 0 || nA == 0 || iszero(α)
+        return _rmul_or_fill!(C, β)
     end
     if mA == 2 && nA == 2
-        return matmul2x2!(C, tA, tAt, A, A, _add)
+        return matmul2x2!(C, tA, tAt, A, A, MulAddMul(α, β))
     end
     if mA == 3 && nA == 3
-        return matmul3x3!(C, tA, tAt, A, A, _add)
+        return matmul3x3!(C, tA, tAt, A, A, MulAddMul(α, β))
     end
 
-    if stride(A, 1) == stride(C, 1) == 1 && stride(A, 2) >= size(A, 1) && stride(C, 2) >= size(C, 1)
-        return copytri!(BLAS.syrk!('U', tA, _add.alpha, A, _add.beta, C), 'U')
+    # BLAS.syrk! only updates symmetric C
+    # alternatively, make non-zero β a show-stopper for BLAS.syrk!
+    if iszero(β) || issymmetric(C)
+        alpha, beta = promote(α, β, zero(T))
+        if (alpha isa Union{Bool,T} &&
+            beta isa Union{Bool,T} &&
+            stride(A, 1) == stride(C, 1) == 1 &&
+            stride(A, 2) >= size(A, 1) &&
+            stride(C, 2) >= size(C, 1))
+            return copytri!(BLAS.syrk!('U', tA, alpha, A, beta, C), 'U')
+        end
     end
-    return generic_matmatmul!(C, tA, tAt, A, A, _add)
+    return gemm_wrapper!(C, tA, tAt, A, A, MulAddMul(α, β))
 end
 
 function herk_wrapper!(C::Union{StridedMatrix{T}, StridedMatrix{Complex{T}}}, tA::AbstractChar, A::Union{StridedVecOrMat{T}, StridedVecOrMat{Complex{T}}},
-                       _add::MulAddMul = MulAddMul()) where T<:BlasReal
+                       α::Number=true, β::Number=false) where {T<:BlasReal}
     nC = checksquare(C)
     if tA == 'C'
         (nA, mA) = size(A,1), size(A,2)
@@ -508,27 +525,34 @@ function herk_wrapper!(C::Union{StridedM
         throw(DimensionMismatch("output matrix has size: $(nC), but should have size $(mA)"))
     end
     if mA == 0 || nA == 0
-        return _rmul_or_fill!(C, _add.beta)
+        return _rmul_or_fill!(C, β)
     end
     if mA == 2 && nA == 2
-        return matmul2x2!(C, tA, tAt, A, A, _add)
+        return matmul2x2!(C, tA, tAt, A, A, MulAddMul(α, β))
     end
     if mA == 3 && nA == 3
-        return matmul3x3!(C, tA, tAt, A, A, _add)
+        return matmul3x3!(C, tA, tAt, A, A, MulAddMul(α, β))
     end
 
     # Result array does not need to be initialized as long as beta==0
     #    C = Matrix{T}(undef, mA, mA)
 
-    if stride(A, 1) == stride(C, 1) == 1 && stride(A, 2) >= size(A, 1) && stride(C, 2) >= size(C, 1)
-        return copytri!(BLAS.herk!('U', tA, _add.alpha, A, _add.beta, C), 'U', true)
+    if iszero(β) || issymmetric(C)
+        alpha, beta = promote(α, β, zero(T))
+        if (alpha isa Union{Bool,T} &&
+            beta isa Union{Bool,T} &&
+            stride(A, 1) == stride(C, 1) == 1 &&
+            stride(A, 2) >= size(A, 1) &&
+            stride(C, 2) >= size(C, 1))
+            return copytri!(BLAS.herk!('U', tA, alpha, A, beta, C), 'U', true)
+        end
     end
-    return generic_matmatmul!(C, tA, tAt, A, A, _add)
+    return gemm_wrapper!(C, tA, tAt, A, A, MulAddMul(α, β))
 end
 
 function gemm_wrapper(tA::AbstractChar, tB::AbstractChar,
                       A::StridedVecOrMat{T},
-                      B::StridedVecOrMat{T}) where T<:BlasFloat
+                      B::StridedVecOrMat{T}) where {T<:BlasFloat}
     mA, nA = lapack_size(tA, A)
     mB, nB = lapack_size(tB, B)
     C = similar(B, T, mA, nB)
@@ -537,7 +561,7 @@ end
 
 function gemm_wrapper!(C::StridedVecOrMat{T}, tA::AbstractChar, tB::AbstractChar,
                        A::StridedVecOrMat{T}, B::StridedVecOrMat{T},
-                       _add::MulAddMul = MulAddMul()) where T<:BlasFloat
+                       _add = MulAddMul()) where {T<:BlasFloat}
     mA, nA = lapack_size(tA, A)
     mB, nB = lapack_size(tB, B)
 
@@ -563,8 +587,14 @@ function gemm_wrapper!(C::StridedVecOrMa
         return matmul3x3!(C, tA, tB, A, B, _add)
     end
 
-    if stride(A, 1) == stride(B, 1) == stride(C, 1) == 1 && stride(A, 2) >= size(A, 1) && stride(B, 2) >= size(B, 1) && stride(C, 2) >= size(C, 1)
-        return BLAS.gemm!(tA, tB, _add.alpha, A, B, _add.beta, C)
+    alpha, beta = promote(_add.alpha, _add.beta, zero(T))
+    if (alpha isa Union{Bool,T} &&
+        beta isa Union{Bool,T} &&
+        stride(A, 1) == stride(B, 1) == stride(C, 1) == 1 &&
+        stride(A, 2) >= size(A, 1) &&
+        stride(B, 2) >= size(B, 1) &&
+        stride(C, 2) >= size(C, 1))
+        return BLAS.gemm!(tA, tB, alpha, A, B, beta, C)
     end
     generic_matmatmul!(C, tA, tB, A, B, _add)
 end
@@ -677,7 +707,7 @@ const Bbuf = [Vector{UInt8}(undef, tileb
 const Cbuf = [Vector{UInt8}(undef, tilebufsize)]
 
 function generic_matmatmul!(C::AbstractMatrix, tA, tB, A::AbstractMatrix, B::AbstractMatrix,
-                            _add::MulAddMul = MulAddMul())
+                            _add::MulAddMul=MulAddMul())
     mA, nA = lapack_size(tA, A)
     mB, nB = lapack_size(tB, B)
     mC, nC = size(C)
@@ -708,7 +738,8 @@ function _generic_matmatmul!(C::Abstract
     if size(C,1) != mA || size(C,2) != nB
         throw(DimensionMismatch("result C has dimensions $(size(C)), needs ($mA,$nB)"))
     end
-    if isempty(A) || isempty(B) || iszero(_add.alpha)
+
+    if iszero(_add.alpha) || isempty(A) || isempty(B)
         return _rmul_or_fill!(C, _add.beta)
     end
 
diff -pruN 1.3.1+dfsg-1/stdlib/LinearAlgebra/src/qr.jl 1.4.0+dfsg-1/stdlib/LinearAlgebra/src/qr.jl
--- 1.3.1+dfsg-1/stdlib/LinearAlgebra/src/qr.jl	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/stdlib/LinearAlgebra/src/qr.jl	2020-03-21 16:36:32.000000000 +0000
@@ -66,15 +66,22 @@ A = Q R
 
 where ``Q`` is an orthogonal/unitary matrix and ``R`` is upper triangular. It is similar
 to the [`QR`](@ref) format except that the orthogonal/unitary matrix ``Q`` is stored in
-*Compact WY* format [^Schreiber1989], as a lower trapezoidal matrix ``V`` and an upper
-triangular matrix ``T`` where
+*Compact WY* format [^Schreiber1989].  For the block size ``n_b``, it is stored as
+a `m`×`n` lower trapezoidal matrix ``V`` and a matrix ``T = (T_1 \\; T_2 \\; ... \\;
+T_{b-1} \\; T_b')`` composed of ``b = \\lceil \\min(m,n) / n_b \\rceil`` upper triangular
+matrices ``T_j`` of size ``n_b``×``n_b`` (``j = 1, ..., b-1``) and an upper trapezoidal
+``n_b``×``\\min(m,n) - (b-1) n_b`` matrix ``T_b'`` (``j=b``) whose upper square part
+denoted with ``T_b`` satisfying
 
 ```math
-Q = \\prod_{i=1}^{\\min(m,n)} (I - \\tau_i v_i v_i^T) = I - V T V^T
+Q = \\prod_{i=1}^{\\min(m,n)} (I - \\tau_i v_i v_i^T)
+= \\prod_{j=1}^{b} (I - V_j T_j V_j^T)
 ```
 
-such that ``v_i`` is the ``i``th column of ``V``, and ``\tau_i`` is the ``i``th diagonal
-element of ``T``.
+such that ``v_i`` is the ``i``th column of ``V``, ``\\tau_i`` is the ``i``th element
+of `[diag(T_1); diag(T_2); …; diag(T_b)]`, and ``(V_1 \\; V_2 \\; ... \\; V_b)``
+is the left `m`×`min(m, n)` block of ``V``.  When constructed using [`qr`](@ref),
+the block size is given by ``n_b = \\min(m, n, 36)``.
 
 Iterating the decomposition produces the components `Q` and `R`.
 
@@ -88,8 +95,8 @@ The object has two fields:
   - The subdiagonal part contains the reflectors ``v_i`` stored in a packed format such
     that `V = I + tril(F.factors, -1)`.
 
-* `T` is a square matrix with `min(m,n)` columns, whose upper triangular part gives the
-  matrix ``T`` above (the subdiagonal elements are ignored).
+* `T` is a ``n_b``-by-``\\min(m,n)`` matrix as described above. The subdiagonal elements
+  for each triangular matrix ``T_j`` are ignored.
 
 !!! note
 
@@ -239,20 +246,23 @@ function qrfactPivotedUnblocked!(A::Stri
 end
 
 # LAPACK version
-qr!(A::StridedMatrix{<:BlasFloat}, ::Val{false}) = QRCompactWY(LAPACK.geqrt!(A, min(min(size(A)...), 36))...)
+qr!(A::StridedMatrix{<:BlasFloat}, ::Val{false} = Val(false); blocksize=36) =
+    QRCompactWY(LAPACK.geqrt!(A, min(min(size(A)...), blocksize))...)
 qr!(A::StridedMatrix{<:BlasFloat}, ::Val{true}) = QRPivoted(LAPACK.geqp3!(A)...)
-qr!(A::StridedMatrix{<:BlasFloat}) = qr!(A, Val(false))
 
 # Generic fallbacks
 
 """
-    qr!(A, pivot=Val(false))
+    qr!(A, pivot=Val(false); blocksize)
 
 `qr!` is the same as [`qr`](@ref) when `A` is a subtype of
 `StridedMatrix`, but saves space by overwriting the input `A`, instead of creating a copy.
 An [`InexactError`](@ref) exception is thrown if the factorization produces a number not
 representable by the element type of `A`, e.g. for integer types.
 
+!!! compat "Julia 1.4"
+    The `blocksize` keyword argument requires Julia 1.4 or later.
+
 # Examples
 ```jldoctest
 julia> a = [1. 2.; 3. 4.]
@@ -289,7 +299,7 @@ qr!(A::StridedMatrix) = qr!(A, Val(false
 _qreltype(::Type{T}) where T = typeof(zero(T)/sqrt(abs2(one(T))))
 
 """
-    qr(A, pivot=Val(false)) -> F
+    qr(A, pivot=Val(false); blocksize) -> F
 
 Compute the QR factorization of the matrix `A`: an orthogonal (or unitary if `A` is
 complex-valued) matrix `Q`, and an upper triangular matrix `R` such that
@@ -329,6 +339,13 @@ and `F.Q*A` are supported. A `Q` matrix
 `m`×`m` orthogonal matrix, use `F.Q*Matrix(I,m,m)`.  If `m<=n`, then `Matrix(F.Q)` yields an `m`×`m`
 orthogonal matrix.
 
+The block size for QR decomposition can be specified by keyword argument
+`blocksize :: Integer` when `pivot == Val(false)` and `A isa StridedMatrix{<:BlasFloat}`.
+It is ignored when `blocksize > minimum(size(A))`.  See [`QRCompactWY`](@ref).
+
+!!! compat "Julia 1.4"
+    The `blocksize` keyword argument requires Julia 1.4 or later.
+
 # Examples
 ```jldoctest
 julia> A = [3.0 -6.0; 4.0 -8.0; 0.0 1.0]
@@ -359,17 +376,11 @@ true
     elementary reflectors, so that the `Q` and `R` matrices can be stored
     compactly rather as two separate dense matrices.
 """
-function qr(A::AbstractMatrix{T}, arg) where T
-    require_one_based_indexing(A)
-    AA = similar(A, _qreltype(T), size(A))
-    copyto!(AA, A)
-    return qr!(AA, arg)
-end
-function qr(A::AbstractMatrix{T}) where T
+function qr(A::AbstractMatrix{T}, arg...; kwargs...) where T
     require_one_based_indexing(A)
     AA = similar(A, _qreltype(T), size(A))
     copyto!(AA, A)
-    return qr!(AA)
+    return qr!(AA, arg...; kwargs...)
 end
 qr(x::Number) = qr(fill(x,1,1))
 function qr(v::AbstractVector)
@@ -906,3 +917,25 @@ end
 ## Lower priority: Add LQ, QL and RQ factorizations
 
 # FIXME! Should add balancing option through xgebal
+
+
+det(Q::QRPackedQ) = _det_tau(Q.τ)
+
+det(Q::QRCompactWYQ) =
+    prod(i -> _det_tau(_diagview(Q.T[:, i:min(i + size(Q.T, 1), size(Q.T, 2))])),
+         1:size(Q.T, 1):size(Q.T, 2))
+
+_diagview(A) = @view A[diagind(A)]
+
+# Compute `det` from the number of Householder reflections.  Handle
+# the case `Q.τ` contains zeros.
+_det_tau(τs::AbstractVector{<:Real}) =
+    isodd(count(!iszero, τs)) ? -one(eltype(τs)) : one(eltype(τs))
+
+# In complex case, we need to compute the non-unit eigenvalue `λ = 1 - c*τ`
+# (where `c = v'v`) of each Householder reflector.  As we know that the
+# reflector must have the determinant of 1, it must satisfy `abs2(λ) == 1`.
+# Combining this with the constraint `c > 0`, it turns out that the eigenvalue
+# (hence the determinant) can be computed as `λ = -sign(τ)^2`.
+# See: https://github.com/JuliaLang/julia/pull/32887#issuecomment-521935716
+_det_tau(τs) = prod(τ -> iszero(τ) ? one(τ) : -sign(τ)^2, τs)
diff -pruN 1.3.1+dfsg-1/stdlib/LinearAlgebra/src/structuredbroadcast.jl 1.4.0+dfsg-1/stdlib/LinearAlgebra/src/structuredbroadcast.jl
--- 1.3.1+dfsg-1/stdlib/LinearAlgebra/src/structuredbroadcast.jl	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/stdlib/LinearAlgebra/src/structuredbroadcast.jl	2020-03-21 16:36:32.000000000 +0000
@@ -40,6 +40,17 @@ Broadcast.BroadcastStyle(::StructuredMat
 Broadcast.BroadcastStyle(::StructuredMatrixStyle{<:UnitUpperTriangular}, ::StructuredMatrixStyle{<:Union{Diagonal,UpperTriangular,UnitUpperTriangular}}) =
     StructuredMatrixStyle{UpperTriangular}()
 
+Broadcast.BroadcastStyle(::StructuredMatrixStyle{<:Union{LowerTriangular,UnitLowerTriangular}}, ::StructuredMatrixStyle{<:Union{UpperTriangular,UnitUpperTriangular}}) =
+    StructuredMatrixStyle{Matrix}()
+Broadcast.BroadcastStyle(::StructuredMatrixStyle{<:Union{UpperTriangular,UnitUpperTriangular}}, ::StructuredMatrixStyle{<:Union{LowerTriangular,UnitLowerTriangular}}) =
+    StructuredMatrixStyle{Matrix}()
+
+# Make sure that `StructuredMatrixStyle{<:Matrix}` doesn't ever end up falling
+# through and give back `DefaultArrayStyle{2}`
+Broadcast.BroadcastStyle(T::StructuredMatrixStyle{<:Matrix}, ::StructuredMatrixStyle) = T
+Broadcast.BroadcastStyle(::StructuredMatrixStyle, T::StructuredMatrixStyle{<:Matrix}) = T
+Broadcast.BroadcastStyle(T::StructuredMatrixStyle{<:Matrix}, ::StructuredMatrixStyle{<:Matrix}) = T
+
 # All other combinations fall back to the default style
 Broadcast.BroadcastStyle(::StructuredMatrixStyle, ::StructuredMatrixStyle) = DefaultArrayStyle{2}()
 
@@ -69,6 +80,8 @@ structured_broadcast_alloc(bc, ::Type{<:
     UnitLowerTriangular(Array{ElType}(undef, n, n))
 structured_broadcast_alloc(bc, ::Type{<:UnitUpperTriangular}, ::Type{ElType}, n) where {ElType} =
     UnitUpperTriangular(Array{ElType}(undef, n, n))
+structured_broadcast_alloc(bc, ::Type{<:Matrix}, ::Type{ElType}, n) where {ElType} =
+    Matrix(Array{ElType}(undef, n, n))
 
 # A _very_ limited list of structure-preserving functions known at compile-time. This list is
 # derived from the formerly-implemented `broadcast` methods in 0.6. Note that this must
diff -pruN 1.3.1+dfsg-1/stdlib/LinearAlgebra/src/svd.jl 1.4.0+dfsg-1/stdlib/LinearAlgebra/src/svd.jl
--- 1.3.1+dfsg-1/stdlib/LinearAlgebra/src/svd.jl	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/stdlib/LinearAlgebra/src/svd.jl	2020-03-21 16:36:32.000000000 +0000
@@ -87,32 +87,7 @@ default_svd_alg(A) = DivideAndConquer()
     svd!(A; full::Bool = false, alg::Algorithm = default_svd_alg(A)) -> SVD
 
 `svd!` is the same as [`svd`](@ref), but saves space by
-overwriting the input `A`, instead of creating a copy.
-
-# Examples
-```jldoctest
-julia> A = [1. 0. 0. 0. 2.; 0. 0. 3. 0. 0.; 0. 0. 0. 0. 0.; 0. 2. 0. 0. 0.]
-4×5 Array{Float64,2}:
- 1.0  0.0  0.0  0.0  2.0
- 0.0  0.0  3.0  0.0  0.0
- 0.0  0.0  0.0  0.0  0.0
- 0.0  2.0  0.0  0.0  0.0
-
-julia> F = svd!(A);
-
-julia> F.U * Diagonal(F.S) * F.Vt
-4×5 Array{Float64,2}:
- 1.0  0.0  0.0  0.0  2.0
- 0.0  0.0  3.0  0.0  0.0
- 0.0  0.0  0.0  0.0  0.0
- 0.0  2.0  0.0  0.0  0.0
-
-julia> A
-4×5 Array{Float64,2}:
- -2.23607   0.0   0.0  0.0  0.618034
-  0.0      -3.0   1.0  0.0  0.0
-  0.0       0.0   0.0  0.0  0.0
-  0.0       0.0  -2.0  0.0  0.0
+overwriting the input `A`, instead of creating a copy. See documentation of [`svd`](@ref) for details.
 ```
 """
 function svd!(A::StridedMatrix{T}; full::Bool = false, alg::Algorithm = default_svd_alg(A)) where T<:BlasFloat
@@ -161,25 +136,21 @@ Another (typically slower but more accur
 
 # Examples
 ```jldoctest
-julia> A = [1. 0. 0. 0. 2.; 0. 0. 3. 0. 0.; 0. 0. 0. 0. 0.; 0. 2. 0. 0. 0.]
-4×5 Array{Float64,2}:
- 1.0  0.0  0.0  0.0  2.0
- 0.0  0.0  3.0  0.0  0.0
- 0.0  0.0  0.0  0.0  0.0
- 0.0  2.0  0.0  0.0  0.0
+julia> A = rand(4,3);
 
-julia> F = svd(A);
+julia> F = svd(A); # Store the Factorization Object
 
-julia> F.U * Diagonal(F.S) * F.Vt
-4×5 Array{Float64,2}:
- 1.0  0.0  0.0  0.0  2.0
- 0.0  0.0  3.0  0.0  0.0
- 0.0  0.0  0.0  0.0  0.0
- 0.0  2.0  0.0  0.0  0.0
+julia> A ≈ F.U * Diagonal(F.S) * F.Vt
+true
+
+julia> U, S, V = F; # destructuring via iteration
+
+julia> A ≈ U * Diagonal(S) * V'
+true
 
-julia> u, s, v = F; # destructuring via iteration
+julia> Uonly, = svd(A); # Store U only
 
-julia> u == F.U && s == F.S && v == F.V
+julia> Uonly == U
 true
 ```
 """
@@ -217,29 +188,6 @@ Base.propertynames(F::SVD, private::Bool
 
 Return the singular values of `A`, saving space by overwriting the input.
 See also [`svdvals`](@ref) and [`svd`](@ref).
-
-# Examples
-```jldoctest
-julia> A = [1. 0. 0. 0. 2.; 0. 0. 3. 0. 0.; 0. 0. 0. 0. 0.; 0. 2. 0. 0. 0.]
-4×5 Array{Float64,2}:
- 1.0  0.0  0.0  0.0  2.0
- 0.0  0.0  3.0  0.0  0.0
- 0.0  0.0  0.0  0.0  0.0
- 0.0  2.0  0.0  0.0  0.0
-
-julia> svdvals!(A)
-4-element Array{Float64,1}:
- 3.0
- 2.23606797749979
- 2.0
- 0.0
-
-julia> A
-4×5 Array{Float64,2}:
- -2.23607   0.0   0.0  0.0  0.618034
-  0.0      -3.0   1.0  0.0  0.0
-  0.0       0.0   0.0  0.0  0.0
-  0.0       0.0  -2.0  0.0  0.0
 ```
 """
 svdvals!(A::StridedMatrix{T}) where {T<:BlasFloat} = isempty(A) ? zeros(real(T), 0) : LAPACK.gesdd!('N', A)[2]
@@ -339,7 +287,32 @@ julia> B = [0. 1.; 1. 0.]
  0.0  1.0
  1.0  0.0
 
-julia> F = svd(A, B);
+julia> F = svd(A, B)
+GeneralizedSVD{Float64,Array{Float64,2}}
+U factor:
+2×2 Array{Float64,2}:
+ 1.0  0.0
+ 0.0  1.0
+V factor:
+2×2 Array{Float64,2}:
+ -0.0  -1.0
+  1.0   0.0
+Q factor:
+2×2 Array{Float64,2}:
+ 1.0  0.0
+ 0.0  1.0
+D1 factor:
+2×2 SparseArrays.SparseMatrixCSC{Float64,Int64} with 2 stored entries:
+  [1, 1]  =  0.707107
+  [2, 2]  =  0.707107
+D2 factor:
+2×2 SparseArrays.SparseMatrixCSC{Float64,Int64} with 2 stored entries:
+  [1, 1]  =  0.707107
+  [2, 2]  =  0.707107
+R0 factor:
+2×2 Array{Float64,2}:
+ 1.41421   0.0
+ 0.0      -1.41421
 
 julia> F.U*F.D1*F.R0*F.Q'
 2×2 Array{Float64,2}:
@@ -384,41 +357,7 @@ Base.iterate(S::GeneralizedSVD, ::Val{:d
     svd!(A, B) -> GeneralizedSVD
 
 `svd!` is the same as [`svd`](@ref), but modifies the arguments
-`A` and `B` in-place, instead of making copies.
-
-# Examples
-```jldoctest
-julia> A = [1. 0.; 0. -1.]
-2×2 Array{Float64,2}:
- 1.0   0.0
- 0.0  -1.0
-
-julia> B = [0. 1.; 1. 0.]
-2×2 Array{Float64,2}:
- 0.0  1.0
- 1.0  0.0
-
-julia> F = svd!(A, B);
-
-julia> F.U*F.D1*F.R0*F.Q'
-2×2 Array{Float64,2}:
- 1.0   0.0
- 0.0  -1.0
-
-julia> F.V*F.D2*F.R0*F.Q'
-2×2 Array{Float64,2}:
- 0.0  1.0
- 1.0  0.0
-
-julia> A
-2×2 Array{Float64,2}:
- 1.41421   0.0
- 0.0      -1.41421
-
-julia> B
-2×2 Array{Float64,2}:
- 1.0  -0.0
- 0.0  -1.0
+`A` and `B` in-place, instead of making copies. See documentation of [`svd`](@ref) for details.
 ```
 """
 function svd!(A::StridedMatrix{T}, B::StridedMatrix{T}) where T<:BlasFloat
@@ -433,12 +372,11 @@ end
 svd(A::StridedMatrix{T}, B::StridedMatrix{T}) where {T<:BlasFloat} = svd!(copy(A),copy(B))
 
 """
+
     svd(A, B) -> GeneralizedSVD
 
 Compute the generalized SVD of `A` and `B`, returning a `GeneralizedSVD` factorization
-object `F`, such that `A = F.U*F.D1*F.R0*F.Q'` and `B = F.V*F.D2*F.R0*F.Q'`.
-
-For an M-by-N matrix `A` and P-by-N matrix `B`,
+object `F` such that `[A;B] = [F.U * F.D1; F.V * F.D2] * F.R0 * F.Q'`
 
 - `U` is a M-by-M orthogonal matrix,
 - `V` is a P-by-P orthogonal matrix,
@@ -452,35 +390,36 @@ For an M-by-N matrix `A` and P-by-N matr
 
 Iterating the decomposition produces the components `U`, `V`, `Q`, `D1`, `D2`, and `R0`.
 
-The entries of `F.D1` and `F.D2` are related, as explained in the LAPACK
-documentation for the
-[generalized SVD](http://www.netlib.org/lapack/lug/node36.html) and the
-[xGGSVD3](http://www.netlib.org/lapack/explore-html/d6/db3/dggsvd3_8f.html)
-routine which is called underneath (in LAPACK 3.6.0 and newer).
+The generalized SVD is used in applications such as when one wants to compare how much belongs
+to `A` vs. how much belongs to `B`, as in human vs yeast genome, or signal vs noise, or between
+clusters vs within clusters. (See Edelman and Wang for discussion: https://arxiv.org/abs/1901.00485)
+
+It decomposes `[A; B]` into `[UC; VS]H`, where `[UC; VS]` is a natural orthogonal basis for the
+column space of `[A; B]`, and `H = RQ'` is a natural non-orthogonal basis for the rowspace of `[A;B]`,
+where the top rows are most closely attributed to the `A` matrix, and the bottom to the `B` matrix.
+The multi-cosine/sine matrices `C` and `S` provide a multi-measure of how much `A` vs how much `B`,
+and `U` and `V` provide directions in which these are measured.
 
 # Examples
 ```jldoctest
-julia> A = [1. 0.; 0. -1.]
-2×2 Array{Float64,2}:
- 1.0   0.0
- 0.0  -1.0
-
-julia> B = [0. 1.; 1. 0.]
-2×2 Array{Float64,2}:
- 0.0  1.0
- 1.0  0.0
+julia> A = randn(3,2); B=randn(4,2);
 
 julia> F = svd(A, B);
 
-julia> F.U*F.D1*F.R0*F.Q'
-2×2 Array{Float64,2}:
- 1.0   0.0
- 0.0  -1.0
+julia> U,V,Q,C,S,R = F;
 
-julia> F.V*F.D2*F.R0*F.Q'
-2×2 Array{Float64,2}:
- 0.0  1.0
- 1.0  0.0
+julia> H = R*Q';
+
+julia> [A; B] ≈ [U*C; V*S]*H
+true
+
+julia> [A; B] ≈ [F.U*F.D1; F.V*F.D2]*F.R0*F.Q'
+true
+
+julia> Uonly, = svd(A,B);
+
+julia> U == Uonly
+true
 ```
 """
 function svd(A::StridedMatrix{TA}, B::StridedMatrix{TB}) where {TA,TB}
@@ -535,39 +474,28 @@ end
 Base.propertynames(F::GeneralizedSVD) =
     (:alpha, :beta, :vals, :S, :D1, :D2, :R0, fieldnames(typeof(F))...)
 
+function show(io::IO, mime::MIME{Symbol("text/plain")}, F::GeneralizedSVD{<:Any,<:AbstractArray})
+    summary(io, F); println(io)
+    println(io, "U factor:")
+    show(io, mime, F.U)
+    println(io, "\nV factor:")
+    show(io, mime, F.V)
+    println(io, "\nQ factor:")
+    show(io, mime, F.Q)
+    println(io, "\nD1 factor:")
+    show(io, mime, F.D1)
+    println(io, "\nD2 factor:")
+    show(io, mime, F.D2)
+    println(io, "\nR0 factor:")
+    show(io, mime, F.R0)
+end
+
 """
     svdvals!(A, B)
 
 Return the generalized singular values from the generalized singular value
 decomposition of `A` and `B`, saving space by overwriting `A` and `B`.
 See also [`svd`](@ref) and [`svdvals`](@ref).
-
-# Examples
-```jldoctest
-julia> A = [1. 0.; 0. -1.]
-2×2 Array{Float64,2}:
- 1.0   0.0
- 0.0  -1.0
-
-julia> B = [0. 1.; 1. 0.]
-2×2 Array{Float64,2}:
- 0.0  1.0
- 1.0  0.0
-
-julia> svdvals!(A, B)
-2-element Array{Float64,1}:
- 1.0
- 1.0
-
-julia> A
-2×2 Array{Float64,2}:
- 1.41421   0.0
- 0.0      -1.41421
-
-julia> B
-2×2 Array{Float64,2}:
- 1.0  -0.0
- 0.0  -1.0
 ```
 """
 function svdvals!(A::StridedMatrix{T}, B::StridedMatrix{T}) where T<:BlasFloat
diff -pruN 1.3.1+dfsg-1/stdlib/LinearAlgebra/src/symmetric.jl 1.4.0+dfsg-1/stdlib/LinearAlgebra/src/symmetric.jl
--- 1.3.1+dfsg-1/stdlib/LinearAlgebra/src/symmetric.jl	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/stdlib/LinearAlgebra/src/symmetric.jl	2020-03-21 16:36:32.000000000 +0000
@@ -414,6 +414,49 @@ function triu(A::Symmetric, k::Integer=0
     end
 end
 
+for (T, trans, real) in [(:Symmetric, :transpose, :identity), (:Hermitian, :adjoint, :real)]
+    @eval begin
+        function dot(A::$T, B::$T)
+            n = size(A, 2)
+            if n != size(B, 2)
+                throw(DimensionMismatch("A has dimensions $(size(A)) but B has dimensions $(size(B))"))
+            end
+
+            dotprod = zero(dot(first(A), first(B)))
+            @inbounds if A.uplo == 'U' && B.uplo == 'U'
+                for j in 1:n
+                    for i in 1:(j - 1)
+                        dotprod += 2 * $real(dot(A.data[i, j], B.data[i, j]))
+                    end
+                    dotprod += dot(A[j, j], B[j, j])
+                end
+            elseif A.uplo == 'L' && B.uplo == 'L'
+                for j in 1:n
+                    dotprod += dot(A[j, j], B[j, j])
+                    for i in (j + 1):n
+                        dotprod += 2 * $real(dot(A.data[i, j], B.data[i, j]))
+                    end
+                end
+            elseif A.uplo == 'U' && B.uplo == 'L'
+                for j in 1:n
+                    for i in 1:(j - 1)
+                        dotprod += 2 * $real(dot(A.data[i, j], $trans(B.data[j, i])))
+                    end
+                    dotprod += dot(A[j, j], B[j, j])
+                end
+            else
+                for j in 1:n
+                    dotprod += dot(A[j, j], B[j, j])
+                    for i in (j + 1):n
+                        dotprod += 2 * $real(dot(A.data[i, j], $trans(B.data[j, i])))
+                    end
+                end
+            end
+            return dotprod
+        end
+    end
+end
+
 (-)(A::Symmetric) = Symmetric(-A.data, sym_uplo(A.uplo))
 (-)(A::Hermitian) = Hermitian(-A.data, sym_uplo(A.uplo))
 
@@ -426,37 +469,116 @@ for f in (:+, :-)
 end
 
 ## Matvec
-@inline mul!(y::StridedVector{T}, A::Symmetric{T,<:StridedMatrix}, x::StridedVector{T},
-             alpha::Union{T, Bool}, beta::Union{T, Bool}) where {T<:BlasFloat} =
-    BLAS.symv!(A.uplo, alpha, A.data, x, beta, y)
-@inline mul!(y::StridedVector{T}, A::Hermitian{T,<:StridedMatrix}, x::StridedVector{T},
-             alpha::Union{T, Bool}, beta::Union{T, Bool}) where {T<:BlasReal} =
-    BLAS.symv!(A.uplo, alpha, A.data, x, beta, y)
-@inline mul!(y::StridedVector{T}, A::Hermitian{T,<:StridedMatrix}, x::StridedVector{T},
-             alpha::Union{T, Bool}, beta::Union{T, Bool}) where {T<:BlasComplex} =
-    BLAS.hemv!(A.uplo, alpha, A.data, x, beta, y)
+@inline function mul!(y::StridedVector{T}, A::Symmetric{T,<:StridedMatrix}, x::StridedVector{T},
+             α::Number, β::Number) where {T<:BlasFloat}
+    alpha, beta = promote(α, β, zero(T))
+    if alpha isa Union{Bool,T} && beta isa Union{Bool,T}
+        return BLAS.symv!(A.uplo, alpha, A.data, x, beta, y)
+    else
+        return generic_matvecmul!(y, 'N', A, x, MulAddMul(α, β))
+    end
+end
+@inline function mul!(y::StridedVector{T}, A::Hermitian{T,<:StridedMatrix}, x::StridedVector{T},
+             α::Number, β::Number) where {T<:BlasReal}
+    alpha, beta = promote(α, β, zero(T))
+    if alpha isa Union{Bool,T} && beta isa Union{Bool,T}
+        return BLAS.symv!(A.uplo, alpha, A.data, x, beta, y)
+    else
+        return generic_matvecmul!(y, 'N', A, x, MulAddMul(α, β))
+    end
+end
+@inline function mul!(y::StridedVector{T}, A::Hermitian{T,<:StridedMatrix}, x::StridedVector{T},
+             α::Number, β::Number) where {T<:BlasComplex}
+    alpha, beta = promote(α, β, zero(T))
+    if alpha isa Union{Bool,T} && beta isa Union{Bool,T}
+        return BLAS.hemv!(A.uplo, alpha, A.data, x, beta, y)
+    else
+        return generic_matvecmul!(y, 'N', A, x, MulAddMul(α, β))
+    end
+end
 ## Matmat
-@inline mul!(C::StridedMatrix{T}, A::Symmetric{T,<:StridedMatrix}, B::StridedMatrix{T},
-             alpha::Union{T, Bool}, beta::Union{T, Bool}) where {T<:BlasFloat} =
-    BLAS.symm!('L', A.uplo, alpha, A.data, B, beta, C)
-@inline mul!(C::StridedMatrix{T}, A::StridedMatrix{T}, B::Symmetric{T,<:StridedMatrix},
-             alpha::Union{T, Bool}, beta::Union{T, Bool}) where {T<:BlasFloat} =
-    BLAS.symm!('R', B.uplo, alpha, B.data, A, beta, C)
-@inline mul!(C::StridedMatrix{T}, A::Hermitian{T,<:StridedMatrix}, B::StridedMatrix{T},
-             alpha::Union{T, Bool}, beta::Union{T, Bool}) where {T<:BlasReal} =
-    BLAS.symm!('L', A.uplo, alpha, A.data, B, beta, C)
-@inline mul!(C::StridedMatrix{T}, A::StridedMatrix{T}, B::Hermitian{T,<:StridedMatrix},
-             alpha::Union{T, Bool}, beta::Union{T, Bool}) where {T<:BlasReal} =
-    BLAS.symm!('R', B.uplo, alpha, B.data, A, beta, C)
-@inline mul!(C::StridedMatrix{T}, A::Hermitian{T,<:StridedMatrix}, B::StridedMatrix{T},
-             alpha::Union{T, Bool}, beta::Union{T, Bool}) where {T<:BlasComplex} =
-    BLAS.hemm!('L', A.uplo, alpha, A.data, B, beta, C)
-@inline mul!(C::StridedMatrix{T}, A::StridedMatrix{T}, B::Hermitian{T,<:StridedMatrix},
-             alpha::Union{T, Bool}, beta::Union{T, Bool}) where {T<:BlasComplex} =
-    BLAS.hemm!('R', B.uplo, alpha, B.data, A, beta, C)
+@inline function mul!(C::StridedMatrix{T}, A::Symmetric{T,<:StridedMatrix}, B::StridedMatrix{T},
+             α::Number, β::Number) where {T<:BlasFloat}
+    alpha, beta = promote(α, β, zero(T))
+    if alpha isa Union{Bool,T} && beta isa Union{Bool,T}
+        return BLAS.symm!('L', A.uplo, alpha, A.data, B, beta, C)
+    else
+        return generic_matmatmul!(C, 'N', 'N', A, B, MulAddMul(alpha, beta))
+    end
+end
+@inline function mul!(C::StridedMatrix{T}, A::StridedMatrix{T}, B::Symmetric{T,<:StridedMatrix},
+             α::Number, β::Number) where {T<:BlasFloat}
+    alpha, beta = promote(α, β, zero(T))
+    if alpha isa Union{Bool,T} && beta isa Union{Bool,T}
+        return BLAS.symm!('R', B.uplo, alpha, B.data, A, beta, C)
+    else
+        return generic_matmatmul!(C, 'N', 'N', A, B, MulAddMul(alpha, beta))
+    end
+end
+@inline function mul!(C::StridedMatrix{T}, A::Hermitian{T,<:StridedMatrix}, B::StridedMatrix{T},
+             α::Number, β::Number) where {T<:BlasReal}
+    alpha, beta = promote(α, β, zero(T))
+    if alpha isa Union{Bool,T} && beta isa Union{Bool,T}
+        return BLAS.symm!('L', A.uplo, alpha, A.data, B, beta, C)
+    else
+        return generic_matmatmul!(C, 'N', 'N', A, B, MulAddMul(alpha, beta))
+    end
+end
+@inline function mul!(C::StridedMatrix{T}, A::StridedMatrix{T}, B::Hermitian{T,<:StridedMatrix},
+             α::Number, β::Number) where {T<:BlasReal}
+    alpha, beta = promote(α, β, zero(T))
+    if alpha isa Union{Bool,T} && beta isa Union{Bool,T}
+        return BLAS.symm!('R', B.uplo, alpha, B.data, A, beta, C)
+    else
+        return generic_matmatmul!(C, 'N', 'N', A, B, MulAddMul(alpha, beta))
+    end
+end
+@inline function mul!(C::StridedMatrix{T}, A::Hermitian{T,<:StridedMatrix}, B::StridedMatrix{T},
+             α::Number, β::Number) where {T<:BlasComplex}
+    alpha, beta = promote(α, β, zero(T))
+    if alpha isa Union{Bool,T} && beta isa Union{Bool,T}
+        return BLAS.hemm!('L', A.uplo, alpha, A.data, B, beta, C)
+    else
+        return generic_matmatmul!(C, 'N', 'N', A, B, MulAddMul(alpha, beta))
+    end
+end
+@inline function mul!(C::StridedMatrix{T}, A::StridedMatrix{T}, B::Hermitian{T,<:StridedMatrix},
+             α::Number, β::Number) where {T<:BlasComplex}
+    alpha, beta = promote(α, β, zero(T))
+    if alpha isa Union{Bool,T} && beta isa Union{Bool,T}
+        return BLAS.hemm!('R', B.uplo, alpha, B.data, A, beta, C)
+    else
+        return generic_matmatmul!(C, 'N', 'N', A, B, MulAddMul(alpha, beta))
+    end
+end
 
 *(A::HermOrSym, B::HermOrSym) = A * copyto!(similar(parent(B)), B)
 
+function dot(x::AbstractVector, A::RealHermSymComplexHerm, y::AbstractVector)
+    require_one_based_indexing(x, y)
+    (length(x) == length(y) == size(A, 1)) || throw(DimensionMismatch())
+    data = A.data
+    r = zero(eltype(x)) * zero(eltype(A)) * zero(eltype(y))
+    if A.uplo == 'U'
+        @inbounds for j = 1:length(y)
+            r += dot(x[j], real(data[j,j]), y[j])
+            @simd for i = 1:j-1
+                Aij = data[i,j]
+                r += dot(x[i], Aij, y[j]) + dot(x[j], adjoint(Aij), y[i])
+            end
+        end
+    else # A.uplo == 'L'
+        @inbounds for j = 1:length(y)
+            r += dot(x[j], real(data[j,j]), y[j])
+            @simd for i = j+1:length(y)
+                Aij = data[i,j]
+                r += dot(x[i], Aij, y[j]) + dot(x[j], adjoint(Aij), y[i])
+            end
+        end
+    end
+    return r
+end
+
 # Fallbacks to avoid generic_matvecmul!/generic_matmatmul!
 ## Symmetric{<:Number} and Hermitian{<:Real} are invariant to transpose; peel off the t
 *(transA::Transpose{<:Any,<:RealHermSymComplexSym}, B::AbstractVector) = transA.parent * B
@@ -495,18 +617,19 @@ end
 /(A::Symmetric, x::Number) = Symmetric(A.data/x, sym_uplo(A.uplo))
 /(A::Hermitian, x::Real) = Hermitian(A.data/x, sym_uplo(A.uplo))
 
-function factorize(A::HermOrSym{T}) where T
+factorize(A::HermOrSym) = _factorize(A)
+function _factorize(A::HermOrSym{T}; check::Bool=true) where T
     TT = typeof(sqrt(oneunit(T)))
     if TT <: BlasFloat
-        return bunchkaufman(A)
+        return bunchkaufman(A; check=check)
     else # fallback
-        return lu(A)
+        return lu(A; check=check)
     end
 end
 
-det(A::RealHermSymComplexHerm) = real(det(factorize(A)))
-det(A::Symmetric{<:Real}) = det(factorize(A))
-det(A::Symmetric) = det(factorize(A))
+det(A::RealHermSymComplexHerm) = real(det(_factorize(A; check=false)))
+det(A::Symmetric{<:Real}) = det(_factorize(A; check=false))
+det(A::Symmetric) = det(_factorize(A; check=false))
 
 \(A::HermOrSym{<:Any,<:StridedMatrix}, B::AbstractVector) = \(factorize(A), B)
 # Bunch-Kaufman solves can not utilize BLAS-3 for multiple right hand sides
diff -pruN 1.3.1+dfsg-1/stdlib/LinearAlgebra/src/triangular.jl 1.4.0+dfsg-1/stdlib/LinearAlgebra/src/triangular.jl
--- 1.3.1+dfsg-1/stdlib/LinearAlgebra/src/triangular.jl	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/stdlib/LinearAlgebra/src/triangular.jl	2020-03-21 16:36:32.000000000 +0000
@@ -50,6 +50,16 @@ for t in (:LowerTriangular, :UnitLowerTr
     end
 end
 
+similar(A::Union{Adjoint{Ti,Tv}, Transpose{Ti,Tv}}, ::Type{T}) where {T,Ti,Tv<:LowerTriangular} =
+    UpperTriangular(similar(parent(parent(A)), T))
+similar(A::Union{Adjoint{Ti,Tv}, Transpose{Ti,Tv}}, ::Type{T}) where {T,Ti,Tv<:UnitLowerTriangular} =
+    UnitUpperTriangular(similar(parent(parent(A)), T))
+similar(A::Union{Adjoint{Ti,Tv}, Transpose{Ti,Tv}}, ::Type{T}) where {T,Ti,Tv<:UpperTriangular} =
+    LowerTriangular(similar(parent(parent(A)), T))
+similar(A::Union{Adjoint{Ti,Tv}, Transpose{Ti,Tv}}, ::Type{T}) where {T,Ti,Tv<:UnitUpperTriangular} =
+    UnitLowerTriangular(similar(parent(parent(A)), T))
+
+
 LowerTriangular(U::UpperTriangular) = throw(ArgumentError(
     "cannot create a LowerTriangular matrix from an UpperTriangular input"))
 UpperTriangular(U::LowerTriangular) = throw(ArgumentError(
@@ -545,6 +555,90 @@ end
 rmul!(A::Union{UpperTriangular,LowerTriangular}, c::Number) = mul!(A, A, c)
 lmul!(c::Number, A::Union{UpperTriangular,LowerTriangular}) = mul!(A, c, A)
 
+function dot(x::AbstractVector, A::UpperTriangular, y::AbstractVector)
+    require_one_based_indexing(x, y)
+    m = size(A, 1)
+    (length(x) == m == length(y)) || throw(DimensionMismatch())
+    if iszero(m)
+        return dot(zero(eltype(x)), zero(eltype(A)), zero(eltype(y)))
+    end
+    x₁ = x[1]
+    r = dot(x₁, A[1,1], y[1])
+    @inbounds for j in 2:m
+        yj = y[j]
+        if !iszero(yj)
+            temp = adjoint(A[1,j]) * x₁
+            @simd for i in 2:j
+                temp += adjoint(A[i,j]) * x[i]
+            end
+            r += dot(temp, yj)
+        end
+    end
+    return r
+end
+function dot(x::AbstractVector, A::UnitUpperTriangular, y::AbstractVector)
+    require_one_based_indexing(x, y)
+    m = size(A, 1)
+    (length(x) == m == length(y)) || throw(DimensionMismatch())
+    if iszero(m)
+        return dot(zero(eltype(x)), zero(eltype(A)), zero(eltype(y)))
+    end
+    x₁ = first(x)
+    r = dot(x₁, y[1])
+    @inbounds for j in 2:m
+        yj = y[j]
+        if !iszero(yj)
+            temp = adjoint(A[1,j]) * x₁
+            @simd for i in 2:j-1
+                temp += adjoint(A[i,j]) * x[i]
+            end
+            r += dot(temp, yj)
+            r += dot(x[j], yj)
+        end
+    end
+    return r
+end
+function dot(x::AbstractVector, A::LowerTriangular, y::AbstractVector)
+    require_one_based_indexing(x, y)
+    m = size(A, 1)
+    (length(x) == m == length(y)) || throw(DimensionMismatch())
+    if iszero(m)
+        return dot(zero(eltype(x)), zero(eltype(A)), zero(eltype(y)))
+    end
+    r = zero(typeof(dot(first(x), first(A), first(y))))
+    @inbounds for j in 1:m
+        yj = y[j]
+        if !iszero(yj)
+            temp = adjoint(A[j,j]) * x[j]
+            @simd for i in j+1:m
+                temp += adjoint(A[i,j]) * x[i]
+            end
+            r += dot(temp, yj)
+        end
+    end
+    return r
+end
+function dot(x::AbstractVector, A::UnitLowerTriangular, y::AbstractVector)
+    require_one_based_indexing(x, y)
+    m = size(A, 1)
+    (length(x) == m == length(y)) || throw(DimensionMismatch())
+    if iszero(m)
+        return dot(zero(eltype(x)), zero(eltype(A)), zero(eltype(y)))
+    end
+    r = zero(typeof(dot(first(x), first(y))))
+    @inbounds for j in 1:m
+        yj = y[j]
+        if !iszero(yj)
+            temp = x[j]
+            @simd for i in j+1:m
+                temp += adjoint(A[i,j]) * x[i]
+            end
+            r += dot(temp, yj)
+        end
+    end
+    return r
+end
+
 fillstored!(A::LowerTriangular, x)     = (fillband!(A.data, x, 1-size(A,1), 0); A)
 fillstored!(A::UnitLowerTriangular, x) = (fillband!(A.data, x, 1-size(A,1), -1); A)
 fillstored!(A::UpperTriangular, x)     = (fillband!(A.data, x, 0, size(A,2)-1); A)
@@ -2210,32 +2304,14 @@ function log(A0::UpperTriangular{T}) whe
     end
 
     # Compute accurate superdiagonal of T
-    p = 1 / 2^s
-    for k = 1:n-1
-        Ak = A0[k,k]
-        Akp1 = A0[k+1,k+1]
-        Akp = Ak^p
-        Akp1p = Akp1^p
-        A[k,k] = Akp
-        A[k+1,k+1] = Akp1p
-        if Ak == Akp1
-            A[k,k+1] = p * A0[k,k+1] * Ak^(p-1)
-        elseif 2 * abs(Ak) < abs(Akp1) || 2 * abs(Akp1) < abs(Ak)
-            A[k,k+1] = A0[k,k+1] * (Akp1p - Akp) / (Akp1 - Ak)
-        else
-            logAk = log(Ak)
-            logAkp1 = log(Akp1)
-            w = atanh((Akp1 - Ak)/(Akp1 + Ak)) + im*pi*ceil((imag(logAkp1-logAk)-pi)/(2*pi))
-            dd = 2 * exp(p*(logAk+logAkp1)/2) * sinh(p*w) / (Akp1 - Ak)
-            A[k,k+1] = A0[k,k+1] * dd
-        end
-    end
+    blockpower!(A, A0, 0.5^s)
 
     # Compute accurate diagonal of T
     for i = 1:n
         a = A0[i,i]
         if s == 0
-            r = a - 1
+            A[i,i] = a - 1
+            continue
         end
         s0 = s
         if angle(a) >= pi / 2
@@ -2272,7 +2348,7 @@ function log(A0::UpperTriangular{T}) whe
     end
 
     # Scale back
-    lmul!(2^s, Y)
+    lmul!(2.0^s, Y)
 
     # Compute accurate diagonal and superdiagonal of log(T)
     for k = 1:n-1
@@ -2284,11 +2360,16 @@ function log(A0::UpperTriangular{T}) whe
         Y[k+1,k+1] = logAkp1
         if Ak == Akp1
             Y[k,k+1] = A0[k,k+1] / Ak
-        elseif 2 * abs(Ak) < abs(Akp1) || 2 * abs(Akp1) < abs(Ak)
+        elseif 2 * abs(Ak) < abs(Akp1) || 2 * abs(Akp1) < abs(Ak) || iszero(Akp1 + Ak)
             Y[k,k+1] = A0[k,k+1] * (logAkp1 - logAk) / (Akp1 - Ak)
         else
-            w = atanh((Akp1 - Ak)/(Akp1 + Ak) + im*pi*(ceil((imag(logAkp1-logAk) - pi)/(2*pi))))
-            Y[k,k+1] = 2 * A0[k,k+1] * w / (Akp1 - Ak)
+            z = (Akp1 - Ak)/(Akp1 + Ak)
+            if abs(z) > 1
+                Y[k,k+1] = A0[k,k+1] * (logAkp1 - logAk) / (Akp1 - Ak)
+            else
+                w = atanh(z) + im * pi * (unw(logAkp1-logAk) - unw(log1p(z)-log1p(-z)))
+                Y[k,k+1] = 2 * A0[k,k+1] * w / (Akp1 - Ak)
+            end
         end
     end
 
@@ -2435,14 +2516,19 @@ function blockpower!(A::UpperTriangular,
 
         if Ak == Akp1
             A[k,k+1] = p * A0[k,k+1] * Ak^(p-1)
-        elseif 2 * abs(Ak) < abs(Akp1) || 2 * abs(Akp1) < abs(Ak)
+        elseif 2 * abs(Ak) < abs(Akp1) || 2 * abs(Akp1) < abs(Ak) || iszero(Akp1 + Ak)
             A[k,k+1] = A0[k,k+1] * (Akp1p - Akp) / (Akp1 - Ak)
         else
             logAk = log(Ak)
             logAkp1 = log(Akp1)
-            w = atanh((Akp1 - Ak)/(Akp1 + Ak)) + im * pi * unw(logAkp1-logAk)
-            dd = 2 * exp(p*(logAk+logAkp1)/2) * sinh(p*w) / (Akp1 - Ak);
-            A[k,k+1] = A0[k,k+1] * dd
+            z = (Akp1 - Ak)/(Akp1 + Ak)
+            if abs(z) > 1
+                A[k,k+1] = A0[k,k+1] * (Akp1p - Akp) / (Akp1 - Ak)
+            else
+                w = atanh(z) + im * pi * (unw(logAkp1-logAk) - unw(log1p(z)-log1p(-z)))
+                dd = 2 * exp(p*(logAk+logAkp1)/2) * sinh(p*w) / (Akp1 - Ak);
+                A[k,k+1] = A0[k,k+1] * dd
+            end
         end
     end
 end
diff -pruN 1.3.1+dfsg-1/stdlib/LinearAlgebra/src/tridiag.jl 1.4.0+dfsg-1/stdlib/LinearAlgebra/src/tridiag.jl
--- 1.3.1+dfsg-1/stdlib/LinearAlgebra/src/tridiag.jl	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/stdlib/LinearAlgebra/src/tridiag.jl	2020-03-21 16:36:32.000000000 +0000
@@ -202,6 +202,27 @@ end
     return C
 end
 
+function dot(x::AbstractVector, S::SymTridiagonal, y::AbstractVector)
+    require_one_based_indexing(x, y)
+    nx, ny = length(x), length(y)
+    (nx == size(S, 1) == ny) || throw(DimensionMismatch())
+    if iszero(nx)
+        return dot(zero(eltype(x)), zero(eltype(S)), zero(eltype(y)))
+    end
+    dv, ev = S.dv, S.ev
+    x₀ = x[1]
+    x₊ = x[2]
+    sub = transpose(ev[1])
+    r = dot(adjoint(dv[1])*x₀ + adjoint(sub)*x₊, y[1])
+    @inbounds for j in 2:nx-1
+        x₋, x₀, x₊ = x₀, x₊, x[j+1]
+        sup, sub = transpose(sub), transpose(ev[j])
+        r += dot(adjoint(sup)*x₋ + adjoint(dv[j])*x₀ + adjoint(sub)*x₊, y[j])
+    end
+    r += dot(adjoint(transpose(sub))*x₀ + adjoint(dv[nx])*x₊, y[nx])
+    return r
+end
+
 (\)(T::SymTridiagonal, B::StridedVecOrMat) = ldlt(T)\B
 
 # division with optional shift for use in shifted-Hessenberg solvers (hessenberg.jl):
@@ -398,7 +419,7 @@ struct Tridiagonal{T,V<:AbstractVector{T
     function Tridiagonal{T,V}(dl, d, du) where {T,V<:AbstractVector{T}}
         require_one_based_indexing(dl, d, du)
         n = length(d)
-        if (length(dl) != n-1 || length(du) != n-1)
+        if (length(dl) != n-1 || length(du) != n-1) && !(length(d) == 0 && length(dl) == 0 && length(du) == 0)
             throw(ArgumentError(string("cannot construct Tridiagonal from incompatible ",
                 "lengths of subdiagonal, diagonal and superdiagonal: ",
                 "($(length(dl)), $(length(d)), $(length(du)))")))
@@ -657,3 +678,22 @@ end
 
 Base._sum(A::Tridiagonal, ::Colon) = sum(A.d) + sum(A.dl) + sum(A.du)
 Base._sum(A::SymTridiagonal, ::Colon) = sum(A.dv) + 2sum(A.ev)
+
+function dot(x::AbstractVector, A::Tridiagonal, y::AbstractVector)
+    require_one_based_indexing(x, y)
+    nx, ny = length(x), length(y)
+    (nx == size(A, 1) == ny) || throw(DimensionMismatch())
+    if iszero(nx)
+        return dot(zero(eltype(x)), zero(eltype(A)), zero(eltype(y)))
+    end
+    x₀ = x[1]
+    x₊ = x[2]
+    dl, d, du = A.dl, A.d, A.du
+    r = dot(adjoint(d[1])*x₀ + adjoint(dl[1])*x₊, y[1])
+    @inbounds for j in 2:nx-1
+        x₋, x₀, x₊ = x₀, x₊, x[j+1]
+        r += dot(adjoint(du[j-1])*x₋ + adjoint(d[j])*x₀ + adjoint(dl[j])*x₊, y[j])
+    end
+    r += dot(adjoint(du[nx-1])*x₀ + adjoint(d[nx])*x₊, y[nx])
+    return r
+end
diff -pruN 1.3.1+dfsg-1/stdlib/LinearAlgebra/src/uniformscaling.jl 1.4.0+dfsg-1/stdlib/LinearAlgebra/src/uniformscaling.jl
--- 1.3.1+dfsg-1/stdlib/LinearAlgebra/src/uniformscaling.jl	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/stdlib/LinearAlgebra/src/uniformscaling.jl	2020-03-21 16:36:32.000000000 +0000
@@ -1,7 +1,7 @@
 # This file is a part of Julia. License is MIT: https://julialang.org/license
 
 import Base: copy, adjoint, getindex, show, transpose, one, zero, inv,
-             hcat, vcat, hvcat
+             hcat, vcat, hvcat, ^
 
 """
     UniformScaling{T<:Number}
@@ -210,6 +210,7 @@ end
     rmul!(inv(A), J.λ)
 \(J::UniformScaling, A::AbstractVecOrMat) = J.λ == 0 ? throw(SingularException(1)) : J.λ\A
 \(A::AbstractMatrix, J::UniformScaling) = rmul!(inv(A), J.λ)
+\(F::Factorization, J::UniformScaling) = F \ J(size(F,1))
 
 \(x::Number, J::UniformScaling) = UniformScaling(x\J.λ)
 
@@ -221,12 +222,21 @@ rmul!(A::AbstractMatrix, J::UniformScali
 lmul!(J::UniformScaling, B::AbstractVecOrMat) = lmul!(J.λ, B)
 rdiv!(A::AbstractMatrix, J::UniformScaling) = rdiv!(A, J.λ)
 ldiv!(J::UniformScaling, B::AbstractVecOrMat) = ldiv!(J.λ, B)
+ldiv!(Y::AbstractVecOrMat, J::UniformScaling, B::AbstractVecOrMat) = (Y .= J.λ .\ B)
 
 Broadcast.broadcasted(::typeof(*), x::Number,J::UniformScaling) = UniformScaling(x*J.λ)
 Broadcast.broadcasted(::typeof(*), J::UniformScaling,x::Number) = UniformScaling(J.λ*x)
 
 Broadcast.broadcasted(::typeof(/), J::UniformScaling,x::Number) = UniformScaling(J.λ/x)
 
+(^)(J::UniformScaling, x::Number) = UniformScaling((J.λ)^x)
+Base.literal_pow(::typeof(^), J::UniformScaling, x::Val) = UniformScaling(Base.literal_pow(^, J.λ, x))
+
+Broadcast.broadcasted(::typeof(^), J::UniformScaling, x::Number) = UniformScaling(J.λ^x)
+function Broadcast.broadcasted(::typeof(Base.literal_pow), ::typeof(^), J::UniformScaling, x::Val)
+    UniformScaling(Base.literal_pow(^, J.λ, x))
+end
+
 ==(J1::UniformScaling,J2::UniformScaling) = (J1.λ == J2.λ)
 
 ## equality comparison with UniformScaling
@@ -400,3 +410,7 @@ Array(s::UniformScaling, dims::Dims{2})
 ## Diagonal construction from UniformScaling
 Diagonal{T}(s::UniformScaling, m::Integer) where {T} = Diagonal{T}(fill(T(s.λ), m))
 Diagonal(s::UniformScaling, m::Integer) = Diagonal{eltype(s)}(s, m)
+
+dot(x::AbstractVector, J::UniformScaling, y::AbstractVector) = dot(x, J.λ, y)
+dot(x::AbstractVector, a::Number, y::AbstractVector) = sum(t -> dot(t[1], a, t[2]), zip(x, y))
+dot(x::AbstractVector, a::Union{Real,Complex}, y::AbstractVector) = a*dot(x, y)
diff -pruN 1.3.1+dfsg-1/stdlib/LinearAlgebra/test/adjtrans.jl 1.4.0+dfsg-1/stdlib/LinearAlgebra/test/adjtrans.jl
--- 1.3.1+dfsg-1/stdlib/LinearAlgebra/test/adjtrans.jl	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/stdlib/LinearAlgebra/test/adjtrans.jl	2020-03-21 16:36:32.000000000 +0000
@@ -504,4 +504,25 @@ using .Main.OffsetArrays
     @test_throws BoundsError s[1, 4]
 end
 
+@testset "specialized conj of Adjoint/Transpose" begin
+    realmat = [1 2; 3 4]
+    complexmat = ComplexF64[1+im 2; 3 4-im]
+    nested = [[complexmat] [-complexmat]; [0complexmat] [3complexmat]]
+    @testset "AdjOrTrans{...,$(typeof(i))}" for i in (
+                                                      realmat, vec(realmat),
+                                                      complexmat, vec(complexmat),
+                                                      nested, vec(nested),
+                                                     )
+        for (t,type) in ((transpose, Adjoint), (adjoint, Transpose))
+            M = t(i)
+            @test conj(M) isa type
+            @test conj(M) == conj(collect(M))
+            @test conj(conj(M)) === M
+        end
+    end
+    # test if `conj(transpose(::Hermitian))` is a no-op
+    hermitian = Hermitian([1 2+im; 2-im 3])
+    @test conj(transpose(hermitian)) === hermitian
+end
+
 end # module TestAdjointTranspose
diff -pruN 1.3.1+dfsg-1/stdlib/LinearAlgebra/test/bidiag.jl 1.4.0+dfsg-1/stdlib/LinearAlgebra/test/bidiag.jl
--- 1.3.1+dfsg-1/stdlib/LinearAlgebra/test/bidiag.jl	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/stdlib/LinearAlgebra/test/bidiag.jl	2020-03-21 16:36:32.000000000 +0000
@@ -455,4 +455,47 @@ end
     @test A * Tridiagonal(ones(1, 1)) == A
 end
 
+@testset "generalized dot" begin
+    for elty in (Float64, ComplexF64)
+        dv = randn(elty, 5)
+        ev = randn(elty, 4)
+        x = randn(elty, 5)
+        y = randn(elty, 5)
+        for uplo in (:U, :L)
+            B = Bidiagonal(dv, ev, uplo)
+            @test dot(x, B, y) ≈ dot(B'x, y) ≈ dot(x, Matrix(B), y)
+        end
+    end
+end
+
+@testset "multiplication of bidiagonal and triangular matrix" begin
+    n = 5
+    for eltyB in (Int, ComplexF64)
+        if eltyB == Int
+            BU = Bidiagonal(rand(1:7, n), rand(1:7, n - 1), :U)
+            BL = Bidiagonal(rand(1:7, n), rand(1:7, n - 1), :L)
+        else
+            BU = Bidiagonal(randn(eltyB, n), randn(eltyB, n - 1), :U)
+            BL = Bidiagonal(randn(eltyB, n), randn(eltyB, n - 1), :L)
+        end
+        for eltyT in (Int, ComplexF64)
+            for TriT in (LowerTriangular, UnitLowerTriangular, UpperTriangular, UnitUpperTriangular)
+                if eltyT == Int
+                    T = TriT(rand(1:7, n, n))
+                else
+                    T = TriT(randn(eltyT, n, n))
+                end
+                for B in (BU, BL)
+                    MB = Matrix(B)
+                    MT = Matrix(T)
+                    for transB in (identity, adjoint, transpose), transT in (identity, adjoint, transpose)
+                        @test transB(B) * transT(T) ≈ transB(MB) * transT(MT)
+                        @test transT(T) * transB(B) ≈ transT(MT) * transB(MB)
+                    end
+                end
+            end
+        end
+    end
+end
+
 end # module TestBidiagonal
diff -pruN 1.3.1+dfsg-1/stdlib/LinearAlgebra/test/bunchkaufman.jl 1.4.0+dfsg-1/stdlib/LinearAlgebra/test/bunchkaufman.jl
--- 1.3.1+dfsg-1/stdlib/LinearAlgebra/test/bunchkaufman.jl	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/stdlib/LinearAlgebra/test/bunchkaufman.jl	2020-03-21 16:36:32.000000000 +0000
@@ -153,6 +153,22 @@ end
 
 @test_throws DomainError logdet(bunchkaufman([-1 -1; -1 1]))
 @test logabsdet(bunchkaufman([8 4; 4 2]; check = false))[1] == -Inf
-@test isa(bunchkaufman(Symmetric(ones(0,0))), BunchKaufman) # 0x0 matrix
+
+@testset "0x0 matrix" begin
+    for ul in (:U, :L)
+        B = bunchkaufman(Symmetric(ones(0, 0), ul))
+        @test isa(B, BunchKaufman)
+        @test B.D == Tridiagonal([], [], [])
+        @test B.P == ones(0, 0)
+        @test B.p == []
+        if ul == :U
+            @test B.U == UnitUpperTriangular(ones(0, 0))
+            @test_throws ArgumentError B.L
+        else
+            @test B.L == UnitLowerTriangular(ones(0, 0))
+            @test_throws ArgumentError B.U
+        end
+    end
+end
 
 end # module TestBunchKaufman
diff -pruN 1.3.1+dfsg-1/stdlib/LinearAlgebra/test/cholesky.jl 1.4.0+dfsg-1/stdlib/LinearAlgebra/test/cholesky.jl
--- 1.3.1+dfsg-1/stdlib/LinearAlgebra/test/cholesky.jl	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/stdlib/LinearAlgebra/test/cholesky.jl	2020-03-21 16:36:32.000000000 +0000
@@ -336,9 +336,10 @@ end
     d = abs.(randn(3)) .+ 0.1
     D = Diagonal(d)
     CD = cholesky(D)
+    CM = cholesky(Matrix(D))
     @test CD isa Cholesky{Float64}
-    @test CD.U isa UpperTriangular{Float64}
-    @test CD.U == Diagonal(.√d)
+    @test CD.U == Diagonal(.√d) == CM.U
+    @test D ≈ CD.L * CD.U
     @test CD.info == 0
 
     # real, failing
@@ -347,13 +348,12 @@ end
     @test Dnpd.info == 2
 
     # complex
-    d = cis.(rand(3) .* 2*π)
-    d .*= abs.(randn(3) .+ 0.1)
-    D = Diagonal(d)
+    D = complex(D)
     CD = cholesky(D)
+    CM = cholesky(Matrix(D))
     @test CD isa Cholesky{Complex{Float64}}
-    @test CD.U isa UpperTriangular{Complex{Float64}}
-    @test CD.U == Diagonal(.√d)
+    @test CD.U == Diagonal(.√d) == CM.U
+    @test D ≈ CD.L * CD.U
     @test CD.info == 0
 
     # complex, failing
@@ -392,4 +392,11 @@ end
 
 end
 
+@testset "issue #33704, casting low-rank CholeskyPivoted to Matrix" begin
+    A = randn(1,8)
+    B = A'A
+    C = cholesky(B, Val(true), check=false)
+    @test B ≈ Matrix(C)
+end
+
 end # module TestCholesky
diff -pruN 1.3.1+dfsg-1/stdlib/LinearAlgebra/test/dense.jl 1.4.0+dfsg-1/stdlib/LinearAlgebra/test/dense.jl
--- 1.3.1+dfsg-1/stdlib/LinearAlgebra/test/dense.jl	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/stdlib/LinearAlgebra/test/dense.jl	2020-03-21 16:36:32.000000000 +0000
@@ -29,6 +29,16 @@ Random.seed!(1234321)
             @test_throws ArgumentError cond(a,3)
         end
     end
+    @testset "Singular matrices" for p in (1, 2, Inf)
+        @test cond(zeros(Int, 2, 2), p) == Inf
+        @test cond(zeros(2, 2), p) == Inf
+        @test cond([0 0; 1 1], p) == Inf
+        @test cond([0. 0.; 1. 1.], p) == Inf
+    end
+    @testset "Issue #33547, condition number of 2x2 matrix" begin
+        M = [1.0 -2.0; -2.0 -1.5]
+        @test cond(M, 1) ≈ 2.227272727272727
+    end
 end
 
 areal = randn(n,n)/2
@@ -903,4 +913,19 @@ end
     @test adjoint(factorize(adjoint(a))) == factorize(a)
 end
 
+@testset "Matrix log issue #32313" begin
+    for A in ([30 20; -50 -30], [10.0im 0; 0 -10.0im], randn(6,6))
+        @test exp(log(A)) ≈ A
+    end
+end
+
+@testset "Matrix log PR #33245" begin
+    # edge case for divided difference
+    A1 = triu(ones(3,3),1) + diagm([1.0, -2eps()-1im, -eps()+0.75im])
+    @test exp(log(A1)) ≈ A1
+    # case where no sqrt is needed (s=0)
+    A2 = [1.01 0.01 0.01; 0 1.01 0.01; 0 0 1.01]
+    @test exp(log(A2)) ≈ A2
+end
+
 end # module TestDense
diff -pruN 1.3.1+dfsg-1/stdlib/LinearAlgebra/test/diagonal.jl 1.4.0+dfsg-1/stdlib/LinearAlgebra/test/diagonal.jl
--- 1.3.1+dfsg-1/stdlib/LinearAlgebra/test/diagonal.jl	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/stdlib/LinearAlgebra/test/diagonal.jl	2020-03-21 16:36:32.000000000 +0000
@@ -115,6 +115,14 @@ Random.seed!(1)
                 @test ldiv!(D, copy(U)) ≈ DM\U atol=atol_three
                 @test ldiv!(transpose(D), copy(U)) ≈ DM\U atol=atol_three
                 @test ldiv!(adjoint(conj(D)), copy(U)) ≈ DM\U atol=atol_three
+
+                @test ldiv!(zero(v), D, copy(v)) ≈ DM\v atol=atol_two
+                @test ldiv!(zero(v), transpose(D), copy(v)) ≈ DM\v atol=atol_two
+                @test ldiv!(zero(v), adjoint(conj(D)), copy(v)) ≈ DM\v atol=atol_two
+                @test ldiv!(zero(U), D, copy(U)) ≈ DM\U atol=atol_three
+                @test ldiv!(zero(U), transpose(D), copy(U)) ≈ DM\U atol=atol_three
+                @test ldiv!(zero(U), adjoint(conj(D)), copy(U)) ≈ DM\U atol=atol_three
+
                 Uc = copy(U')
                 target = rmul!(Uc, Diagonal(inv.(D.diag)))
                 @test rdiv!(Uc, D) ≈ target atol=atol_three
@@ -322,10 +330,15 @@ Random.seed!(1)
         @test(transpose(D) * vv == D * vv)
     end
 
-    #logdet
+    # logdet and logabsdet
     if relty <: Real
-        ld=convert(Vector{relty},rand(n))
-        @test logdet(Diagonal(ld)) ≈ logdet(Matrix(Diagonal(ld)))
+        lD = Diagonal(convert(Vector{relty}, rand(n)))
+        lM = Matrix(lD)
+        @test logdet(lD) ≈ logdet(lM)
+        d1, s1 = @inferred logabsdet(lD)
+        d2, s2 = logabsdet(lM)
+        @test d1 ≈ d2
+        @test s1 == s2
     end
 
     @testset "similar" begin
@@ -439,14 +452,54 @@ end
 @test Matrix(1.0I, 5, 5) \ Diagonal(fill(1.,5)) == Matrix(I, 5, 5)
 
 @testset "Triangular and Diagonal" begin
-    for T in (LowerTriangular(randn(5,5)), LinearAlgebra.UnitLowerTriangular(randn(5,5)))
-        D = Diagonal(randn(5))
-        @test T*D   == Array(T)*Array(D)
-        @test T'D   == Array(T)'*Array(D)
-        @test transpose(T)*D  == transpose(Array(T))*Array(D)
-        @test D*T'  == Array(D)*Array(T)'
-        @test D*transpose(T) == Array(D)*transpose(Array(T))
-        @test D*T   == Array(D)*Array(T)
+    function _test_matrix(type)
+        if type == Int
+            return rand(1:9, 5, 5)
+        else
+            return randn(type, 5, 5)
+        end
+    end
+    types = (Float64, Int, ComplexF64)
+    for ta in types
+        D = Diagonal(_test_matrix(ta))
+        for tb in types
+            B = _test_matrix(tb)
+            Tmats = (LowerTriangular(B), UnitLowerTriangular(B), UpperTriangular(B), UnitUpperTriangular(B))
+            restypes = (LowerTriangular, LowerTriangular, UpperTriangular, UpperTriangular)
+            for (T, rtype) in zip(Tmats, restypes)
+                adjtype = (rtype == LowerTriangular) ? UpperTriangular : LowerTriangular
+
+                # Triangular * Diagonal
+                R = T * D
+                @test R ≈ Array(T) * Array(D)
+                @test isa(R, rtype)
+
+                # Diagonal * Triangular
+                R = D * T
+                @test R ≈ Array(D) * Array(T)
+                @test isa(R, rtype)
+
+                # Adjoint of Triangular * Diagonal
+                R = T' * D
+                @test R ≈ Array(T)' * Array(D)
+                @test isa(R, adjtype)
+
+                # Diagonal * Adjoint of Triangular
+                R = D * T'
+                @test R ≈ Array(D) * Array(T)'
+                @test isa(R, adjtype)
+
+                # Transpose of Triangular * Diagonal
+                R = transpose(T) * D
+                @test R ≈ transpose(Array(T)) * Array(D)
+                @test isa(R, adjtype)
+
+                # Diagonal * Transpose of Triangular
+                R = D * transpose(T)
+                @test R ≈ Array(D) * transpose(Array(T))
+                @test isa(R, adjtype)
+            end
+        end
     end
 end
 
@@ -595,4 +648,12 @@ end
     @test sum(Diagonal([1,2,3])) == 6
 end
 
+@testset "logabsdet for generic eltype" begin
+    d = Any[1, -2.0, -3.0]
+    D = Diagonal(d)
+    d1, s1 = logabsdet(D)
+    @test d1 ≈ sum(log ∘ abs, d)
+    @test s1 == prod(sign, d)
+end
+
 end # module TestDiagonal
diff -pruN 1.3.1+dfsg-1/stdlib/LinearAlgebra/test/eigen.jl 1.4.0+dfsg-1/stdlib/LinearAlgebra/test/eigen.jl
--- 1.3.1+dfsg-1/stdlib/LinearAlgebra/test/eigen.jl	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/stdlib/LinearAlgebra/test/eigen.jl	2020-03-21 16:36:32.000000000 +0000
@@ -129,7 +129,7 @@ end
     valsstring = sprint((t, s) -> show(t, "text/plain", s), e.values)
     vecsstring = sprint((t, s) -> show(t, "text/plain", s), e.vectors)
     factstring = sprint((t, s) -> show(t, "text/plain", s), e)
-    @test factstring == "$(summary(e))\neigenvalues:\n$valsstring\neigenvectors:\n$vecsstring"
+    @test factstring == "$(summary(e))\nvalues:\n$valsstring\nvectors:\n$vecsstring"
 end
 
 @testset "eigen of an Adjoint" begin
diff -pruN 1.3.1+dfsg-1/stdlib/LinearAlgebra/test/generic.jl 1.4.0+dfsg-1/stdlib/LinearAlgebra/test/generic.jl
--- 1.3.1+dfsg-1/stdlib/LinearAlgebra/test/generic.jl	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/stdlib/LinearAlgebra/test/generic.jl	2020-03-21 16:36:32.000000000 +0000
@@ -119,6 +119,7 @@ end
         @testset "Scaling with rdiv! and ldiv!" begin
             @test rdiv!(copy(a), 5.) == a/5
             @test ldiv!(5., copy(a)) == a/5
+            @test ldiv!(zero(a), 5., copy(a)) == a/5
         end
 
         @testset "Scaling with 3-argument mul!" begin
@@ -409,4 +410,32 @@ end
     @test all(!isnan, lmul!(false, Any[NaN]))
 end
 
+@testset "generalized dot #32739" begin
+    for elty in (Int, Float32, Float64, BigFloat, Complex{Float32}, Complex{Float64}, Complex{BigFloat})
+        n = 10
+        if elty <: Int
+            A = rand(-n:n, n, n)
+            x = rand(-n:n, n)
+            y = rand(-n:n, n)
+        elseif elty <: Real
+            A = convert(Matrix{elty}, randn(n,n))
+            x = rand(elty, n)
+            y = rand(elty, n)
+        else
+            A = convert(Matrix{elty}, complex.(randn(n,n), randn(n,n)))
+            x = rand(elty, n)
+            y = rand(elty, n)
+        end
+        @test dot(x, A, y) ≈ dot(A'x, y) ≈ *(x', A, y) ≈ (x'A)*y
+        @test dot(x, A', y) ≈ dot(A*x, y) ≈ *(x', A', y) ≈ (x'A')*y
+        elty <: Real && @test dot(x, transpose(A), y) ≈ dot(x, transpose(A)*y) ≈ *(x', transpose(A), y) ≈ (x'*transpose(A))*y
+        B = reshape([A], 1, 1)
+        x = [x]
+        y = [y]
+        @test dot(x, B, y) ≈ dot(B'x, y)
+        @test dot(x, B', y) ≈ dot(B*x, y)
+        elty <: Real && @test dot(x, transpose(B), y) ≈ dot(x, transpose(B)*y)
+    end
+end
+
 end # module TestGeneric
diff -pruN 1.3.1+dfsg-1/stdlib/LinearAlgebra/test/hessenberg.jl 1.4.0+dfsg-1/stdlib/LinearAlgebra/test/hessenberg.jl
--- 1.3.1+dfsg-1/stdlib/LinearAlgebra/test/hessenberg.jl	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/stdlib/LinearAlgebra/test/hessenberg.jl	2020-03-21 16:36:32.000000000 +0000
@@ -88,6 +88,11 @@ let n = 10
             @test det(H + shift*I) ≈ det(A + shift*I)
             @test logabsdet(H + shift*I) ≅ logabsdet(A + shift*I)
         end
+
+        HM = Matrix(h)
+        @test dot(b, h, b) ≈ dot(h'b, b) ≈ dot(b, HM, b) ≈ dot(HM'b, b)
+        c = b .+ 1
+        @test dot(b, h, c) ≈ dot(h'b, c) ≈ dot(b, HM, c) ≈ dot(HM'b, c)
     end
 end
 
diff -pruN 1.3.1+dfsg-1/stdlib/LinearAlgebra/test/ldlt.jl 1.4.0+dfsg-1/stdlib/LinearAlgebra/test/ldlt.jl
--- 1.3.1+dfsg-1/stdlib/LinearAlgebra/test/ldlt.jl	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/stdlib/LinearAlgebra/test/ldlt.jl	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1,18 @@
+# This file is a part of Julia. License is MIT: https://julialang.org/license
+
+module TestLDLT
+
+using Test, LinearAlgebra, Random
+
+Random.seed!(123)
+
+@testset "REPL printing of LDLT" begin
+    S = SymTridiagonal(randn(5), randn(4))
+    F = ldlt(S)
+    ldltstring = sprint((t, s) -> show(t, "text/plain", s), F)
+    lstring = sprint((t, s) -> show(t, "text/plain", s), F.L)
+    dstring = sprint((t, s) -> show(t, "text/plain", s), F.D)
+    @test ldltstring == "$(summary(F))\nL factor:\n$lstring\nD factor:\n$dstring"
+end
+
+end # module TestLDLT
diff -pruN 1.3.1+dfsg-1/stdlib/LinearAlgebra/test/lq.jl 1.4.0+dfsg-1/stdlib/LinearAlgebra/test/lq.jl
--- 1.3.1+dfsg-1/stdlib/LinearAlgebra/test/lq.jl	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/stdlib/LinearAlgebra/test/lq.jl	2020-03-21 16:36:32.000000000 +0000
@@ -191,4 +191,19 @@ end
     @test_throws DimensionMismatch adjoint(C) * adjoint(implicitQ)
 end
 
+@testset "det(Q::LQPackedQ)" begin
+    @testset for n in 1:3, m in 1:3
+        @testset "real" begin
+            _, Q = lq(randn(n, m))
+            @test det(Q) ≈ det(collect(Q))
+            @test abs(det(Q)) ≈ 1
+        end
+        @testset "complex" begin
+            _, Q = lq(randn(ComplexF64, n, m))
+            @test det(Q) ≈ det(collect(Q))
+            @test abs(det(Q)) ≈ 1
+        end
+    end
+end
+
 end # module TestLQ
diff -pruN 1.3.1+dfsg-1/stdlib/LinearAlgebra/test/lu.jl 1.4.0+dfsg-1/stdlib/LinearAlgebra/test/lu.jl
--- 1.3.1+dfsg-1/stdlib/LinearAlgebra/test/lu.jl	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/stdlib/LinearAlgebra/test/lu.jl	2020-03-21 16:36:32.000000000 +0000
@@ -207,10 +207,10 @@ end
     @test_throws SingularException lu!(copy(A); check = true)
     @test !issuccess(lu(A; check = false))
     @test !issuccess(lu!(copy(A); check = false))
-    @test_throws SingularException lu(A, Val(false))
-    @test_throws SingularException lu!(copy(A), Val(false))
-    @test_throws SingularException lu(A, Val(false); check = true)
-    @test_throws SingularException lu!(copy(A), Val(false); check = true)
+    @test_throws ZeroPivotException lu(A, Val(false))
+    @test_throws ZeroPivotException lu!(copy(A), Val(false))
+    @test_throws ZeroPivotException lu(A, Val(false); check = true)
+    @test_throws ZeroPivotException lu!(copy(A), Val(false); check = true)
     @test !issuccess(lu(A, Val(false); check = false))
     @test !issuccess(lu!(copy(A), Val(false); check = false))
     F = lu(A; check = false)
@@ -265,10 +265,6 @@ end
     @test_throws DomainError logdet([1 1; 1 -1])
 end
 
-@testset "Issue 21453" begin
-    @test_throws ArgumentError LinearAlgebra._cond1Inf(lu(randn(5,5)), 2, 2.0)
-end
-
 @testset "REPL printing" begin
         bf = IOBuffer()
         show(bf, "text/plain", lu(Matrix(I, 4, 4)))
@@ -332,4 +328,13 @@ end
     @test (transpose(A) / F') * B ≈ transpose(A)
 end
 
+@testset "0x0 matrix" begin
+    A = ones(0, 0)
+    F = lu(A)
+    @test F.U == ones(0, 0)
+    @test F.L == ones(0, 0)
+    @test F.P == ones(0, 0)
+    @test F.p == []
+end
+
 end # module TestLU
diff -pruN 1.3.1+dfsg-1/stdlib/LinearAlgebra/test/matmul.jl 1.4.0+dfsg-1/stdlib/LinearAlgebra/test/matmul.jl
--- 1.3.1+dfsg-1/stdlib/LinearAlgebra/test/matmul.jl	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/stdlib/LinearAlgebra/test/matmul.jl	2020-03-21 16:36:32.000000000 +0000
@@ -178,6 +178,18 @@ end
     end
 end
 
+@testset "mixed Blas-non-Blas matmul" begin
+    AA = rand(-10:10,6,6)
+    BB = rand(Float64,6,6)
+    CC = zeros(Float64,6,6)
+    for A in (copy(AA), view(AA, 1:6, 1:6)), B in (copy(BB), view(BB, 1:6, 1:6)), C in (copy(CC), view(CC, 1:6, 1:6))
+        @test LinearAlgebra.mul!(C, A, B) == A*B
+        @test LinearAlgebra.mul!(C, transpose(A), transpose(B)) == transpose(A)*transpose(B)
+        @test LinearAlgebra.mul!(C, A, adjoint(B)) == A*transpose(B)
+        @test LinearAlgebra.mul!(C, adjoint(A), B) == transpose(A)*B
+    end
+end
+
 @testset "matrix algebra with subarrays of floats (stride != 1)" begin
     A = reshape(map(Float64,1:20),5,4)
     Aref = A[1:2:end,1:2:end]
@@ -597,4 +609,19 @@ end
     @test D ≈ C
 end
 
+@testset "multiplication of empty matrices without calling zero" begin
+    r, c = rand(0:9, 2)
+    A = collect(Number, rand(r, c))
+    B = rand(c, 0)
+    C = A * B
+    @test size(C) == (r, 0)
+    @test_throws MethodError zero(eltype(C))
+end
+
+@testset "Issue #33873: genmatmul! with empty operands" begin
+    @test Matrix{Any}(undef, 0, 2) * Matrix{Any}(undef, 2, 3) == Matrix{Any}(undef, 0, 3)
+    @test_throws MethodError Matrix{Any}(undef, 2, 0) * Matrix{Any}(undef, 0, 3)
+    @test Matrix{Int}(undef, 2, 0) * Matrix{Int}(undef, 0, 3) == zeros(Int, 2, 3)
+end
+
 end # module TestMatmul
diff -pruN 1.3.1+dfsg-1/stdlib/LinearAlgebra/test/qr.jl 1.4.0+dfsg-1/stdlib/LinearAlgebra/test/qr.jl
--- 1.3.1+dfsg-1/stdlib/LinearAlgebra/test/qr.jl	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/stdlib/LinearAlgebra/test/qr.jl	2020-03-21 16:36:32.000000000 +0000
@@ -246,4 +246,26 @@ end
     @test c0 == c
 end
 
+@testset "det(Q::Union{QRCompactWYQ, QRPackedQ})" begin
+    # 40 is the number larger than the default block size 36 of QRCompactWY
+    @testset for n in [1:3; 40], m in [1:3; 40], pivot in [false, true]
+        @testset "real" begin
+            @testset for k in 0:min(n, m, 5)
+                A = cat(Array(I(k)), randn(n - k, m - k); dims=(1, 2))
+                Q, = qr(A, Val(pivot))
+                @test det(Q) ≈ det(collect(Q))
+                @test abs(det(Q)) ≈ 1
+            end
+        end
+        @testset "complex" begin
+            @testset for k in 0:min(n, m, 5)
+                A = cat(Array(I(k)), randn(ComplexF64, n - k, m - k); dims=(1, 2))
+                Q, = qr(A, Val(pivot))
+                @test det(Q) ≈ det(collect(Q))
+                @test abs(det(Q)) ≈ 1
+            end
+        end
+    end
+end
+
 end # module TestQR
diff -pruN 1.3.1+dfsg-1/stdlib/LinearAlgebra/test/structuredbroadcast.jl 1.4.0+dfsg-1/stdlib/LinearAlgebra/test/structuredbroadcast.jl
--- 1.3.1+dfsg-1/stdlib/LinearAlgebra/test/structuredbroadcast.jl	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/stdlib/LinearAlgebra/test/structuredbroadcast.jl	2020-03-21 16:36:32.000000000 +0000
@@ -14,7 +14,8 @@ using Test, LinearAlgebra
     T = Tridiagonal(rand(N - 1), rand(N), rand(N - 1))
     U = UpperTriangular(rand(N,N))
     L = LowerTriangular(rand(N,N))
-    structuredarrays = (D, B, T, U, L)
+    M = Matrix(rand(N,N))
+    structuredarrays = (D, B, T, U, L, M)
     fstructuredarrays = map(Array, structuredarrays)
     for (X, fX) in zip(structuredarrays, fstructuredarrays)
         @test (Q = broadcast(sin, X); typeof(Q) == typeof(X) && Q == broadcast(sin, fX))
@@ -56,6 +57,7 @@ end
     T = Tridiagonal(rand(N - 1), rand(N), rand(N - 1))
     ◣ = LowerTriangular(rand(N,N))
     ◥ = UpperTriangular(rand(N,N))
+    M = Matrix(rand(N,N))
 
     @test broadcast!(sin, copy(D), D) == Diagonal(sin.(D))
     @test broadcast!(sin, copy(Bu), Bu) == Bidiagonal(sin.(Bu), :U)
@@ -63,12 +65,14 @@ end
     @test broadcast!(sin, copy(T), T) == Tridiagonal(sin.(T))
     @test broadcast!(sin, copy(◣), ◣) == LowerTriangular(sin.(◣))
     @test broadcast!(sin, copy(◥), ◥) == UpperTriangular(sin.(◥))
+    @test broadcast!(sin, copy(M), M) == Matrix(sin.(M))
     @test broadcast!(*, copy(D), D, A) == Diagonal(broadcast(*, D, A))
     @test broadcast!(*, copy(Bu), Bu, A) == Bidiagonal(broadcast(*, Bu, A), :U)
     @test broadcast!(*, copy(Bl), Bl, A) == Bidiagonal(broadcast(*, Bl, A), :L)
     @test broadcast!(*, copy(T), T, A) == Tridiagonal(broadcast(*, T, A))
     @test broadcast!(*, copy(◣), ◣, A) == LowerTriangular(broadcast(*, ◣, A))
     @test broadcast!(*, copy(◥), ◥, A) == UpperTriangular(broadcast(*, ◥, A))
+    @test broadcast!(*, copy(M), M, A) == Matrix(broadcast(*, M, A))
 
     @test_throws ArgumentError broadcast!(cos, copy(D), D) == Diagonal(sin.(D))
     @test_throws ArgumentError broadcast!(cos, copy(Bu), Bu) == Bidiagonal(sin.(Bu), :U)
@@ -93,7 +97,8 @@ end
     T = Tridiagonal(rand(N - 1), rand(N), rand(N - 1))
     U = UpperTriangular(rand(N,N))
     L = LowerTriangular(rand(N,N))
-    structuredarrays = (D, B, T, U, L)
+    M = Matrix(rand(N,N))
+    structuredarrays = (M, D, B, T, U, L)
     fstructuredarrays = map(Array, structuredarrays)
     for (X, fX) in zip(structuredarrays, fstructuredarrays)
         @test (Q = map(sin, X); typeof(Q) == typeof(X) && Q == map(sin, fX))
@@ -123,4 +128,22 @@ end
     end
 end
 
+@testset "Issue #33397" begin
+    N = 5
+    U = UpperTriangular(rand(N, N))
+    L = LowerTriangular(rand(N, N))
+    UnitU = UnitUpperTriangular(rand(N, N))
+    UnitL = UnitLowerTriangular(rand(N, N))
+    D = Diagonal(rand(N))
+    @test U .+ L .+ D == U + L + D
+    @test L .+ U .+ D == L + U + D
+    @test UnitU .+ UnitL .+ D == UnitU + UnitL + D
+    @test UnitL .+ UnitU .+ D == UnitL + UnitU + D
+    @test U .+ UnitL .+ D == U + UnitL + D
+    @test L .+ UnitU .+ D == L + UnitU + D
+    @test L .+ U .+ L .+ U == L + U + L + U
+    @test U .+ L .+ U .+ L == U + L + U + L
+    @test L .+ UnitL .+ UnitU .+ U .+ D == L + UnitL + UnitU + U + D
+    @test L .+ U .+ D .+ D .+ D .+ D == L + U + D + D + D + D
+end
 end
diff -pruN 1.3.1+dfsg-1/stdlib/LinearAlgebra/test/symmetric.jl 1.4.0+dfsg-1/stdlib/LinearAlgebra/test/symmetric.jl
--- 1.3.1+dfsg-1/stdlib/LinearAlgebra/test/symmetric.jl	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/stdlib/LinearAlgebra/test/symmetric.jl	2020-03-21 16:36:32.000000000 +0000
@@ -365,6 +365,52 @@ end
                 @test Symmetric(asym)\b  ≈ asym\b
             end
         end
+        @testset "generalized dot product" begin
+            for uplo in (:U, :L)
+                @test dot(x, Hermitian(aherm, uplo), y) ≈ dot(x, Hermitian(aherm, uplo)*y) ≈ dot(x, Matrix(Hermitian(aherm, uplo)), y)
+                @test dot(x, Hermitian(aherm, uplo), x) ≈ dot(x, Hermitian(aherm, uplo)*x) ≈ dot(x, Matrix(Hermitian(aherm, uplo)), x)
+            end
+            if eltya <: Real
+                for uplo in (:U, :L)
+                    @test dot(x, Symmetric(aherm, uplo), y) ≈ dot(x, Symmetric(aherm, uplo)*y) ≈ dot(x, Matrix(Symmetric(aherm, uplo)), y)
+                    @test dot(x, Symmetric(aherm, uplo), x) ≈ dot(x, Symmetric(aherm, uplo)*x) ≈ dot(x, Matrix(Symmetric(aherm, uplo)), x)
+                end
+            end
+        end
+
+        @testset "dot product of symmetric and Hermitian matrices" begin
+            for mtype in (Symmetric, Hermitian)
+                symau = mtype(a, :U)
+                symal = mtype(a, :L)
+                msymau = Matrix(symau)
+                msymal = Matrix(symal)
+                @test_throws DimensionMismatch dot(symau, mtype(zeros(eltya, n-1, n-1)))
+                for eltyc in (Float32, Float64, ComplexF32, ComplexF64, BigFloat, Int)
+                    creal = randn(n, n)/2
+                    cimag = randn(n, n)/2
+                    c = eltya == Int ? rand(1:7, n, n) : convert(Matrix{eltya}, eltya <: Complex ? complex.(creal, cimag) : creal)
+                    symcu = mtype(c, :U)
+                    symcl = mtype(c, :L)
+                    msymcu = Matrix(symcu)
+                    msymcl = Matrix(symcl)
+                    @test dot(symau, symcu) ≈ dot(msymau, msymcu)
+                    @test dot(symau, symcl) ≈ dot(msymau, msymcl)
+                    @test dot(symal, symcu) ≈ dot(msymal, msymcu)
+                    @test dot(symal, symcl) ≈ dot(msymal, msymcl)
+                end
+
+                # block matrices
+                blockm = [eltya == Int ? rand(1:7, 3, 3) : convert(Matrix{eltya}, eltya <: Complex ? complex.(randn(3, 3)/2, randn(3, 3)/2) : randn(3, 3)/2) for _ in 1:3, _ in 1:3]
+                symblockmu = mtype(blockm, :U)
+                symblockml = mtype(blockm, :L)
+                msymblockmu = Matrix(symblockmu)
+                msymblockml = Matrix(symblockml)
+                @test dot(symblockmu, symblockmu) ≈ dot(msymblockmu, msymblockmu)
+                @test dot(symblockmu, symblockml) ≈ dot(msymblockmu, msymblockml)
+                @test dot(symblockml, symblockmu) ≈ dot(msymblockml, msymblockmu)
+                @test dot(symblockml, symblockml) ≈ dot(msymblockml, msymblockml)
+            end
+        end
     end
 end
 
@@ -598,6 +644,15 @@ end
     @test Symmetric(B) == Symmetric(Matrix(B))
 end
 
+@testset "issue #32079: det for singular Symmetric matrix" begin
+    A = ones(Float64, 3, 3)
+    @test det(Symmetric(A))::Float64 == det(A) == 0.0
+    @test det(Hermitian(A))::Float64 == det(A) == 0.0
+    A = ones(ComplexF64, 3, 3)
+    @test det(Symmetric(A))::ComplexF64 == det(A) == 0.0
+    @test det(Hermitian(A))::Float64 == det(A) == 0.0
+end
+
 @testset "symmetric()/hermitian() for Numbers" begin
     @test LinearAlgebra.symmetric(1, :U) == 1
     @test LinearAlgebra.symmetric_type(Int) == Int
diff -pruN 1.3.1+dfsg-1/stdlib/LinearAlgebra/test/triangular.jl 1.4.0+dfsg-1/stdlib/LinearAlgebra/test/triangular.jl
--- 1.3.1+dfsg-1/stdlib/LinearAlgebra/test/triangular.jl	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/stdlib/LinearAlgebra/test/triangular.jl	2020-03-21 16:36:32.000000000 +0000
@@ -236,6 +236,17 @@ for elty1 in (Float32, Float64, BigFloat
             end
         end
 
+        # generalized dot
+        for eltyb in (Float32, Float64, BigFloat, ComplexF32, ComplexF64, Complex{BigFloat})
+            b1 = convert(Vector{eltyb}, (elty1 <: Complex ? real(A1) : A1)*fill(1., n))
+            b2 = convert(Vector{eltyb}, (elty1 <: Complex ? real(A1) : A1)*randn(n))
+            if elty1 in (BigFloat, Complex{BigFloat}) || eltyb in (BigFloat, Complex{BigFloat})
+                @test dot(b1, A1, b2) ≈ dot(A1'b1, b2)  atol=sqrt(max(eps(real(float(one(elty1)))),eps(real(float(one(eltyb))))))*n*n
+            else
+                @test dot(b1, A1, b2) ≈ dot(A1'b1, b2)  atol=sqrt(max(eps(real(float(one(elty1)))),eps(real(float(one(eltyb))))))*n*n
+            end
+        end
+
         # Binary operations
         @test A1*0.5 == Matrix(A1)*0.5
         @test 0.5*A1 == 0.5*Matrix(A1)
diff -pruN 1.3.1+dfsg-1/stdlib/LinearAlgebra/test/tridiag.jl 1.4.0+dfsg-1/stdlib/LinearAlgebra/test/tridiag.jl
--- 1.3.1+dfsg-1/stdlib/LinearAlgebra/test/tridiag.jl	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/stdlib/LinearAlgebra/test/tridiag.jl	2020-03-21 16:36:32.000000000 +0000
@@ -390,6 +390,11 @@ end
                 end
             end
         end
+        @testset "generalized dot" begin
+            x = fill(convert(elty, 1), n)
+            y = fill(convert(elty, 1), n)
+            @test dot(x, A, y) ≈ dot(A'x, y)
+        end
     end
 end
 
diff -pruN 1.3.1+dfsg-1/stdlib/LinearAlgebra/test/uniformscaling.jl 1.4.0+dfsg-1/stdlib/LinearAlgebra/test/uniformscaling.jl
--- 1.3.1+dfsg-1/stdlib/LinearAlgebra/test/uniformscaling.jl	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/stdlib/LinearAlgebra/test/uniformscaling.jl	2020-03-21 16:36:32.000000000 +0000
@@ -4,6 +4,10 @@ module TestUniformscaling
 
 using Test, LinearAlgebra, Random, SparseArrays
 
+const BASE_TEST_PATH = joinpath(Sys.BINDIR, "..", "share", "julia", "test")
+isdefined(Main, :Quaternions) || @eval Main include(joinpath($(BASE_TEST_PATH), "testhelpers", "Quaternions.jl"))
+using .Main.Quaternions
+
 Random.seed!(123)
 
 @testset "basic functions" begin
@@ -62,6 +66,15 @@ end
     @test UniformScaling(α)./α == UniformScaling(1.0)
     @test α * UniformScaling(1.0) == UniformScaling(1.0) * α
     @test UniformScaling(α)/α == UniformScaling(1.0)
+
+    β = rand()
+    @test (α*I)^2    == UniformScaling(α^2)
+    @test (α*I)^(-2) == UniformScaling(α^(-2))
+    @test (α*I)^(.5) == UniformScaling(α^(.5))
+    @test (α*I)^β    == UniformScaling(α^β)
+
+    @test (α * I) .^ 2 == UniformScaling(α^2)
+    @test (α * I) .^ β == UniformScaling(α^β)
 end
 
 @testset "det and logdet" begin
@@ -313,6 +326,7 @@ end
     @test lmul!(J, copyto!(C, A)) == target_mul
     @test rmul!(copyto!(C, A), J) == target_mul
     @test ldiv!(J, copyto!(C, A)) == target_div
+    @test ldiv!(C, J, A) == target_div
     @test rdiv!(copyto!(C, A), J) == target_div
 
     A = randn(4, 3)
@@ -330,4 +344,48 @@ end
     @test I(3) == [1 0 0; 0 1 0; 0 0 1]
 end
 
+@testset "generalized dot" begin
+    x = rand(-10:10, 3)
+    y = rand(-10:10, 3)
+    λ = rand(-10:10)
+    J = UniformScaling(λ)
+    @test dot(x, J, y) == λ*dot(x, y)
+    λ = Quaternion(0.44567, 0.755871, 0.882548, 0.423612)
+    x, y = Quaternion(rand(4)...), Quaternion(rand(4)...)
+    @test dot([x], λ*I, [y]) ≈ dot(x, λ, y) ≈ dot(x, λ*y)
+end
+
+@testset "Factorization solutions" begin
+    J = complex(randn(),randn()) * I
+    qrp = A -> qr(A, Val(true))
+
+    # thin matrices
+    X = randn(3,2)
+    Z = pinv(X)
+    for fac in (qr,qrp,svd)
+        F = fac(X)
+        @test @inferred(F \ I) ≈ Z
+        @test @inferred(F \ J) ≈ Z * J
+    end
+
+    # square matrices
+    X = randn(3,3)
+    X = X'X + rand()I # make positive definite for cholesky
+    Z = pinv(X)
+    for fac in (bunchkaufman,cholesky,lu,qr,qrp,svd)
+        F = fac(X)
+        @test @inferred(F \ I) ≈ Z
+        @test @inferred(F \ J) ≈ Z * J
+    end
+
+    # fat matrices - only rank-revealing variants
+    X = randn(2,3)
+    Z = pinv(X)
+    for fac in (qrp,svd)
+        F = fac(X)
+        @test @inferred(F \ I) ≈ Z
+        @test @inferred(F \ J) ≈ Z * J
+    end
+end
+
 end # module TestUniformscaling
diff -pruN 1.3.1+dfsg-1/stdlib/Logging/docs/src/index.md 1.4.0+dfsg-1/stdlib/Logging/docs/src/index.md
--- 1.3.1+dfsg-1/stdlib/Logging/docs/src/index.md	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/stdlib/Logging/docs/src/index.md	2020-03-21 16:36:32.000000000 +0000
@@ -58,13 +58,18 @@ automatically extracted. Let's examine t
 * The *log level* is a broad category for the message that is used for early
   filtering. There are several standard levels of type [`LogLevel`](@ref);
   user-defined levels are also possible.
-  - Use `Debug` for verbose information that could be useful when debugging an
-    application or module. These events are disabled by default.
-  - Use `Info` to inform the user about the normal operation of the program.
-  - Use `Warn` when a potential problem is detected.
-  - Use `Error` to report errors where the code has enough context to recover
-    and continue.  (When the code doesn't have enough context, an exception or
-    early return is more appropriate.)
+  Each is distinct in purpose:
+  - `Debug` is information intended for the developer of the program.
+  These events are disabled by default.
+  - `Info` is for general information to the user.
+  Think of it as an alternative to using `println` directly.
+  - `Warn` means something is wrong and action is likely required
+  but that for now the program is still working.
+  - `Error` means something is wrong and it is unlikely to be recovered,
+  at least by this part of the code.
+  Often this log-level is unneeded as throwing an exception can convey
+  all the required information.
+
 * The *message*  is an object describing the event. By convention
   `AbstractString`s passed as messages are assumed to be in markdown format.
   Other types will be displayed using `show(io,mime,obj)` according to the
@@ -193,6 +198,24 @@ Similarly, the environment variable can
 modules, such as `Pkg`, or module roots (see [`Base.moduleroot`](@ref)). To
 enable all debug logging, use the special value `all`.
 
+To turn debug logging on from the REPL, set `ENV["JULIA_DEBUG"]` to the
+name of the module of interest. Functions defined in the REPL belong to
+module `Main`; logging for them can be enabled like this:
+```julia-repl
+julia> foo() = @debug "foo"
+foo (generic function with 1 method)
+
+julia> foo()
+
+julia> ENV["JULIA_DEBUG"] = Main
+Main
+
+julia> foo()
+┌ Debug: foo
+└ @ Main REPL[1]:1
+
+```
+
 ## Writing log events to a file
 
 Sometimes it can be useful to write log events to a file. Here is an example
diff -pruN 1.3.1+dfsg-1/stdlib/Logging/test/runtests.jl 1.4.0+dfsg-1/stdlib/Logging/test/runtests.jl
--- 1.3.1+dfsg-1/stdlib/Logging/test/runtests.jl	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/stdlib/Logging/test/runtests.jl	2020-03-21 16:36:32.000000000 +0000
@@ -213,7 +213,7 @@ end
         │     1.00001  1.00001  1.00001  1.00001  …  1.00001  1.00001  1.00001
         │     1.00001  1.00001  1.00001  1.00001     1.00001  1.00001  1.00001
         │     1.00001  1.00001  1.00001  1.00001     1.00001  1.00001  1.00001
-        │     ⋮                                   ⋱                           EOL
+        │     ⋮                                   ⋱                    EOL
         │     1.00001  1.00001  1.00001  1.00001     1.00001  1.00001  1.00001
         │     1.00001  1.00001  1.00001  1.00001     1.00001  1.00001  1.00001
         │   b =
@@ -221,7 +221,7 @@ end
         │     2.00002  2.00002  2.00002  2.00002  …  2.00002  2.00002  2.00002
         │     2.00002  2.00002  2.00002  2.00002     2.00002  2.00002  2.00002
         │     2.00002  2.00002  2.00002  2.00002     2.00002  2.00002  2.00002
-        │     ⋮                                   ⋱                           EOL
+        │     ⋮                                   ⋱                    EOL
         │     2.00002  2.00002  2.00002  2.00002     2.00002  2.00002  2.00002
         │     2.00002  2.00002  2.00002  2.00002     2.00002  2.00002  2.00002
         └ SUFFIX
diff -pruN 1.3.1+dfsg-1/stdlib/Makefile 1.4.0+dfsg-1/stdlib/Makefile
--- 1.3.1+dfsg-1/stdlib/Makefile	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/stdlib/Makefile	2020-03-21 16:36:32.000000000 +0000
@@ -17,10 +17,12 @@ $(build_datarootdir)/julia/stdlib/$(VERS
 STDLIBS = Base64 CRC32c Dates DelimitedFiles Distributed FileWatching \
           Future InteractiveUtils Libdl LibGit2 LinearAlgebra Logging \
           Markdown Mmap Printf Profile Random REPL Serialization SHA \
-          SharedArrays Sockets SparseArrays Statistics SuiteSparse Test Unicode UUIDs
-STDLIBS_EXT = Pkg
+          SharedArrays Sockets SparseArrays SuiteSparse Test Unicode UUIDs
+STDLIBS_EXT = Pkg Statistics
 PKG_GIT_URL := git://github.com/JuliaLang/Pkg.jl.git
 PKG_TAR_URL = https://api.github.com/repos/JuliaLang/Pkg.jl/tarball/$1
+STATISTICS_GIT_URL := git://github.com/JuliaLang/Statistics.jl.git
+STATISTICS_TAR_URL = https://api.github.com/repos/JuliaLang/Statistics.jl/tarball/$1
 
 $(foreach module, $(STDLIBS_EXT), $(eval $(call stdlib-external,$(module),$(shell echo $(module) | tr a-z A-Z))))
 
@@ -33,3 +35,6 @@ getall get: $(addprefix get-, $(STDLIBS_
 install: $(addprefix install-, $(STDLIBS_EXT)) $(STDLIBS_LINK_TARGETS)
 clean: $(addprefix clean-, $(STDLIBS_EXT)) $(CLEAN_TARGETS)
 distclean: $(addprefix distclean-, $(STDLIBS_EXT)) clean
+
+DEP_LIBS_STAGED := $(STDLIBS_EXT)
+include $(JULIAHOME)/deps/tools/uninstallers.mk
diff -pruN 1.3.1+dfsg-1/stdlib/Markdown/docs/src/index.md 1.4.0+dfsg-1/stdlib/Markdown/docs/src/index.md
--- 1.3.1+dfsg-1/stdlib/Markdown/docs/src/index.md	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/stdlib/Markdown/docs/src/index.md	2020-03-21 16:36:32.000000000 +0000
@@ -1,4 +1,4 @@
-# Markdown
+# [Markdown](@id markdown_stdlib)
 
 This section describes Julia's markdown syntax, which is enabled by the
 Markdown standard library. The following Markdown elements are supported:
diff -pruN 1.3.1+dfsg-1/stdlib/Markdown/src/GitHub/table.jl 1.4.0+dfsg-1/stdlib/Markdown/src/GitHub/table.jl
--- 1.3.1+dfsg-1/stdlib/Markdown/src/GitHub/table.jl	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/stdlib/Markdown/src/GitHub/table.jl	2020-03-21 16:36:32.000000000 +0000
@@ -65,8 +65,10 @@ function html(io::IO, md::Table)
     withtag(io, :table) do
         for (i, row) in enumerate(md.rows)
             withtag(io, :tr) do
-                for c in md.rows[i]
-                    withtag(io, i == 1 ? :th : :td) do
+                for (j, c) in enumerate(md.rows[i])
+                    alignment = md.align[j]
+                    alignment = alignment === :l ? "left" : alignment === :r ? "right" : "center"
+                     withtag(io, i == 1 ? :th : :td, ("align", alignment)) do
                         htmlinline(io, c)
                     end
                 end
diff -pruN 1.3.1+dfsg-1/stdlib/Markdown/test/runtests.jl 1.4.0+dfsg-1/stdlib/Markdown/test/runtests.jl
--- 1.3.1+dfsg-1/stdlib/Markdown/test/runtests.jl	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/stdlib/Markdown/test/runtests.jl	2020-03-21 16:36:32.000000000 +0000
@@ -510,6 +510,7 @@ let text =
     """,
     table = Markdown.parse(text)
     @test text == Markdown.plain(table)
+    @test Markdown.html(table) == """<table><tr><th align="left">Markdown</th><th align="center">Table</th><th align="right">Test</th></tr><tr><td align="left">foo</td><td align="center"><code>bar</code></td><td align="right"><em>baz</em></td></tr><tr><td align="left"><code>bar</code></td><td align="center">baz</td><td align="right"><em>foo</em></td></tr></table>\n"""
 end
 let text =
     """
@@ -519,6 +520,7 @@ let text =
     """,
     table = Markdown.parse(text)
     @test text == Markdown.plain(table)
+    @test Markdown.html(table) == """<table><tr><th align="left">a</th><th align="right">b</th></tr><tr><td align="left"><code>x | y</code></td><td align="right">2</td></tr></table>\n"""
 end
 
 # LaTeX extension
diff -pruN 1.3.1+dfsg-1/stdlib/Pkg.version 1.4.0+dfsg-1/stdlib/Pkg.version
--- 1.3.1+dfsg-1/stdlib/Pkg.version	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/stdlib/Pkg.version	2020-03-21 16:36:32.000000000 +0000
@@ -1,2 +1,2 @@
 PKG_BRANCH = master
-PKG_SHA1 = f71e2c5a119b9c850f9b357fc8c56068f5b51cc0
+PKG_SHA1 = 9419c70af69153cd5c4276bff90fbb135e0aa3f1
diff -pruN 1.3.1+dfsg-1/stdlib/Printf/src/Printf.jl 1.4.0+dfsg-1/stdlib/Printf/src/Printf.jl
--- 1.3.1+dfsg-1/stdlib/Printf/src/Printf.jl	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/stdlib/Printf/src/Printf.jl	2020-03-21 16:36:32.000000000 +0000
@@ -1,15 +1,1239 @@
 # This file is a part of Julia. License is MIT: https://julialang.org/license
 
 module Printf
-# the macro implementations here exactly mirrors the
-# macros left in base/printf.jl, and uses the utility there
 
 export @printf, @sprintf
-using Base.Printf: _printf, is_str_expr, fix_dec, DIGITS, DIGITSs, print_fixed, print_fixed_width, decode_dec, decode_hex,
-                   ini_hex, ini_HEX, print_exp_a, decode_0ct, decode_HEX, ini_dec, print_exp_e,
-                   decode_oct, _limit, SmallNumber
+using Base.Grisu
+using Base.GMP
 using Unicode: textwidth
 
+### printf formatter generation ###
+const SmallFloatingPoint = Union{Float64,Float32,Float16}
+const SmallNumber = Union{SmallFloatingPoint,Base.BitInteger}
+
+function gen(s::AbstractString)
+    args = []
+    blk = Expr(:block, :(local neg, pt, len, exp, do_out, args, buf))
+    gotbuf = false
+    for x in parse(s)
+        if isa(x,AbstractString)
+            push!(blk.args, :(print(out, $(length(x)==1 ? x[1] : x))))
+        else
+            c = lowercase(x[end])
+            f = c=='f' ? gen_f :
+                c=='e' ? gen_e :
+                c=='a' ? gen_a :
+                c=='g' ? gen_g :
+                c=='c' ? gen_c :
+                c=='s' ? gen_s :
+                c=='p' ? gen_p :
+                         gen_d
+            if !gotbuf && c != 'c' && c != 's' && c != 'p'
+                push!(blk.args, :(buf = $Grisu.getbuf()))
+                gotbuf = true
+            end
+            arg, ex = f(x...)
+            push!(args, arg)
+            push!(blk.args, ex)
+        end
+    end
+    push!(blk.args, :nothing)
+    return args, blk
+end
+
+### printf format string parsing ###
+
+function parse(s::AbstractString)
+    # parse format string into strings and format tuples
+    list = []
+    a = Iterators.Stateful(pairs(s))
+    lastparse = firstindex(s)
+    lastidx = 0 # invariant: lastidx == prevind(s, idx)
+    for (idx, c) in a
+        if c == '%'
+            lastparse > lastidx || push!(list, s[lastparse:lastidx])
+            flags, width, precision, conversion = parse1!(s,  a)
+            '\'' in flags && error("printf format flag ' not yet supported")
+            conversion == 'n'    && error("printf feature %n not supported")
+            push!(list, conversion == '%' ? "%" : (flags,width,precision,conversion))
+            lastparse = isempty(a) ? lastindex(s)+1 : Base.peek(a)[1]
+        end
+        lastidx = idx
+    end
+    lastparse > lastindex(s) || push!(list, s[lastparse:end])
+    # coalesce adjacent strings
+    i = j = 1
+    while i < length(list)
+        if isa(list[i],AbstractString)
+            for outer j = i+1:length(list)
+                if !isa(list[j],AbstractString)
+                    j -= 1
+                    break
+                end
+                list[i] *= list[j]
+            end
+            deleteat!(list,i+1:j)
+        end
+        i += 1
+    end
+    return list
+end
+
+## parse a single printf specifier ##
+
+# printf specifiers:
+#   %                       # start
+#   (\d+\$)?                # arg (not supported)
+#   [\-\+#0' ]*             # flags
+#   (\d+)?                  # width
+#   (\.\d*)?                # precision
+#   (h|hh|l|ll|L|j|t|z|q)?  # modifier (ignored)
+#   [diouxXeEfFgGaAcCsSp%]  # conversion
+
+pop_or_die!(s, a) = !isempty(a) ? popfirst!(a) :
+    throw(ArgumentError("invalid printf format string: $(repr(s))"))
+
+function parse1!(s, a)
+    width = 0
+    precision = -1
+    k, c = pop_or_die!(s, a)
+    j = k
+    # handle %%
+    if c == '%'
+        return "", width, precision, c
+    end
+    # parse flags
+    while c in "#0- + '"
+        k, c = pop_or_die!(s, a)
+    end
+    flags = String(s[j:k-1]) # All flags are 1 byte
+    # parse width
+    while '0' <= c <= '9'
+        width = 10*width + c-'0'
+        _, c = pop_or_die!(s, a)
+    end
+    # parse precision
+    if c == '.'
+        _, c = pop_or_die!(s, a)
+        if '0' <= c <= '9'
+            precision = 0
+            while '0' <= c <= '9'
+                precision = 10*precision + c-'0'
+                _, c = pop_or_die!(s, a)
+            end
+        end
+    end
+    # parse length modifer (ignored)
+    if c == 'h' || c == 'l'
+        prev = c
+        _, c = pop_or_die!(s, a)
+        if c == prev
+            _, c = pop_or_die!(s, a)
+        end
+    elseif c in "Ljqtz"
+        _, c = pop_or_die!(s, a)
+    end
+    # validate conversion
+    if !(c in "diouxXDOUeEfFgGaAcCsSpn")
+        throw(ArgumentError("invalid printf format string: $(repr(s))"))
+    end
+    # TODO: warn about silly flag/conversion combinations
+    flags, width, precision, c
+end
+
+### printf formatter generation ###
+
+function special_handler(flags::String, width::Int)
+    @gensym x
+    blk = Expr(:block)
+    pad = '-' in flags ? rpad : lpad
+    pos = '+' in flags ? "+" :
+          ' ' in flags ? " " : ""
+    abn = quote
+        isnan($x) ? $(pad("NaN", width)) :
+         $x < 0   ? $(pad("-Inf", width)) :
+                    $(pad("$(pos)Inf", width))
+    end
+    ex = :(isfinite($x) ? $blk : print(out, $abn))
+    x, ex, blk
+end
+
+function pad(m::Int, n, c::Char)
+    if m <= 1
+        :($n > 0 && print(out,$c))
+    else
+        @gensym i
+        quote
+            $i = $n
+            while $i > 0
+                print(out,$c)
+                $i -= 1
+            end
+        end
+    end
+end
+
+function dynamic_pad(m, val, c::Char)
+    @gensym i
+    quote
+        if $m <= 1
+            $val > 0 && print(out,$c)
+        else
+            $i = $val
+            while $i > 0
+                print(out,$c)
+                $i -= 1
+            end
+        end
+    end
+end
+
+# returns the number of (ASCII) chars output by print_fixed
+function print_fixed_width(precision, pt, ndigits, trailingzeros=true)
+    count = 0
+    if pt <= 0
+        # 0.0dddd0
+        count += 2
+        precision += pt
+        if pt < 0
+            count -= pt
+        end
+        count += ndigits
+        precision -= ndigits
+    elseif ndigits <= pt
+        # dddd000.000000
+        count += ndigits
+        if ndigits < pt
+            count += pt - ndigits
+        end
+        count += trailingzeros
+    else # 0 < pt < ndigits
+        # dd.dd0000
+        ndigits -= pt
+        count += pt + 1 + ndigits
+        precision -= ndigits
+    end
+    if trailingzeros && precision > 0
+        count += precision
+    end
+    return count
+end
+
+# note: if print_fixed is changed, print_fixed_width should be changed accordingly
+function print_fixed(out, precision, pt, ndigits, trailingzeros=true, buf = Grisu.getbuf())
+    pdigits = pointer(buf)
+    if pt <= 0
+        # 0.0dddd0
+        print(out, '0')
+        print(out, '.')
+        precision += pt
+        while pt < 0
+            print(out, '0')
+            pt += 1
+        end
+        unsafe_write(out, pdigits, ndigits)
+        precision -= ndigits
+    elseif ndigits <= pt
+        # dddd000.000000
+        unsafe_write(out, pdigits, ndigits)
+        while ndigits < pt
+            print(out, '0')
+            ndigits += 1
+        end
+        if trailingzeros
+            print(out, '.')
+        end
+    else # 0 < pt < ndigits
+        # dd.dd0000
+        ndigits -= pt
+        unsafe_write(out, pdigits, pt)
+        print(out, '.')
+        unsafe_write(out, pdigits+pt, ndigits)
+        precision -= ndigits
+    end
+    if trailingzeros
+        while precision > 0
+            print(out, '0')
+            precision -= 1
+        end
+    end
+end
+
+function print_exp_e(out, exp::Integer)
+    print(out, exp < 0 ? '-' : '+')
+    exp = abs(exp)
+    d = div(exp,100)
+    if d > 0
+        if d >= 10
+            print(out, exp)
+            return
+        end
+        print(out, Char('0'+d))
+    end
+    exp = rem(exp,100)
+    print(out, Char('0'+div(exp,10)))
+    print(out, Char('0'+rem(exp,10)))
+end
+
+function print_exp_a(out, exp::Integer)
+    print(out, exp < 0 ? '-' : '+')
+    exp = abs(exp)
+    print(out, exp)
+end
+
+
+function gen_d(flags::String, width::Int, precision::Int, c::Char)
+    # print integer:
+    #  [dDiu]: print decimal digits
+    #  [o]:    print octal digits
+    #  [x]:    print hex digits, lowercase
+    #  [X]:    print hex digits, uppercase
+    #
+    # flags:
+    #  (#): prefix hex with 0x/0X; octal leads with 0
+    #  (0): pad left with zeros
+    #  (-): left justify
+    #  ( ): precede non-negative values with " "
+    #  (+): precede non-negative values with "+"
+    #
+    x, ex, blk = special_handler(flags,width)
+    # interpret the number
+    prefix = ""
+    if lowercase(c)=='o'
+        fn = '#' in flags ? :decode_0ct : :decode_oct
+    elseif c=='x'
+        '#' in flags && (prefix = "0x")
+        fn = :decode_hex
+    elseif c=='X'
+        '#' in flags && (prefix = "0X")
+        fn = :decode_HEX
+    else
+        fn = :decode_dec
+    end
+    push!(blk.args, :((do_out, args) = $fn(out, $x, $flags, $width, $precision, $c, buf)))
+    ifblk = Expr(:if, :do_out, Expr(:block))
+    push!(blk.args, ifblk)
+    blk = ifblk.args[2]
+    push!(blk.args, :((len, pt, neg) = args))
+    # calculate padding
+    width -= length(prefix)
+    space_pad = width > max(1,precision) && '-' in flags ||
+                precision < 0 && width > 1 && !('0' in flags) ||
+                precision >= 0 && width > precision
+    padding = nothing
+    if precision < 1; precision = 1; end
+    if space_pad
+        if '+' in flags || ' ' in flags
+            width -= 1
+            if width > precision
+                padding = :($width-(pt > $precision ? pt : $precision))
+            end
+        else
+            if width > precision
+                padding = :($width-neg-(pt > $precision ? pt : $precision))
+            end
+        end
+    end
+    # print space padding
+    if padding !== nothing && !('-' in flags)
+        push!(blk.args, pad(width-precision, padding, ' '))
+    end
+    # print sign
+    '+' in flags ? push!(blk.args, :(print(out, neg ? '-' : '+'))) :
+    ' ' in flags ? push!(blk.args, :(print(out, neg ? '-' : ' '))) :
+                   push!(blk.args, :(neg && print(out, '-')))
+    # print prefix
+    for ch in prefix
+        push!(blk.args, :(print(out, $ch)))
+    end
+    # print zero padding & leading zeros
+    if space_pad && precision > 1
+        push!(blk.args, pad(precision-1, :($precision-pt), '0'))
+    elseif !space_pad && width > 1
+        zeros = '+' in flags || ' ' in flags ? :($(width-1)-pt) : :($width-neg-pt)
+        push!(blk.args, pad(width-1, zeros, '0'))
+    end
+    # print integer
+    push!(blk.args, :(unsafe_write(out, pointer(buf), pt)))
+    # print padding
+    if padding !== nothing && '-' in flags
+        push!(blk.args, pad(width-precision, padding, ' '))
+    end
+    # return arg, expr
+    :(($x)::Real), ex
+end
+
+function gen_f(flags::String, width::Int, precision::Int, c::Char)
+    # print to fixed trailing precision
+    #  [fF]: the only choice
+    #
+    # flags
+    #  (#): always print a decimal point
+    #  (0): pad left with zeros
+    #  (-): left justify
+    #  ( ): precede non-negative values with " "
+    #  (+): precede non-negative values with "+"
+    #
+    x, ex, blk = special_handler(flags,width)
+    # interpret the number
+    if precision < 0; precision = 6; end
+    push!(blk.args, :((do_out, args) = fix_dec(out, $x, $flags, $width, $precision, $c, buf)))
+    ifblk = Expr(:if, :do_out, Expr(:block))
+    push!(blk.args, ifblk)
+    blk = ifblk.args[2]
+    push!(blk.args, :((len, pt, neg) = args))
+    # calculate padding
+    padding = nothing
+    if precision > 0 || '#' in flags
+        width -= precision+1
+    end
+    if '+' in flags || ' ' in flags
+        width -= 1
+        if width > 1
+            padding = :($width-(pt > 0 ? pt : 1))
+        end
+    else
+        if width > 1
+            padding = :($width-(pt > 0 ? pt : 1)-neg)
+        end
+    end
+    # print space padding
+    if padding !== nothing && !('-' in flags) && !('0' in flags)
+        push!(blk.args, pad(width-1, padding, ' '))
+    end
+    # print sign
+    '+' in flags ? push!(blk.args, :(print(out, neg ? '-' : '+'))) :
+    ' ' in flags ? push!(blk.args, :(print(out, neg ? '-' : ' '))) :
+                   push!(blk.args, :(neg && print(out, '-')))
+    # print zero padding
+    if padding !== nothing && !('-' in flags) && '0' in flags
+        push!(blk.args, pad(width-1, padding, '0'))
+    end
+    # print digits
+    if precision > 0
+        push!(blk.args, :(print_fixed(out,$precision,pt,len,true,buf)))
+    else
+        push!(blk.args, :(unsafe_write(out, pointer(buf), len)))
+        push!(blk.args, :(while pt >= (len+=1) print(out,'0') end))
+        '#' in flags && push!(blk.args, :(print(out, '.')))
+    end
+    # print space padding
+    if padding !== nothing && '-' in flags
+        push!(blk.args, pad(width-1, padding, ' '))
+    end
+    # return arg, expr
+    :(($x)::Real), ex
+end
+
+function gen_e(flags::String, width::Int, precision::Int, c::Char, inside_g::Bool=false)
+    # print float in scientific form:
+    #  [e]: use 'e' to introduce exponent
+    #  [E]: use 'E' to introduce exponent
+    #
+    # flags:
+    #  (#): always print a decimal point
+    #  (0): pad left with zeros
+    #  (-): left justify
+    #  ( ): precede non-negative values with " "
+    #  (+): precede non-negative values with "+"
+    #
+    x, ex, blk = if inside_g
+        @gensym x
+        blk = Expr(:block)
+        x, blk, blk
+    else
+        special_handler(flags,width)
+    end
+    # interpret the number
+    if precision < 0; precision = 6; end
+    ndigits = min(precision+1,length(Grisu.getbuf())-1)
+    push!(blk.args, :((do_out, args) = ini_dec(out,$x,$ndigits, $flags, $width, $precision, $c, buf)))
+    push!(blk.args, :(digits = buf))
+    ifblk = Expr(:if, :do_out, Expr(:block))
+    push!(blk.args, ifblk)
+    blk = ifblk.args[2]
+    push!(blk.args, :((len, pt, neg) = args))
+    push!(blk.args, :(exp = pt-1))
+    expmark = isuppercase(c) ? "E" : "e"
+    if precision==0 && '#' in flags
+        expmark = string(".",expmark)
+    end
+    # calculate padding
+    padding = nothing
+    width -= precision+length(expmark)+(precision>0)+4
+    # 4 = leading + expsign + 2 exp digits
+    if '+' in flags || ' ' in flags
+        width -= 1 # for the sign indicator
+        if width > 0
+            padding = quote
+                padn=$width
+                if (exp<=-100)|(100<=exp)
+                    if isa($x,SmallNumber)
+                        padn -= 1
+                    else
+                        padn -= Base.ndigits0z(exp) - 2
+                    end
+                end
+                padn
+            end
+        end
+    else
+        if width > 0
+            padding = quote
+                padn=$width-neg
+                if (exp<=-100)|(100<=exp)
+                    if isa($x,SmallNumber)
+                        padn -= 1
+                    else
+                        padn -= Base.ndigits0z(exp) - 2
+                    end
+                end
+                padn
+            end
+        end
+    end
+    # print space padding
+    if padding !== nothing && !('-' in flags) && !('0' in flags)
+        push!(blk.args, pad(width, padding, ' '))
+    end
+    # print sign
+    '+' in flags ? push!(blk.args, :(print(out, neg ? '-' : '+'))) :
+    ' ' in flags ? push!(blk.args, :(print(out, neg ? '-' : ' '))) :
+                   push!(blk.args, :(neg && print(out, '-')))
+    # print zero padding
+    if padding !== nothing && !('-' in flags) && '0' in flags
+        push!(blk.args, pad(width, padding, '0'))
+    end
+    # print digits
+    push!(blk.args, :(write(out, digits[1])))
+    if precision > 0
+        if inside_g && !('#' in flags)
+            push!(blk.args, :(endidx = $ndigits;
+                              while endidx > 1 && digits[endidx] == UInt8('0')
+                                  endidx -= 1
+                              end;
+                              if endidx > 1
+                                  print(out, '.')
+                                  unsafe_write(out, pointer(digits)+1, endidx-1)
+                              end
+                              ))
+        else
+            push!(blk.args, :(print(out, '.')))
+            push!(blk.args, :(unsafe_write(out, pointer(digits)+1, $(ndigits-1))))
+            if ndigits < precision+1
+                n = precision+1-ndigits
+                push!(blk.args, pad(n, n, '0'))
+            end
+        end
+    end
+    for ch in expmark
+        push!(blk.args, :(print(out, $ch)))
+    end
+    push!(blk.args, :(print_exp_e(out, exp)))
+    # print space padding
+    if padding !== nothing && '-' in flags
+        push!(blk.args, pad(width, padding, ' '))
+    end
+    # return arg, expr
+    :(($x)::Real), ex
+end
+
+function gen_a(flags::String, width::Int, precision::Int, c::Char)
+    # print float in hexadecimal format
+    #  [a]: lowercase hex float, e.g. -0x1.cfp-2
+    #  [A]: uppercase hex float, e.g. -0X1.CFP-2
+    #
+    # flags:
+    #  (#): always print a decimal point
+    #  (0): pad left with zeros
+    #  (-): left justify
+    #  ( ): precede non-negative values with " "
+    #  (+): precede non-negative values with "+"
+    #
+    x, ex, blk = special_handler(flags,width)
+    if c == 'A'
+        hexmark, expmark = "0X", "P"
+        fn = :ini_HEX
+    else
+        hexmark, expmark = "0x", "p"
+        fn = :ini_hex
+    end
+    # if no precision, print max non-zero
+    if precision < 0
+        push!(blk.args, :((do_out, args) = $fn(out,$x, $flags, $width, $precision, $c, buf)))
+    else
+        ndigits = min(precision+1,length(Grisu.getbuf())-1)
+        push!(blk.args, :((do_out, args) = $fn(out,$x,$ndigits, $flags, $width, $precision, $c, buf)))
+    end
+    push!(blk.args, :(digits = buf))
+    ifblk = Expr(:if, :do_out, Expr(:block))
+    push!(blk.args, ifblk)
+    blk = ifblk.args[2]
+    push!(blk.args, :((len, exp, neg) = args))
+    if precision==0 && '#' in flags
+        expmark = string(".",expmark)
+    end
+    # calculate padding
+    padding = nothing
+    if precision > 0
+        width -= precision+length(hexmark)+length(expmark)+4
+        # 4 = leading + expsign + 1 exp digit + decimal
+    else
+        width -= length(hexmark)+length(expmark)+3+(precision<0 && '#' in flags)
+        # 3 = leading + expsign + 1 exp digit
+    end
+    if '+' in flags || ' ' in flags
+        width -= 1 # for the sign indicator
+        if width > 0
+            padding = :($(width+1) - Base.ndigits(exp))
+        end
+    else
+        if width > 0
+            padding = :($(width+1) - neg - Base.ndigits(exp))
+        end
+    end
+    if precision < 0 && width > 0
+        if '#' in flags
+            padding = :($padding - (len-1))
+        else
+            padding = :($padding - (len>1 ? len : 0))
+        end
+    end
+    # print space padding
+    if padding !== nothing && !('-' in flags) && !('0' in flags)
+        push!(blk.args, pad(width, padding, ' '))
+    end
+    # print sign
+    '+' in flags ? push!(blk.args, :(print(out, neg ? '-' : '+'))) :
+    ' ' in flags ? push!(blk.args, :(print(out, neg ? '-' : ' '))) :
+                    push!(blk.args, :(neg && print(out, '-')))
+    # hex prefix
+    for ch in hexmark
+        push!(blk.args, :(print(out, $ch)))
+    end
+    # print zero padding
+    if padding !== nothing && !('-' in flags) && '0' in flags
+        push!(blk.args, pad(width, padding, '0'))
+    end
+    # print digits: assumes ASCII/UTF8 encoding of digits is okay for `out`
+    push!(blk.args, :(write(out, digits[1])))
+    if precision > 0
+        push!(blk.args, :(print(out, '.')))
+        push!(blk.args, :(unsafe_write(out, pointer(digits)+1, $(ndigits-1))))
+        if ndigits < precision+1
+            n = precision+1-ndigits
+            push!(blk.args, pad(n, n, '0'))
+        end
+    elseif precision < 0
+        ifvpblk = Expr(:if, :(len > 1), Expr(:block))
+        vpblk = ifvpblk.args[2]
+        if '#' in flags
+            push!(blk.args, :(print(out, '.')))
+        else
+            push!(vpblk.args, :(print(out, '.')))
+        end
+        push!(vpblk.args, :(unsafe_write(out, pointer(digits)+1, len-1)))
+        push!(blk.args, ifvpblk)
+    end
+    for ch in expmark
+        push!(blk.args, :(print(out, $ch)))
+    end
+    push!(blk.args, :(print_exp_a(out, exp)))
+    # print space padding
+    if padding !== nothing && '-' in flags
+        push!(blk.args, pad(width, padding, ' '))
+    end
+    # return arg, expr
+    :(($x)::Real), ex
+end
+
+function gen_c(flags::String, width::Int, precision::Int, c::Char)
+    # print a character:
+    #  [cC]: both the same for us (Unicode)
+    #
+    # flags:
+    #  (0): pad left with zeros
+    #  (-): left justify
+    #
+    @gensym x
+    blk = Expr(:block, :($x = Char($x)))
+    if width > 1 && !('-' in flags)
+        p = '0' in flags ? '0' : ' '
+        push!(blk.args, pad(width-1, :($width-textwidth($x)), p))
+    end
+    push!(blk.args, :(print(out, $x)))
+    if width > 1 && '-' in flags
+        push!(blk.args, pad(width-1, :($width-textwidth($x)), ' '))
+    end
+    :(($x)::Integer), blk
+end
+
+function _limit(s, prec)
+    prec >= sizeof(s) && return s
+    p = prevind(s, prec+1)
+    n = nextind(s, p)-1
+    s[1:(prec>=n ? n : prevind(s,p))]
+end
+
+function gen_s(flags::String, width::Int, precision::Int, c::Char)
+    # print a string:
+    #  [sS]: both the same for us (Unicode)
+    #
+    # flags:
+    #  (-): left justify
+    #  (#): use `show`/`repr` instead of `print`/`string`
+    #
+    @gensym x
+    blk = Expr(:block)
+    if width > 0
+        if !('#' in flags)
+            push!(blk.args, :($x = string($x)))
+        else
+            push!(blk.args, :($x = repr($x)))
+        end
+        if precision!=-1
+            push!(blk.args, :($x = _limit($x, $precision)))
+        end
+        if !('-' in flags)
+            push!(blk.args, pad(width, :($width-textwidth($x)), ' '))
+        end
+        push!(blk.args, :(print(out, $x)))
+        if '-' in flags
+            push!(blk.args, pad(width, :($width-textwidth($x)), ' '))
+        end
+    else
+        if precision!=-1
+            push!(blk.args, :(io = IOBuffer()))
+        else
+            push!(blk.args, :(io = out))
+        end
+        if !('#' in flags)
+            push!(blk.args, :(print(io, $x)))
+        else
+            push!(blk.args, :(show(io, $x)))
+        end
+        if precision!=-1
+            push!(blk.args, :(print(out, _limit(String(take!(io)), $precision))))
+        end
+    end
+    :(($x)::Any), blk
+end
+
+# TODO: faster pointer printing.
+
+function gen_p(flags::String, width::Int, precision::Int, c::Char)
+    # print pointer:
+    #  [p]: the only option
+    #
+    # flags:
+    #  (-): left justify
+    #
+    @gensym x
+    blk = Expr(:block)
+    ptrwidth = Sys.WORD_SIZE>>2
+    width -= ptrwidth+2
+    if width > 0 && !('-' in flags)
+        push!(blk.args, pad(width, width, ' '))
+    end
+    push!(blk.args, :(print(out, '0')))
+    push!(blk.args, :(print(out, 'x')))
+    push!(blk.args, :(print(out, String(string(unsigned($x), pad = $ptrwidth, base = 16)))))
+    if width > 0 && '-' in flags
+        push!(blk.args, pad(width, width, ' '))
+    end
+    :(($x)::Ptr), blk
+end
+
+function gen_g(flags::String, width::Int, precision::Int, c::Char)
+    # print to fixed trailing precision
+    #  [g]: lower case e on scientific
+    #  [G]: Upper case e on scientific
+    #
+    # flags
+    #  (#): always print a decimal point
+    #  (0): pad left with zeros
+    #  (-): left justify
+    #  ( ): precede non-negative values with " "
+    #  (+): precede non-negative values with "+"
+    #
+    x, ex, blk = special_handler(flags,width)
+    if precision < 0; precision = 6; end
+    ndigits = min(precision+1,length(Grisu.getbuf())-1)
+    # See if anyone else wants to handle it
+    push!(blk.args, :((do_out, args) = ini_dec(out,$x,$ndigits, $flags, $width, $precision, $c, buf)))
+    ifblk = Expr(:if, :do_out, Expr(:block))
+    push!(blk.args, ifblk)
+    blk = ifblk.args[2]
+    push!(blk.args, :((len, pt, neg) = args))
+    push!(blk.args, :(exp = pt-1))
+    push!(blk.args, :(do_f = $precision > exp >= -4)) # Should we interpret like %f or %e?
+    feblk = Expr(:if, :do_f, Expr(:block), Expr(:block))
+    push!(blk.args, feblk)
+    fblk = feblk.args[2]
+    eblk = feblk.args[3]
+
+    ### %f branch
+    # Follow the same logic as gen_f() but more work has to be deferred until runtime
+    # because precision is unknown until then.
+    push!(fblk.args, :(fprec = $precision - (exp+1)))
+    push!(fblk.args, :((do_out, args) = fix_dec(out, $x, $flags, $width, fprec, $c - 1, buf)))
+    fifblk = Expr(:if, :do_out, Expr(:block))
+    push!(fblk.args, fifblk)
+    blk = fifblk.args[2]
+    push!(blk.args, :((len, pt, neg) = args))
+    push!(blk.args, :(padding = 0))
+    push!(blk.args, :(width = $width))
+    # need to compute value before left-padding since trailing zeros are elided
+    push!(blk.args, :(width -= print_fixed_width(fprec,pt,len,$('#' in flags))))
+    if '+' in flags || ' ' in flags
+        push!(blk.args, :(width -= 1))
+    else
+        push!(blk.args, :(if neg width -= 1; end))
+    end
+    push!(blk.args, :(if width >= 1 padding = width; end))
+    # print space padding
+    if !('-' in flags) && !('0' in flags)
+        padexpr = dynamic_pad(:width, :padding, ' ')
+        push!(blk.args, :(if padding > 0
+                          $padexpr; end))
+    end
+    # print sign
+    '+' in flags ? push!(blk.args, :(print(out, neg ? '-' : '+'))) :
+    ' ' in flags ? push!(blk.args, :(print(out, neg ? '-' : ' '))) :
+                   push!(blk.args, :(neg && print(out, '-')))
+    # print zero padding
+    if !('-' in flags) && '0' in flags
+        padexpr = dynamic_pad(:width, :padding, '0')
+        push!(blk.args, :(if padding > 0
+                          $padexpr; end))
+    end
+    # finally print value
+    push!(blk.args, :(print_fixed(out,fprec,pt,len,$('#' in flags),buf)))
+    # print space padding
+    if '-' in flags
+        padexpr = dynamic_pad(:width, :padding, ' ')
+        push!(blk.args, :(if padding > 0
+                          $padexpr; end))
+    end
+
+    ### %e branch
+    # Here we can do all the work at macro expansion time
+    var, eex = gen_e(flags, width, precision-1, c, true)
+    push!(eblk.args, :($(var.args[1]) = $x))
+    push!(eblk.args, eex)
+
+    :(($x)::Real), ex
+end
+
+### core unsigned integer decoding functions ###
+
+macro handle_zero(ex, digits)
+    quote
+        if $(esc(ex)) == 0
+            $(esc(digits))[1] = '0'
+            return Int32(1), Int32(1), $(esc(:neg))
+        end
+    end
+end
+
+decode_oct(out, d, flags::String, width::Int, precision::Int, c::Char, digits) = (true, decode_oct(d, digits))
+decode_0ct(out, d, flags::String, width::Int, precision::Int, c::Char, digits) = (true, decode_0ct(d, digits))
+decode_dec(out, d, flags::String, width::Int, precision::Int, c::Char, digits) = (true, decode_dec(d, digits))
+decode_hex(out, d, flags::String, width::Int, precision::Int, c::Char, digits) = (true, decode_hex(d, digits))
+decode_HEX(out, d, flags::String, width::Int, precision::Int, c::Char, digits) = (true, decode_HEX(d, digits))
+fix_dec(out, d, flags::String, width::Int, precision::Int, c::Char, digits) = (true, fix_dec(d, precision, digits))
+ini_dec(out, d, ndigits::Int, flags::String, width::Int, precision::Int, c::Char, digits) = (true, ini_dec(d, ndigits, digits))
+ini_hex(out, d, ndigits::Int, flags::String, width::Int, precision::Int, c::Char, digits) = (true, ini_hex(d, ndigits, digits))
+ini_HEX(out, d, ndigits::Int, flags::String, width::Int, precision::Int, c::Char, digits) = (true, ini_HEX(d, ndigits, digits))
+ini_hex(out, d, flags::String, width::Int, precision::Int, c::Char, digits) = (true, ini_hex(d, digits))
+ini_HEX(out, d, flags::String, width::Int, precision::Int, c::Char, digits) = (true, ini_HEX(d, digits))
+
+
+# fallbacks for Real types without explicit decode_* implementation
+decode_oct(d::Real, digits) = decode_oct(Integer(d), digits)
+decode_0ct(d::Real, digits) = decode_0ct(Integer(d), digits)
+decode_dec(d::Real, digits) = decode_dec(Integer(d), digits)
+decode_hex(d::Real, digits) = decode_hex(Integer(d), digits)
+decode_HEX(d::Real, digits) = decode_HEX(Integer(d), digits)
+
+handlenegative(d::Unsigned) = (false, d)
+function handlenegative(d::Integer)
+    if d < 0
+        return true, unsigned(oftype(d,-d))
+    else
+        return false, unsigned(d)
+    end
+end
+
+function decode_oct(d::Integer, digits)
+    neg, x = handlenegative(d)
+    @handle_zero x digits
+    pt = i = div((sizeof(x)<<3)-leading_zeros(x)+2,3)
+    while i > 0
+        digits[i] = 48+(x&0x7)
+        x >>= 3
+        i -= 1
+    end
+    return Int32(pt), Int32(pt), neg
+end
+
+function decode_0ct(d::Integer, digits)
+    neg, x = handlenegative(d)
+    # doesn't need special handling for zero
+    pt = i = div((sizeof(x)<<3)-leading_zeros(x)+5,3)
+    while i > 0
+        digits[i] = 48+(x&0x7)
+        x >>= 3
+        i -= 1
+    end
+    return Int32(pt), Int32(pt), neg
+end
+
+function decode_dec(d::Integer, digits)
+    neg, x = handlenegative(d)
+    @handle_zero x digits
+    pt = i = Base.ndigits0z(x)
+    while i > 0
+        digits[i] = 48+rem(x,10)
+        x = div(x,10)
+        i -= 1
+    end
+    return Int32(pt), Int32(pt), neg
+end
+
+function decode_hex(d::Integer, symbols::AbstractArray{UInt8,1}, digits)
+    neg, x = handlenegative(d)
+    @handle_zero x digits
+    pt = i = (sizeof(x)<<1)-(leading_zeros(x)>>2)
+    while i > 0
+        digits[i] = symbols[(x&0xf)+1]
+        x >>= 4
+        i -= 1
+    end
+    return Int32(pt), Int32(pt), neg
+end
+
+const hex_symbols = b"0123456789abcdef"
+const HEX_symbols = b"0123456789ABCDEF"
+
+decode_hex(x::Integer, digits) = decode_hex(x,hex_symbols,digits)
+decode_HEX(x::Integer, digits) = decode_hex(x,HEX_symbols,digits)
+
+function decode(b::Int, x::BigInt, digits)
+    neg = x.size < 0
+    pt = Base.ndigits(x, base=abs(b))
+    length(digits) < pt+1 && resize!(digits, pt+1)
+    neg && (x.size = -x.size)
+    GMP.MPZ.get_str!(digits, b, x)
+    neg && (x.size = -x.size)
+    return Int32(pt), Int32(pt), neg
+end
+decode_oct(x::BigInt, digits) = decode(8, x, digits)
+decode_dec(x::BigInt, digits) = decode(10, x, digits)
+decode_hex(x::BigInt, digits) = decode(16, x, digits)
+decode_HEX(x::BigInt, digits) = decode(-16, x, digits)
+
+function decode_0ct(x::BigInt, digits)
+    neg = x.size < 0
+    digits[1] = '0'
+    if x.size == 0
+        return Int32(1), Int32(1), neg
+    end
+    pt = Base.ndigits0z(x, 8) + 1
+    length(digits) < pt+1 && resize!(digits, pt+1)
+    neg && (x.size = -x.size)
+    p = convert(Ptr{UInt8}, digits) + 1
+    GMP.MPZ.get_str!(p, 8, x)
+    neg && (x.size = -x.size)
+    return neg, Int32(pt), Int32(pt)
+end
+
+### decoding functions directly used by printf generated code ###
+
+# decode_*(x)=> fixed precision, to 0th place, filled out
+# fix_*(x,n) => fixed precision, to nth place, not filled out
+# ini_*(x,n) => n initial digits, filled out
+
+# alternate versions:
+#   *_0ct(x,n) => ensure that the first octal digits is zero
+#   *_HEX(x,n) => use uppercase digits for hexadecimal
+
+# - returns (len, point, neg)
+# - implies len = point
+#
+
+function decode_dec(x::SmallFloatingPoint, digits)
+    if x == 0.0
+        digits[1] = '0'
+        return (Int32(1), Int32(1), false)
+    end
+    len,pt,neg = grisu(x,Grisu.FIXED,0,digits)
+    if len == 0
+        digits[1] = '0'
+        return (Int32(1), Int32(1), false)
+    else
+        for i = len+1:pt
+            digits[i] = '0'
+        end
+    end
+    return Int32(len), Int32(pt), neg
+end
+# TODO: implement decode_oct, decode_0ct, decode_hex, decode_HEX for SmallFloatingPoint
+
+## fix decoding functions ##
+#
+# - returns (neg, point, len)
+# - if len less than point, trailing zeros implied
+#
+
+# fallback for Real types without explicit fix_dec implementation
+fix_dec(x::Real, n::Int, digits) = fix_dec(float(x),n,digits)
+
+fix_dec(x::Integer, n::Int, digits) = decode_dec(x, digits)
+
+function fix_dec(x::SmallFloatingPoint, n::Int, digits)
+    if n > length(digits)-1; n = length(digits)-1; end
+    len,pt,neg = grisu(x,Grisu.FIXED,n,digits)
+    if len == 0
+        digits[1] = '0'
+        return (Int32(1), Int32(1), neg)
+    end
+    return Int32(len), Int32(pt), neg
+end
+
+## ini decoding functions ##
+#
+# - returns (neg, point, len)
+# - implies len = n (requested digits)
+#
+
+# fallback for Real types without explicit fix_dec implementation
+ini_dec(x::Real, n::Int, digits) = ini_dec(float(x),n,digits)
+
+function ini_dec(d::Integer, n::Int, digits)
+    neg, x = handlenegative(d)
+    k = ndigits(x)
+    if k <= n
+        pt = k
+        for i = k:-1:1
+            digits[i] = '0'+rem(x,10)
+            x = div(x,10)
+        end
+        for i = k+1:n
+            digits[i] = '0'
+        end
+    else
+        p = Base.powers_of_ten[k-n+1]
+        r = rem(x,p)
+        if r >= (p>>1)
+            x += p
+            if x >= Base.powers_of_ten[k+1]
+                p *= 10
+                k += 1
+            end
+        end
+        pt = k
+        x = div(x,p)
+        for i = n:-1:1
+            digits[i] = '0'+rem(x,10)
+            x = div(x,10)
+        end
+    end
+    return n, pt, neg
+end
+
+function ini_dec(x::SmallFloatingPoint, n::Int, digits)
+    if x == 0.0
+        ccall(:memset, Ptr{Cvoid}, (Ptr{Cvoid}, Cint, Csize_t), digits, '0', n)
+        return Int32(1), Int32(1), signbit(x)
+    else
+        len,pt,neg = grisu(x,Grisu.PRECISION,n,digits)
+    end
+    return Int32(len), Int32(pt), neg
+end
+
+function ini_dec(x::BigInt, n::Int, digits)
+    if x.size == 0
+        ccall(:memset, Ptr{Cvoid}, (Ptr{Cvoid}, Cint, Csize_t), digits, '0', n)
+        return Int32(1), Int32(1), false
+    end
+    d = Base.ndigits0z(x)
+    if d <= n
+        info = decode_dec(x)
+        d == n && return info
+        p = convert(Ptr{Cvoid}, digits) + info[2]
+        ccall(:memset, Ptr{Cvoid}, (Ptr{Cvoid}, Cint, Csize_t), p, '0', n - info[2])
+        return info
+    end
+    return (n, d, decode_dec(round(BigInt,x/big(10)^(d-n)))[3])
+end
+
+
+ini_hex(x::Real, n::Int, digits) = ini_hex(x,n,hex_symbols,digits)
+ini_HEX(x::Real, n::Int, digits) = ini_hex(x,n,HEX_symbols,digits)
+
+ini_hex(x::Real, digits) = ini_hex(x,hex_symbols,digits)
+ini_HEX(x::Real, digits) = ini_hex(x,HEX_symbols,digits)
+
+ini_hex(x::Real, n::Int, symbols::AbstractArray{UInt8,1}, digits) = ini_hex(float(x), n, symbols, digits)
+ini_hex(x::Real, symbols::AbstractArray{UInt8,1}, digits) = ini_hex(float(x), symbols, digits)
+
+function ini_hex(x::SmallFloatingPoint, n::Int, symbols::AbstractArray{UInt8,1}, digits)
+    x = Float64(x)
+    if x == 0.0
+        ccall(:memset, Ptr{Cvoid}, (Ptr{Cvoid}, Cint, Csize_t), digits, '0', n)
+        return Int32(1), Int32(0), signbit(x)
+    else
+        s, p = frexp(x)
+        sigbits = 4*min(n-1,13)
+        s = 0.25*round(ldexp(s,1+sigbits))
+        # ensure last 2 exponent bits either 01 or 10
+        u = (reinterpret(UInt64,s) & 0x003f_ffff_ffff_ffff) >> (52-sigbits)
+        if n > 14
+            ccall(:memset, Ptr{Cvoid}, (Ptr{Cvoid}, Cint, Csize_t), digits, '0', n)
+        end
+        i = (sizeof(u)<<1)-(leading_zeros(u)>>2)
+        while i > 0
+            digits[i] = symbols[(u&0xf)+1]
+            u >>= 4
+            i -= 1
+        end
+        # pt is the binary exponent
+        return Int32(n), Int32(p-1), x < 0.0
+    end
+end
+
+function ini_hex(x::SmallFloatingPoint, symbols::AbstractArray{UInt8,1}, digits)
+    x = Float64(x)
+    if x == 0.0
+        ccall(:memset, Ptr{Cvoid}, (Ptr{Cvoid}, Cint, Csize_t), digits, '0', 1)
+        return Int32(1), Int32(0), signbit(x)
+    else
+        s, p = frexp(x)
+        s *= 2.0
+        u = (reinterpret(UInt64,s) & 0x001f_ffff_ffff_ffff)
+        t = (trailing_zeros(u) >> 2)
+        u >>= (t<<2)
+        n = 14-t
+        for i = n:-1:1
+            digits[i] = symbols[(u&0xf)+1]
+            u >>= 4
+        end
+        # pt is the binary exponent
+        return Int32(n), Int32(p-1), x < 0.0
+    end
+end
+
+function ini_hex(x::Integer, digits)
+    len,pt,neg = decode_hex(x, digits)
+    pt = (len-1)<<2
+    len,pt,neg
+end
+function ini_HEX(x::Integer, digits)
+    len,pt,neg = decode_HEX(x, digits)
+    pt = (len-1)<<2
+    len,pt,neg
+end
+
+# not implemented
+ini_hex(x::Integer,ndigits::Int,digits) = throw(MethodError(ini_hex,(x,ndigits,digits)))
+
+#BigFloat
+fix_dec(out, d::BigFloat, flags::String, width::Int, precision::Int, c::Char, digits) = bigfloat_printf(out, d, flags, width, precision, c, digits)
+ini_dec(out, d::BigFloat, ndigits::Int, flags::String, width::Int, precision::Int, c::Char, digits) = bigfloat_printf(out, d, flags, width, precision, c, digits)
+ini_hex(out, d::BigFloat, ndigits::Int, flags::String, width::Int, precision::Int, c::Char, digits) = bigfloat_printf(out, d, flags, width, precision, c, digits)
+ini_HEX(out, d::BigFloat, ndigits::Int, flags::String, width::Int, precision::Int, c::Char, digits) = bigfloat_printf(out, d, flags, width, precision, c, digits)
+ini_hex(out, d::BigFloat, flags::String, width::Int, precision::Int, c::Char, digits) = bigfloat_printf(out, d, flags, width, precision, c, digits)
+ini_HEX(out, d::BigFloat, flags::String, width::Int, precision::Int, c::Char, digits) = bigfloat_printf(out, d, flags, width, precision, c, digits)
+function bigfloat_printf(out, d::BigFloat, flags::String, width::Int, precision::Int, c::Char, digits)
+    fmt_len = sizeof(flags)+4
+    if width > 0
+        fmt_len += ndigits(width)
+    end
+    if precision >= 0
+        fmt_len += ndigits(precision)+1
+    end
+    fmt = IOBuffer(maxsize=fmt_len)
+    print(fmt, '%')
+    print(fmt, flags)
+    if width > 0
+        print(fmt, width)
+    end
+    if precision == 0
+        print(fmt, '.')
+        print(fmt, '0')
+    elseif precision > 0
+        print(fmt, '.')
+        print(fmt, precision)
+    end
+    print(fmt, 'R')
+    print(fmt, c)
+    write(fmt, UInt8(0))
+    printf_fmt = take!(fmt)
+    @assert length(printf_fmt) == fmt_len
+    bufsiz = length(digits)
+    lng = ccall((:mpfr_snprintf,:libmpfr), Int32,
+                (Ptr{UInt8}, Culong, Ptr{UInt8}, Ref{BigFloat}...),
+                digits, bufsiz, printf_fmt, d)
+    lng > 0 || error("invalid printf formatting for BigFloat")
+    unsafe_write(out, pointer(digits), min(lng, bufsiz-1))
+    return (false, ())
+end
+
+### external printf interface ###
+
+is_str_expr(ex) =
+    isa(ex,Expr) && (ex.head === :string || (ex.head === :macrocall && isa(ex.args[1],Symbol) &&
+    endswith(string(ex.args[1]),"str")))
+
+function _printf(macroname, io, fmt, args)
+    isa(fmt, AbstractString) || throw(ArgumentError("$macroname: format must be a plain static string (no interpolation or prefix)"))
+    sym_args, blk = gen(fmt)
+
+    has_splatting = false
+    for arg in args
+       if isa(arg, Expr) && arg.head === :...
+          has_splatting = true
+          break
+       end
+    end
+
+    #
+    #  Immediately check for corresponding arguments if there is no splatting
+    #
+    if !has_splatting && length(sym_args) != length(args)
+       throw(ArgumentError("$macroname: wrong number of arguments ($(length(args))) should be ($(length(sym_args)))"))
+    end
+
+    for i = length(sym_args):-1:1
+        var = sym_args[i].args[1]
+        if has_splatting
+           pushfirst!(blk.args, :($var = G[$i]))
+        else
+           pushfirst!(blk.args, :($var = $(esc(args[i]))))
+        end
+    end
+
+    #
+    #  Delay generation of argument list and check until evaluation time instead of macro
+    #  expansion time if there is splatting.
+    #
+    if has_splatting
+       x = Expr(:call,:tuple,args...)
+       pushfirst!(blk.args,
+          quote
+             G = $(esc(x))
+             if length(G) != $(length(sym_args))
+                 throw(ArgumentError(string($macroname,": wrong number of arguments (",length(G),") should be (",$(length(sym_args)),")")))
+             end
+          end
+       )
+    end
+
+    pushfirst!(blk.args, :(out = $io))
+    Expr(:let, Expr(:block), blk)
+end
+
 """
     @printf([io::IOStream], "%Fmt", args...)
 
@@ -66,4 +1290,4 @@ macro sprintf(args...)
     letexpr
 end
 
-end # module
+end
diff -pruN 1.3.1+dfsg-1/stdlib/Printf/test/runtests.jl 1.4.0+dfsg-1/stdlib/Printf/test/runtests.jl
--- 1.3.1+dfsg-1/stdlib/Printf/test/runtests.jl	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/stdlib/Printf/test/runtests.jl	2020-03-21 16:36:32.000000000 +0000
@@ -271,6 +271,7 @@ end
 @test (@sprintf "%s %s %s %d %d %d %f %f %f" Any[10^x+y for x=1:3,y=1:3 ]...) == "11 101 1001 12 102 1002 13.000000 103.000000 1003.000000"
 
 # @printf
+@test_me ArgumentError("@printf: called with no arguments") @macroexpand(@printf)
 @test_me ArgumentError("@printf: first or second argument must be a format string") @macroexpand(@printf 1)
 
 # Check bug with trailing nul printing BigFloat
diff -pruN 1.3.1+dfsg-1/stdlib/Profile/src/Profile.jl 1.4.0+dfsg-1/stdlib/Profile/src/Profile.jl
--- 1.3.1+dfsg-1/stdlib/Profile/src/Profile.jl	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/stdlib/Profile/src/Profile.jl	2020-03-21 16:36:32.000000000 +0000
@@ -7,6 +7,9 @@ module Profile
 
 import Base.StackTraces: lookup, UNKNOWN, show_spec_linfo, StackFrame
 
+# deprecated functions: use `getdict` instead
+lookup(ip::UInt) = lookup(convert(Ptr{Cvoid}, ip))
+
 export @profile
 
 """
@@ -85,14 +88,16 @@ struct ProfileFormat
     sortedby::Symbol
     combine::Bool
     C::Bool
+    recur::Symbol
     function ProfileFormat(;
         C = false,
         combine = true,
         maxdepth::Int = typemax(Int),
         mincount::Int = 0,
         noisefloor = 0,
-        sortedby::Symbol = :filefuncline)
-        return new(maxdepth, mincount, noisefloor, sortedby, combine, C)
+        sortedby::Symbol = :filefuncline,
+        recur::Symbol = :off)
+        return new(maxdepth, mincount, noisefloor, sortedby, combine, C, recur)
     end
 end
 
@@ -115,37 +120,50 @@ The keyword arguments can be any combina
  - `maxdepth` -- Limits the depth higher than `maxdepth` in the `:tree` format.
 
  - `sortedby` -- Controls the order in `:flat` format. `:filefuncline` (default) sorts by the source
-    line, whereas `:count` sorts in order of number of collected samples.
+    line, `:count` sorts in order of number of collected samples, and `:overhead` sorts by the number of samples
+    incurred by each function by itself.
 
  - `noisefloor` -- Limits frames that exceed the heuristic noise floor of the sample (only applies to format `:tree`).
     A suggested value to try for this is 2.0 (the default is 0). This parameter hides samples for which `n <= noisefloor * √N`,
     where `n` is the number of samples on this line, and `N` is the number of samples for the callee.
 
  - `mincount` -- Limits the printout to only those lines with at least `mincount` occurrences.
-"""
-function print(io::IO, data::Vector{<:Unsigned} = fetch(), lidict::Union{LineInfoDict, LineInfoFlatDict} = getdict(data);
+
+ - `recur` -- Controls the recursion handling in `:tree` format. `:off` (default) prints the tree as normal. `:flat` instead
+    compresses any recursion (by ip), showing the approximate effect of converting any self-recursion into an iterator.
+    `:flatc` does the same but also includes collapsing of C frames (may do odd things around `jl_apply`).
+"""
+function print(io::IO,
+        data::Vector{<:Unsigned} = fetch(),
+        lidict::Union{LineInfoDict, LineInfoFlatDict} = getdict(data)
+        ;
         format = :tree,
         C = false,
         combine = true,
         maxdepth::Int = typemax(Int),
         mincount::Int = 0,
         noisefloor = 0,
-        sortedby::Symbol = :filefuncline)
-    print(io, data, lidict, ProfileFormat(C = C,
+        sortedby::Symbol = :filefuncline,
+        recur::Symbol = :off)
+    print(io, data, lidict, ProfileFormat(
+            C = C,
             combine = combine,
             maxdepth = maxdepth,
             mincount = mincount,
             noisefloor = noisefloor,
-            sortedby = sortedby),
+            sortedby = sortedby,
+            recur = recur),
         format)
 end
 
 function print(io::IO, data::Vector{<:Unsigned}, lidict::Union{LineInfoDict, LineInfoFlatDict}, fmt::ProfileFormat, format::Symbol)
     cols::Int = Base.displaysize(io)[2]
     data = convert(Vector{UInt64}, data)
+    fmt.recur ∈ (:off, :flat, :flatc) || throw(ArgumentError("recur value not recognized"))
     if format === :tree
         tree(io, data, lidict, cols, fmt)
     elseif format === :flat
+        fmt.recur === :off || throw(ArgumentError("format flat only implements recur=:off"))
         flat(io, data, lidict, cols, fmt)
     else
         throw(ArgumentError("output format $(repr(format)) not recognized"))
@@ -174,12 +192,15 @@ allows you to save profiling results for
 """
 function retrieve()
     data = fetch()
-    return (copy(data), getdict(data))
+    return (data, getdict(data))
 end
 
 function getdict(data::Vector{UInt})
-    uip = unique(data)
-    return LineInfoDict(UInt64(ip)=>lookup(ip) for ip in uip)
+    dict = LineInfoDict()
+    for ip in data
+        get!(() -> lookup(convert(Ptr{Cvoid}, ip)), dict, UInt64(ip))
+    end
+    return dict
 end
 
 """
@@ -225,6 +246,45 @@ function flatten(data::Vector, lidict::L
     return (newdata, newdict)
 end
 
+# Take a file-system path and try to form a concise representation of it
+# based on the package ecosystem
+function short_path(spath::Symbol, filenamecache::Dict{Symbol, String})
+    return get!(filenamecache, spath) do
+        path = string(spath)
+        if isabspath(path)
+            if ispath(path)
+                # try to replace the file-system prefix with a short "@Module" one,
+                # assuming that profile came from the current machine
+                # (or at least has the same file-system layout)
+                root = path
+                while !isempty(root)
+                    root, base = splitdir(root)
+                    isempty(base) && break
+                    @assert startswith(path, root)
+                    for proj in Base.project_names
+                        project_file = joinpath(root, proj)
+                        if Base.isfile_casesensitive(project_file)
+                            pkgid = Base.project_file_name_uuid(project_file, "")
+                            isempty(pkgid.name) && return path # bad Project file
+                            # return the joined the module name prefix and path suffix
+                            path = path[nextind(path, sizeof(root)):end]
+                            return string("@", pkgid.name, path)
+                        end
+                    end
+                end
+            end
+            return path
+        elseif isfile(joinpath(Sys.BINDIR::String, Base.DATAROOTDIR, "julia", "base", path))
+            # do the same mechanic for Base (or Core/Compiler) files as above,
+            # but they start from a relative path
+            return joinpath("@Base", normpath(path))
+        else
+            # for non-existent relative paths (such as "REPL[1]"), just consider simplifying them
+            return normpath(path) # drop leading "./"
+        end
+    end
+end
+
 """
     callers(funcname, [data, lidict], [filename=<filename>], [linerange=<start:stop>]) -> Vector{Tuple{count, lineinfo}}
 
@@ -299,217 +359,306 @@ error_codes = Dict(
 """
     fetch() -> data
 
-Returns a reference to the internal buffer of backtraces. Note that subsequent operations,
-like [`clear`](@ref), can affect `data` unless you first make a copy. Note that the
+Returns a copy of the buffer of profile backtraces. Note that the
 values in `data` have meaning only on this machine in the current session, because it
 depends on the exact memory addresses used in JIT-compiling. This function is primarily for
 internal use; [`retrieve`](@ref) may be a better choice for most users.
 """
 function fetch()
-    len = len_data()
     maxlen = maxlen_data()
+    len = len_data()
     if (len == maxlen)
         @warn """The profile data buffer is full; profiling probably terminated
                  before your program finished. To profile for longer runs, call
                  `Profile.init()` with a larger buffer and/or larger delay."""
     end
-    return unsafe_wrap(Array, get_data_pointer(), (len,))
+    data = Vector{UInt}(undef, len)
+    GC.@preserve data unsafe_copyto!(pointer(data), get_data_pointer(), len)
+    return data
 end
 
 
 ## Print as a flat list
-# Counts the number of times each line appears, at any nesting level
-function count_flat(data::Vector{UInt64})
-    linecount = Dict{UInt64, Int}()
+# Counts the number of times each line appears, at any nesting level and at the topmost level
+# Merging multiple equivalent entries and recursive calls
+function parse_flat(::Type{T}, data::Vector{UInt64}, lidict::Union{LineInfoDict, LineInfoFlatDict}, C::Bool) where {T}
+    lilist = StackFrame[]
+    n = Int[]
+    m = Int[]
+    lilist_idx = Dict{T, Int}()
+    recursive = Set{T}()
+    first = true
+    totalshots = 0
     for ip in data
-        if ip != 0
-            linecount[ip] = get(linecount, ip, 0) + 1
+        if ip == 0
+            totalshots += 1
+            empty!(recursive)
+            first = true
+            continue
         end
-    end
-    iplist = Vector{UInt64}()
-    n = Vector{Int}()
-    for (k, v) in linecount
-        push!(iplist, k)
-        push!(n, v)
-    end
-    return (iplist, n)
-end
-
-function parse_flat(iplist::Vector{UInt64}, n::Vector{Int}, lidict::Union{LineInfoDict, LineInfoFlatDict}, C::Bool)
-    # Convert instruction pointers to names & line numbers
-    lilist = StackFrame[]
-    nlist = Int[]
-    for (ip, count) in zip(iplist, n)
         frames = lidict[ip]
         nframes = (frames isa Vector ? length(frames) : 1)
-        # add all the inlining frames
-        for i = nframes:-1:1
+        for i = 1:nframes
             frame = (frames isa Vector ? frames[i] : frames)
-            # Keep only the interpretable ones
-            # The ones with no line number might appear multiple times in a single
-            # backtrace, giving the wrong impression about the total number of backtraces.
-            # Delete them too.
-            if frame != UNKNOWN && frame.line != 0 && (C || !frame.from_c)
+            !C && frame.from_c && continue
+            key = (T === UInt64 ? ip : frame)
+            idx = get!(lilist_idx, key, length(lilist) + 1)
+            if idx > length(lilist)
+                push!(recursive, key)
                 push!(lilist, frame)
-                push!(nlist, count)
+                push!(n, 1)
+                push!(m, 0)
+            elseif !(key in recursive)
+                push!(recursive, key)
+                n[idx] += 1
+            end
+            if first
+                m[idx] += 1
+                first = false
             end
         end
     end
-    return (lilist, nlist)
+    @assert length(lilist) == length(n) == length(m) == length(lilist_idx)
+    return (lilist, n, m, totalshots)
 end
 
 function flat(io::IO, data::Vector{UInt64}, lidict::Union{LineInfoDict, LineInfoFlatDict}, cols::Int, fmt::ProfileFormat)
-    iplist, n = count_flat(data)
-    lilist, n = parse_flat(iplist, n, lidict, fmt.C)
-    if isempty(n)
+    lilist, n, m, totalshots = parse_flat(fmt.combine ? StackFrame : UInt64, data, lidict, fmt.C)
+    if isempty(lilist)
         warning_empty()
         return
     end
-    print_flat(io, lilist, n, cols, fmt)
+    if false # optional: drop the "non-interpretable" ones
+        keep = map(frame -> frame != UNKNOWN && frame.line != 0, lilist)
+        lilist = lilist[keep]
+        n = n[keep]
+        m = m[keep]
+    end
+    filenamemap = Dict{Symbol,String}()
+    print_flat(io, lilist, n, m, cols, filenamemap, fmt)
+    Base.println(io, "Total snapshots: ", totalshots)
     nothing
 end
 
-function print_flat(io::IO, lilist::Vector{StackFrame}, n::Vector{Int},
-        cols::Int, fmt::ProfileFormat)
-    p = liperm(lilist)
-    lilist = lilist[p]
-    n = n[p]
-    if fmt.combine
-        # now that lilist is sorted by li,
-        # combine adjacent entries that are equivlent
-        j = 1
-        for i = 2:length(lilist)
-            if lilist[i] == lilist[j]
-                n[j] += n[i]
-                n[i] = 0
-            else
-                j = i
-            end
-        end
-        keep = n .> 0
-        n = n[keep]
-        lilist = lilist[keep]
-    end
+function print_flat(io::IO, lilist::Vector{StackFrame},
+        n::Vector{Int}, m::Vector{Int},
+        cols::Int, filenamemap::Dict{Symbol,String},
+        fmt::ProfileFormat)
     if fmt.sortedby === :count
         p = sortperm(n)
-        n = n[p]
-        lilist = lilist[p]
+    elseif fmt.sortedby === :overhead
+        p = sortperm(m)
+    else
+        p = liperm(lilist)
     end
+    lilist = lilist[p]
+    n = n[p]
+    m = m[p]
+    filenames = String[short_path(li.file, filenamemap) for li in lilist]
+    funcnames = String[string(li.func) for li in lilist]
     wcounts = max(6, ndigits(maximum(n)))
-    maxline = 0
+    wself = max(9, ndigits(maximum(m)))
+    maxline = 1
     maxfile = 6
     maxfunc = 10
-    for li in lilist
+    for i in 1:length(lilist)
+        li = lilist[i]
         maxline = max(maxline, li.line)
-        maxfile = max(maxfile, length(string(li.file)))
-        maxfunc = max(maxfunc, length(string(li.func)))
+        maxfunc = max(maxfunc, length(funcnames[i]))
+        maxfile = max(maxfile, length(filenames[i]))
     end
     wline = max(5, ndigits(maxline))
-    ntext = cols - wcounts - wline - 3
-    maxfunc += 25
+    ntext = max(20, cols - wcounts - wself - wline - 3)
+    maxfunc += 25 # for type signatures
     if maxfile + maxfunc <= ntext
         wfile = maxfile
-        wfunc = maxfunc
+        wfunc = ntext - maxfunc # take the full width (for type sig)
     else
-        wfile = floor(Integer, 2*ntext/5)
-        wfunc = floor(Integer, 3*ntext/5)
+        wfile = 2*ntext÷5
+        wfunc = 3*ntext÷5
     end
-    println(io, lpad("Count", wcounts, " "), " ", rpad("File", wfile, " "), " ",
-        lpad("Line", wline, " "), " ", rpad("Function", wfunc, " "))
+    println(io, lpad("Count", wcounts, " "), " ", lpad("Overhead", wself, " "), " ",
+            rpad("File", wfile, " "), " ", lpad("Line", wline, " "), " Function")
+    println(io, lpad("=====", wcounts, " "), " ", lpad("========", wself, " "), " ",
+            rpad("====", wfile, " "), " ", lpad("====", wline, " "), " ========")
     for i = 1:length(n)
         n[i] < fmt.mincount && continue
         li = lilist[i]
         Base.print(io, lpad(string(n[i]), wcounts, " "), " ")
-        Base.print(io, rpad(rtruncto(string(li.file), wfile), wfile, " "), " ")
-        Base.print(io, lpad(string(li.line), wline, " "), " ")
-        fname = string(li.func)
-        if !li.from_c && li.linfo !== nothing
-            fname = sprint(show_spec_linfo, li)
+        Base.print(io, lpad(string(m[i]), wself, " "), " ")
+        if li == UNKNOWN
+            if !fmt.combine && li.pointer != 0
+                Base.print(io, "@0x", string(li.pointer, base=16))
+            else
+                Base.print(io, "[any unknown stackframes]")
+            end
+        else
+            file = filenames[i]
+            isempty(file) && (file = "[unknown file]")
+            Base.print(io, rpad(rtruncto(file, wfile), wfile, " "), " ")
+            Base.print(io, lpad(li.line > 0 ? string(li.line) : "?", wline, " "), " ")
+            fname = funcnames[i]
+            if !li.from_c && li.linfo !== nothing
+                fname = sprint(show_spec_linfo, li)
+            end
+            isempty(fname) && (fname = "[unknown function]")
+            Base.print(io, ltruncto(fname, wfunc))
         end
-        Base.print(io, rpad(ltruncto(fname, wfunc), wfunc, " "))
         println(io)
     end
     nothing
 end
 
 ## A tree representation
-tree_format_linewidth(x::StackFrame) = ndigits(x.line) + 6
 
-function tree_format(lilist::Vector{StackFrame}, counts::Vector{Int}, level::Int, cols::Int)
+# Representation of a prefix trie of backtrace counts
+mutable struct StackFrameTree{T} # where T <: Union{UInt64, StackFrame}
+    # content fields:
+    frame::StackFrame
+    count::Int          # number of frames this appeared in
+    overhead::Int       # number frames where this was the code being executed
+    flat_count::Int     # number of times this frame was in the flattened representation (unlike count, this'll sum to 100% of parent)
+    max_recur::Int      # maximum number of times this frame was the *top* of the recursion in the stack
+    count_recur::Int    # sum of the number of times this frame was the *top* of the recursion in a stack (divide by count to get an average)
+    down::Dict{T, StackFrameTree{T}}
+    # construction workers:
+    recur::Int
+    builder_key::Vector{UInt64}
+    builder_value::Vector{StackFrameTree{T}}
+    up::StackFrameTree{T}
+    StackFrameTree{T}() where {T} = new(UNKNOWN, 0, 0, 0, 0, 0, Dict{T, StackFrameTree{T}}(), 0, UInt64[], StackFrameTree{T}[])
+end
+
+
+const indent_s = "    ╎"^10
+const indent_z = collect(eachindex(indent_s))
+function indent(depth::Int)
+    depth < 1 && return ""
+    depth <= length(indent_z) && return indent_s[1:indent_z[depth]]
+    div, rem = divrem(depth, length(indent_z))
+    indent = indent_s^div
+    rem != 0 && (indent *= SubString(indent_s, 1, indent_z[rem]))
+    return indent
+end
+
+function tree_format(frames::Vector{<:StackFrameTree}, level::Int, cols::Int, maxes, filenamemap::Dict{Symbol,String}, showpointer::Bool)
     nindent = min(cols>>1, level)
-    ndigcounts = ndigits(maximum(counts))
-    ndigline = maximum([tree_format_linewidth(x) for x in lilist])
-    ntext = cols - nindent - ndigcounts - ndigline - 5
-    widthfile = floor(Integer, 0.4ntext)
-    widthfunc = floor(Integer, 0.6ntext)
-    strs = Vector{String}(undef, length(lilist))
+    ndigoverhead = ndigits(maxes.overhead)
+    ndigcounts = ndigits(maxes.count)
+    ndigline = ndigits(maximum(frame.frame.line for frame in frames)) + 6
+    ntext = max(30, cols - ndigoverhead - nindent - ndigcounts - ndigline - 6)
+    widthfile = 2*ntext÷5 # min 12
+    widthfunc = 3*ntext÷5 # min 18
+    strs = Vector{String}(undef, length(frames))
     showextra = false
     if level > nindent
         nextra = level - nindent
         nindent -= ndigits(nextra) + 2
         showextra = true
     end
-    for i = 1:length(lilist)
-        li = lilist[i]
+    for i = 1:length(frames)
+        frame = frames[i]
+        li = frame.frame
+        stroverhead = lpad(frame.overhead > 0 ? string(frame.overhead) : "", ndigoverhead, " ")
+        base = nindent == 0 ? "" : indent(nindent - 1) * " "
+        if showextra
+            base = string(base, "+", nextra, " ")
+        end
+        strcount = rpad(string(frame.count), ndigcounts, " ")
         if li != UNKNOWN
-            base = " "^nindent
-            if showextra
-                base = string(base, "+", nextra, " ")
-            end
             if li.line == li.pointer
-                strs[i] = string(base,
-                    rpad(string(counts[i]), ndigcounts, " "),
-                    " ",
-                    "unknown function (pointer: 0x",
+                strs[i] = string(stroverhead, "╎", base, strcount, " ",
+                    "[unknown function] (pointer: 0x",
                     string(li.pointer, base = 16, pad = 2*sizeof(Ptr{Cvoid})),
                     ")")
             else
-                fname = string(li.func)
                 if !li.from_c && li.linfo !== nothing
                     fname = sprint(show_spec_linfo, li)
+                else
+                    fname = string(li.func)
+                end
+                filename = short_path(li.file, filenamemap)
+                if showpointer
+                    fname = string(
+                        "0x",
+                        string(li.pointer, base = 16, pad = 2*sizeof(Ptr{Cvoid})),
+                        " ",
+                        fname)
                 end
-                strs[i] = string(base,
-                    rpad(string(counts[i]), ndigcounts, " "),
-                    " ",
-                    rtruncto(string(li.file), widthfile),
+                strs[i] = string(stroverhead, "╎", base, strcount, " ",
+                    rtruncto(filename, widthfile),
                     ":",
                     li.line == -1 ? "?" : string(li.line),
                     "; ",
                     ltruncto(fname, widthfunc))
             end
         else
-            strs[i] = ""
+            strs[i] = string(stroverhead, "╎", base, strcount, " [unknown stackframe]")
         end
     end
     return strs
 end
 
-# Construct a prefix trie of backtrace counts
-mutable struct StackFrameTree{T} # where T <: Union{UInt64, StackFrame}
-    # content fields:
-    frame::StackFrame
-    count::Int
-    down::Dict{T, StackFrameTree{T}}
-    # construction helpers:
-    builder_key::Vector{UInt64}
-    builder_value::Vector{StackFrameTree{T}}
-    up::StackFrameTree{T}
-    StackFrameTree{T}() where {T} = new(UNKNOWN, 0, Dict{T, StackFrameTree{T}}(), UInt64[], StackFrameTree{T}[])
-end
-
 # turn a list of backtraces into a tree (implicitly separated by NULL markers)
-function tree!(root::StackFrameTree{T}, all::Vector{UInt64}, lidict::Union{LineInfoFlatDict, LineInfoDict}, C::Bool) where {T}
+function tree!(root::StackFrameTree{T}, all::Vector{UInt64}, lidict::Union{LineInfoFlatDict, LineInfoDict}, C::Bool, recur::Symbol) where {T}
     parent = root
-    for i in length(all):-1:1
+    tops = Vector{StackFrameTree{T}}()
+    build = Vector{StackFrameTree{T}}()
+    startframe = length(all)
+    for i in startframe:-1:1
         ip = all[i]
         if ip == 0
             # sentinel value indicates the start of a new backtrace
+            empty!(build)
+            root.recur = 0
+            if recur !== :off
+                # We mark all visited nodes to so we'll only count those branches
+                # once for each backtrace. Reset that now for the next backtrace.
+                push!(tops, parent)
+                for top in tops
+                    while top.recur != 0
+                        top.max_recur < top.recur && (top.max_recur = top.recur)
+                        top.recur = 0
+                        top = top.up
+                    end
+                end
+                empty!(tops)
+            end
+            let this = parent
+                while this !== root
+                    this.flat_count += 1
+                    this = this.up
+                end
+            end
+            parent.overhead += 1
             parent = root
-            parent.count += 1
+            root.count += 1
+            startframe = i
         else
+            pushfirst!(build, parent)
+            if recur === :flat || recur === :flatc
+                # Rewind the `parent` tree back, if this exact ip was already present *higher* in the current tree
+                found = false
+                for j in 1:(startframe - i)
+                    if ip == all[i + j]
+                        if recur === :flat # if not flattening C frames, check that now
+                            frames = lidict[ip]
+                            frame = (frames isa Vector ? frames[1] : frames)
+                            frame.from_c && break # not flattening this frame
+                        end
+                        push!(tops, parent)
+                        parent = build[j]
+                        parent.recur += 1
+                        parent.count_recur += 1
+                        found = true
+                        break
+                    end
+                end
+                found && continue
+            end
             builder_key = parent.builder_key
             builder_value = parent.builder_value
-            fastkey = searchsortedfirst(parent.builder_key, ip)
+            fastkey = searchsortedfirst(builder_key, ip)
             if fastkey < length(builder_key) && builder_key[fastkey] === ip
                 # jump forward to the end of the inlining chain
                 # avoiding an extra (slow) lookup of `ip` in `lidict`
@@ -517,8 +666,9 @@ function tree!(root::StackFrameTree{T},
                 # note that we may even have this === parent (if we're ignoring this frame ip)
                 this = builder_value[fastkey]
                 let this = this
-                    while this !== parent
+                    while this !== parent && (recur === :off || this.recur == 0)
                         this.count += 1
+                        this.recur = 1
                         this = this.up
                     end
                 end
@@ -533,12 +683,13 @@ function tree!(root::StackFrameTree{T},
                 frame = (frames isa Vector ? frames[i] : frames)
                 !C && frame.from_c && continue
                 key = (T === UInt64 ? ip : frame)
-                this = get!(parent.down, key) do
-                    return StackFrameTree{T}()
+                this = get!(StackFrameTree{T}, parent.down, key)
+                if recur === :off || this.recur == 0
+                    this.frame = frame
+                    this.up = parent
+                    this.count += 1
+                    this.recur = 1
                 end
-                this.frame = frame
-                this.up = parent
-                this.count += 1
                 parent = this
             end
             # record where the end of this chain is for this ip
@@ -547,9 +698,10 @@ function tree!(root::StackFrameTree{T},
         end
     end
     function cleanup!(node::StackFrameTree)
-        stack = StackFrameTree[node]
+        stack = [node]
         while !isempty(stack)
             node = pop!(stack)
+            node.recur = 0
             empty!(node.builder_key)
             empty!(node.builder_value)
             append!(stack, values(node.down))
@@ -560,10 +712,31 @@ function tree!(root::StackFrameTree{T},
     return root
 end
 
+function maxstats(root::StackFrameTree)
+    maxcount = Ref(0)
+    maxflatcount = Ref(0)
+    maxoverhead = Ref(0)
+    maxmaxrecur = Ref(0)
+    stack = [root]
+    while !isempty(stack)
+        node = pop!(stack)
+        maxcount[] = max(maxcount[], node.count)
+        maxoverhead[] = max(maxoverhead[], node.overhead)
+        maxflatcount[] = max(maxflatcount[], node.flat_count)
+        maxmaxrecur[] = max(maxmaxrecur[], node.max_recur)
+        append!(stack, values(node.down))
+    end
+    return (count=maxcount[], count_flat=maxflatcount[], overhead=maxoverhead[], max_recur=maxmaxrecur[])
+end
+
 # Print the stack frame tree starting at a particular root. Uses a worklist to
 # avoid stack overflows.
-function tree(io::IO, bt::StackFrameTree, cols::Int, fmt::ProfileFormat)
+function print_tree(io::IO, bt::StackFrameTree{T}, cols::Int, fmt::ProfileFormat) where T
+    maxes = maxstats(bt)
+    filenamemap = Dict{Symbol,String}()
     worklist = [(bt, 0, 0, "")]
+    println(io, "Overhead ╎ [+additional indent] Count File:Line; Function")
+    println(io, "=========================================================")
     while !isempty(worklist)
         (bt, level, noisefloor, str) = popfirst!(worklist)
         isempty(str) || println(io, str)
@@ -571,18 +744,28 @@ function tree(io::IO, bt::StackFrameTree
         isempty(bt.down) && continue
         # Order the line information
         nexts = collect(values(bt.down))
-        lilist = collect(frame.frame for frame in nexts)
-        counts = collect(frame.count for frame in nexts)
         # Generate the string for each line
-        strs = tree_format(lilist, counts, level, cols)
+        strs = tree_format(nexts, level, cols, maxes, filenamemap, T === UInt64)
         # Recurse to the next level
-        for i in reverse(liperm(lilist))
+        if fmt.sortedby === :count
+            counts = collect(frame.count for frame in nexts)
+            p = sortperm(counts)
+        elseif fmt.sortedby === :overhead
+            m = collect(frame.overhead for frame in nexts)
+            p = sortperm(m)
+        elseif fmt.sortedby === :flat_count
+            m = collect(frame.flat_count for frame in nexts)
+            p = sortperm(m)
+        else
+            lilist = collect(frame.frame for frame in nexts)
+            p = liperm(lilist)
+        end
+        for i in reverse(p)
             down = nexts[i]
             count = down.count
             count < fmt.mincount && continue
             count < noisefloor && continue
             str = strs[i]
-            isempty(str) && (str = "$count unknown stackframe")
             noisefloor_down = fmt.noisefloor > 0 ? floor(Int, fmt.noisefloor * sqrt(count)) : 0
             pushfirst!(worklist, (down, level + 1, noisefloor_down, str))
         end
@@ -591,15 +774,16 @@ end
 
 function tree(io::IO, data::Vector{UInt64}, lidict::Union{LineInfoFlatDict, LineInfoDict}, cols::Int, fmt::ProfileFormat)
     if fmt.combine
-        root = tree!(StackFrameTree{StackFrame}(), data, lidict, fmt.C)
+        root = tree!(StackFrameTree{StackFrame}(), data, lidict, fmt.C, fmt.recur)
     else
-        root = tree!(StackFrameTree{UInt64}(), data, lidict, fmt.C)
+        root = tree!(StackFrameTree{UInt64}(), data, lidict, fmt.C, fmt.recur)
     end
     if isempty(root.down)
         warning_empty()
         return
     end
-    tree(io, root, cols, fmt)
+    print_tree(io, root, cols, fmt)
+    Base.println(io, "Total snapshots: ", root.count)
     nothing
 end
 
diff -pruN 1.3.1+dfsg-1/stdlib/Profile/test/runtests.jl 1.4.0+dfsg-1/stdlib/Profile/test/runtests.jl
--- 1.3.1+dfsg-1/stdlib/Profile/test/runtests.jl	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/stdlib/Profile/test/runtests.jl	2020-03-21 16:36:32.000000000 +0000
@@ -22,6 +22,7 @@ end
     end
 end
 
+busywait(0, 0) # compile
 @profile busywait(1, 20)
 
 let r = Profile.retrieve()
@@ -52,8 +53,16 @@ let iobuf = IOBuffer()
     truncate(iobuf, 0)
     Profile.print(iobuf, format=:flat, sortedby=:count)
     @test !isempty(String(take!(iobuf)))
-    Profile.clear()
-    @test isempty(Profile.fetch())
+    Profile.print(iobuf, format=:tree, recur=:flat)
+    str = String(take!(iobuf))
+    @test !isempty(str)
+    truncate(iobuf, 0)
+end
+
+Profile.clear()
+@test isempty(Profile.fetch())
+
+let
     @test Profile.callers("\\") !== nothing
     @test Profile.callers(\) !== nothing
     # linerange with no filename provided should fail
diff -pruN 1.3.1+dfsg-1/stdlib/Random/docs/src/index.md 1.4.0+dfsg-1/stdlib/Random/docs/src/index.md
--- 1.3.1+dfsg-1/stdlib/Random/docs/src/index.md	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/stdlib/Random/docs/src/index.md	2020-03-21 16:36:32.000000000 +0000
@@ -285,7 +285,10 @@ The API is not clearly defined yet, but
    should be defined for this specific RNG, if they are needed;
 2) other documented `rand` methods accepting an `AbstractRNG` should work out of the box,
    (provided the methods from 1) what are relied on are implemented),
-   but can of course be specialized for this RNG if there is room for optimization.
+   but can of course be specialized for this RNG if there is room for optimization;
+3) `copy` for pseudo-RNGs should return an independent copy that generates the exact same random sequence as the
+   original from that point when called in the same way. When this is not feasible (e.g. hardware-based RNGs),
+   `copy` must not be implemented.
 
 Concerning 1), a `rand` method may happen to work automatically, but it's not officially
 supported and may break without warnings in a subsequent release.
@@ -323,3 +326,14 @@ The non-mutating array method of `rand`
 ```@meta
 DocTestSetup = nothing
 ```
+
+# Reproducibility
+
+By using an RNG parameter initialized with a given seed, you can reproduce the same pseudorandom number sequence when running your program multiple times.  However, a minor release of Julia (e.g. 1.3 to 1.4) *may change* the sequence of pseudorandom numbers generated from a specific seed.  (Even if the sequence produced by a low-level function like [`rand`](@ref) does not change, the output of higher-level functions like [`randsubseq`](@ref) may change due to algorithm updates.)   Rationale: guaranteeing that pseudorandom streams never change prohibits many algorithmic improvements.
+
+If you need to guarantee exact reproducibility of random data, it is advisable to simply *save the data* (e.g. as a supplementary attachment in a scientific publication).  (You can also, of course, specify a
+particular Julia version and package manifest, especially if you require bit reproducibility.)
+
+Software tests that rely on *specific* "random" data should also generally save the data or embed it into the test code.  On the other hand, tests that should pass for *most* random data (e.g. testing `A \ (A*x) ≈ x` for a random matrix `A = randn(n,n)`) can use an RNG with a fixed seed to ensure that simply running the test many times does not encounter a failure due to very improbable data (e.g. an extremely ill-conditioned matrix).
+
+The statistical *distribution* from which random samples are drawn *is* guaranteed to be the same across any minor Julia releases.
diff -pruN 1.3.1+dfsg-1/stdlib/Random/src/generation.jl 1.4.0+dfsg-1/stdlib/Random/src/generation.jl
--- 1.3.1+dfsg-1/stdlib/Random/src/generation.jl	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/stdlib/Random/src/generation.jl	2020-03-21 16:36:32.000000000 +0000
@@ -464,20 +464,25 @@ function rand(rng::AbstractRNG, sp::Samp
     @inbounds return sp[][1 + r ÷ 0x0005555555555555]
 end
 
-### 4
-
-Sampler(RNG::Type{<:AbstractRNG}, t::Tuple{A,B,C,D}, n::Repetition) where {A,B,C,D} =
-    SamplerSimple(t, Sampler(RNG, UInt52Raw(Int), n))
-
-function rand(rng::AbstractRNG, sp::SamplerSimple{Tuple{A,B,C,D}}) where {A,B,C,D}
-    r = rand(rng, sp.data) & 3
-    @inbounds return sp[][1 + r]
-end
-
 ### n
 
-Sampler(RNG::Type{<:AbstractRNG}, t::Tuple, n::Repetition) =
-    SamplerSimple(t, Sampler(RNG, Base.OneTo(length(t)), n))
+@generated function Sampler(RNG::Type{<:AbstractRNG}, t::Tuple, n::Repetition)
+    l = fieldcount(t)
+    if l < typemax(UInt32) && ispow2(l)
+        :(SamplerSimple(t, Sampler(RNG, UInt32, n)))
+    else
+        :(SamplerSimple(t, Sampler(RNG, Base.OneTo(length(t)), n)))
+    end
+end
 
-rand(rng::AbstractRNG, sp::SamplerSimple{<:Tuple}) =
-    @inbounds return sp[][rand(rng, sp.data)]
+@generated function rand(rng::AbstractRNG, sp::SamplerSimple{T}) where T<:Tuple
+    l = fieldcount(T)
+    if l < typemax(UInt32) && ispow2(l)
+        quote
+            r = rand(rng, sp.data) & ($l-1)
+            @inbounds return sp[][1 + r]
+        end
+    else
+        :(@inbounds return sp[][rand(rng, sp.data)])
+    end
+end
diff -pruN 1.3.1+dfsg-1/stdlib/Random/src/Random.jl 1.4.0+dfsg-1/stdlib/Random/src/Random.jl
--- 1.3.1+dfsg-1/stdlib/Random/src/Random.jl	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/stdlib/Random/src/Random.jl	2020-03-21 16:36:32.000000000 +0000
@@ -16,10 +16,8 @@ using Base.GMP: Limb
 
 using Base: BitInteger, BitInteger_types, BitUnsigned, require_one_based_indexing
 
-import Base: copymutable, copy, copy!, ==, hash, convert
-using Serialization
-import Serialization: serialize, deserialize
-import Base: rand, randn
+import Base: copymutable, copy, copy!, ==, hash, convert,
+             rand, randn
 
 export rand!, randn!,
        randexp, randexp!,
@@ -40,6 +38,8 @@ Supertype for random number generators s
 """
 abstract type AbstractRNG end
 
+Base.broadcastable(x::AbstractRNG) = Ref(x)
+
 gentype(::Type{X}) where {X} = eltype(X)
 gentype(x) = gentype(typeof(x))
 
@@ -313,6 +313,9 @@ Pick a random element or array of random
   point numbers and to ``[0, 1)+i[0, 1)]`` for complex floating point numbers;
 
 `S` defaults to [`Float64`](@ref).
+When only one argument is passed besides the optional `rng` and is a `Tuple`, it is interpreted
+as a collection of values (`S`) and not as `dims`.
+
 
 !!! compat "Julia 1.1"
     Support for `S` as a tuple requires at least Julia 1.1.
@@ -328,6 +331,14 @@ julia> using Random
 
 julia> rand(MersenneTwister(0), Dict(1=>2, 3=>4))
 1=>2
+
+julia> rand((2, 3))
+3
+
+julia> rand(Float64, (2, 3))
+2×3 Array{Float64,2}:
+ 0.999717  0.0143835  0.540787
+ 0.696556  0.783855   0.938235
 ```
 
 !!! note
diff -pruN 1.3.1+dfsg-1/stdlib/Random/src/RNGs.jl 1.4.0+dfsg-1/stdlib/Random/src/RNGs.jl
--- 1.3.1+dfsg-1/stdlib/Random/src/RNGs.jl	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/stdlib/Random/src/RNGs.jl	2020-03-21 16:36:32.000000000 +0000
@@ -19,36 +19,37 @@ if Sys.iswindows()
     end
 else # !windows
     struct RandomDevice <: AbstractRNG
-        file::IOStream
         unlimited::Bool
 
-        RandomDevice(; unlimited::Bool=true) =
-            new(open(unlimited ? "/dev/urandom" : "/dev/random"), unlimited)
+        RandomDevice(; unlimited::Bool=true) = new(unlimited)
     end
 
-    rand(rd::RandomDevice, sp::SamplerBoolBitInteger) = read( rd.file, sp[])
+    rand(rd::RandomDevice, sp::SamplerBoolBitInteger) = read(getfile(rd), sp[])
 
-    function serialize(s::AbstractSerializer, rd::RandomDevice)
-        Serialization.serialize_type(s, typeof(rd))
-        serialize(s, rd.unlimited)
-    end
-    function deserialize(s::AbstractSerializer, t::Type{RandomDevice})
-        unlimited = deserialize(s)
-        return RandomDevice(unlimited=unlimited)
+    function getfile(rd::RandomDevice)
+        devrandom = rd.unlimited ? DEV_URANDOM : DEV_RANDOM
+        # TODO: there is a data-race, this can leak up to nthreads() copies of the file descriptors,
+        # so use a "thread-once" utility once available
+        isassigned(devrandom) || (devrandom[] = open(rd.unlimited ? "/dev/urandom" : "/dev/random"))
+        devrandom[]
     end
 
+    const DEV_RANDOM  = Ref{IOStream}()
+    const DEV_URANDOM = Ref{IOStream}()
+
 end # os-test
 
 # NOTE: this can't be put within the if-else block above
 for T in (Bool, BitInteger_types...)
     if Sys.iswindows()
         @eval function rand!(rd::RandomDevice, A::Array{$T}, ::SamplerType{$T})
-            ccall((:SystemFunction036, :Advapi32), stdcall, UInt8, (Ptr{Cvoid}, UInt32),
-                  A, sizeof(A))
+            Base.windowserror("SystemFunction036 (RtlGenRandom)", 0 == ccall(
+                (:SystemFunction036, :Advapi32), stdcall, UInt8, (Ptr{Cvoid}, UInt32),
+                  A, sizeof(A)))
             A
         end
     else
-        @eval rand!(rd::RandomDevice, A::Array{$T}, ::SamplerType{$T}) = read!(rd.file, A)
+        @eval rand!(rd::RandomDevice, A::Array{$T}, ::SamplerType{$T}) = read!(getfile(rd), A)
     end
 end
 
@@ -295,7 +296,7 @@ seed!(seed::Union{Integer,Vector{UInt32}
 const THREAD_RNGs = MersenneTwister[]
 @inline default_rng() = default_rng(Threads.threadid())
 @noinline function default_rng(tid::Int)
-    @assert 0 < tid <= length(THREAD_RNGs)
+    0 < tid <= length(THREAD_RNGs) || _rng_length_assert()
     if @inbounds isassigned(THREAD_RNGs, tid)
         @inbounds MT = THREAD_RNGs[tid]
     else
@@ -304,6 +305,8 @@ const THREAD_RNGs = MersenneTwister[]
     end
     return MT
 end
+@noinline _rng_length_assert() =  @assert false "0 < tid <= length(THREAD_RNGs)"
+
 function __init__()
     resize!(empty!(THREAD_RNGs), Threads.nthreads()) # ensures that we didn't save a bad object
 end
@@ -601,7 +604,7 @@ end
 #### from a range
 
 for T in BitInteger_types, R=(1, Inf) # eval because of ambiguity otherwise
-    @eval Sampler(::Type{MersenneTwister}, r::UnitRange{$T}, ::Val{$R}) =
+    @eval Sampler(::Type{MersenneTwister}, r::AbstractUnitRange{$T}, ::Val{$R}) =
         SamplerRangeFast(r)
 end
 
diff -pruN 1.3.1+dfsg-1/stdlib/Random/test/runtests.jl 1.4.0+dfsg-1/stdlib/Random/test/runtests.jl
--- 1.3.1+dfsg-1/stdlib/Random/test/runtests.jl	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/stdlib/Random/test/runtests.jl	2020-03-21 16:36:32.000000000 +0000
@@ -774,3 +774,7 @@ end
     @test Sampler(GLOBAL_RNG, 2:4, Val(1)) isa SamplerRangeFast
     @test Sampler(GLOBAL_RNG, 2:4, Val(Inf)) isa SamplerRangeFast
 end
+
+@testset "RNGs broadcast as scalars: T" for T in (MersenneTwister, RandomDevice)
+    @test length.(rand.(T(), 1:3)) == 1:3
+end
diff -pruN 1.3.1+dfsg-1/stdlib/REPL/docs/src/index.md 1.4.0+dfsg-1/stdlib/REPL/docs/src/index.md
--- 1.3.1+dfsg-1/stdlib/REPL/docs/src/index.md	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/stdlib/REPL/docs/src/index.md	2020-03-21 16:36:32.000000000 +0000
@@ -52,6 +52,38 @@ If it is enabled, you can try it out by
 the REPL. This feature does not work on the standard Windows command prompt due to its limitation
 at detecting when a paste occurs.
 
+Objects are printed at the REPL using the [`show`](@ref) function with a specific [`IOContext`](@ref).
+In particular, the `:limit` attribute is set to `true`.
+Other attributes can receive in certain `show` methods a default value if it's not already set,
+like `:compact`.
+It's possible, as an experimental feature, to specify the attributes used by the REPL via the
+`Base.active_repl.options.iocontext` dictionary (associating values to attributes). For example:
+
+```julia-repl
+julia> rand(2, 2)
+2×2 Array{Float64,2}:
+ 0.8833    0.329197
+ 0.719708  0.59114
+
+julia> show(IOContext(stdout, :compact => false), "text/plain", rand(2, 2))
+ 0.43540323669187075  0.15759787870609387
+ 0.2540832269192739   0.4597637838786053
+julia> Base.active_repl.options.iocontext[:compact] = false;
+
+julia> rand(2, 2)
+2×2 Array{Float64,2}:
+ 0.2083967319174056  0.13330606013126012
+ 0.6244375177790158  0.9777957560761545
+```
+
+In order to define automatically the values of this dictionary at startup time, one can use the
+[`atreplinit`](@ref) function in the `~/.julia/config/startup.jl` file, for example:
+```julia
+atreplinit() do repl
+    repl.options.iocontext[:compact] = false
+end
+```
+
 ### Help mode
 
 When the cursor is at the beginning of the line, the prompt can be changed to a help mode by typing
@@ -123,7 +155,7 @@ The Julia REPL makes great use of key bi
 above (`^D` to exit, `^R` and `^S` for searching), but there are many more. In addition to the
 control-key, there are also meta-key bindings. These vary more by platform, but most terminals
 default to using alt- or option- held down with a key to send the meta-key (or can be configured
-to do so).
+to do so), or pressing Esc and then the key.
 
 | Keybinding          | Description                                                                                                |
 |:------------------- |:---------------------------------------------------------------------------------------------------------- |
@@ -174,15 +206,18 @@ to do so).
 | `^Q`                | Write a number in REPL and press `^Q` to open editor at corresponding stackframe or method                 |
 | `meta-Left Arrow`   | indent the current line on the left                                                                        |
 | `meta-Right Arrow`  | indent the current line on the right                                                                       |
-
+| `meta-.`            | insert last word from previous history entry                                                               |
 
 ### Customizing keybindings
 
 Julia's REPL keybindings may be fully customized to a user's preferences by passing a dictionary
 to `REPL.setup_interface`. The keys of this dictionary may be characters or strings. The key
 `'*'` refers to the default action. Control plus character `x` bindings are indicated with `"^x"`.
-Meta plus `x` can be written `"\\Mx"`. The values of the custom keymap must be `nothing` (indicating
-that the input should be ignored) or functions that accept the signature `(PromptState, AbstractREPL, Char)`.
+Meta plus `x` can be written `"\\M-x"` or `"\ex"`, and Control plus `x` can be written
+`"\\C-x"` or `"^x"`.
+The values of the custom keymap must be `nothing` (indicating
+that the input should be ignored) or functions that accept the signature
+`(PromptState, AbstractREPL, Char)`.
 The `REPL.setup_interface` function must be called before the REPL is initialized, by registering
 the operation with [`atreplinit`](@ref) . For example, to bind the up and down arrow keys to move through
 history without prefix search, one could put the following code in `~/.julia/config/startup.jl`:
diff -pruN 1.3.1+dfsg-1/stdlib/REPL/src/docview.jl 1.4.0+dfsg-1/stdlib/REPL/src/docview.jl
--- 1.3.1+dfsg-1/stdlib/REPL/src/docview.jl	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/stdlib/REPL/src/docview.jl	2020-03-21 16:36:32.000000000 +0000
@@ -133,6 +133,8 @@ doc(object, sig...)              = doc(o
 function lookup_doc(ex)
     if haskey(keywords, ex)
         parsedoc(keywords[ex])
+    elseif Meta.isexpr(ex, :incomplete)
+        return :($(Markdown.md"No documentation found."))
     elseif isa(ex, Union{Expr, Symbol})
         binding = esc(bindingexpr(namify(ex)))
         if isexpr(ex, :call) || isexpr(ex, :macrocall)
diff -pruN 1.3.1+dfsg-1/stdlib/REPL/src/LineEdit.jl 1.4.0+dfsg-1/stdlib/REPL/src/LineEdit.jl
--- 1.3.1+dfsg-1/stdlib/REPL/src/LineEdit.jl	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/stdlib/REPL/src/LineEdit.jl	2020-03-21 16:36:32.000000000 +0000
@@ -94,10 +94,10 @@ options(s::PromptState) =
     end
 
 function setmark(s::MIState, guess_region_active::Bool=true)
-    was_active = is_region_active(s)
-    guess_region_active && activate_region(s, s.key_repeats > 0 ? :mark : :off)
+    refresh = set_action!(s, :setmark)
+    s.current_action === :setmark && s.key_repeats > 0 && activate_region(s, :mark)
     mark(buffer(s))
-    was_active && refresh_line(s)
+    refresh && refresh_line(s)
     nothing
 end
 
@@ -239,30 +239,35 @@ function preserve_active(command::Symbol
     command ∈ [:edit_indent, :edit_transpose_lines_down!, :edit_transpose_lines_up!]
 end
 
+# returns whether the "active region" status changed visibly,
+# i.e. whether there should be a visual refresh
 function set_action!(s::MIState, command::Symbol)
     # if a command is already running, don't update the current_action field,
     # as the caller is used as a helper function
-    s.current_action === :unknown || return
+    s.current_action === :unknown || return false
+
+    active = region_active(s)
+
+    ## record current action
+    s.current_action = command
 
     ## handle activeness of the region
-    is_shift_move(cmd) = startswith(String(cmd), "shift_")
-    if is_shift_move(command)
-        if region_active(s) !== :shift
-            setmark(s, false)
+    if startswith(String(command), "shift_") # shift-move command
+        if active !== :shift
+            setmark(s) # s.current_action must already have been set
             activate_region(s, :shift)
             # NOTE: if the region was already active from a non-shift
             # move (e.g. ^Space^Space), the region is visibly changed
+            return active !== :off # active status is reset
         end
     elseif !(preserve_active(command) ||
              command_group(command) === :movement && region_active(s) === :mark)
         # if we move after a shift-move, the region is de-activated
         # (e.g. like emacs behavior)
         deactivate_region(s)
+        return active !== :off
     end
-
-    ## record current action
-    s.current_action = command
-    nothing
+    false
 end
 
 set_action!(s, command::Symbol) = nothing
@@ -375,11 +380,13 @@ refresh_multi_line(s::ModeState; kw...)
 refresh_multi_line(termbuf::TerminalBuffer, s::ModeState; kw...) = refresh_multi_line(termbuf, terminal(s), s; kw...)
 refresh_multi_line(termbuf::TerminalBuffer, term, s::ModeState; kw...) = (@assert term == terminal(s); refresh_multi_line(termbuf,s; kw...))
 
-function refresh_multi_line(termbuf::TerminalBuffer, terminal::UnixTerminal, buf::IOBuffer, state::InputAreaState, prompt = "";
+function refresh_multi_line(termbuf::TerminalBuffer, terminal::UnixTerminal, buf::IOBuffer,
+                            state::InputAreaState, prompt = "";
                             indent = 0, region_active = false)
     _clear_input_area(termbuf, state)
 
     cols = width(terminal)
+    rows = height(terminal)
     curs_row = -1 # relative to prompt (1-based)
     curs_pos = -1 # 1-based column position of the cursor
     cur_row = 0   # count of the number of rows
@@ -395,16 +402,31 @@ function refresh_multi_line(termbuf::Ter
     # Now go through the buffer line by line
     seek(buf, 0)
     moreinput = true # add a blank line if there is a trailing newline on the last line
+    lastline = false # indicates when to stop printing lines, even when there are potentially
+                     # more (for the case where rows is too small to print everything)
+                     # Note: when there are too many lines for rows, we still print the first lines
+                     # even if they are going to not be visible in the end: for simplicity, but
+                     # also because it does the 'right thing' when the window is resized
     while moreinput
-        l = readline(buf, keep=true)
-        moreinput = endswith(l, "\n")
+        line = readline(buf, keep=true)
+        moreinput = endswith(line, "\n")
+        if rows == 1 && line_pos <= sizeof(line) - moreinput
+            # we special case rows == 1, as otherwise by the time the cursor is seen to
+            # be in the current line, it's too late to chop the '\n' away
+            lastline = true
+            curs_row = 1
+            curs_pos = lindent + line_pos
+        end
+        if moreinput && lastline # we want to print only one "visual" line, so
+            line = chomp(line)   # don't include the trailing "\n"
+        end
         # We need to deal with on-screen characters, so use textwidth to compute occupied columns
-        llength = textwidth(l)
-        slength = sizeof(l)
+        llength = textwidth(line)
+        slength = sizeof(line)
         cur_row += 1
         # lwrite: what will be written to termbuf
-        lwrite = region_active ? highlight_region(l, regstart, regstop, written, slength) :
-                                 l
+        lwrite = region_active ? highlight_region(line, regstart, regstop, written, slength) :
+                                 line
         written += slength
         cmove_col(termbuf, lindent + 1)
         write(termbuf, lwrite)
@@ -414,7 +436,9 @@ function refresh_multi_line(termbuf::Ter
             line_pos -= slength # '\n' gets an extra pos
             # in this case, we haven't yet written the cursor position
             if line_pos < 0 || !moreinput
-                num_chars = (line_pos >= 0 ? llength : textwidth(l[1:prevind(l, line_pos + slength + 1)]))
+                num_chars = line_pos >= 0 ?
+                                llength :
+                                textwidth(line[1:prevind(line, line_pos + slength + 1)])
                 curs_row, curs_pos = divrem(lindent + num_chars - 1, cols)
                 curs_row += cur_row
                 curs_pos += 1
@@ -434,6 +458,12 @@ function refresh_multi_line(termbuf::Ter
         end
         cur_row += div(max(lindent + llength + miscountnl - 1, 0), cols)
         lindent = indent < 0 ? lindent : indent
+
+        lastline && break
+        if curs_row >= 0 && cur_row + 1 >= rows &&             # when too many lines,
+                            cur_row - curs_row + 1 >= rows ÷ 2 # center the cursor
+            lastline = true
+        end
     end
     seek(buf, buf_pos)
 
@@ -1078,7 +1108,7 @@ function edit_lower_case(s)
 end
 function edit_title_case(s)
     set_action!(s, :edit_title_case)
-    return edit_replace_word_right(s, uppercasefirst)
+    return edit_replace_word_right(s, titlecase)
 end
 
 function edit_replace_word_right(s, replace::Function)
@@ -1270,12 +1300,12 @@ function normalize_key(key::AbstractStri
             c, i = iterate(key, i)
             if c == 'C'
                 c, i = iterate(key, i)
-                @assert c == '-'
+                c == '-' || error("the Control key specifier must start with \"\\\\C-\"")
                 c, i = iterate(key, i)
                 write(buf, uppercase(c)-64)
             elseif c == 'M'
                 c, i = iterate(key, i)
-                @assert c == '-'
+                c == '-' || error("the Meta key specifier must start with \"\\\\M-\"")
                 c, i = iterate(key, i)
                 write(buf, '\e')
                 write(buf, c)
@@ -1327,9 +1357,17 @@ struct KeyAlias
     KeyAlias(seq) = new(normalize_key(seq))
 end
 
-function match_input(k::Function, s, term, cs, keymap)
+function match_input(f::Function, s, term, cs, keymap)
     update_key_repeats(s, cs)
-    return keymap_fcn(k, String(cs))
+    c = String(cs)
+    return function (s, p)
+        r = Base.invokelatest(f, s, p, c)
+        if isa(r, Symbol)
+            return r
+        else
+            return :ok
+        end
+    end
 end
 
 match_input(k::Nothing, s, term, cs, keymap) = (s,p) -> return :ok
@@ -1339,29 +1377,17 @@ match_input(k::KeyAlias, s, term, cs, ke
 function match_input(k::Dict, s, term=terminal(s), cs=Char[], keymap = k)
     # if we run out of characters to match before resolving an action,
     # return an empty keymap function
-    eof(term) && return keymap_fcn(nothing, "")
+    eof(term) && return (s, p) -> :abort
     c = read(term, Char)
     # Ignore any `wildcard` as this is used as a
     # placeholder for the wildcard (see normalize_key("*"))
-    c == wildcard && return keymap_fcn(nothing, "")
+    c == wildcard && return (s, p) -> :ok
     push!(cs, c)
     key = haskey(k, c) ? c : wildcard
     # if we don't match on the key, look for a default action then fallback on 'nothing' to ignore
     return match_input(get(k, key, nothing), s, term, cs, keymap)
 end
 
-keymap_fcn(f::Nothing, c) = (s, p) -> return :ok
-function keymap_fcn(f::Function, c)
-    return function (s, p)
-        r = Base.invokelatest(f, s, p, c)
-        if isa(r, Symbol)
-            return r
-        else
-            return :ok
-        end
-    end
-end
-
 update_key_repeats(s, keystroke) = nothing
 function update_key_repeats(s::MIState, keystroke)
     s.key_repeats  = s.previous_key == keystroke ? s.key_repeats + 1 : 0
@@ -1942,6 +1968,25 @@ function move_line_end(buf::IOBuffer)
     nothing
 end
 
+edit_insert_last_word(s::MIState) =
+    edit_insert(s, get_last_word(IOBuffer(mode(s).hist.history[end])))
+
+function get_last_word(buf::IOBuffer)
+    move_line_end(buf)
+    char_move_word_left(buf)
+    posbeg = position(buf)
+    char_move_word_right(buf)
+    posend = position(buf)
+    buf = take!(buf)
+    word = String(buf[posbeg+1:posend])
+    rest = String(buf[posend+1:end])
+    lp, rp, lb, rb = count.(.==(('(', ')', '[', ']')), rest)
+    special = any(in.(('\'', '"', '`'), rest))
+    !special && lp == rp && lb == rb ?
+        word *= rest :
+        word
+end
+
 function commit_line(s)
     cancel_beep(s)
     move_input_end(s)
@@ -2080,6 +2125,7 @@ AnyDict(
     "\eOc" => "\ef",
     # Meta Enter
     "\e\r" => (s,o...)->edit_insert_newline(s),
+    "\e." =>  (s,o...)->edit_insert_last_word(s),
     "\e\n" => "\e\r",
     "^_" => (s,o...)->edit_undo!(s),
     "\e_" => (s,o...)->edit_redo!(s),
@@ -2176,6 +2222,8 @@ const prefix_history_keymap = merge!(
         "\e[*" => "*",
         "\eO*"  => "*",
         "\e[1;5*" => "*", # Ctrl-Arrow
+        "\e[1;2*" => "*", # Shift-Arrow
+        "\e[1;3*" => "*", # Meta-Arrow
         "\e[200~" => "*"
     ),
     # VT220 editing commands
@@ -2405,6 +2453,7 @@ function prompt!(term::TextTerminal, pro
             end
             status !== :ignore && (s.last_action = s.current_action)
             if status === :abort
+                s.aborted = true
                 return buffer(s), false, false
             elseif status === :done
                 return buffer(s), true, false
diff -pruN 1.3.1+dfsg-1/stdlib/REPL/src/REPLCompletions.jl 1.4.0+dfsg-1/stdlib/REPL/src/REPLCompletions.jl
--- 1.3.1+dfsg-1/stdlib/REPL/src/REPLCompletions.jl	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/stdlib/REPL/src/REPLCompletions.jl	2020-03-21 16:36:32.000000000 +0000
@@ -40,7 +40,6 @@ struct MethodCompletion <: Completion
     func
     input_types::Type
     method::Method
-    kwtype # needed for printing
 end
 
 struct BslashCompletion <: Completion
@@ -62,7 +61,7 @@ completion_text(c::ModuleCompletion) = c
 completion_text(c::PackageCompletion) = c.package
 completion_text(c::PropertyCompletion) = string(c.property)
 completion_text(c::FieldCompletion) = string(c.field)
-completion_text(c::MethodCompletion) = sprint(io -> show(io, c.method, kwtype=c.kwtype))
+completion_text(c::MethodCompletion) = sprint(io -> show(io, c.method))
 completion_text(c::BslashCompletion) = c.bslash
 completion_text(c::ShellCompletion) = c.text
 completion_text(c::DictCompletion) = c.key
@@ -185,7 +184,7 @@ function complete_keyword(s::Union{Strin
     map(KeywordCompletion, sorted_keywords[r])
 end
 
-function complete_path(path::AbstractString, pos; use_envpath=false)::Completions
+function complete_path(path::AbstractString, pos; use_envpath=false, shell_escape=false)::Completions
     if Base.Sys.isunix() && occursin(r"^~(?:/|$)", path)
         # if the path is just "~", don't consider the expanded username as a prefix
         if path == "~"
@@ -260,7 +259,7 @@ function complete_path(path::AbstractStr
         end
     end
 
-    matchList = Completion[PathCompletion(replace(s, r"\s" => "\\ ")) for s in matches]
+    matchList = PathCompletion[PathCompletion(shell_escape ? replace(s, r"\s" => s"\\\0") : s) for s in matches]
     startpos = pos - lastindex(prefix) + 1 - count(isequal(' '), prefix)
     # The pos - lastindex(prefix) + 1 is correct due to `lastindex(prefix)-lastindex(prefix)==0`,
     # hence we need to add one to get the first index. This is also correct when considering
@@ -451,13 +450,12 @@ function complete_methods(ex_org::Expr,
     t_in = Tuple{Core.Typeof(func), args_ex...} # Input types
     na = length(args_ex)+1
     ml = methods(func)
-    kwtype = isdefined(ml.mt, :kwsorter) ? typeof(ml.mt.kwsorter) : nothing
     for method in ml
         ms = method.sig
 
         # Check if the method's type signature intersects the input types
         if typeintersect(Base.rewrap_unionall(Tuple{Base.unwrap_unionall(ms).parameters[1 : min(na, end)]...}, ms), t_in) != Union{}
-            push!(out, MethodCompletion(func, t_in, method, kwtype))
+            push!(out, MethodCompletion(func, t_in, method))
         end
     end
     return out
@@ -539,7 +537,7 @@ end
 
 # This needs to be a separate non-inlined function, see #19441
 @noinline function find_dict_matches(identifier, partial_key)
-    matches = []
+    matches = String[]
     for key in keys(identifier)
         rkey = repr(key)
         startswith(rkey,partial_key) && push!(matches,rkey)
@@ -730,7 +728,7 @@ function shell_completions(string, pos):
         # Also try looking into the env path if the user wants to complete the first argument
         use_envpath = !ignore_last_word && length(args.args) < 2
 
-        return complete_path(prefix, pos, use_envpath=use_envpath)
+        return complete_path(prefix, pos, use_envpath=use_envpath, shell_escape=true)
     elseif isexpr(arg, :incomplete) || isexpr(arg, :error)
         partial = scs[last_parse]
         ret, range = completions(partial, lastindex(partial))
diff -pruN 1.3.1+dfsg-1/stdlib/REPL/src/REPL.jl 1.4.0+dfsg-1/stdlib/REPL/src/REPL.jl
--- 1.3.1+dfsg-1/stdlib/REPL/src/REPL.jl	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/stdlib/REPL/src/REPL.jl	2020-03-21 16:36:32.000000000 +0000
@@ -129,7 +129,12 @@ end
 function display(d::REPLDisplay, mime::MIME"text/plain", x)
     io = outstream(d.repl)
     get(io, :color, false) && write(io, answer_color(d.repl))
-    show(IOContext(io, :limit => true, :module => Main), mime, x)
+    if isdefined(d.repl, :options) && isdefined(d.repl.options, :iocontext)
+        # this can override the :limit property set initially
+        io = foldl(IOContext, d.repl.options.iocontext,
+                   init=IOContext(io, :limit => true, :module => Main))
+    end
+    show(io, mime, x)
     println(io)
     nothing
 end
@@ -283,6 +288,8 @@ mutable struct Options
     auto_indent_bracketed_paste::Bool # set to true if terminal knows paste mode
     # cancel auto-indent when next character is entered within this time frame :
     auto_indent_time_threshold::Float64
+    # default IOContext settings at the REPL
+    iocontext::Dict{Symbol,Any}
 end
 
 Options(;
@@ -299,13 +306,16 @@ Options(;
         auto_indent = true,
         auto_indent_tmp_off = false,
         auto_indent_bracketed_paste = false,
-        auto_indent_time_threshold = 0.005) =
+        auto_indent_time_threshold = 0.005,
+        iocontext = Dict{Symbol,Any}()) =
             Options(hascolor, extra_keymap, tabwidth,
                     kill_ring_max, region_animation_duration,
                     beep_duration, beep_blink, beep_maxduration,
                     beep_colors, beep_use_current,
                     backspace_align, backspace_adjust, confirm_exit,
-                    auto_indent, auto_indent_tmp_off, auto_indent_bracketed_paste, auto_indent_time_threshold)
+                    auto_indent, auto_indent_tmp_off, auto_indent_bracketed_paste,
+                    auto_indent_time_threshold,
+                    iocontext)
 
 # for use by REPLs not having an options field
 const GlobalOptions = Options()
diff -pruN 1.3.1+dfsg-1/stdlib/REPL/test/lineedit.jl 1.4.0+dfsg-1/stdlib/REPL/test/lineedit.jl
--- 1.3.1+dfsg-1/stdlib/REPL/test/lineedit.jl	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/stdlib/REPL/test/lineedit.jl	2020-03-21 16:36:32.000000000 +0000
@@ -606,7 +606,7 @@ end
 
 @testset "change case on the right" begin
     local buf = IOBuffer()
-    edit_insert(buf, "aa bb CC")
+    edit_insert(buf, "aa bB CC")
     seekstart(buf)
     LineEdit.edit_upper_case(buf)
     LineEdit.edit_title_case(buf)
@@ -878,5 +878,20 @@ end
     buf.mark = 0
     seek(buf, 1)
     @test transform!(transpose_lines_down_reg!, buf) == ("l2\nl3\nl1", 4, 3)
+end
 
+@testset "edit_insert_last_word" begin
+    get_last_word(str::String) = LineEdit.get_last_word(IOBuffer(str))
+    @test get_last_word("1+2") == "2"
+    @test get_last_word("1+23") == "23"
+    @test get_last_word("1+2") == "2"
+    @test get_last_word(""" "a" * "b" """) == "b"
+    @test get_last_word(""" "a" * 'b' """) == "b"
+    @test get_last_word(""" "a" * `b` """) == "b"
+    @test get_last_word("g()") == "g()"
+    @test get_last_word("g(1, 2)") == "2"
+    @test get_last_word("g(1, f())") == "f"
+    @test get_last_word("a[1]") == "1"
+    @test get_last_word("a[b[]]") == "b"
+    @test get_last_word("a[]") == "a[]"
 end
diff -pruN 1.3.1+dfsg-1/stdlib/REPL/test/replcompletions.jl 1.4.0+dfsg-1/stdlib/REPL/test/replcompletions.jl
--- 1.3.1+dfsg-1/stdlib/REPL/test/replcompletions.jl	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/stdlib/REPL/test/replcompletions.jl	2020-03-21 16:36:32.000000000 +0000
@@ -717,7 +717,7 @@ mktempdir() do path
             s = Sys.iswindows() ? "cd(\"β $dir_space\\\\space" : "cd(\"β $dir_space/space"
             c, r = test_complete(s)
             @test r == lastindex(s)-4:lastindex(s)
-            @test "space\\ .file\"" in c
+            @test "space .file\"" in c
         end
         # Test for issue #10324
         s = "cd(\"$dir_space"
@@ -768,7 +768,7 @@ end
 if Sys.iswindows()
     tmp = tempname()
     touch(tmp)
-    path = dirname(tmp)
+    path = realpath(dirname(tmp))
     file = basename(tmp)
     temp_name = basename(path)
     cd(path) do
diff -pruN 1.3.1+dfsg-1/stdlib/REPL/test/repl.jl 1.4.0+dfsg-1/stdlib/REPL/test/repl.jl
--- 1.3.1+dfsg-1/stdlib/REPL/test/repl.jl	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/stdlib/REPL/test/repl.jl	2020-03-21 16:36:32.000000000 +0000
@@ -66,6 +66,24 @@ end
 
 # Writing ^C to the repl will cause sigint, so let's not die on that
 ccall(:jl_exit_on_sigint, Cvoid, (Cint,), 0)
+
+# make sure `run_interface` can normally handle `eof`
+# without any special handling by the user
+fake_repl() do stdin_write, stdout_read, repl
+    panel = LineEdit.Prompt("test";
+        prompt_prefix = "",
+        prompt_suffix = Base.text_colors[:white],
+        on_enter = s -> true)
+    panel.on_done = (s, buf, ok) -> begin
+        @test !ok
+        @test bytesavailable(buf) == position(buf) == 0
+        nothing
+    end
+    repltask = @async REPL.run_interface(repl.t, LineEdit.ModalInterface(Any[panel]))
+    close(stdin_write)
+    Base.wait(repltask)
+end
+
 # These are integration tests. If you want to unit test test e.g. completion, or
 # exact LineEdit behavior, put them in the appropriate test files.
 # Furthermore since we are emulating an entire terminal, there may be control characters
@@ -228,7 +246,7 @@ fake_repl() do stdin_write, stdout_read,
         write(stdin_write, ";")
         readuntil(stdout_read, "shell> ")
         Base.print_shell_escaped(stdin_write, Base.julia_cmd().exec..., special=Base.shell_special)
-        write(stdin_write, """ -e "println(\\"HI\\")\"""")
+        write(stdin_write, """ -e "println(\\"HI\\")\" """)
         readuntil(stdout_read, ")\"")
         proc_stdout_read, proc_stdout = redirect_stdout()
         get_stdout = @async read(proc_stdout_read, String)
@@ -306,8 +324,16 @@ fake_repl() do stdin_write, stdout_read,
     write(stdin_write, "\e[B\n")
     readuntil(stdout_read, s2)
 
-    # Close REPL ^D
-    write(stdin_write, '\x04')
+    # test that prefix history search "passes through" key bindings to parent mode
+    write(stdin_write, "0x321\n")
+    readuntil(stdout_read, "0x321")
+    write(stdin_write, "\e[A\e[1;3C|||") # uparrow (go up history) and then Meta-rightarrow (indent right)
+    s2 = readuntil(stdout_read, "|||", keep=true)
+    @test endswith(s2, " 0x321\r\e[13C|||") # should have a space (from Meta-rightarrow) and not
+                                            # have a spurious C before ||| (the one here is not spurious!)
+
+    # Delete line (^U) and close REPL (^D)
+    write(stdin_write, "\x15\x04")
     Base.wait(repltask)
 
     nothing
@@ -422,6 +448,11 @@ for prompt = ["TestΠ", () -> randstring
         s = LineEdit.init_state(repl.t, repl.interface)
         LineEdit.edit_insert(s, "wip")
 
+        # LineEdit functions related to history
+        LineEdit.edit_insert_last_word(s)
+        @test buffercontents(LineEdit.buffer(s)) == "wip2"
+        LineEdit.edit_backspace(s) # remove the "2"
+
         # Test that navigating history skips invalid modes
         # (in both directions)
         LineEdit.history_prev(s, hp)
@@ -708,16 +739,17 @@ fake_repl() do stdin_write, stdout_read,
         LineEdit.default_keymap, LineEdit.escape_defaults])
 
     c = Condition()
-    panel.on_done = (s,buf,ok)->begin
+    panel.on_done = (s, buf, ok) -> begin
         if !ok
-            LineEdit.transition(s,:abort)
+            LineEdit.transition(s, :abort)
         end
         line = strip(String(take!(buf)))
         LineEdit.reset_state(s)
-        return notify(c,line)
+        notify(c, line)
+        nothing
     end
 
-    repltask = @async REPL.run_interface(repl.t, LineEdit.ModalInterface([panel,search_prompt]))
+    repltask = @async REPL.run_interface(repl.t, LineEdit.ModalInterface(Any[panel, search_prompt]))
 
     write(stdin_write,"a\n")
     @test wait(c) == "a"
@@ -782,12 +814,12 @@ let exename = Base.julia_cmd()
     @test read(p, String) == "1\n"
 end # let exename
 
-# issue #19864:
+# issue #19864
 mutable struct Error19864 <: Exception; end
 function test19864()
     @eval Base.showerror(io::IO, e::Error19864) = print(io, "correct19864")
     buf = IOBuffer()
-    fake_response = (Any[(Error19864(),[])],true)
+    fake_response = (Any[(Error19864(), Ptr{Cvoid}[])], true)
     REPL.print_response(buf, fake_response, false, false, nothing)
     return String(take!(buf))
 end
@@ -798,6 +830,7 @@ let io = IOBuffer()
     Base.display_error(io,
         try
             [][trues(6000)]
+            @assert false
         catch e
             e
         end, [])
@@ -1039,3 +1072,21 @@ fake_repl() do stdin_write, stdout_read,
     wait(repltask)
     @test istaskdone(repltask)
 end
+
+fake_repl() do stdin_write, stdout_read, repl
+    repltask = @async begin
+        REPL.run_repl(repl)
+    end
+    write(stdin_write, "anything\x15\x19\x19") # ^u^y^y : kill line backwards + 2 yanks
+    s1 = readuntil(stdout_read, "anything") # typed
+    s2 = readuntil(stdout_read, "anything") # yanked (first ^y)
+    s3 = readuntil(stdout_read, "anything") # previous yanked refreshed (from second ^y)
+    s4 = readuntil(stdout_read, "anything", keep=true) # last yanked
+    # necessary to read at least some part of the buffer,
+    # for the "region_active" to have time to be updated
+
+    @test LineEdit.state(repl.mistate).region_active == :off
+    @test s4 == "anything" # no control characters between the last two occurrences of "anything"
+    write(stdin_write, "\x15\x04")
+    Base.wait(repltask)
+end
diff -pruN 1.3.1+dfsg-1/stdlib/Serialization/src/precompile.jl 1.4.0+dfsg-1/stdlib/Serialization/src/precompile.jl
--- 1.3.1+dfsg-1/stdlib/Serialization/src/precompile.jl	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/stdlib/Serialization/src/precompile.jl	1970-01-01 00:00:00.000000000 +0000
@@ -1,40 +0,0 @@
-# This file is a part of Julia. License is MIT: https://julialang.org/license
-
-precompile(Tuple{typeof(Serialization.object_number), Core.TypeName})
-precompile(Tuple{typeof(Serialization.deserialize_array), Serialization.Serializer{Base.PipeEndpoint}})
-precompile(Tuple{typeof(Serialization.deserialize), Base.PipeEndpoint})
-precompile(Tuple{typeof(Serialization.deserialize), Serialization.Serializer{Base.PipeEndpoint}})
-precompile(Tuple{typeof(Serialization.deserialize), Serialization.Serializer{Base.PipeEndpoint}, Type{Int64}})
-precompile(Tuple{typeof(Serialization.deserialize), Serialization.Serializer{Base.PipeEndpoint}, Type{QuoteNode}})
-precompile(Tuple{typeof(Serialization.deserialize), Serialization.Serializer{Base.PipeEndpoint}, Type{String}})
-precompile(Tuple{typeof(Serialization.deserialize), Serialization.Serializer{Base.PipeEndpoint}, Type{UInt64}})
-precompile(Tuple{typeof(Serialization.deserialize_cycle), Serialization.Serializer{Base.PipeEndpoint}, Expr})
-precompile(Tuple{typeof(Serialization.deserialize_datatype), Serialization.Serializer{Base.PipeEndpoint}})
-precompile(Tuple{typeof(Serialization.deserialize_expr), Serialization.Serializer{Base.PipeEndpoint}, Int64})
-precompile(Tuple{typeof(Serialization.handle_deserialize), Serialization.Serializer{Base.PipeEndpoint}, Int32})
-precompile(Tuple{typeof(Serialization.serialize_any), Serialization.Serializer{Base.Pipe}, QuoteNode})
-precompile(Tuple{typeof(Serialization.serialize), Serialization.Serializer{Base.Pipe}, Array{Any, 1}})
-precompile(Tuple{typeof(Serialization.serialize), Serialization.Serializer{Base.Pipe}, Array{String, 1}})
-precompile(Tuple{typeof(Serialization.serialize), Serialization.Serializer{Base.Pipe}, Bool})
-precompile(Tuple{typeof(Serialization.serialize), Serialization.Serializer{Base.Pipe}, Expr})
-precompile(Tuple{typeof(Serialization.serialize), Serialization.Serializer{Base.Pipe}, Int64})
-precompile(Tuple{typeof(Serialization.serialize), Serialization.Serializer{Base.Pipe}, Module})
-precompile(Tuple{typeof(Serialization.serialize), Serialization.Serializer{Base.Pipe}, QuoteNode})
-precompile(Tuple{typeof(Serialization.serialize), Serialization.Serializer{Base.Pipe}, Core.SimpleVector})
-precompile(Tuple{typeof(Serialization.serialize), Serialization.Serializer{Base.Pipe}, String})
-precompile(Tuple{typeof(Serialization.serialize), Serialization.Serializer{Base.Pipe}, Symbol})
-precompile(Tuple{typeof(Serialization.serialize), Serialization.Serializer{Base.Pipe}, Tuple{Int64}})
-precompile(Tuple{typeof(Serialization.serialize), Serialization.Serializer{Base.Pipe}, Tuple{Symbol, UInt64}})
-precompile(Tuple{typeof(Serialization.serialize), Serialization.Serializer{Base.Pipe}, Type{Any}})
-precompile(Tuple{typeof(Serialization.serialize), Serialization.Serializer{Base.Pipe}, Core.TypeName})
-precompile(Tuple{typeof(Serialization.serialize), Serialization.Serializer{Base.Pipe}, UInt64})
-precompile(Tuple{typeof(Serialization.serialize_cycle), Serialization.Serializer{Base.Pipe}, Expr})
-precompile(Tuple{typeof(Serialization.serialize_cycle), Serialization.Serializer{Base.Pipe}, Core.TypeName})
-precompile(Tuple{typeof(Serialization.serialize_cycle), Serialization.Serializer{Base.Pipe}, UInt64})
-precompile(Tuple{typeof(Serialization.serialize_cycle_header), Serialization.Serializer{Base.Pipe}, QuoteNode})
-precompile(Tuple{typeof(Serialization.serialize_mod_names), Serialization.Serializer{Base.Pipe}, Module})
-precompile(Tuple{typeof(Serialization.serialize_type), Serialization.Serializer{Base.Pipe}, DataType})
-precompile(Tuple{typeof(Serialization.serialize_type_data), Serialization.Serializer{Base.Pipe}, Type{Any}, Bool})
-precompile(Tuple{typeof(Serialization.serialize_typename), Serialization.Serializer{Base.Pipe}, Core.TypeName})
-precompile(Tuple{typeof(Serialization.should_send_whole_type), Serialization.Serializer{Base.Pipe}, Type{Any}})
-precompile(Tuple{typeof(Serialization.write_as_tag), Base.Pipe, Int32})
diff -pruN 1.3.1+dfsg-1/stdlib/Serialization/src/Serialization.jl 1.4.0+dfsg-1/stdlib/Serialization/src/Serialization.jl
--- 1.3.1+dfsg-1/stdlib/Serialization/src/Serialization.jl	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/stdlib/Serialization/src/Serialization.jl	2020-03-21 16:36:32.000000000 +0000
@@ -31,7 +31,7 @@ Serializer(io::IO) = Serializer{typeof(i
 
 const n_int_literals = 33
 const n_reserved_slots = 24
-const n_reserved_tags = 12
+const n_reserved_tags = 11
 
 const TAGS = Any[
     Symbol, Int8, UInt8, Int16, UInt16, Int32, UInt32, Int64, UInt64, Int128, UInt128,
@@ -56,6 +56,7 @@ const TAGS = Any[
     Symbol, # REF_OBJECT_TAG
     Symbol, # FULL_GLOBALREF_TAG
     Symbol, # HEADER_TAG
+    Symbol, # IDDICT_TAG
     fill(Symbol, n_reserved_tags)...,
 
     (), Bool, Any, Bottom, Core.TypeofBottom, Type, svec(), Tuple{}, false, true, nothing,
@@ -75,7 +76,7 @@ const TAGS = Any[
 
 @assert length(TAGS) == 255
 
-const ser_version = 8 # do not make changes without bumping the version #!
+const ser_version = 9 # do not make changes without bumping the version #!
 
 const NTAGS = length(TAGS)
 
@@ -103,7 +104,7 @@ const TUPLE_TAG = sertag(Tuple)
 const SIMPLEVECTOR_TAG = sertag(SimpleVector)
 const SYMBOL_TAG = sertag(Symbol)
 const INT8_TAG = sertag(Int8)
-const ARRAY_TAG = sertag(Array)
+const ARRAY_TAG = findfirst(==(Array), TAGS)%Int32
 const EXPR_TAG = sertag(Expr)
 const MODULE_TAG = sertag(Module)
 const METHODINSTANCE_TAG = sertag(Core.MethodInstance)
@@ -133,6 +134,7 @@ const OBJECT_TAG           = Int32(o0+12
 const REF_OBJECT_TAG       = Int32(o0+13)
 const FULL_GLOBALREF_TAG   = Int32(o0+14)
 const HEADER_TAG           = Int32(o0+15)
+const IDDICT_TAG           = Int32(o0+16)
 
 writetag(s::IO, tag) = (write(s, UInt8(tag)); nothing)
 
@@ -327,8 +329,7 @@ function serialize(s::AbstractSerializer
     end
 end
 
-function serialize(s::AbstractSerializer, d::Dict)
-    serialize_cycle_header(s, d) && return
+function serialize_dict_data(s::AbstractSerializer, d::AbstractDict)
     write(s.io, Int32(length(d)))
     for (k,v) in d
         serialize(s, k)
@@ -336,6 +337,18 @@ function serialize(s::AbstractSerializer
     end
 end
 
+function serialize(s::AbstractSerializer, d::Dict)
+    serialize_cycle_header(s, d) && return
+    serialize_dict_data(s, d)
+end
+
+function serialize(s::AbstractSerializer, d::IdDict)
+    serialize_cycle(s, d) && return
+    writetag(s.io, IDDICT_TAG)
+    serialize_type_data(s, typeof(d))
+    serialize_dict_data(s, d)
+end
+
 function serialize_mod_names(s::AbstractSerializer, m::Module)
     p = parentmodule(m)
     if p === m || m === Base
@@ -618,7 +631,7 @@ function serialize_any(s::AbstractSerial
         serialize_type(s, t)
         write(s.io, x)
     else
-        if t.mutable && nf > 0
+        if t.mutable
             serialize_cycle(s, x) && return
             serialize_type(s, t, true)
         else
@@ -851,6 +864,11 @@ function handle_deserialize(s::AbstractS
         return read(s.io, Float64)
     elseif b == INT8_TAG+13
         return read(s.io, Char)
+    elseif b == IDDICT_TAG
+        slot = s.counter; s.counter += 1
+        push!(s.pending_refs, slot)
+        t = deserialize(s)
+        return deserialize_dict(s, t)
     end
     t = desertag(b)::DataType
     if t.mutable && length(t.types) > 0  # manual specialization of fieldcount
@@ -1270,29 +1288,9 @@ function deserialize(s::AbstractSerializ
     if nf == 0 && t.size > 0
         # bits type
         return read(s.io, t)
-    end
-    if nf == 0
-        return ccall(:jl_new_struct, Any, (Any,Any...), t)
-    elseif isbitstype(t)
-        if nf == 1
-            f1 = deserialize(s)
-            return ccall(:jl_new_struct, Any, (Any,Any...), t, f1)
-        elseif nf == 2
-            f1 = deserialize(s)
-            f2 = deserialize(s)
-            return ccall(:jl_new_struct, Any, (Any,Any...), t, f1, f2)
-        elseif nf == 3
-            f1 = deserialize(s)
-            f2 = deserialize(s)
-            f3 = deserialize(s)
-            return ccall(:jl_new_struct, Any, (Any,Any...), t, f1, f2, f3)
-        else
-            flds = Any[ deserialize(s) for i = 1:nf ]
-            return ccall(:jl_new_structv, Any, (Any,Ptr{Cvoid},UInt32), t, flds, nf)
-        end
-    else
+    elseif t.mutable
         x = ccall(:jl_new_struct_uninit, Any, (Any,), t)
-        t.mutable && deserialize_cycle(s, x)
+        deserialize_cycle(s, x)
         for i in 1:nf
             tag = Int32(read(s.io, UInt8)::UInt8)
             if tag != UNDEFREF_TAG
@@ -1300,10 +1298,25 @@ function deserialize(s::AbstractSerializ
             end
         end
         return x
+    elseif nf == 0
+        return ccall(:jl_new_struct_uninit, Any, (Any,), t)
+    else
+        na = nf
+        vflds = Vector{Any}(undef, nf)
+        for i in 1:nf
+            tag = Int32(read(s.io, UInt8)::UInt8)
+            if tag != UNDEFREF_TAG
+                f = handle_deserialize(s, tag)
+                na >= i && (vflds[i] = f)
+            else
+                na >= i && (na = i - 1) # rest of tail must be undefined values
+            end
+        end
+        return ccall(:jl_new_structv, Any, (Any, Ptr{Any}, UInt32), t, vflds, na)
     end
 end
 
-function deserialize(s::AbstractSerializer, T::Type{Dict{K,V}}) where {K,V}
+function deserialize_dict(s::AbstractSerializer, T::Type{<:AbstractDict})
     n = read(s.io, Int32)
     t = T(); sizehint!(t, n)
     deserialize_cycle(s, t)
@@ -1315,6 +1328,10 @@ function deserialize(s::AbstractSerializ
     return t
 end
 
+function deserialize(s::AbstractSerializer, T::Type{Dict{K,V}}) where {K,V}
+    return deserialize_dict(s, T)
+end
+
 deserialize(s::AbstractSerializer, ::Type{BigInt}) = parse(BigInt, deserialize(s), base = 62)
 
 function deserialize(s::AbstractSerializer, t::Type{Regex})
@@ -1350,6 +1367,4 @@ function deserialize(s::AbstractSerializ
     return Base.StackTraces.StackFrame(func, file, line, nothing, from_c, inlined, pointer)
 end
 
-include("precompile.jl")
-
 end
diff -pruN 1.3.1+dfsg-1/stdlib/Serialization/test/runtests.jl 1.4.0+dfsg-1/stdlib/Serialization/test/runtests.jl
--- 1.3.1+dfsg-1/stdlib/Serialization/test/runtests.jl	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/stdlib/Serialization/test/runtests.jl	2020-03-21 16:36:32.000000000 +0000
@@ -427,6 +427,17 @@ create_serialization_stream() do s
     @test C[1] === C[2]
 end
 
+mutable struct MSingle end
+create_serialization_stream() do s
+    x = MSingle()
+    A = [x, x, MSingle()]
+    serialize(s, A)
+    seekstart(s)
+    C = deserialize(s)
+    @test A[1] === x === A[2] !== A[3]
+    @test x !== C[1] === C[2] !== C[3]
+end
+
 # Regex
 create_serialization_stream() do s
     r1 = r"a?b.*"
@@ -562,3 +573,12 @@ let f_data
     f = deserialize(IOBuffer(base64decode(f_data)))
     @test f(10,3) == 23
 end
+
+# issue #33466, IdDict
+let d = IdDict([1] => 2, [3] => 4), io = IOBuffer()
+    serialize(io, d)
+    seekstart(io)
+    ds = deserialize(io)
+    @test Dict(d) == Dict(ds)
+    @test all([k in keys(ds) for k in keys(ds)])
+end
diff -pruN 1.3.1+dfsg-1/stdlib/SharedArrays/test/runtests.jl 1.4.0+dfsg-1/stdlib/SharedArrays/test/runtests.jl
--- 1.3.1+dfsg-1/stdlib/SharedArrays/test/runtests.jl	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/stdlib/SharedArrays/test/runtests.jl	2020-03-21 16:36:32.000000000 +0000
@@ -145,9 +145,9 @@ finalize(S)
 
 # call gc 3 times to avoid unlink: operation not permitted (EPERM) on Windows
 S = nothing
-@everywhere GC.gc()
-@everywhere GC.gc()
-@everywhere GC.gc()
+@everywhere GC.gc(true)
+@everywhere GC.gc(true)
+@everywhere GC.gc(true)
 rm(fn); rm(fn2); rm(fn3)
 
 ### Utility functions
@@ -213,7 +213,7 @@ d[5,1:2:4,8] .= 19
 AA = rand(4,2)
 A = @inferred(convert(SharedArray, AA))
 B = @inferred(convert(SharedArray, copy(AA')))
-@test B*A == AA'*AA
+@test B*A ≈ AA'*AA
 
 d=SharedArray{Int64,2}((10,10); init = D->fill!(D.loc_subarr_1d, myid()), pids=[id_me, id_other])
 d2 = map(x->1, d)
@@ -288,7 +288,7 @@ let
     id = a1.id
     aorig = nothing
     a1 = remotecall_fetch(fill!, id_other, a1, 1.0)
-    GC.gc(); GC.gc()
+    GC.gc(true); GC.gc(true)
     a1 = remotecall_fetch(fill!, id_other, a1, 1.0)
     @test haskey(SharedArrays.sa_refs, id)
     finalize(a1)
diff -pruN 1.3.1+dfsg-1/stdlib/Sockets/test/runtests.jl 1.4.0+dfsg-1/stdlib/Sockets/test/runtests.jl
--- 1.3.1+dfsg-1/stdlib/Sockets/test/runtests.jl	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/stdlib/Sockets/test/runtests.jl	2020-03-21 16:36:32.000000000 +0000
@@ -2,6 +2,26 @@
 
 using Sockets, Random, Test
 
+# set up a watchdog alarm for 10 minutes
+# so that we can attempt to get a "friendly" backtrace if something gets stuck
+# (although this'll also terminate any attempted debugging session)
+# expected test duration is about 5-10 seconds
+function killjob(d)
+    Core.print(Core.stderr, d)
+    if Sys.islinux()
+        SIGINFO = 10
+    elseif Sys.isbsd()
+        SIGINFO = 29
+    end
+    if @isdefined(SIGINFO)
+        ccall(:uv_kill, Cint, (Cint, Cint), getpid(), SIGINFO)
+        sleep(1)
+    end
+    ccall(:uv_kill, Cint, (Cint, Cint), getpid(), Base.SIGTERM)
+    nothing
+end
+Timer(t -> killjob("KILLING BY SOCKETS TEST WATCHDOG\n"), 600)
+
 @testset "parsing" begin
     @test ip"127.0.0.1" == IPv4(127,0,0,1)
     @test ip"192.0" == IPv4(192,0,0,0)
diff -pruN 1.3.1+dfsg-1/stdlib/SparseArrays/docs/src/index.md 1.4.0+dfsg-1/stdlib/SparseArrays/docs/src/index.md
--- 1.3.1+dfsg-1/stdlib/SparseArrays/docs/src/index.md	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/stdlib/SparseArrays/docs/src/index.md	2020-03-21 16:36:32.000000000 +0000
@@ -50,15 +50,17 @@ matrix. [`dropzeros`](@ref), and the in-
 remove stored zeros from the sparse matrix.
 
 ```jldoctest
-julia> A = sparse([1, 2, 3], [1, 2, 3], [0, 2, 0])
-3×3 SparseMatrixCSC{Int64,Int64} with 3 stored entries:
+julia> A = sparse([1, 1, 2, 3], [1, 3, 2, 3], [0, 1, 2, 0])
+3×3 SparseMatrixCSC{Int64,Int64} with 4 stored entries:
   [1, 1]  =  0
   [2, 2]  =  2
+  [1, 3]  =  1
   [3, 3]  =  0
 
 julia> dropzeros(A)
-3×3 SparseMatrixCSC{Int64,Int64} with 1 stored entry:
+3×3 SparseMatrixCSC{Int64,Int64} with 2 stored entries:
   [2, 2]  =  2
+  [1, 3]  =  1
 ```
 
 ## Sparse Vector Storage
@@ -197,7 +199,7 @@ section of the standard library referenc
 | [`Array(S)`](@ref)         | [`sparse(A)`](@ref)    | Interconverts between dense and sparse formats.                                                                                                                       |
 | [`sprand(m,n,d)`](@ref)    | [`rand(m,n)`](@ref)    | Creates a *m*-by-*n* random matrix (of density *d*) with iid non-zero elements distributed uniformly on the half-open interval ``[0, 1)``.                            |
 | [`sprandn(m,n,d)`](@ref)   | [`randn(m,n)`](@ref)   | Creates a *m*-by-*n* random matrix (of density *d*) with iid non-zero elements distributed according to the standard normal (Gaussian) distribution.                  |
-| [`sprandn(m,n,d,X)`](@ref) | [`randn(m,n,X)`](@ref) | Creates a *m*-by-*n* random matrix (of density *d*) with iid non-zero elements distributed according to the *X* distribution. (Requires the `Distributions` package.) |
+| [`sprandn(rng,m,n,d)`](@ref) | [`randn(rng,m,n)`](@ref) | Creates a *m*-by-*n* random matrix (of density *d*) with iid non-zero elements generated with the `rng` random number generator                                   |
 
 # [Sparse Arrays](@id stdlib-sparse-arrays)
 
diff -pruN 1.3.1+dfsg-1/stdlib/SparseArrays/src/abstractsparse.jl 1.4.0+dfsg-1/stdlib/SparseArrays/src/abstractsparse.jl
--- 1.3.1+dfsg-1/stdlib/SparseArrays/src/abstractsparse.jl	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/stdlib/SparseArrays/src/abstractsparse.jl	2020-03-21 16:36:32.000000000 +0000
@@ -13,7 +13,7 @@ abstract type AbstractSparseArray{Tv,Ti,
     AbstractSparseVector{Tv,Ti}
 
 Supertype for one-dimensional sparse arrays (or array-like types) with elements
-of type `Tv` and index type `Ti`. Alias for `AbstractSparseArray{Tv,Ti,1}``.
+of type `Tv` and index type `Ti`. Alias for `AbstractSparseArray{Tv,Ti,1}`.
 """
 const AbstractSparseVector{Tv,Ti} = AbstractSparseArray{Tv,Ti,1}
 """
@@ -25,6 +25,13 @@ of type `Tv` and index type `Ti`. Alias
 const AbstractSparseMatrix{Tv,Ti} = AbstractSparseArray{Tv,Ti,2}
 
 """
+    AbstractSparseMatrixCSC{Tv,Ti<:Integer} <: AbstractSparseMatrix{Tv,Ti}
+
+Supertype for matrix with compressed sparse column (CSC).
+"""
+abstract type AbstractSparseMatrixCSC{Tv,Ti<:Integer} <: AbstractSparseMatrix{Tv,Ti} end
+
+"""
     issparse(S)
 
 Returns `true` if `S` is sparse, and `false` otherwise.
diff -pruN 1.3.1+dfsg-1/stdlib/SparseArrays/src/higherorderfns.jl 1.4.0+dfsg-1/stdlib/SparseArrays/src/higherorderfns.jl
--- 1.3.1+dfsg-1/stdlib/SparseArrays/src/higherorderfns.jl	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/stdlib/SparseArrays/src/higherorderfns.jl	2020-03-21 16:36:32.000000000 +0000
@@ -7,9 +7,9 @@ module HigherOrderFns
 import Base: map, map!, broadcast, copy, copyto!
 
 using Base: front, tail, to_shape
-using ..SparseArrays: SparseVector, SparseMatrixCSC, AbstractSparseVector,
+using ..SparseArrays: SparseVector, SparseMatrixCSC, AbstractSparseVector, AbstractSparseMatrixCSC,
                       AbstractSparseMatrix, AbstractSparseArray, indtype, nnz, nzrange,
-                      SparseVectorUnion, AdjOrTransSparseVectorUnion, nonzeroinds, nonzeros
+                      SparseVectorUnion, AdjOrTransSparseVectorUnion, nonzeroinds, nonzeros, rowvals, getcolptr
 using Base.Broadcast: BroadcastStyle, Broadcasted, flatten
 using LinearAlgebra
 
@@ -33,13 +33,13 @@ using LinearAlgebra
 
 # (0) BroadcastStyle rules and convenience types for dispatch
 
-SparseVecOrMat = Union{SparseVector,SparseMatrixCSC}
+SparseVecOrMat = Union{SparseVector,AbstractSparseMatrixCSC}
 
 # broadcast container type promotion for combinations of sparse arrays and other types
 struct SparseVecStyle <: Broadcast.AbstractArrayStyle{1} end
 struct SparseMatStyle <: Broadcast.AbstractArrayStyle{2} end
 Broadcast.BroadcastStyle(::Type{<:SparseVector}) = SparseVecStyle()
-Broadcast.BroadcastStyle(::Type{<:SparseMatrixCSC}) = SparseMatStyle()
+Broadcast.BroadcastStyle(::Type{<:AbstractSparseMatrixCSC}) = SparseMatStyle()
 const SPVM = Union{SparseVecStyle,SparseMatStyle}
 
 # SparseVecStyle handles 0-1 dimensions, SparseMatStyle 0-2 dimensions.
@@ -108,24 +108,24 @@ const SpBroadcasted2{Style<:SPVM,Axes,F,
 # sufficient for the purposes of map[!]/broadcast[!]. This interface treats sparse vectors
 # as n-by-one sparse matrices which, though technically incorrect, is how broacast[!] views
 # sparse vectors in practice.
-@inline numrows(A::SparseVector) = A.n
-@inline numrows(A::SparseMatrixCSC) = A.m
+@inline numrows(A::SparseVector) = length(A)
+@inline numrows(A::AbstractSparseMatrixCSC) = size(A, 1)
 @inline numcols(A::SparseVector) = 1
-@inline numcols(A::SparseMatrixCSC) = A.n
+@inline numcols(A::AbstractSparseMatrixCSC) = size(A, 2)
 # numrows and numcols respectively yield size(A, 1) and size(A, 2), but avoid a branch
 @inline columns(A::SparseVector) = 1
-@inline columns(A::SparseMatrixCSC) = 1:A.n
-@inline colrange(A::SparseVector, j) = 1:length(A.nzind)
-@inline colrange(A::SparseMatrixCSC, j) = nzrange(A, j)
+@inline columns(A::AbstractSparseMatrixCSC) = 1:size(A, 2)
+@inline colrange(A::SparseVector, j) = 1:length(nonzeroinds(A))
+@inline colrange(A::AbstractSparseMatrixCSC, j) = nzrange(A, j)
 @inline colstartind(A::SparseVector, j) = one(indtype(A))
-@inline colboundind(A::SparseVector, j) = convert(indtype(A), length(A.nzind) + 1)
-@inline colstartind(A::SparseMatrixCSC, j) = A.colptr[j]
-@inline colboundind(A::SparseMatrixCSC, j) = A.colptr[j + 1]
-@inline storedinds(A::SparseVector) = A.nzind
-@inline storedinds(A::SparseMatrixCSC) = A.rowval
-@inline storedvals(A::SparseVecOrMat) = A.nzval
+@inline colboundind(A::SparseVector, j) = convert(indtype(A), length(nonzeroinds(A)) + 1)
+@inline colstartind(A::AbstractSparseMatrixCSC, j) = getcolptr(A)[j]
+@inline colboundind(A::AbstractSparseMatrixCSC, j) = getcolptr(A)[j + 1]
+@inline storedinds(A::SparseVector) = nonzeroinds(A)
+@inline storedinds(A::AbstractSparseMatrixCSC) = rowvals(A)
+@inline storedvals(A::SparseVecOrMat) = nonzeros(A)
 @inline setcolptr!(A::SparseVector, j, val) = val
-@inline setcolptr!(A::SparseMatrixCSC, j, val) = A.colptr[j] = val
+@inline setcolptr!(A::AbstractSparseMatrixCSC, j, val) = getcolptr(A)[j] = val
 function trimstorage!(A::SparseVecOrMat, maxstored)
     resize!(storedinds(A), maxstored)
     resize!(storedvals(A), maxstored)
@@ -140,12 +140,12 @@ end
 
 # (2) map[!] entry points
 map(f::Tf, A::SparseVector) where {Tf} = _noshapecheck_map(f, A)
-map(f::Tf, A::SparseMatrixCSC) where {Tf} = _noshapecheck_map(f, A)
-map(f::Tf, A::SparseMatrixCSC, Bs::Vararg{SparseMatrixCSC,N}) where {Tf,N} =
+map(f::Tf, A::AbstractSparseMatrixCSC) where {Tf} = _noshapecheck_map(f, A)
+map(f::Tf, A::AbstractSparseMatrixCSC, Bs::Vararg{SparseMatrixCSC,N}) where {Tf,N} =
     (_checksameshape(A, Bs...); _noshapecheck_map(f, A, Bs...))
 map(f::Tf, A::SparseVecOrMat, Bs::Vararg{SparseVecOrMat,N}) where {Tf,N} =
     (_checksameshape(A, Bs...); _noshapecheck_map(f, A, Bs...))
-map!(f::Tf, C::SparseMatrixCSC, A::SparseMatrixCSC, Bs::Vararg{SparseMatrixCSC,N}) where {Tf,N} =
+map!(f::Tf, C::AbstractSparseMatrixCSC, A::AbstractSparseMatrixCSC, Bs::Vararg{SparseMatrixCSC,N}) where {Tf,N} =
     (_checksameshape(C, A, Bs...); _noshapecheck_map!(f, C, A, Bs...))
 map!(f::Tf, C::SparseVecOrMat, A::SparseVecOrMat, Bs::Vararg{SparseVecOrMat,N}) where {Tf,N} =
     (_checksameshape(C, A, Bs...); _noshapecheck_map!(f, C, A, Bs...))
@@ -214,9 +214,9 @@ end
 @inline _all_args_isa(t::Tuple{Broadcasted,Vararg{Any}}, ::Type{T}) where T = _all_args_isa(t[1].args, T) & _all_args_isa(tail(t), T)
 @inline _densennz(shape::NTuple{1}) = shape[1]
 @inline _densennz(shape::NTuple{2}) = shape[1] * shape[2]
-_maxnnzfrom(shape::NTuple{1}, A) = nnz(A) * div(shape[1], A.n)
-_maxnnzfrom(shape::NTuple{2}, A::SparseVector) = nnz(A) * div(shape[1], A.n) * shape[2]
-_maxnnzfrom(shape::NTuple{2}, A::SparseMatrixCSC) = nnz(A) * div(shape[1], A.m) * div(shape[2], A.n)
+_maxnnzfrom(shape::NTuple{1}, A::SparseVector) = nnz(A) * div(shape[1], length(A))
+_maxnnzfrom(shape::NTuple{2}, A::SparseVector) = nnz(A) * div(shape[1], length(A)) * shape[2]
+_maxnnzfrom(shape::NTuple{2}, A::AbstractSparseMatrixCSC) = nnz(A) * div(shape[1], size(A, 1)) * div(shape[2], size(A, 2))
 @inline _maxnnzfrom_each(shape, ::Tuple{}) = ()
 @inline _maxnnzfrom_each(shape, As) = (_maxnnzfrom(shape, first(As)), _maxnnzfrom_each(shape, tail(As))...)
 @inline _unchecked_maxnnzbcres(shape, As::Tuple) = min(_densennz(shape), sum(_maxnnzfrom_each(shape, As)))
@@ -277,18 +277,18 @@ function _map_notzeropres!(f::Tf, fillva
 end
 # helper functions for these methods and some of those below
 @inline _densecoloffsets(A::SparseVector) = 0
-@inline _densecoloffsets(A::SparseMatrixCSC) = 0:A.m:(A.m*(A.n - 1))
+@inline _densecoloffsets(A::AbstractSparseMatrixCSC) = 0:size(A, 1):(size(A, 1)*(size(A, 2) - 1))
 function _densestructure!(A::SparseVector)
-    expandstorage!(A, A.n)
-    copyto!(A.nzind, 1:A.n)
+    expandstorage!(A, length(A))
+    copyto!(nonzeroinds(A), 1:length(A))
     return A
 end
-function _densestructure!(A::SparseMatrixCSC)
-    nnzA = A.m * A.n
+function _densestructure!(A::AbstractSparseMatrixCSC)
+    nnzA = size(A, 1) * size(A, 2)
     expandstorage!(A, nnzA)
-    copyto!(A.colptr, 1:A.m:(nnzA + 1))
+    copyto!(getcolptr(A), 1:size(A, 1):(nnzA + 1))
     for k in _densecoloffsets(A)
-        copyto!(A.rowval, k + 1, 1:A.m)
+        copyto!(rowvals(A), k + 1, 1:size(A, 1))
     end
     return A
 end
@@ -405,7 +405,7 @@ function _map_notzeropres!(f::Tf, fillva
     # Populate values
     fill!(storedvals(C), fillvalue)
     # NOTE: Combining this fill! into the loop below to avoid multiple sweeps over /
-    # nonsequential access of C.nzval does not appear to improve performance.
+    # nonsequential access of nonzeros(C) does not appear to improve performance.
     rowsentinel = numrows(C) + 1
     stopks = _colstartind_all(1, As)
     @inbounds for (j, jo) in zip(columns(C), _densecoloffsets(C))
@@ -812,7 +812,7 @@ function _broadcast_notzeropres!(f::Tf,
     return C
 end
 _finishempty!(C::SparseVector) = C
-_finishempty!(C::SparseMatrixCSC) = (fill!(C.colptr, 1); C)
+_finishempty!(C::AbstractSparseMatrixCSC) = (fill!(getcolptr(C), 1); C)
 
 # special case - vector outer product
 _copy(f::typeof(*), x::SparseVectorUnion, y::AdjOrTransSparseVectorUnion) = _outer(x, y)
@@ -1012,7 +1012,7 @@ end
 end
 
 _copy(f, args::SparseVector...) = _shapecheckbc(f, args...)
-_copy(f, args::SparseMatrixCSC...) = _shapecheckbc(f, args...)
+_copy(f, args::AbstractSparseMatrixCSC...) = _shapecheckbc(f, args...)
 _copy(f, args::SparseVecOrMat...) = _diffshape_broadcast(f, args...)
 # Otherwise, we incorporate scalars into the function and re-dispatch
 function _copy(f, args...)
@@ -1112,8 +1112,8 @@ end
 end
 
 # NOTE: The following two method definitions work around #19096.
-broadcast(f::Tf, ::Type{T}, A::SparseMatrixCSC) where {Tf,T} = broadcast(y -> f(T, y), A)
-broadcast(f::Tf, A::SparseMatrixCSC, ::Type{T}) where {Tf,T} = broadcast(x -> f(x, T), A)
+broadcast(f::Tf, ::Type{T}, A::AbstractSparseMatrixCSC) where {Tf,T} = broadcast(y -> f(T, y), A)
+broadcast(f::Tf, A::AbstractSparseMatrixCSC, ::Type{T}) where {Tf,T} = broadcast(x -> f(x, T), A)
 
 
 # (11) broadcast[!] over combinations of scalars, sparse vectors/matrices, structured matrices,
@@ -1151,7 +1151,7 @@ _sparsifystructured(x) = x
 SparseOrStructuredMatrix = Union{SparseMatrixCSC,LinearAlgebra.StructuredMatrix}
 map(f::Tf, A::SparseOrStructuredMatrix, Bs::Vararg{SparseOrStructuredMatrix,N}) where {Tf,N} =
     (_checksameshape(A, Bs...); _noshapecheck_map(f, _sparsifystructured(A), map(_sparsifystructured, Bs)...))
-map!(f::Tf, C::SparseMatrixCSC, A::SparseOrStructuredMatrix, Bs::Vararg{SparseOrStructuredMatrix,N}) where {Tf,N} =
+map!(f::Tf, C::AbstractSparseMatrixCSC, A::SparseOrStructuredMatrix, Bs::Vararg{SparseOrStructuredMatrix,N}) where {Tf,N} =
     (_checksameshape(C, A, Bs...); _noshapecheck_map!(f, C, _sparsifystructured(A), map(_sparsifystructured, Bs)...))
 
 end
diff -pruN 1.3.1+dfsg-1/stdlib/SparseArrays/src/linalg.jl 1.4.0+dfsg-1/stdlib/SparseArrays/src/linalg.jl
--- 1.3.1+dfsg-1/stdlib/SparseArrays/src/linalg.jl	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/stdlib/SparseArrays/src/linalg.jl	2020-03-21 16:36:32.000000000 +0000
@@ -3,72 +3,48 @@
 import LinearAlgebra: checksquare
 using Random: rand!
 
-## sparse matrix multiplication
-
-*(A::SparseMatrixCSC{TvA,TiA}, B::SparseMatrixCSC{TvB,TiB}) where {TvA,TiA,TvB,TiB} =
-    *(sppromote(A, B)...)
-*(A::SparseMatrixCSC{TvA,TiA}, transB::Transpose{<:Any,<:SparseMatrixCSC{TvB,TiB}}) where {TvA,TiA,TvB,TiB} =
-    (B = transB.parent; (pA, pB) = sppromote(A, B); *(pA, transpose(pB)))
-*(A::SparseMatrixCSC{TvA,TiA}, adjB::Adjoint{<:Any,<:SparseMatrixCSC{TvB,TiB}}) where {TvA,TiA,TvB,TiB} =
-    (B = adjB.parent; (pA, pB) = sppromote(A, B); *(pA, adjoint(pB)))
-*(transA::Transpose{<:Any,<:SparseMatrixCSC{TvA,TiA}}, B::SparseMatrixCSC{TvB,TiB}) where {TvA,TiA,TvB,TiB} =
-    (A = transA.parent; (pA, pB) = sppromote(A, B); *(transpose(pA), pB))
-*(adjA::Adjoint{<:Any,<:SparseMatrixCSC{TvA,TiA}}, B::SparseMatrixCSC{TvB,TiB}) where {TvA,TiA,TvB,TiB} =
-    (A = adjA.parent; (pA, pB) = sppromote(A, B); *(adjoint(pA), pB))
-*(transA::Transpose{<:Any,<:SparseMatrixCSC{TvA,TiA}}, transB::Transpose{<:Any,<:SparseMatrixCSC{TvB,TiB}}) where {TvA,TiA,TvB,TiB} =
-    (A = transA.parent; B = transB.parent; (pA, pB) = sppromote(A, B); *(transpose(pA), transpose(pB)))
-*(adjA::Adjoint{<:Any,<:SparseMatrixCSC{TvA,TiA}}, adjB::Adjoint{<:Any,<:SparseMatrixCSC{TvB,TiB}}) where {TvA,TiA,TvB,TiB} =
-    (A = adjA.parent; B = adjB.parent; (pA, pB) = sppromote(A, B); *(adjoint(pA), adjoint(pB)))
-
-function sppromote(A::SparseMatrixCSC{TvA,TiA}, B::SparseMatrixCSC{TvB,TiB}) where {TvA,TiA,TvB,TiB}
-    Tv = promote_type(TvA, TvB)
-    Ti = promote_type(TiA, TiB)
-    A  = convert(SparseMatrixCSC{Tv,Ti}, A)
-    B  = convert(SparseMatrixCSC{Tv,Ti}, B)
-    A, B
-end
-
 # In matrix-vector multiplication, the correct orientation of the vector is assumed.
-const AdjOrTransStridedMatrix{T} = Union{StridedMatrix{T},Adjoint{<:Any,<:StridedMatrix{T}},Transpose{<:Any,<:StridedMatrix{T}}}
+const StridedOrTriangularMatrix{T} = Union{StridedMatrix{T}, LowerTriangular{T}, UnitLowerTriangular{T}, UpperTriangular{T}, UnitUpperTriangular{T}}
+const AdjOrTransStridedOrTriangularMatrix{T} = Union{StridedOrTriangularMatrix{T},Adjoint{<:Any,<:StridedOrTriangularMatrix{T}},Transpose{<:Any,<:StridedOrTriangularMatrix{T}}}
 
-function mul!(C::StridedVecOrMat, A::SparseMatrixCSC, B::Union{StridedVector,AdjOrTransStridedMatrix}, α::Number, β::Number)
-    A.n == size(B, 1) || throw(DimensionMismatch())
-    A.m == size(C, 1) || throw(DimensionMismatch())
+function mul!(C::StridedVecOrMat, A::AbstractSparseMatrixCSC, B::Union{StridedVector,AdjOrTransStridedOrTriangularMatrix}, α::Number, β::Number)
+    size(A, 2) == size(B, 1) || throw(DimensionMismatch())
+    size(A, 1) == size(C, 1) || throw(DimensionMismatch())
     size(B, 2) == size(C, 2) || throw(DimensionMismatch())
-    nzv = A.nzval
-    rv = A.rowval
+    nzv = nonzeros(A)
+    rv = rowvals(A)
     if β != 1
         β != 0 ? rmul!(C, β) : fill!(C, zero(eltype(C)))
     end
     for k = 1:size(C, 2)
-        @inbounds for col = 1:A.n
+        @inbounds for col = 1:size(A, 2)
             αxj = B[col,k] * α
-            for j = A.colptr[col]:(A.colptr[col + 1] - 1)
+            for j = getcolptr(A)[col]:(getcolptr(A)[col + 1] - 1)
                 C[rv[j], k] += nzv[j]*αxj
             end
         end
     end
     C
 end
-*(A::SparseMatrixCSC{TA,S}, x::StridedVector{Tx}) where {TA,S,Tx} =
-    (T = promote_op(matprod, TA, Tx); mul!(similar(x, T, A.m), A, x, one(T), zero(T)))
-*(A::SparseMatrixCSC{TA,S}, B::StridedMatrix{Tx}) where {TA,S,Tx} =
-    (T = promote_op(matprod, TA, Tx); mul!(similar(B, T, (A.m, size(B, 2))), A, B, one(T), zero(T)))
+*(A::AbstractSparseMatrixCSC{TA}, x::StridedVector{Tx}) where {TA,Tx} =
+    (T = promote_op(matprod, TA, Tx); mul!(similar(x, T, size(A, 1)), A, x, true, false))
+*(A::AbstractSparseMatrixCSC{TA}, B::AdjOrTransStridedOrTriangularMatrix{Tx}) where {TA,Tx} =
+    (T = promote_op(matprod, TA, Tx); mul!(similar(B, T, (size(A, 1), size(B, 2))), A, B, true, false))
 
-function mul!(C::StridedVecOrMat, adjA::Adjoint{<:Any,<:SparseMatrixCSC}, B::Union{StridedVector,AdjOrTransStridedMatrix}, α::Number, β::Number)
+function mul!(C::StridedVecOrMat, adjA::Adjoint{<:Any,<:AbstractSparseMatrixCSC}, B::Union{StridedVector,AdjOrTransStridedOrTriangularMatrix}, α::Number, β::Number)
     A = adjA.parent
-    A.n == size(C, 1) || throw(DimensionMismatch())
-    A.m == size(B, 1) || throw(DimensionMismatch())
+    size(A, 2) == size(C, 1) || throw(DimensionMismatch())
+    size(A, 1) == size(B, 1) || throw(DimensionMismatch())
     size(B, 2) == size(C, 2) || throw(DimensionMismatch())
-    nzv = A.nzval
-    rv = A.rowval
+    nzv = nonzeros(A)
+    rv = rowvals(A)
     if β != 1
         β != 0 ? rmul!(C, β) : fill!(C, zero(eltype(C)))
     end
     for k = 1:size(C, 2)
-        @inbounds for col = 1:A.n
+        @inbounds for col = 1:size(A, 2)
             tmp = zero(eltype(C))
-            for j = A.colptr[col]:(A.colptr[col + 1] - 1)
+            for j = getcolptr(A)[col]:(getcolptr(A)[col + 1] - 1)
                 tmp += adjoint(nzv[j])*B[rv[j],k]
             end
             C[col,k] += tmp * α
@@ -76,25 +52,25 @@ function mul!(C::StridedVecOrMat, adjA::
     end
     C
 end
-*(adjA::Adjoint{<:Any,<:SparseMatrixCSC{TA,S}}, x::StridedVector{Tx}) where {TA,S,Tx} =
-    (T = promote_op(matprod, TA, Tx); mul!(similar(x, T, size(adjA, 1)), adjA, x, one(T), zero(T)))
-*(adjA::Adjoint{<:Any,<:SparseMatrixCSC{TA,S}}, B::AdjOrTransStridedMatrix{Tx}) where {TA,S,Tx} =
-    (T = promote_op(matprod, TA, Tx); mul!(similar(B, T, (size(adjA, 1), size(B, 2))), adjA, B, one(T), zero(T)))
+*(adjA::Adjoint{<:Any,<:AbstractSparseMatrixCSC}, x::StridedVector{Tx}) where {Tx} =
+    (T = promote_op(matprod, eltype(adjA), Tx); mul!(similar(x, T, size(adjA, 1)), adjA, x, true, false))
+*(adjA::Adjoint{<:Any,<:AbstractSparseMatrixCSC}, B::AdjOrTransStridedOrTriangularMatrix) =
+    (T = promote_op(matprod, eltype(adjA), eltype(B)); mul!(similar(B, T, (size(adjA, 1), size(B, 2))), adjA, B, true, false))
 
-function mul!(C::StridedVecOrMat, transA::Transpose{<:Any,<:SparseMatrixCSC}, B::Union{StridedVector,AdjOrTransStridedMatrix}, α::Number, β::Number)
+function mul!(C::StridedVecOrMat, transA::Transpose{<:Any,<:AbstractSparseMatrixCSC}, B::Union{StridedVector,AdjOrTransStridedOrTriangularMatrix}, α::Number, β::Number)
     A = transA.parent
-    A.n == size(C, 1) || throw(DimensionMismatch())
-    A.m == size(B, 1) || throw(DimensionMismatch())
+    size(A, 2) == size(C, 1) || throw(DimensionMismatch())
+    size(A, 1) == size(B, 1) || throw(DimensionMismatch())
     size(B, 2) == size(C, 2) || throw(DimensionMismatch())
-    nzv = A.nzval
-    rv = A.rowval
+    nzv = nonzeros(A)
+    rv = rowvals(A)
     if β != 1
         β != 0 ? rmul!(C, β) : fill!(C, zero(eltype(C)))
     end
     for k = 1:size(C, 2)
-        @inbounds for col = 1:A.n
+        @inbounds for col = 1:size(A, 2)
             tmp = zero(eltype(C))
-            for j = A.colptr[col]:(A.colptr[col + 1] - 1)
+            for j = getcolptr(A)[col]:(getcolptr(A)[col + 1] - 1)
                 tmp += transpose(nzv[j])*B[rv[j],k]
             end
             C[col,k] += tmp * α
@@ -102,81 +78,81 @@ function mul!(C::StridedVecOrMat, transA
     end
     C
 end
-*(transA::Transpose{<:Any,<:SparseMatrixCSC{TA,S}}, x::StridedVector{Tx}) where {TA,S,Tx} =
-    (T = promote_op(matprod, TA, Tx); mul!(similar(x, T, size(transA, 1)), transA, x, one(T), zero(T)))
-*(transA::Transpose{<:Any,<:SparseMatrixCSC{TA,S}}, B::AdjOrTransStridedMatrix{Tx}) where {TA,S,Tx} =
-    (T = promote_op(matprod, TA, Tx); mul!(similar(B, T, (size(transA, 1), size(B, 2))), transA, B, one(T), zero(T)))
+*(transA::Transpose{<:Any,<:AbstractSparseMatrixCSC}, x::StridedVector{Tx}) where {Tx} =
+    (T = promote_op(matprod, eltype(transA), Tx); mul!(similar(x, T, size(transA, 1)), transA, x, true, false))
+*(transA::Transpose{<:Any,<:AbstractSparseMatrixCSC}, B::AdjOrTransStridedOrTriangularMatrix) =
+    (T = promote_op(matprod, eltype(transA), eltype(B)); mul!(similar(B, T, (size(transA, 1), size(B, 2))), transA, B, true, false))
 
 # For compatibility with dense multiplication API. Should be deleted when dense multiplication
 # API is updated to follow BLAS API.
-mul!(C::StridedVecOrMat, A::SparseMatrixCSC, B::Union{StridedVector,AdjOrTransStridedMatrix}) =
-    mul!(C, A, B, one(eltype(B)), zero(eltype(C)))
-mul!(C::StridedVecOrMat, adjA::Adjoint{<:Any,<:SparseMatrixCSC}, B::Union{StridedVector,AdjOrTransStridedMatrix}) =
-    mul!(C, adjA, B, one(eltype(B)), zero(eltype(C)))
-mul!(C::StridedVecOrMat, transA::Transpose{<:Any,<:SparseMatrixCSC}, B::Union{StridedVector,AdjOrTransStridedMatrix}) =
-    mul!(C, transA, B, one(eltype(B)), zero(eltype(C)))
+mul!(C::StridedVecOrMat, A::AbstractSparseMatrixCSC, B::Union{StridedVector,AdjOrTransStridedOrTriangularMatrix}) =
+    mul!(C, A, B, true, false)
+mul!(C::StridedVecOrMat, adjA::Adjoint{<:Any,<:AbstractSparseMatrixCSC}, B::Union{StridedVector,AdjOrTransStridedOrTriangularMatrix}) =
+    mul!(C, adjA, B, true, false)
+mul!(C::StridedVecOrMat, transA::Transpose{<:Any,<:AbstractSparseMatrixCSC}, B::Union{StridedVector,AdjOrTransStridedOrTriangularMatrix}) =
+    mul!(C, transA, B, true, false)
 
-function mul!(C::StridedVecOrMat, X::AdjOrTransStridedMatrix, A::SparseMatrixCSC, α::Number, β::Number)
+function mul!(C::StridedVecOrMat, X::AdjOrTransStridedOrTriangularMatrix, A::AbstractSparseMatrixCSC, α::Number, β::Number)
     mX, nX = size(X)
-    nX == A.m || throw(DimensionMismatch())
+    nX == size(A, 1) || throw(DimensionMismatch())
     mX == size(C, 1) || throw(DimensionMismatch())
-    A.n == size(C, 2) || throw(DimensionMismatch())
-    rv = A.rowval
-    nzv = A.nzval
+    size(A, 2) == size(C, 2) || throw(DimensionMismatch())
+    rv = rowvals(A)
+    nzv = nonzeros(A)
     if β != 1
         β != 0 ? rmul!(C, β) : fill!(C, zero(eltype(C)))
     end
-    @inbounds for multivec_row=1:mX, col = 1:A.n, k=A.colptr[col]:(A.colptr[col+1]-1)
+    @inbounds for multivec_row=1:mX, col = 1:size(A, 2), k=getcolptr(A)[col]:(getcolptr(A)[col+1]-1)
         C[multivec_row, col] += α * X[multivec_row, rv[k]] * nzv[k] # perhaps suboptimal position of α?
     end
     C
 end
-*(X::AdjOrTransStridedMatrix{TX}, A::SparseMatrixCSC{TvA,TiA}) where {TX,TvA,TiA} =
-    (T = promote_op(matprod, TX, TvA); mul!(similar(X, T, (size(X, 1), A.n)), X, A, one(T), zero(T)))
+*(X::AdjOrTransStridedOrTriangularMatrix, A::AbstractSparseMatrixCSC{TvA}) where {TvA} =
+    (T = promote_op(matprod, eltype(X), TvA); mul!(similar(X, T, (size(X, 1), size(A, 2))), X, A, true, false))
 
-function mul!(C::StridedVecOrMat, X::AdjOrTransStridedMatrix, adjA::Adjoint{<:Any,<:SparseMatrixCSC}, α::Number, β::Number)
+function mul!(C::StridedVecOrMat, X::AdjOrTransStridedOrTriangularMatrix, adjA::Adjoint{<:Any,<:AbstractSparseMatrixCSC}, α::Number, β::Number)
     A = adjA.parent
     mX, nX = size(X)
-    nX == A.n || throw(DimensionMismatch())
+    nX == size(A, 2) || throw(DimensionMismatch())
     mX == size(C, 1) || throw(DimensionMismatch())
-    A.m == size(C, 2) || throw(DimensionMismatch())
-    rv = A.rowval
-    nzv = A.nzval
+    size(A, 1) == size(C, 2) || throw(DimensionMismatch())
+    rv = rowvals(A)
+    nzv = nonzeros(A)
     if β != 1
         β != 0 ? rmul!(C, β) : fill!(C, zero(eltype(C)))
     end
-    @inbounds for col = 1:A.n, k=A.colptr[col]:(A.colptr[col+1]-1), multivec_col=1:mX
+    @inbounds for col = 1:size(A, 2), k=getcolptr(A)[col]:(getcolptr(A)[col+1]-1), multivec_col=1:mX
         C[multivec_col, rv[k]] += α * X[multivec_col, col] * adjoint(nzv[k]) # perhaps suboptimal position of α?
     end
     C
 end
-*(X::AdjOrTransStridedMatrix{TX}, adjA::Adjoint{<:Any,<:SparseMatrixCSC{TvA,TiA}}) where {TX,TvA,TiA} =
-    (T = promote_op(matprod, TX, TvA); mul!(similar(X, T, (size(X, 1), size(adjA, 2))), X, adjA, one(T), zero(T)))
+*(X::AdjOrTransStridedOrTriangularMatrix, adjA::Adjoint{<:Any,<:AbstractSparseMatrixCSC}) =
+    (T = promote_op(matprod, eltype(X), eltype(adjA)); mul!(similar(X, T, (size(X, 1), size(adjA, 2))), X, adjA, true, false))
 
-function mul!(C::StridedVecOrMat, X::AdjOrTransStridedMatrix, transA::Transpose{<:Any,<:SparseMatrixCSC}, α::Number, β::Number)
+function mul!(C::StridedVecOrMat, X::AdjOrTransStridedOrTriangularMatrix, transA::Transpose{<:Any,<:AbstractSparseMatrixCSC}, α::Number, β::Number)
     A = transA.parent
     mX, nX = size(X)
-    nX == A.n || throw(DimensionMismatch())
+    nX == size(A, 2) || throw(DimensionMismatch())
     mX == size(C, 1) || throw(DimensionMismatch())
-    A.m == size(C, 2) || throw(DimensionMismatch())
-    rv = A.rowval
-    nzv = A.nzval
+    size(A, 1) == size(C, 2) || throw(DimensionMismatch())
+    rv = rowvals(A)
+    nzv = nonzeros(A)
     if β != 1
         β != 0 ? rmul!(C, β) : fill!(C, zero(eltype(C)))
     end
-    @inbounds for col = 1:A.n, k=A.colptr[col]:(A.colptr[col+1]-1), multivec_col=1:mX
+    @inbounds for col = 1:size(A, 2), k=getcolptr(A)[col]:(getcolptr(A)[col+1]-1), multivec_col=1:mX
         C[multivec_col, rv[k]] += α * X[multivec_col, col] * transpose(nzv[k]) # perhaps suboptimal position of α?
     end
     C
 end
-*(X::AdjOrTransStridedMatrix{TX}, transA::Transpose{<:Any,<:SparseMatrixCSC{TvA,TiA}}) where {TX,TvA,TiA} =
-    (T = promote_op(matprod, TX, TvA); mul!(similar(X, T, (size(X, 1), size(transA, 2))), X, transA, one(T), zero(T)))
+*(X::AdjOrTransStridedOrTriangularMatrix, transA::Transpose{<:Any,<:AbstractSparseMatrixCSC}) =
+    (T = promote_op(matprod, eltype(X), eltype(transA)); mul!(similar(X, T, (size(X, 1), size(transA, 2))), X, transA, true, false))
 
-function (*)(D::Diagonal, A::SparseMatrixCSC)
+function (*)(D::Diagonal, A::AbstractSparseMatrixCSC)
     T = Base.promote_op(*, eltype(D), eltype(A))
     mul!(LinearAlgebra.copy_oftype(A, T), D, A)
 end
-function (*)(A::SparseMatrixCSC, D::Diagonal)
+function (*)(A::AbstractSparseMatrixCSC, D::Diagonal)
     T = Base.promote_op(*, eltype(D), eltype(A))
     mul!(LinearAlgebra.copy_oftype(A, T), A, D)
 end
@@ -184,13 +160,13 @@ end
 # Sparse matrix multiplication as described in [Gustavson, 1978]:
 # http://dl.acm.org/citation.cfm?id=355796
 
-*(A::SparseMatrixCSC{Tv,Ti}, B::SparseMatrixCSC{Tv,Ti}) where {Tv,Ti} = spmatmul(A,B)
-*(A::SparseMatrixCSC{Tv,Ti}, B::Adjoint{<:Any,<:SparseMatrixCSC{Tv,Ti}}) where {Tv,Ti} = spmatmul(A, copy(B))
-*(A::SparseMatrixCSC{Tv,Ti}, B::Transpose{<:Any,<:SparseMatrixCSC{Tv,Ti}}) where {Tv,Ti} = spmatmul(A, copy(B))
-*(A::Transpose{<:Any,<:SparseMatrixCSC{Tv,Ti}}, B::SparseMatrixCSC{Tv,Ti}) where {Tv,Ti} = spmatmul(copy(A), B)
-*(A::Adjoint{<:Any,<:SparseMatrixCSC{Tv,Ti}}, B::SparseMatrixCSC{Tv,Ti}) where {Tv,Ti} = spmatmul(copy(A), B)
-*(A::Adjoint{<:Any,<:SparseMatrixCSC{Tv,Ti}}, B::Adjoint{<:Any,<:SparseMatrixCSC{Tv,Ti}}) where {Tv,Ti} = spmatmul(copy(A), copy(B))
-*(A::Transpose{<:Any,<:SparseMatrixCSC{Tv,Ti}}, B::Transpose{<:Any,<:SparseMatrixCSC{Tv,Ti}}) where {Tv,Ti} = spmatmul(copy(A), copy(B))
+*(A::AbstractSparseMatrixCSC, B::AbstractSparseMatrixCSC) = spmatmul(A,B)
+*(A::AbstractSparseMatrixCSC, B::Adjoint{<:Any,<:AbstractSparseMatrixCSC}) = spmatmul(A, copy(B))
+*(A::AbstractSparseMatrixCSC, B::Transpose{<:Any,<:AbstractSparseMatrixCSC}) = spmatmul(A, copy(B))
+*(A::Transpose{<:Any,<:AbstractSparseMatrixCSC}, B::AbstractSparseMatrixCSC) = spmatmul(copy(A), B)
+*(A::Adjoint{<:Any,<:AbstractSparseMatrixCSC}, B::AbstractSparseMatrixCSC) = spmatmul(copy(A), B)
+*(A::Adjoint{<:Any,<:AbstractSparseMatrixCSC}, B::Adjoint{<:Any,<:AbstractSparseMatrixCSC}) = spmatmul(copy(A), copy(B))
+*(A::Transpose{<:Any,<:AbstractSparseMatrixCSC}, B::Transpose{<:Any,<:AbstractSparseMatrixCSC}) = spmatmul(copy(A), copy(B))
 
 # Gustavsen's matrix multiplication algorithm revisited.
 # The result rowval vector is already sorted by construction.
@@ -200,7 +176,9 @@ end
 # done by a quicksort of the row indices or by a full scan of the dense result vector.
 # The last is faster, if more than ≈ 1/32 of the result column is nonzero.
 # TODO: extend to SparseMatrixCSCUnion to allow for SubArrays (view(X, :, r)).
-function spmatmul(A::SparseMatrixCSC{Tv,Ti}, B::SparseMatrixCSC{Tv,Ti}) where {Tv,Ti}
+function spmatmul(A::AbstractSparseMatrixCSC{TvA,TiA}, B::AbstractSparseMatrixCSC{TvB,TiB}) where {TvA,TiA,TvB,TiB}
+    Tv = promote_op(matprod, TvA, TvB)
+    Ti = promote_type(TiA, TiB)
     mA, nA = size(A)
     nB = size(B, 2)
     nA == size(B, 1) || throw(DimensionMismatch())
@@ -291,29 +269,29 @@ prefer_sort(nz::Integer, m::Integer) = m
 ilog2(n::Integer) = sizeof(n)<<3 - leading_zeros(n)
 
 # Frobenius dot/inner product: trace(A'B)
-function dot(A::SparseMatrixCSC{T1,S1},B::SparseMatrixCSC{T2,S2}) where {T1,T2,S1,S2}
+function dot(A::AbstractSparseMatrixCSC{T1,S1},B::AbstractSparseMatrixCSC{T2,S2}) where {T1,T2,S1,S2}
     m, n = size(A)
     size(B) == (m,n) || throw(DimensionMismatch("matrices must have the same dimensions"))
     r = dot(zero(T1), zero(T2))
     @inbounds for j = 1:n
-        ia = A.colptr[j]; ia_nxt = A.colptr[j+1]
-        ib = B.colptr[j]; ib_nxt = B.colptr[j+1]
+        ia = getcolptr(A)[j]; ia_nxt = getcolptr(A)[j+1]
+        ib = getcolptr(B)[j]; ib_nxt = getcolptr(B)[j+1]
         if ia < ia_nxt && ib < ib_nxt
-            ra = A.rowval[ia]; rb = B.rowval[ib]
+            ra = rowvals(A)[ia]; rb = rowvals(B)[ib]
             while true
                 if ra < rb
                     ia += oneunit(S1)
                     ia < ia_nxt || break
-                    ra = A.rowval[ia]
+                    ra = rowvals(A)[ia]
                 elseif ra > rb
                     ib += oneunit(S2)
                     ib < ib_nxt || break
-                    rb = B.rowval[ib]
+                    rb = rowvals(B)[ib]
                 else # ra == rb
-                    r += dot(A.nzval[ia], B.nzval[ib])
+                    r += dot(nonzeros(A)[ia], nonzeros(B)[ib])
                     ia += oneunit(S1); ib += oneunit(S2)
                     ia < ia_nxt && ib < ib_nxt || break
-                    ra = A.rowval[ia]; rb = B.rowval[ib]
+                    ra = rowvals(A)[ia]; rb = rowvals(B)[ib]
                 end
             end
         end
@@ -321,10 +299,58 @@ function dot(A::SparseMatrixCSC{T1,S1},B
     return r
 end
 
+function dot(x::AbstractVector, A::AbstractSparseMatrixCSC, y::AbstractVector)
+    require_one_based_indexing(x, y)
+    m, n = size(A)
+    (length(x) == m && n == length(y)) || throw(DimensionMismatch())
+    if iszero(m) || iszero(n)
+        return dot(zero(eltype(x)), zero(eltype(A)), zero(eltype(y)))
+    end
+    T = promote_type(eltype(x), eltype(A), eltype(y))
+    r = zero(T)
+    rvals = getrowval(A)
+    nzvals = getnzval(A)
+    @inbounds for col in 1:n
+        ycol = y[col]
+        if !iszero(ycol)
+            temp = zero(T)
+            for k in nzrange(A, col)
+                temp += adjoint(x[rvals[k]]) * nzvals[k]
+            end
+            r += temp * ycol
+        end
+    end
+    return r
+end
+function dot(x::SparseVector, A::AbstractSparseMatrixCSC, y::SparseVector)
+    m, n = size(A)
+    length(x) == m && n == length(y) || throw(DimensionMismatch())
+    if iszero(m) || iszero(n)
+        return dot(zero(eltype(x)), zero(eltype(A)), zero(eltype(y)))
+    end
+    r = zero(promote_type(eltype(x), eltype(A), eltype(y)))
+    xnzind = nonzeroinds(x)
+    xnzval = nonzeros(x)
+    ynzind = nonzeroinds(y)
+    ynzval = nonzeros(y)
+    Acolptr = getcolptr(A)
+    Arowval = getrowval(A)
+    Anzval = getnzval(A)
+    for (yi, yv) in zip(ynzind, ynzval)
+        A_ptr_lo = Acolptr[yi]
+        A_ptr_hi = Acolptr[yi+1] - 1
+        if A_ptr_lo <= A_ptr_hi
+            r += _spdot(dot, 1, length(xnzind), xnzind, xnzval,
+                                            A_ptr_lo, A_ptr_hi, Arowval, Anzval) * yv
+        end
+    end
+    r
+end
+
 ## triangular sparse handling
 
-possible_adjoint(adj::Bool, a::Real ) = a
-possible_adjoint(adj::Bool, a ) = adj ? adjoint(a) : a
+possible_adjoint(adj::Bool, a::Real) = a
+possible_adjoint(adj::Bool, a) = adj ? adjoint(a) : a
 
 const UnitDiagonalTriangular = Union{UnitUpperTriangular,UnitLowerTriangular}
 
@@ -717,8 +743,8 @@ function _ldiv!(U::UpperTriangularWrappe
     B
 end
 
-(\)(L::TriangularSparse, B::SparseMatrixCSC) = ldiv!(L, Array(B))
-(*)(L::TriangularSparse, B::SparseMatrixCSC) = lmul!(L, Array(B))
+(\)(L::TriangularSparse, B::AbstractSparseMatrixCSC) = ldiv!(L, Array(B))
+(*)(L::TriangularSparse, B::AbstractSparseMatrixCSC) = lmul!(L, Array(B))
 
 ## end of triangular
 
@@ -728,7 +754,6 @@ mul!(y::StridedVecOrMat, A::SparseMatrix
 # C .= α * A * B + β * C
 function mul!(C::StridedVecOrMat{T}, sA::SparseMatrixCSCSymmHerm, B::StridedVecOrMat,
               α::Number, β::Number) where T
-
     fuplo = sA.uplo == 'U' ? nzrangeup : nzrangelo
     _mul!(fuplo, C, sA, B, T(α), T(β))
 end
@@ -779,14 +804,14 @@ function nzrangelo(A, i)
 end
 ## end of symmetric/Hermitian
 
-\(A::Transpose{<:Real,<:Hermitian{<:Real,<:SparseMatrixCSC}}, B::Vector) = A.parent \ B
-\(A::Transpose{<:Complex,<:Hermitian{<:Complex,<:SparseMatrixCSC}}, B::Vector) = copy(A) \ B
-\(A::Transpose{<:Number,<:Symmetric{<:Number,<:SparseMatrixCSC}}, B::Vector) = A.parent \ B
+\(A::Transpose{<:Real,<:Hermitian{<:Real,<:AbstractSparseMatrixCSC}}, B::Vector) = A.parent \ B
+\(A::Transpose{<:Complex,<:Hermitian{<:Complex,<:AbstractSparseMatrixCSC}}, B::Vector) = copy(A) \ B
+\(A::Transpose{<:Number,<:Symmetric{<:Number,<:AbstractSparseMatrixCSC}}, B::Vector) = A.parent \ B
 
-function rdiv!(A::SparseMatrixCSC{T}, D::Diagonal{T}) where T
+function rdiv!(A::AbstractSparseMatrixCSC{T}, D::Diagonal{T}) where T
     dd = D.diag
-    if (k = length(dd)) ≠ A.n
-        throw(DimensionMismatch("size(A, 2)=$(A.n) should be size(D, 1)=$k"))
+    if (k = length(dd)) ≠ size(A, 2)
+        throw(DimensionMismatch("size(A, 2)=$(size(A, 2)) should be size(D, 1)=$k"))
     end
     nonz = nonzeros(A)
     @inbounds for j in 1:k
@@ -801,35 +826,35 @@ function rdiv!(A::SparseMatrixCSC{T}, D:
     A
 end
 
-rdiv!(A::SparseMatrixCSC{T}, adjD::Adjoint{<:Any,<:Diagonal{T}}) where {T} =
+rdiv!(A::AbstractSparseMatrixCSC{T}, adjD::Adjoint{<:Any,<:Diagonal{T}}) where {T} =
     (D = adjD.parent; rdiv!(A, conj(D)))
-rdiv!(A::SparseMatrixCSC{T}, transD::Transpose{<:Any,<:Diagonal{T}}) where {T} =
+rdiv!(A::AbstractSparseMatrixCSC{T}, transD::Transpose{<:Any,<:Diagonal{T}}) where {T} =
     (D = transD.parent; rdiv!(A, D))
 
-function ldiv!(D::Diagonal{T}, A::SparseMatrixCSC{T}) where {T}
+function ldiv!(D::Diagonal{T}, A::AbstractSparseMatrixCSC{T}) where {T}
     # require_one_based_indexing(A)
-    if A.m != length(D.diag)
-        throw(DimensionMismatch("diagonal matrix is $(length(D.diag)) by $(length(D.diag)) but right hand side has $(A.m) rows"))
+    if size(A, 1) != length(D.diag)
+        throw(DimensionMismatch("diagonal matrix is $(length(D.diag)) by $(length(D.diag)) but right hand side has $(size(A, 1)) rows"))
     end
     nonz = nonzeros(A)
-    Arowval = A.rowval
+    Arowval = rowvals(A)
     b = D.diag
     for i=1:length(b)
         iszero(b[i]) && throw(SingularException(i))
     end
-    @inbounds for col = 1:A.n, p = A.colptr[col]:(A.colptr[col + 1] - 1)
+    @inbounds for col = 1:size(A, 2), p = getcolptr(A)[col]:(getcolptr(A)[col + 1] - 1)
         nonz[p] = b[Arowval[p]] \ nonz[p]
     end
     A
 end
-ldiv!(adjD::Adjoint{<:Any,<:Diagonal{T}}, A::SparseMatrixCSC{T}) where {T} =
+ldiv!(adjD::Adjoint{<:Any,<:Diagonal{T}}, A::AbstractSparseMatrixCSC{T}) where {T} =
     (D = adjD.parent; ldiv!(conj(D), A))
-ldiv!(transD::Transpose{<:Any,<:Diagonal{T}}, A::SparseMatrixCSC{T}) where {T} =
+ldiv!(transD::Transpose{<:Any,<:Diagonal{T}}, A::AbstractSparseMatrixCSC{T}) where {T} =
     (D = transD.parent; ldiv!(D, A))
 
 ## triu, tril
 
-function triu(S::SparseMatrixCSC{Tv,Ti}, k::Integer=0) where {Tv,Ti}
+function triu(S::AbstractSparseMatrixCSC{Tv,Ti}, k::Integer=0) where {Tv,Ti}
     m,n = size(S)
     colptr = Vector{Ti}(undef, n+1)
     nnz = 0
@@ -837,8 +862,8 @@ function triu(S::SparseMatrixCSC{Tv,Ti},
         colptr[col] = 1
     end
     for col = max(k+1,1) : n
-        for c1 = S.colptr[col] : S.colptr[col+1]-1
-            S.rowval[c1] > col - k && break
+        for c1 = getcolptr(S)[col] : getcolptr(S)[col+1]-1
+            rowvals(S)[c1] > col - k && break
             nnz += 1
         end
         colptr[col+1] = nnz+1
@@ -847,25 +872,25 @@ function triu(S::SparseMatrixCSC{Tv,Ti},
     nzval = Vector{Tv}(undef, nnz)
     A = SparseMatrixCSC(m, n, colptr, rowval, nzval)
     for col = max(k+1,1) : n
-        c1 = S.colptr[col]
-        for c2 = A.colptr[col] : A.colptr[col+1]-1
-            A.rowval[c2] = S.rowval[c1]
-            A.nzval[c2] = S.nzval[c1]
+        c1 = getcolptr(S)[col]
+        for c2 = getcolptr(A)[col] : getcolptr(A)[col+1]-1
+            rowvals(A)[c2] = rowvals(S)[c1]
+            nonzeros(A)[c2] = nonzeros(S)[c1]
             c1 += 1
         end
     end
     A
 end
 
-function tril(S::SparseMatrixCSC{Tv,Ti}, k::Integer=0) where {Tv,Ti}
+function tril(S::AbstractSparseMatrixCSC{Tv,Ti}, k::Integer=0) where {Tv,Ti}
     m,n = size(S)
     colptr = Vector{Ti}(undef, n+1)
     nnz = 0
     colptr[1] = 1
     for col = 1 : min(n, m+k)
-        l1 = S.colptr[col+1]-1
-        for c1 = 0 : (l1 - S.colptr[col])
-            S.rowval[l1 - c1] < col - k && break
+        l1 = getcolptr(S)[col+1]-1
+        for c1 = 0 : (l1 - getcolptr(S)[col])
+            rowvals(S)[l1 - c1] < col - k && break
             nnz += 1
         end
         colptr[col+1] = nnz+1
@@ -877,11 +902,11 @@ function tril(S::SparseMatrixCSC{Tv,Ti},
     nzval = Vector{Tv}(undef, nnz)
     A = SparseMatrixCSC(m, n, colptr, rowval, nzval)
     for col = 1 : min(n, m+k)
-        c1 = S.colptr[col+1]-1
-        l2 = A.colptr[col+1]-1
-        for c2 = 0 : l2 - A.colptr[col]
-            A.rowval[l2 - c2] = S.rowval[c1]
-            A.nzval[l2 - c2] = S.nzval[c1]
+        c1 = getcolptr(S)[col+1]-1
+        l2 = getcolptr(A)[col+1]-1
+        for c2 = 0 : l2 - getcolptr(A)[col]
+            rowvals(A)[l2 - c2] = rowvals(S)[c1]
+            nonzeros(A)[l2 - c2] = nonzeros(S)[c1]
             c1 -= 1
         end
     end
@@ -890,7 +915,7 @@ end
 
 ## diff
 
-function sparse_diff1(S::SparseMatrixCSC{Tv,Ti}) where {Tv,Ti}
+function sparse_diff1(S::AbstractSparseMatrixCSC{Tv,Ti}) where {Tv,Ti}
     m,n = size(S)
     m > 1 || return SparseMatrixCSC(0, n, fill(one(Ti),n+1), Ti[], Tv[])
     colptr = Vector{Ti}(undef, n+1)
@@ -902,9 +927,9 @@ function sparse_diff1(S::SparseMatrixCSC
     for col = 1 : n
         last_row = 0
         last_val = 0
-        for k = S.colptr[col] : S.colptr[col+1]-1
-            row = S.rowval[k]
-            val = S.nzval[k]
+        for k = getcolptr(S)[col] : getcolptr(S)[col+1]-1
+            row = rowvals(S)[k]
+            val = nonzeros(S)[k]
             if row > 1
                 if row == last_row + 1
                     nzval[numnz] += val
@@ -930,7 +955,7 @@ function sparse_diff1(S::SparseMatrixCSC
     return SparseMatrixCSC(m-1, n, colptr, rowval, nzval)
 end
 
-function sparse_diff2(a::SparseMatrixCSC{Tv,Ti}) where {Tv,Ti}
+function sparse_diff2(a::AbstractSparseMatrixCSC{Tv,Ti}) where {Tv,Ti}
     m,n = size(a)
     colptr = Vector{Ti}(undef, max(n,1))
     numnz = 2 * nnz(a) # upper bound; will shrink later
@@ -939,9 +964,9 @@ function sparse_diff2(a::SparseMatrixCSC
 
     z = zero(Tv)
 
-    colptr_a = a.colptr
-    rowval_a = a.rowval
-    nzval_a = a.nzval
+    colptr_a = getcolptr(a)
+    rowval_a = rowvals(a)
+    nzval_a = nonzeros(a)
 
     ptrS = 1
     colptr[1] = 1
@@ -1019,12 +1044,12 @@ function sparse_diff2(a::SparseMatrixCSC
     return SparseMatrixCSC(m, n-1, colptr, rowval, nzval)
 end
 
-diff(a::SparseMatrixCSC; dims::Integer) = dims==1 ? sparse_diff1(a) : sparse_diff2(a)
+diff(a::AbstractSparseMatrixCSC; dims::Integer) = dims==1 ? sparse_diff1(a) : sparse_diff2(a)
 
 ## norm and rank
-norm(A::SparseMatrixCSC, p::Real=2) = norm(view(A.nzval, 1:nnz(A)), p)
+norm(A::AbstractSparseMatrixCSC, p::Real=2) = norm(view(nonzeros(A), 1:nnz(A)), p)
 
-function opnorm(A::SparseMatrixCSC, p::Real=2)
+function opnorm(A::AbstractSparseMatrixCSC, p::Real=2)
     m, n = size(A)
     if m == 0 || n == 0 || isempty(A)
         return float(real(zero(eltype(A))))
@@ -1045,8 +1070,8 @@ function opnorm(A::SparseMatrixCSC, p::R
             nA::Tsum = 0
             for j=1:n
                 colSum::Tsum = 0
-                for i = A.colptr[j]:A.colptr[j+1]-1
-                    colSum += abs(A.nzval[i])
+                for i = getcolptr(A)[j]:getcolptr(A)[j+1]-1
+                    colSum += abs(nonzeros(A)[i])
                 end
                 nA = max(nA, colSum)
             end
@@ -1055,8 +1080,8 @@ function opnorm(A::SparseMatrixCSC, p::R
             throw(ArgumentError("2-norm not yet implemented for sparse matrices. Try opnorm(Array(A)) or opnorm(A, p) where p=1 or Inf."))
         elseif p==Inf
             rowSum = zeros(Tsum,m)
-            for i=1:length(A.nzval)
-                rowSum[A.rowval[i]] += abs(A.nzval[i])
+            for i=1:length(nonzeros(A))
+                rowSum[rowvals(A)[i]] += abs(nonzeros(A)[i])
             end
             return convert(Tnorm, maximum(rowSum))
         end
@@ -1067,7 +1092,7 @@ end
 # TODO rank
 
 # cond
-function cond(A::SparseMatrixCSC, p::Real=2)
+function cond(A::AbstractSparseMatrixCSC, p::Real=2)
     if p == 1
         normAinv = opnormestinv(A)
         normA = opnorm(A, 1)
@@ -1083,7 +1108,7 @@ function cond(A::SparseMatrixCSC, p::Rea
     end
 end
 
-function opnormestinv(A::SparseMatrixCSC{T}, t::Integer = min(2,maximum(size(A)))) where T
+function opnormestinv(A::AbstractSparseMatrixCSC{T}, t::Integer = min(2,maximum(size(A)))) where T
     maxiter = 5
     # Check the input
     n = checksquare(A)
@@ -1251,7 +1276,7 @@ end
 ## kron
 
 # sparse matrix ⊗ sparse matrix
-function kron(A::SparseMatrixCSC{T1,S1}, B::SparseMatrixCSC{T2,S2}) where {T1,S1,T2,S2}
+function kron(A::AbstractSparseMatrixCSC{T1,S1}, B::AbstractSparseMatrixCSC{T2,S2}) where {T1,S1,T2,S2}
     nnzC = nnz(A)*nnz(B)
     mA, nA = size(A); mB, nB = size(B)
     mC, nC = mA*mB, nA*nB
@@ -1261,12 +1286,12 @@ function kron(A::SparseMatrixCSC{T1,S1},
     colptrC[1] = 1
     col = 1
     @inbounds for j = 1:nA
-        startA = A.colptr[j]
-        stopA = A.colptr[j+1] - 1
+        startA = getcolptr(A)[j]
+        stopA = getcolptr(A)[j+1] - 1
         lA = stopA - startA + 1
         for i = 1:nB
-            startB = B.colptr[i]
-            stopB = B.colptr[i+1] - 1
+            startB = getcolptr(B)[i]
+            stopB = getcolptr(B)[i+1] - 1
             lB = stopB - startB + 1
             ptr_range = (1:lB) .+ (colptrC[col]-1)
             colptrC[col+1] = colptrC[col] + lA*lB
@@ -1274,8 +1299,8 @@ function kron(A::SparseMatrixCSC{T1,S1},
             for ptrA = startA : stopA
                 ptrB = startB
                 for ptr = ptr_range
-                    rowvalC[ptr] = (A.rowval[ptrA]-1)*mB + B.rowval[ptrB]
-                    nzvalC[ptr] = A.nzval[ptrA] * B.nzval[ptrB]
+                    rowvalC[ptr] = (rowvals(A)[ptrA]-1)*mB + rowvals(B)[ptrB]
+                    nzvalC[ptr] = nonzeros(A)[ptrA] * nonzeros(B)[ptrB]
                     ptrB += 1
                 end
                 ptr_range = ptr_range .+ lB
@@ -1293,125 +1318,125 @@ function kron(x::SparseVector{T1,S1}, y:
     nzval = Vector{typeof(one(T1)*one(T2))}(undef, nnzz) # the values of nonzeros
     @inbounds for i = 1:nnzx, j = 1:nnzy
         this_ind = (i-1)*nnzy+j
-        nzind[this_ind] = (x.nzind[i]-1)*y.n + y.nzind[j]
-        nzval[this_ind] = x.nzval[i] * y.nzval[j]
+        nzind[this_ind] = (nonzeroinds(x)[i]-1)*length(y::SparseVector) + nonzeroinds(y)[j]
+        nzval[this_ind] = nonzeros(x)[i] * nonzeros(y)[j]
     end
-    return SparseVector(x.n*y.n, nzind, nzval)
+    return SparseVector(length(x::SparseVector)*length(y::SparseVector), nzind, nzval)
 end
 
 # sparse matrix ⊗ sparse vector & vice versa
-kron(A::SparseMatrixCSC, x::SparseVector) = kron(A, SparseMatrixCSC(x))
-kron(x::SparseVector, A::SparseMatrixCSC) = kron(SparseMatrixCSC(x), A)
+kron(A::AbstractSparseMatrixCSC, x::SparseVector) = kron(A, SparseMatrixCSC(x))
+kron(x::SparseVector, A::AbstractSparseMatrixCSC) = kron(SparseMatrixCSC(x), A)
 
 # sparse vec/mat ⊗ vec/mat and vice versa
-kron(A::Union{SparseVector,SparseMatrixCSC}, B::VecOrMat) = kron(A, sparse(B))
-kron(A::VecOrMat, B::Union{SparseVector,SparseMatrixCSC}) = kron(sparse(A), B)
+kron(A::Union{SparseVector,AbstractSparseMatrixCSC}, B::VecOrMat) = kron(A, sparse(B))
+kron(A::VecOrMat, B::Union{SparseVector,AbstractSparseMatrixCSC}) = kron(sparse(A), B)
 
 # sparse vec/mat ⊗ Diagonal and vice versa
-kron(A::Diagonal{T}, B::Union{SparseVector{S}, SparseMatrixCSC{S}}) where {T<:Number, S<:Number} = kron(sparse(A), B)
-kron(A::Union{SparseVector{T}, SparseMatrixCSC{T}}, B::Diagonal{S}) where {T<:Number, S<:Number} = kron(A, sparse(B))
+kron(A::Diagonal{T}, B::Union{SparseVector{S}, AbstractSparseMatrixCSC{S}}) where {T<:Number, S<:Number} = kron(sparse(A), B)
+kron(A::Union{SparseVector{T}, AbstractSparseMatrixCSC{T}}, B::Diagonal{S}) where {T<:Number, S<:Number} = kron(A, sparse(B))
 
 # sparse outer product
 kron(A::SparseVectorUnion, B::AdjOrTransSparseVectorUnion) = A .* B
 
 ## det, inv, cond
 
-inv(A::SparseMatrixCSC) = error("The inverse of a sparse matrix can often be dense and can cause the computer to run out of memory. If you are sure you have enough memory, please convert your matrix to a dense matrix.")
+inv(A::AbstractSparseMatrixCSC) = error("The inverse of a sparse matrix can often be dense and can cause the computer to run out of memory. If you are sure you have enough memory, please convert your matrix to a dense matrix.")
 
 # TODO
 
 ## scale methods
 
 # Copy colptr and rowval from one sparse matrix to another
-function copyinds!(C::SparseMatrixCSC, A::SparseMatrixCSC)
-    if C.colptr !== A.colptr
-        resize!(C.colptr, length(A.colptr))
-        copyto!(C.colptr, A.colptr)
-    end
-    if C.rowval !== A.rowval
-        resize!(C.rowval, length(A.rowval))
-        copyto!(C.rowval, A.rowval)
+function copyinds!(C::AbstractSparseMatrixCSC, A::AbstractSparseMatrixCSC)
+    if getcolptr(C) !== getcolptr(A)
+        resize!(getcolptr(C), length(getcolptr(A)))
+        copyto!(getcolptr(C), getcolptr(A))
+    end
+    if rowvals(C) !== rowvals(A)
+        resize!(rowvals(C), length(rowvals(A)))
+        copyto!(rowvals(C), rowvals(A))
     end
 end
 
 # multiply by diagonal matrix as vector
-function mul!(C::SparseMatrixCSC, A::SparseMatrixCSC, D::Diagonal{T, <:Vector}) where T
+function mul!(C::AbstractSparseMatrixCSC, A::AbstractSparseMatrixCSC, D::Diagonal)
     m, n = size(A)
     b    = D.diag
     (n==length(b) && size(A)==size(C)) || throw(DimensionMismatch())
     copyinds!(C, A)
-    Cnzval = C.nzval
-    Anzval = A.nzval
+    Cnzval = nonzeros(C)
+    Anzval = nonzeros(A)
     resize!(Cnzval, length(Anzval))
-    for col = 1:n, p = A.colptr[col]:(A.colptr[col+1]-1)
+    for col = 1:n, p = getcolptr(A)[col]:(getcolptr(A)[col+1]-1)
         @inbounds Cnzval[p] = Anzval[p] * b[col]
     end
     C
 end
 
-function mul!(C::SparseMatrixCSC, D::Diagonal{T, <:Vector}, A::SparseMatrixCSC) where T
+function mul!(C::AbstractSparseMatrixCSC, D::Diagonal, A::AbstractSparseMatrixCSC)
     m, n = size(A)
     b    = D.diag
     (m==length(b) && size(A)==size(C)) || throw(DimensionMismatch())
     copyinds!(C, A)
-    Cnzval = C.nzval
-    Anzval = A.nzval
-    Arowval = A.rowval
+    Cnzval = nonzeros(C)
+    Anzval = nonzeros(A)
+    Arowval = rowvals(A)
     resize!(Cnzval, length(Anzval))
-    for col = 1:n, p = A.colptr[col]:(A.colptr[col+1]-1)
+    for col = 1:n, p = getcolptr(A)[col]:(getcolptr(A)[col+1]-1)
         @inbounds Cnzval[p] = b[Arowval[p]] * Anzval[p]
     end
     C
 end
 
-function mul!(C::SparseMatrixCSC, A::SparseMatrixCSC, b::Number)
+function mul!(C::AbstractSparseMatrixCSC, A::AbstractSparseMatrixCSC, b::Number)
     size(A)==size(C) || throw(DimensionMismatch())
     copyinds!(C, A)
-    resize!(C.nzval, length(A.nzval))
-    mul!(C.nzval, A.nzval, b)
+    resize!(nonzeros(C), length(nonzeros(A)))
+    mul!(nonzeros(C), nonzeros(A), b)
     C
 end
 
-function mul!(C::SparseMatrixCSC, b::Number, A::SparseMatrixCSC)
+function mul!(C::AbstractSparseMatrixCSC, b::Number, A::AbstractSparseMatrixCSC)
     size(A)==size(C) || throw(DimensionMismatch())
     copyinds!(C, A)
-    resize!(C.nzval, length(A.nzval))
-    mul!(C.nzval, b, A.nzval)
+    resize!(nonzeros(C), length(nonzeros(A)))
+    mul!(nonzeros(C), b, nonzeros(A))
     C
 end
 
-function rmul!(A::SparseMatrixCSC, b::Number)
-    rmul!(A.nzval, b)
+function rmul!(A::AbstractSparseMatrixCSC, b::Number)
+    rmul!(nonzeros(A), b)
     return A
 end
 
-function lmul!(b::Number, A::SparseMatrixCSC)
-    lmul!(b, A.nzval)
+function lmul!(b::Number, A::AbstractSparseMatrixCSC)
+    lmul!(b, nonzeros(A))
     return A
 end
 
-function rmul!(A::SparseMatrixCSC, D::Diagonal)
+function rmul!(A::AbstractSparseMatrixCSC, D::Diagonal)
     m, n = size(A)
     (n == size(D, 1)) || throw(DimensionMismatch())
-    Anzval = A.nzval
-    @inbounds for col = 1:n, p = A.colptr[col]:(A.colptr[col + 1] - 1)
+    Anzval = nonzeros(A)
+    @inbounds for col = 1:n, p = getcolptr(A)[col]:(getcolptr(A)[col + 1] - 1)
          Anzval[p] = Anzval[p] * D.diag[col]
     end
     return A
 end
 
-function lmul!(D::Diagonal, A::SparseMatrixCSC)
+function lmul!(D::Diagonal, A::AbstractSparseMatrixCSC)
     m, n = size(A)
     (m == size(D, 2)) || throw(DimensionMismatch())
-    Anzval = A.nzval
-    Arowval = A.rowval
-    @inbounds for col = 1:n, p = A.colptr[col]:(A.colptr[col + 1] - 1)
+    Anzval = nonzeros(A)
+    Arowval = rowvals(A)
+    @inbounds for col = 1:n, p = getcolptr(A)[col]:(getcolptr(A)[col + 1] - 1)
         Anzval[p] = D.diag[Arowval[p]] * Anzval[p]
     end
     return A
 end
 
-function \(A::SparseMatrixCSC, B::AbstractVecOrMat)
+function \(A::AbstractSparseMatrixCSC, B::AbstractVecOrMat)
     require_one_based_indexing(A, B)
     m, n = size(A)
     if m == n
@@ -1434,7 +1459,7 @@ function \(A::SparseMatrixCSC, B::Abstra
 end
 for (xformtype, xformop) in ((:Adjoint, :adjoint), (:Transpose, :transpose))
     @eval begin
-        function \(xformA::($xformtype){<:Any,<:SparseMatrixCSC}, B::AbstractVecOrMat)
+        function \(xformA::($xformtype){<:Any,<:AbstractSparseMatrixCSC}, B::AbstractVecOrMat)
             A = xformA.parent
             require_one_based_indexing(A, B)
             m, n = size(A)
@@ -1459,7 +1484,7 @@ for (xformtype, xformop) in ((:Adjoint,
     end
 end
 
-function factorize(A::SparseMatrixCSC)
+function factorize(A::AbstractSparseMatrixCSC)
     m, n = size(A)
     if m == n
         if istril(A)
@@ -1480,7 +1505,7 @@ function factorize(A::SparseMatrixCSC)
     end
 end
 
-# function factorize(A::Symmetric{Float64,SparseMatrixCSC{Float64,Ti}}) where Ti
+# function factorize(A::Symmetric{Float64,AbstractSparseMatrixCSC{Float64,Ti}}) where Ti
 #     F = cholesky(A)
 #     if LinearAlgebra.issuccess(F)
 #         return F
@@ -1489,7 +1514,7 @@ end
 #         return F
 #     end
 # end
-function factorize(A::LinearAlgebra.RealHermSymComplexHerm{Float64,<:SparseMatrixCSC})
+function factorize(A::LinearAlgebra.RealHermSymComplexHerm{Float64,<:AbstractSparseMatrixCSC})
     F = cholesky(A; check = false)
     if LinearAlgebra.issuccess(F)
         return F
@@ -1499,5 +1524,5 @@ function factorize(A::LinearAlgebra.Real
     end
 end
 
-eigen(A::SparseMatrixCSC) =
+eigen(A::AbstractSparseMatrixCSC) =
     error("eigen(A) not supported for sparse matrices. Use for example eigs(A) from the Arpack package instead.")
diff -pruN 1.3.1+dfsg-1/stdlib/SparseArrays/src/SparseArrays.jl 1.4.0+dfsg-1/stdlib/SparseArrays/src/SparseArrays.jl
--- 1.3.1+dfsg-1/stdlib/SparseArrays/src/SparseArrays.jl	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/stdlib/SparseArrays/src/SparseArrays.jl	2020-03-21 16:36:32.000000000 +0000
@@ -10,7 +10,7 @@ using Base: ReshapedArray, promote_op, s
 using Base.Sort: Forward
 using LinearAlgebra
 
-import Base: +, -, *, \, /, &, |, xor, ==
+import Base: +, -, *, \, /, &, |, xor, ==, zero
 import LinearAlgebra: mul!, ldiv!, rdiv!, cholesky, adjoint!, diag, eigen, dot,
     issymmetric, istril, istriu, lu, tr, transpose!, tril!, triu!,
     cond, diagm, factorize, ishermitian, norm, opnorm, lmul!, rmul!, tril, triu, matprod
@@ -52,6 +52,8 @@ similar(D::Diagonal, ::Type{T}, dims::Un
 similar(S::SymTridiagonal, ::Type{T}, dims::Union{Dims{1},Dims{2}}) where {T} = spzeros(T, dims...)
 similar(M::Tridiagonal, ::Type{T}, dims::Union{Dims{1},Dims{2}}) where {T} = spzeros(T, dims...)
 
+zero(a::AbstractSparseArray) = spzeros(eltype(a), size(a)...)
+
 const BiTriSym = Union{Bidiagonal,SymTridiagonal,Tridiagonal}
 function *(A::BiTriSym, B::BiTriSym)
     TS = promote_op(matprod, eltype(A), eltype(B))
diff -pruN 1.3.1+dfsg-1/stdlib/SparseArrays/src/sparseconvert.jl 1.4.0+dfsg-1/stdlib/SparseArrays/src/sparseconvert.jl
--- 1.3.1+dfsg-1/stdlib/SparseArrays/src/sparseconvert.jl	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/stdlib/SparseArrays/src/sparseconvert.jl	2020-03-21 16:36:32.000000000 +0000
@@ -100,18 +100,18 @@ _sparsem(A::AbstractSparseVector) = A
 function _sparsem(A::Union{Transpose{<:Any,<:AbstractSparseVector},Adjoint{<:Any,<:AbstractSparseVector}})
     B = parent(A)
     n = length(B)
-    Ti = eltype(B.nzind)
+    Ti = eltype(nonzeroinds(B))
     fadj = A isa Transpose ? transpose : adjoint
     colptr = fill!(Vector{Ti}(undef, n + 1), 0)
     colptr[1] = 1
-    colptr[B.nzind .+ 1] .= 1
+    colptr[nonzeroinds(B) .+ 1] .= 1
     cumsum!(colptr, colptr)
-    rowval = fill!(similar(B.nzind), 1)
+    rowval = fill!(similar(nonzeroinds(B)), 1)
     nzval = fadj.(nonzeros(B))
     SparseMatrixCSC(1, n, colptr, rowval, nzval)
 end
 
-function _sparsem(A::Union{Transpose{<:Any,<:SparseMatrixCSC},Adjoint{<:Any,<:SparseMatrixCSC}})
+function _sparsem(A::Union{Transpose{<:Any,<:AbstractSparseMatrixCSC},Adjoint{<:Any,<:AbstractSparseMatrixCSC}})
     ftranspose(parent(A), A isa Transpose ? transpose : adjoint)
 end
 
@@ -121,7 +121,7 @@ _sparsem(A::SparseMatrixCSCSymmHerm) = _
 _sparsem(A::UpperTriangular{T,<:AbstractSparseMatrix}) where T = triu(A.data)
 _sparsem(A::LowerTriangular{T,<:AbstractSparseMatrix}) where T = tril(A.data)
 # view of sparse matrix
-_sparsem(S::SubArray{<:Any,2,<:SparseMatrixCSC}) = getindex(S.parent,S.indices...)
+_sparsem(S::SubArray{<:Any,2,<:AbstractSparseMatrixCSC}) = getindex(S.parent,S.indices...)
 
 # 4 cases: (Symmetric|Hermitian) variants (:U|:L)
 function _sparsem(fnzrange::Function, sA::SparseMatrixCSCSymmHerm{Tv}) where {Tv}
@@ -174,7 +174,7 @@ function _sparsem(fnzrange::Function, sA
     _sparse_gen(m, n, newcolptr, newrowval, newnzval)
 end
 
-# 2 cases: Unit(Upper|Lower)Triangular{Tv,SparseMatrixCSC}
+# 2 cases: Unit(Upper|Lower)Triangular{Tv,AbstractSparseMatrixCSC}
 function _sparsem(A::AbstractTriangularSparse{Tv}) where Tv
     S = A.data
     rowval = rowvals(S)
diff -pruN 1.3.1+dfsg-1/stdlib/SparseArrays/src/sparsematrix.jl 1.4.0+dfsg-1/stdlib/SparseArrays/src/sparsematrix.jl
--- 1.3.1+dfsg-1/stdlib/SparseArrays/src/sparsematrix.jl	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/stdlib/SparseArrays/src/sparsematrix.jl	2020-03-21 16:36:32.000000000 +0000
@@ -9,14 +9,14 @@
 # Assumes that 0   <= length(nzval) < typemax(Ti)
 
 """
-    SparseMatrixCSC{Tv,Ti<:Integer} <: AbstractSparseMatrix{Tv,Ti}
+    SparseMatrixCSC{Tv,Ti<:Integer} <: AbstractSparseMatrixCSC{Tv,Ti}
 
 Matrix type for storing sparse matrices in the
 [Compressed Sparse Column](@ref man-csc) format. The standard way
 of constructing SparseMatrixCSC is through the [`sparse`](@ref) function.
 See also [`spzeros`](@ref), [`spdiagm`](@ref) and [`sprand`](@ref).
 """
-struct SparseMatrixCSC{Tv,Ti<:Integer} <: AbstractSparseMatrix{Tv,Ti}
+struct SparseMatrixCSC{Tv,Ti<:Integer} <: AbstractSparseMatrixCSC{Tv,Ti}
     m::Int                  # Number of rows
     n::Int                  # Number of columns
     colptr::Vector{Ti}      # Column i is in colptr[i]:(colptr[i+1]-1)
@@ -71,7 +71,7 @@ function sparse_check_length(rowstr, row
         throw(ArgumentError("$len == length($rowstr) >= $(typemax(Ti))"))
 end
 
-size(S::SparseMatrixCSC) = (S.m, S.n)
+size(S::SparseMatrixCSC) = (getfield(S, :m), getfield(S, :n))
 
 # Define an alias for views of a SparseMatrixCSC which include all rows and a unit range of the columns.
 # Also define a union of SparseMatrixCSC and this view since many methods can be defined efficiently for
@@ -79,17 +79,17 @@ size(S::SparseMatrixCSC) = (S.m, S.n)
 # insight is that getcolptr on a SparseMatrixCSCView returns an offset view of the colptr of the
 # underlying SparseMatrixCSC
 const SparseMatrixCSCView{Tv,Ti} =
-    SubArray{Tv,2,SparseMatrixCSC{Tv,Ti},
+    SubArray{Tv,2,<:AbstractSparseMatrixCSC{Tv,Ti},
         Tuple{Base.Slice{Base.OneTo{Int}},I}} where {I<:AbstractUnitRange}
-const SparseMatrixCSCUnion{Tv,Ti} = Union{SparseMatrixCSC{Tv,Ti}, SparseMatrixCSCView{Tv,Ti}}
+const SparseMatrixCSCUnion{Tv,Ti} = Union{AbstractSparseMatrixCSC{Tv,Ti}, SparseMatrixCSCView{Tv,Ti}}
 
-getcolptr(S::SparseMatrixCSC)     = S.colptr
-getcolptr(S::SparseMatrixCSCView) = view(S.parent.colptr, first(axes(S, 2)):(last(axes(S, 2)) + 1))
-getrowval(S::SparseMatrixCSC)     = S.rowval
-getrowval(S::SparseMatrixCSCView) = S.parent.rowval
-getnzval( S::SparseMatrixCSC)     = S.nzval
-getnzval( S::SparseMatrixCSCView) = S.parent.nzval
-nzvalview(S::SparseMatrixCSC)     = view(S.nzval, 1:nnz(S))
+getcolptr(S::SparseMatrixCSC)     = getfield(S, :colptr)
+getcolptr(S::SparseMatrixCSCView) = view(getcolptr(parent(S)), first(axes(S, 2)):(last(axes(S, 2)) + 1))
+getrowval(S::AbstractSparseMatrixCSC) = rowvals(S)
+getrowval(S::SparseMatrixCSCView) = rowvals(parent(S))
+getnzval( S::AbstractSparseMatrixCSC) = nonzeros(S)
+getnzval( S::SparseMatrixCSCView) = nonzeros(parent(S))
+nzvalview(S::AbstractSparseMatrixCSC) = view(nonzeros(S), 1:nnz(S))
 
 """
     nnz(A)
@@ -108,9 +108,9 @@ julia> nnz(A)
 3
 ```
 """
-nnz(S::SparseMatrixCSC)         = Int(S.colptr[S.n + 1] - 1)
-nnz(S::ReshapedArray{T,1,<:SparseMatrixCSC}) where T = nnz(parent(S))
-count(pred, S::SparseMatrixCSC) = count(pred, nzvalview(S)) + pred(zero(eltype(S)))*(prod(size(S)) - nnz(S))
+nnz(S::AbstractSparseMatrixCSC) = Int(getcolptr(S)[size(S, 2) + 1] - 1)
+nnz(S::ReshapedArray{T,1,<:AbstractSparseMatrixCSC}) where T = nnz(parent(S))
+count(pred, S::AbstractSparseMatrixCSC) = count(pred, nzvalview(S)) + pred(zero(eltype(S)))*(prod(size(S)) - nnz(S))
 
 """
     nonzeros(A)
@@ -136,11 +136,11 @@ julia> nonzeros(A)
  2
 ```
 """
-nonzeros(S::SparseMatrixCSC) = S.nzval
+nonzeros(S::SparseMatrixCSC) = getfield(S, :nzval)
 nonzeros(S::SparseMatrixCSCView)  = nonzeros(S.parent)
 
 """
-    rowvals(A::SparseMatrixCSC)
+    rowvals(A::AbstractSparseMatrixCSC)
 
 Return a vector of the row indices of `A`. Any modifications to the returned
 vector will mutate `A` as well. Providing access to how the row indices are
@@ -162,11 +162,11 @@ julia> rowvals(A)
  3
 ```
 """
-rowvals(S::SparseMatrixCSC) = S.rowval
+rowvals(S::SparseMatrixCSC) = getfield(S, :rowval)
 rowvals(S::SparseMatrixCSCView) = rowvals(S.parent)
 
 """
-    nzrange(A::SparseMatrixCSC, col::Integer)
+    nzrange(A::AbstractSparseMatrixCSC, col::Integer)
 
 Return the range of indices to the structural nonzero values of a sparse matrix
 column. In conjunction with [`nonzeros`](@ref) and
@@ -184,12 +184,13 @@ column. In conjunction with [`nonzeros`]
        end
     end
 """
-nzrange(S::SparseMatrixCSC, col::Integer) = S.colptr[col]:(S.colptr[col+1]-1)
+nzrange(S::AbstractSparseMatrixCSC, col::Integer) = getcolptr(S)[col]:(getcolptr(S)[col+1]-1)
 nzrange(S::SparseMatrixCSCView, col::Integer) = nzrange(S.parent, S.indices[2][col])
 
-function Base.show(io::IO, ::MIME"text/plain", S::SparseMatrixCSC)
+function Base.show(io::IO, ::MIME"text/plain", S::AbstractSparseMatrixCSC)
     xnnz = nnz(S)
-    print(io, S.m, "×", S.n, " ", typeof(S), " with ", xnnz, " stored ",
+    m, n = size(S)
+    print(io, m, "×", n, " ", typeof(S), " with ", xnnz, " stored ",
               xnnz == 1 ? "entry" : "entries")
     if xnnz != 0
         print(io, ":")
@@ -197,25 +198,25 @@ function Base.show(io::IO, ::MIME"text/p
     end
 end
 
-Base.show(io::IO, S::SparseMatrixCSC) = Base.show(convert(IOContext, io), S::SparseMatrixCSC)
-function Base.show(io::IOContext, S::SparseMatrixCSC)
+Base.show(io::IO, S::AbstractSparseMatrixCSC) = Base.show(convert(IOContext, io), S::AbstractSparseMatrixCSC)
+function Base.show(io::IOContext, S::AbstractSparseMatrixCSC)
     nnz(S) == 0 && return show(io, MIME("text/plain"), S)
 
     ioc = IOContext(io, :compact => true)
     function _format_line(r, col, padr, padc)
-        print(ioc, "\n  [", rpad(S.rowval[r], padr), ", ", lpad(col, padc), "]  =  ")
-        if isassigned(S.nzval, Int(r))
-            show(ioc, S.nzval[r])
+        print(ioc, "\n  [", rpad(rowvals(S)[r], padr), ", ", lpad(col, padc), "]  =  ")
+        if isassigned(nonzeros(S), Int(r))
+            show(ioc, nonzeros(S)[r])
         else
             print(ioc, Base.undef_ref_str)
         end
     end
 
     function _get_cols(from, to)
-        idx = eltype(S.colptr)[]
-        c = searchsortedlast(S.colptr, from)
+        idx = eltype(getcolptr(S))[]
+        c = searchsortedlast(getcolptr(S), from)
         for i = from:to
-            while i == S.colptr[c+1]
+            while i == getcolptr(S)[c+1]
                 c +=1
             end
             push!(idx, c)
@@ -226,7 +227,7 @@ function Base.show(io::IOContext, S::Spa
     rows = displaysize(io)[1] - 4 # -4 from [Prompt, header, newline after elements, new prompt]
     if !get(io, :limit, false) || rows >= nnz(S) # Will the whole matrix fit when printed?
         cols = _get_cols(1, nnz(S))
-        padr, padc = ndigits.((maximum(S.rowval[1:nnz(S)]), cols[end]))
+        padr, padc = ndigits.((maximum(rowvals(S)[1:nnz(S)]), cols[end]))
         _format_line.(1:nnz(S), cols, padr, padc)
     else
         if rows <= 2
@@ -236,7 +237,7 @@ function Base.show(io::IOContext, S::Spa
         s1, e1 = 1, div(rows - 1, 2) # -1 accounts for \vdots
         s2, e2 = nnz(S) - (rows - 1 - e1) + 1, nnz(S)
         cols1, cols2 = _get_cols(s1, e1), _get_cols(s2, e2)
-        padr = ndigits(max(maximum(S.rowval[s1:e1]), maximum(S.rowval[s2:e2])))
+        padr = ndigits(max(maximum(rowvals(S)[s1:e1]), maximum(rowvals(S)[s2:e2])))
         padc = ndigits(cols2[end])
         _format_line.(s1:e1, cols1, padr, padc)
         print(io, "\n  \u22ee")
@@ -281,43 +282,43 @@ function sparse_compute_reshaped_colptr_
     end
 end
 
-function copy(ra::ReshapedArray{<:Any,2,<:SparseMatrixCSC})
+function copy(ra::ReshapedArray{<:Any,2,<:AbstractSparseMatrixCSC})
     mS,nS = size(ra)
     a = parent(ra)
     mA,nA = size(a)
     numnz = nnz(a)
-    colptr = similar(a.colptr, nS+1)
-    rowval = similar(a.rowval)
-    nzval = copy(a.nzval)
+    colptr = similar(getcolptr(a), nS+1)
+    rowval = similar(rowvals(a))
+    nzval = copy(nonzeros(a))
 
-    sparse_compute_reshaped_colptr_and_rowval(colptr, rowval, mS, nS, a.colptr, a.rowval, mA, nA)
+    sparse_compute_reshaped_colptr_and_rowval(colptr, rowval, mS, nS, getcolptr(a), rowvals(a), mA, nA)
 
     return SparseMatrixCSC(mS, nS, colptr, rowval, nzval)
 end
 
 ## Alias detection and prevention
 using Base: dataids, unaliascopy
-Base.dataids(S::SparseMatrixCSC) = (dataids(S.colptr)..., dataids(S.rowval)..., dataids(S.nzval)...)
-Base.unaliascopy(S::SparseMatrixCSC) = typeof(S)(S.m, S.n, unaliascopy(S.colptr), unaliascopy(S.rowval), unaliascopy(S.nzval))
+Base.dataids(S::AbstractSparseMatrixCSC) = (dataids(getcolptr(S))..., dataids(rowvals(S))..., dataids(nonzeros(S))...)
+Base.unaliascopy(S::AbstractSparseMatrixCSC) = typeof(S)(size(S, 1), size(S, 2), unaliascopy(getcolptr(S)), unaliascopy(rowvals(S)), unaliascopy(nonzeros(S)))
 
 ## Constructors
 
-copy(S::SparseMatrixCSC) =
-    SparseMatrixCSC(S.m, S.n, copy(S.colptr), copy(S.rowval), copy(S.nzval))
+copy(S::AbstractSparseMatrixCSC) =
+    SparseMatrixCSC(size(S, 1), size(S, 2), copy(getcolptr(S)), copy(rowvals(S)), copy(nonzeros(S)))
 
-function copyto!(A::SparseMatrixCSC, B::SparseMatrixCSC)
+function copyto!(A::AbstractSparseMatrixCSC, B::AbstractSparseMatrixCSC)
     # If the two matrices have the same length then all the
     # elements in A will be overwritten.
     if length(A) == length(B)
-        resize!(A.nzval, length(B.nzval))
-        resize!(A.rowval, length(B.rowval))
+        resize!(nonzeros(A), length(nonzeros(B)))
+        resize!(rowvals(A), length(rowvals(B)))
         if size(A) == size(B)
             # Simple case: we can simply copy the internal fields of B to A.
-            copyto!(A.colptr, B.colptr)
-            copyto!(A.rowval, B.rowval)
+            copyto!(getcolptr(A), getcolptr(B))
+            copyto!(rowvals(A), rowvals(B))
         else
             # This is like a "reshape B into A".
-            sparse_compute_reshaped_colptr_and_rowval(A.colptr, A.rowval, A.m, A.n, B.colptr, B.rowval, B.m, B.n)
+            sparse_compute_reshaped_colptr_and_rowval(getcolptr(A), rowvals(A), size(A, 1), size(A, 2), getcolptr(B), rowvals(B), size(B, 1), size(B, 2))
         end
     else
         length(A) >= length(B) || throw(BoundsError())
@@ -325,81 +326,81 @@ function copyto!(A::SparseMatrixCSC, B::
         nnzA = nnz(A)
         nnzB = nnz(B)
         # Up to which col, row, and ptr in rowval/nzval will A be overwritten?
-        lastmodcolA = div(lB - 1, A.m) + 1
-        lastmodrowA = mod(lB - 1, A.m) + 1
-        lastmodptrA = A.colptr[lastmodcolA]
-        while lastmodptrA < A.colptr[lastmodcolA+1] && A.rowval[lastmodptrA] <= lastmodrowA
+        lastmodcolA = div(lB - 1, size(A, 1)) + 1
+        lastmodrowA = mod(lB - 1, size(A, 1)) + 1
+        lastmodptrA = getcolptr(A)[lastmodcolA]
+        while lastmodptrA < getcolptr(A)[lastmodcolA+1] && rowvals(A)[lastmodptrA] <= lastmodrowA
             lastmodptrA += 1
         end
         lastmodptrA -= 1
         if lastmodptrA >= nnzB
             # A will have fewer non-zero elements; unmodified elements are kept at the end.
-            deleteat!(A.rowval, nnzB+1:lastmodptrA)
-            deleteat!(A.nzval, nnzB+1:lastmodptrA)
+            deleteat!(rowvals(A), nnzB+1:lastmodptrA)
+            deleteat!(nonzeros(A), nnzB+1:lastmodptrA)
         else
             # A will have more non-zero elements; unmodified elements are kept at the end.
-            resize!(A.rowval, nnzB + nnzA - lastmodptrA)
-            resize!(A.nzval, nnzB + nnzA - lastmodptrA)
-            copyto!(A.rowval, nnzB+1, A.rowval, lastmodptrA+1, nnzA-lastmodptrA)
-            copyto!(A.nzval, nnzB+1, A.nzval, lastmodptrA+1, nnzA-lastmodptrA)
+            resize!(rowvals(A), nnzB + nnzA - lastmodptrA)
+            resize!(nonzeros(A), nnzB + nnzA - lastmodptrA)
+            copyto!(rowvals(A), nnzB+1, rowvals(A), lastmodptrA+1, nnzA-lastmodptrA)
+            copyto!(nonzeros(A), nnzB+1, nonzeros(A), lastmodptrA+1, nnzA-lastmodptrA)
         end
         # Adjust colptr accordingly.
-        @inbounds for i in 2:length(A.colptr)
-            A.colptr[i] += nnzB - lastmodptrA
+        @inbounds for i in 2:length(getcolptr(A))
+            getcolptr(A)[i] += nnzB - lastmodptrA
         end
-        sparse_compute_reshaped_colptr_and_rowval(A.colptr, A.rowval, A.m, lastmodcolA-1, B.colptr, B.rowval, B.m, B.n)
+        sparse_compute_reshaped_colptr_and_rowval(getcolptr(A), rowvals(A), size(A, 1), lastmodcolA-1, getcolptr(B), rowvals(B), size(B, 1), size(B, 2))
     end
-    copyto!(A.nzval, B.nzval)
+    copyto!(nonzeros(A), nonzeros(B))
     return A
 end
 
 ## similar
 #
 # parent method for similar that preserves stored-entry structure (for when new and old dims match)
-function _sparsesimilar(S::SparseMatrixCSC, ::Type{TvNew}, ::Type{TiNew}) where {TvNew,TiNew}
-    newcolptr = copyto!(similar(S.colptr, TiNew), S.colptr)
-    newrowval = copyto!(similar(S.rowval, TiNew), S.rowval)
-    return SparseMatrixCSC(S.m, S.n, newcolptr, newrowval, similar(S.nzval, TvNew))
+function _sparsesimilar(S::AbstractSparseMatrixCSC, ::Type{TvNew}, ::Type{TiNew}) where {TvNew,TiNew}
+    newcolptr = copyto!(similar(getcolptr(S), TiNew), getcolptr(S))
+    newrowval = copyto!(similar(rowvals(S), TiNew), rowvals(S))
+    return SparseMatrixCSC(size(S, 1), size(S, 2), newcolptr, newrowval, similar(nonzeros(S), TvNew))
 end
 # parent methods for similar that preserves only storage space (for when new and old dims differ)
-_sparsesimilar(S::SparseMatrixCSC, ::Type{TvNew}, ::Type{TiNew}, dims::Dims{2}) where {TvNew,TiNew} =
-    SparseMatrixCSC(dims..., fill(one(TiNew), last(dims)+1), similar(S.rowval, TiNew), similar(S.nzval, TvNew))
+_sparsesimilar(S::AbstractSparseMatrixCSC, ::Type{TvNew}, ::Type{TiNew}, dims::Dims{2}) where {TvNew,TiNew} =
+    SparseMatrixCSC(dims..., fill(one(TiNew), last(dims)+1), similar(rowvals(S), TiNew), similar(nonzeros(S), TvNew))
 # parent method for similar that allocates an empty sparse vector (when new dims are single)
-_sparsesimilar(S::SparseMatrixCSC, ::Type{TvNew}, ::Type{TiNew}, dims::Dims{1}) where {TvNew,TiNew} =
-    SparseVector(dims..., similar(S.rowval, TiNew, 0), similar(S.nzval, TvNew, 0))
+_sparsesimilar(S::AbstractSparseMatrixCSC, ::Type{TvNew}, ::Type{TiNew}, dims::Dims{1}) where {TvNew,TiNew} =
+    SparseVector(dims..., similar(rowvals(S), TiNew, 0), similar(nonzeros(S), TvNew, 0))
 #
 # The following methods hook into the AbstractArray similar hierarchy. The first method
 # covers similar(A[, Tv]) calls, which preserve stored-entry structure, and the latter
 # methods cover similar(A[, Tv], shape...) calls, which preserve storage space when the shape
 # calls for a two-dimensional result.
-similar(S::SparseMatrixCSC{<:Any,Ti}, ::Type{TvNew}) where {Ti,TvNew} = _sparsesimilar(S, TvNew, Ti)
-similar(S::SparseMatrixCSC{<:Any,Ti}, ::Type{TvNew}, dims::Union{Dims{1},Dims{2}}) where {Ti,TvNew} =
+similar(S::AbstractSparseMatrixCSC{<:Any,Ti}, ::Type{TvNew}) where {Ti,TvNew} = _sparsesimilar(S, TvNew, Ti)
+similar(S::AbstractSparseMatrixCSC{<:Any,Ti}, ::Type{TvNew}, dims::Union{Dims{1},Dims{2}}) where {Ti,TvNew} =
     _sparsesimilar(S, TvNew, Ti, dims)
 # The following methods cover similar(A, Tv, Ti[, shape...]) calls, which specify the
 # result's index type in addition to its entry type, and aren't covered by the hooks above.
 # The calls without shape again preserve stored-entry structure, whereas those with shape
 # preserve storage space when the shape calls for a two-dimensional result.
-similar(S::SparseMatrixCSC, ::Type{TvNew}, ::Type{TiNew}) where{TvNew,TiNew} =
+similar(S::AbstractSparseMatrixCSC, ::Type{TvNew}, ::Type{TiNew}) where{TvNew,TiNew} =
     _sparsesimilar(S, TvNew, TiNew)
-similar(S::SparseMatrixCSC, ::Type{TvNew}, ::Type{TiNew}, dims::Union{Dims{1},Dims{2}}) where {TvNew,TiNew} =
+similar(S::AbstractSparseMatrixCSC, ::Type{TvNew}, ::Type{TiNew}, dims::Union{Dims{1},Dims{2}}) where {TvNew,TiNew} =
     _sparsesimilar(S, TvNew, TiNew, dims)
-similar(S::SparseMatrixCSC, ::Type{TvNew}, ::Type{TiNew}, m::Integer) where {TvNew,TiNew} =
+similar(S::AbstractSparseMatrixCSC, ::Type{TvNew}, ::Type{TiNew}, m::Integer) where {TvNew,TiNew} =
     _sparsesimilar(S, TvNew, TiNew, (m,))
-similar(S::SparseMatrixCSC, ::Type{TvNew}, ::Type{TiNew}, m::Integer, n::Integer) where {TvNew,TiNew} =
+similar(S::AbstractSparseMatrixCSC, ::Type{TvNew}, ::Type{TiNew}, m::Integer, n::Integer) where {TvNew,TiNew} =
     _sparsesimilar(S, TvNew, TiNew, (m, n))
 
 
 # converting between SparseMatrixCSC types
-SparseMatrixCSC(S::SparseMatrixCSC) = copy(S)
-AbstractMatrix{Tv}(A::SparseMatrixCSC) where {Tv} = SparseMatrixCSC{Tv}(A)
-SparseMatrixCSC{Tv}(S::SparseMatrixCSC{Tv}) where {Tv} = copy(S)
-SparseMatrixCSC{Tv}(S::SparseMatrixCSC) where {Tv} = SparseMatrixCSC{Tv,eltype(S.colptr)}(S)
-SparseMatrixCSC{Tv,Ti}(S::SparseMatrixCSC{Tv,Ti}) where {Tv,Ti} = copy(S)
-function SparseMatrixCSC{Tv,Ti}(S::SparseMatrixCSC) where {Tv,Ti}
-    eltypeTicolptr = convert(Vector{Ti}, S.colptr)
-    eltypeTirowval = convert(Vector{Ti}, S.rowval)
-    eltypeTvnzval = convert(Vector{Tv}, S.nzval)
-    return SparseMatrixCSC(S.m, S.n, eltypeTicolptr, eltypeTirowval, eltypeTvnzval)
+SparseMatrixCSC(S::AbstractSparseMatrixCSC) = copy(S)
+AbstractMatrix{Tv}(A::AbstractSparseMatrixCSC) where {Tv} = SparseMatrixCSC{Tv}(A)
+SparseMatrixCSC{Tv}(S::AbstractSparseMatrixCSC{Tv}) where {Tv} = copy(S)
+SparseMatrixCSC{Tv}(S::AbstractSparseMatrixCSC) where {Tv} = SparseMatrixCSC{Tv,eltype(getcolptr(S))}(S)
+SparseMatrixCSC{Tv,Ti}(S::AbstractSparseMatrixCSC{Tv,Ti}) where {Tv,Ti} = copy(S)
+function SparseMatrixCSC{Tv,Ti}(S::AbstractSparseMatrixCSC) where {Tv,Ti}
+    eltypeTicolptr = convert(Vector{Ti}, getcolptr(S))
+    eltypeTirowval = convert(Vector{Ti}, rowvals(S))
+    eltypeTvnzval = convert(Vector{Tv}, nonzeros(S))
+    return SparseMatrixCSC(size(S, 1), size(S, 2), eltypeTicolptr, eltypeTirowval, eltypeTvnzval)
 end
 # converting from other matrix types to SparseMatrixCSC (also see sparse())
 SparseMatrixCSC(M::Matrix) = sparse(M)
@@ -529,38 +530,38 @@ function SparseMatrixCSC{Tv,Ti}(M::Strid
     end
     return SparseMatrixCSC(size(M, 1), size(M, 2), colptr, rowval, nzval)
 end
-SparseMatrixCSC(M::Adjoint{<:Any,<:SparseMatrixCSC}) = copy(M)
-SparseMatrixCSC(M::Transpose{<:Any,<:SparseMatrixCSC}) = copy(M)
-SparseMatrixCSC{Tv}(M::Adjoint{Tv,SparseMatrixCSC{Tv}}) where {Tv} = copy(M)
-SparseMatrixCSC{Tv}(M::Transpose{Tv,SparseMatrixCSC{Tv}}) where {Tv} = copy(M)
-SparseMatrixCSC{Tv,Ti}(M::Adjoint{Tv,SparseMatrixCSC{Tv,Ti}}) where {Tv,Ti} = copy(M)
-SparseMatrixCSC{Tv,Ti}(M::Transpose{Tv,SparseMatrixCSC{Tv,Ti}}) where {Tv,Ti} = copy(M)
+SparseMatrixCSC(M::Adjoint{<:Any,<:AbstractSparseMatrixCSC}) = copy(M)
+SparseMatrixCSC(M::Transpose{<:Any,<:AbstractSparseMatrixCSC}) = copy(M)
+SparseMatrixCSC{Tv}(M::Adjoint{Tv,<:AbstractSparseMatrixCSC{Tv}}) where {Tv} = copy(M)
+SparseMatrixCSC{Tv}(M::Transpose{Tv,<:AbstractSparseMatrixCSC{Tv}}) where {Tv} = copy(M)
+SparseMatrixCSC{Tv,Ti}(M::Adjoint{Tv,<:AbstractSparseMatrixCSC{Tv,Ti}}) where {Tv,Ti} = copy(M)
+SparseMatrixCSC{Tv,Ti}(M::Transpose{Tv,<:AbstractSparseMatrixCSC{Tv,Ti}}) where {Tv,Ti} = copy(M)
 
 # converting from adjoint or transpose sparse matrices to sparse matrices with different eltype
-SparseMatrixCSC{Tv}(M::Adjoint{<:Any,SparseMatrixCSC}) where {Tv} = SparseMatrixCSC{Tv}(copy(M))
-SparseMatrixCSC{Tv}(M::Transpose{<:Any,SparseMatrixCSC}) where {Tv} = SparseMatrixCSC{Tv}(copy(M))
-SparseMatrixCSC{Tv,Ti}(M::Adjoint{<:Any,SparseMatrixCSC}) where {Tv,Ti} = SparseMatrixCSC{Tv,Ti}(copy(M))
-SparseMatrixCSC{Tv,Ti}(M::Transpose{<:Any,SparseMatrixCSC}) where {Tv,Ti} = SparseMatrixCSC{Tv,Ti}(copy(M))
+SparseMatrixCSC{Tv}(M::Adjoint{<:Any,<:AbstractSparseMatrixCSC}) where {Tv} = SparseMatrixCSC{Tv}(copy(M))
+SparseMatrixCSC{Tv}(M::Transpose{<:Any,<:AbstractSparseMatrixCSC}) where {Tv} = SparseMatrixCSC{Tv}(copy(M))
+SparseMatrixCSC{Tv,Ti}(M::Adjoint{<:Any,<:AbstractSparseMatrixCSC}) where {Tv,Ti} = SparseMatrixCSC{Tv,Ti}(copy(M))
+SparseMatrixCSC{Tv,Ti}(M::Transpose{<:Any,<:AbstractSparseMatrixCSC}) where {Tv,Ti} = SparseMatrixCSC{Tv,Ti}(copy(M))
 
 # converting from SparseMatrixCSC to other matrix types
-function Matrix(S::SparseMatrixCSC{Tv}) where Tv
+function Matrix(S::AbstractSparseMatrixCSC{Tv}) where Tv
     # Handle cases where zero(Tv) is not defined but the array is dense.
-    A = length(S) == nnz(S) ? Matrix{Tv}(undef, S.m, S.n) : zeros(Tv, S.m, S.n)
-    for Sj in 1:S.n
+    A = length(S) == nnz(S) ? Matrix{Tv}(undef, size(S, 1), size(S, 2)) : zeros(Tv, size(S, 1), size(S, 2))
+    for Sj in 1:size(S, 2)
         for Sk in nzrange(S, Sj)
-            Si = S.rowval[Sk]
-            Sv = S.nzval[Sk]
+            Si = rowvals(S)[Sk]
+            Sv = nonzeros(S)[Sk]
             A[Si, Sj] = Sv
         end
     end
     return A
 end
-Array(S::SparseMatrixCSC) = Matrix(S)
+Array(S::AbstractSparseMatrixCSC) = Matrix(S)
 
-convert(T::Type{<:SparseMatrixCSC}, m::AbstractMatrix) = m isa T ? m : T(m)
+convert(T::Type{<:AbstractSparseMatrixCSC}, m::AbstractMatrix) = m isa T ? m : T(m)
 
-float(S::SparseMatrixCSC) = SparseMatrixCSC(S.m, S.n, copy(S.colptr), copy(S.rowval), float.(S.nzval))
-complex(S::SparseMatrixCSC) = SparseMatrixCSC(S.m, S.n, copy(S.colptr), copy(S.rowval), complex(copy(S.nzval)))
+float(S::SparseMatrixCSC) = SparseMatrixCSC(size(S, 1), size(S, 2), copy(getcolptr(S)), copy(rowvals(S)), float.(nonzeros(S)))
+complex(S::SparseMatrixCSC) = SparseMatrixCSC(size(S, 1), size(S, 2), copy(getcolptr(S)), copy(rowvals(S)), complex(copy(nonzeros(S))))
 
 """
     sparse(A)
@@ -584,7 +585,7 @@ julia> sparse(A)
 """
 sparse(A::AbstractMatrix{Tv}) where {Tv} = convert(SparseMatrixCSC{Tv,Int}, A)
 
-sparse(S::SparseMatrixCSC) = copy(S)
+sparse(S::AbstractSparseMatrixCSC) = copy(S)
 
 sparse(T::SymTridiagonal) = SparseMatrixCSC(T)
 
@@ -855,16 +856,17 @@ sparse(I,J,v::Number,m,n,combine::Functi
 ## Transposition and permutation methods
 
 """
-    halfperm!(X::SparseMatrixCSC{Tv,Ti}, A::SparseMatrixCSC{Tv,Ti},
-              q::AbstractVector{<:Integer}, f::Function = identity) where {Tv,Ti}
+    halfperm!(X::AbstractSparseMatrixCSC{Tv,Ti}, A::AbstractSparseMatrixCSC{TvA,Ti},
+              q::AbstractVector{<:Integer}, f::Function = identity) where {Tv,TvA,Ti}
 
 Column-permute and transpose `A`, simultaneously applying `f` to each entry of `A`, storing
 the result `(f(A)Q)^T` (`map(f, transpose(A[:,q]))`) in `X`.
 
-`X`'s dimensions must match those of `transpose(A)` (`X.m == A.n` and `X.n == A.m`), and `X`
-must have enough storage to accommodate all allocated entries in `A` (`length(X.rowval) >= nnz(A)`
-and  `length(X.nzval) >= nnz(A)`). Column-permutation `q`'s length must match `A`'s column
-count (`length(q) == A.n`).
+Element type `Tv` of `X` must match `f(::TvA)`, where `TvA` is the element type of `A`.
+`X`'s dimensions must match those of `transpose(A)` (`size(X, 1) == size(A, 2)` and
+`size(X, 2) == size(A, 1)`), and `X` must have enough storage to accommodate all allocated
+entries in `A` (`length(rowvals(X)) >= nnz(A)` and `length(nonzeros(X)) >= nnz(A)`).
+Column-permutation `q`'s length must match `A`'s column count (`length(q) == size(A, 2)`).
 
 This method is the parent of several methods performing transposition and permutation
 operations on [`SparseMatrixCSC`](@ref)s. As this method performs no argument checking,
@@ -872,98 +874,101 @@ prefer the safer child methods (`[c]tran
 
 This method implements the `HALFPERM` algorithm described in F. Gustavson, "Two fast
 algorithms for sparse matrices: multiplication and permuted transposition," ACM TOMS 4(3),
-250-269 (1978). The algorithm runs in `O(A.m, A.n, nnz(A))` time and requires no space
+250-269 (1978). The algorithm runs in `O(size(A, 1), size(A, 2), nnz(A))` time and requires no space
 beyond that passed in.
 """
-function halfperm!(X::SparseMatrixCSC{Tv,Ti}, A::SparseMatrixCSC{Tv,Ti},
-        q::AbstractVector{<:Integer}, f::Function = identity) where {Tv,Ti}
+function halfperm!(X::AbstractSparseMatrixCSC{Tv,Ti}, A::AbstractSparseMatrixCSC{TvA,Ti},
+        q::AbstractVector{<:Integer}, f::Function = identity) where {Tv,TvA,Ti}
     _computecolptrs_halfperm!(X, A)
     _distributevals_halfperm!(X, A, q, f)
     return X
 end
 """
 Helper method for `halfperm!`. Computes `transpose(A[:,q])`'s column pointers, storing them
-shifted one position forward in `X.colptr`; `_distributevals_halfperm!` fixes this shift.
+shifted one position forward in `getcolptr(X)`; `_distributevals_halfperm!` fixes this shift.
 """
-function _computecolptrs_halfperm!(X::SparseMatrixCSC{Tv,Ti}, A::SparseMatrixCSC{Tv,Ti}) where {Tv,Ti}
-    # Compute `transpose(A[:,q])`'s column counts. Store shifted forward one position in X.colptr.
-    fill!(X.colptr, 0)
+function _computecolptrs_halfperm!(X::AbstractSparseMatrixCSC{Tv,Ti}, A::AbstractSparseMatrixCSC{TvA,Ti}) where {Tv,TvA,Ti}
+    # Compute `transpose(A[:,q])`'s column counts. Store shifted forward one position in getcolptr(X).
+    fill!(getcolptr(X), 0)
     @inbounds for k in 1:nnz(A)
-        X.colptr[A.rowval[k] + 1] += 1
+        getcolptr(X)[rowvals(A)[k] + 1] += 1
     end
-    # Compute `transpose(A[:,q])`'s column pointers. Store shifted forward one position in X.colptr.
-    X.colptr[1] = 1
+    # Compute `transpose(A[:,q])`'s column pointers. Store shifted forward one position in getcolptr(X).
+    getcolptr(X)[1] = 1
     countsum = 1
-    @inbounds for k in 2:(A.m + 1)
-        overwritten = X.colptr[k]
-        X.colptr[k] = countsum
+    @inbounds for k in 2:(size(A, 1) + 1)
+        overwritten = getcolptr(X)[k]
+        getcolptr(X)[k] = countsum
         countsum += overwritten
     end
 end
 """
 Helper method for `halfperm!`. With `transpose(A[:,q])`'s column pointers shifted one
-position forward in `X.colptr`, computes `map(f, transpose(A[:,q]))` by appropriately
-distributing `A.rowval` and `f`-transformed `A.nzval` into `X.rowval` and `X.nzval`
-respectively. Simultaneously fixes the one-position-forward shift in `X.colptr`.
-"""
-@noinline function _distributevals_halfperm!(X::SparseMatrixCSC{Tv,Ti},
-        A::SparseMatrixCSC{Tv,Ti}, q::AbstractVector{<:Integer}, f::Function) where {Tv,Ti}
-    @inbounds for Xi in 1:A.n
+position forward in `getcolptr(X)`, computes `map(f, transpose(A[:,q]))` by appropriately
+distributing `rowvals(A)` and `f`-transformed `nonzeros(A)` into `rowvals(X)` and `nonzeros(X)`
+respectively. Simultaneously fixes the one-position-forward shift in `getcolptr(X)`.
+"""
+@noinline function _distributevals_halfperm!(X::AbstractSparseMatrixCSC{Tv,Ti},
+        A::AbstractSparseMatrixCSC{TvA,Ti}, q::AbstractVector{<:Integer}, f::Function) where {Tv,TvA,Ti}
+    @inbounds for Xi in 1:size(A, 2)
         Aj = q[Xi]
         for Ak in nzrange(A, Aj)
-            Ai = A.rowval[Ak]
-            Xk = X.colptr[Ai + 1]
-            X.rowval[Xk] = Xi
-            X.nzval[Xk] = f(A.nzval[Ak])
-            X.colptr[Ai + 1] += 1
+            Ai = rowvals(A)[Ak]
+            Xk = getcolptr(X)[Ai + 1]
+            rowvals(X)[Xk] = Xi
+            nonzeros(X)[Xk] = f(nonzeros(A)[Ak])
+            getcolptr(X)[Ai + 1] += 1
         end
     end
     return # kill potential type instability
 end
 
-function ftranspose!(X::SparseMatrixCSC{Tv,Ti}, A::SparseMatrixCSC{Tv,Ti}, f::Function) where {Tv,Ti}
+function ftranspose!(X::AbstractSparseMatrixCSC{Tv,Ti}, A::AbstractSparseMatrixCSC{Tv,Ti}, f::Function) where {Tv,Ti}
     # Check compatibility of source argument A and destination argument X
-    if X.n != A.m
+    if size(X, 2) != size(A, 1)
         throw(DimensionMismatch(string("destination argument `X`'s column count, ",
-            "`X.n (= $(X.n))`, must match source argument `A`'s row count, `A.m (= $(A.m))`")))
-    elseif X.m != A.n
+            "`size(X, 2) (= $(size(X, 2)))`, must match source argument `A`'s row count, `size(A, 1) (= $(size(A, 1)))`")))
+    elseif size(X, 1) != size(A, 2)
         throw(DimensionMismatch(string("destination argument `X`'s row count,
-            `X.m (= $(X.m))`, must match source argument `A`'s column count, `A.n (= $(A.n))`")))
-    elseif length(X.rowval) < nnz(A)
+            `size(X, 1) (= $(size(X, 1)))`, must match source argument `A`'s column count, `size(A, 2) (= $(size(A, 2)))`")))
+    elseif length(rowvals(X)) < nnz(A)
         throw(ArgumentError(string("the length of destination argument `X`'s `rowval` ",
-            "array, `length(X.rowval) (= $(length(X.rowval)))`, must be greater than or ",
+            "array, `length(rowvals(X)) (= $(length(rowvals(X))))`, must be greater than or ",
             "equal to source argument `A`'s allocated entry count, `nnz(A) (= $(nnz(A)))`")))
-    elseif length(X.nzval) < nnz(A)
+    elseif length(nonzeros(X)) < nnz(A)
         throw(ArgumentError(string("the length of destination argument `X`'s `nzval` ",
-            "array, `length(X.nzval) (= $(length(X.nzval)))`, must be greater than or ",
+            "array, `length(nonzeros(X)) (= $(length(nonzeros(X))))`, must be greater than or ",
             "equal to source argument `A`'s allocated entry count, `nnz(A) (= $(nnz(A)))`")))
     end
-    halfperm!(X, A, 1:A.n, f)
+    halfperm!(X, A, 1:size(A, 2), f)
 end
-transpose!(X::SparseMatrixCSC{Tv,Ti}, A::SparseMatrixCSC{Tv,Ti}) where {Tv,Ti} = ftranspose!(X, A, identity)
-adjoint!(X::SparseMatrixCSC{Tv,Ti}, A::SparseMatrixCSC{Tv,Ti}) where {Tv,Ti} = ftranspose!(X, A, conj)
+transpose!(X::AbstractSparseMatrixCSC{Tv,Ti}, A::AbstractSparseMatrixCSC{Tv,Ti}) where {Tv,Ti} = ftranspose!(X, A, identity)
+adjoint!(X::AbstractSparseMatrixCSC{Tv,Ti}, A::AbstractSparseMatrixCSC{Tv,Ti}) where {Tv,Ti} = ftranspose!(X, A, conj)
 
-function ftranspose(A::SparseMatrixCSC{Tv,Ti}, f::Function) where {Tv,Ti}
-    X = SparseMatrixCSC(A.n, A.m,
-                        ones(Ti, A.m+1),
+# manually specifying eltype allows to avoid calling return_type of f on TvA
+function ftranspose(A::AbstractSparseMatrixCSC{TvA,Ti}, f::Function, eltype::Type{Tv} = TvA) where {Tv,TvA,Ti}
+    X = SparseMatrixCSC(size(A, 2), size(A, 1),
+                        ones(Ti, size(A, 1)+1),
                         Vector{Ti}(undef, nnz(A)),
                         Vector{Tv}(undef, nnz(A)))
-    halfperm!(X, A, 1:A.n, f)
+    halfperm!(X, A, 1:size(A, 2), f)
 end
-adjoint(A::SparseMatrixCSC) = Adjoint(A)
-transpose(A::SparseMatrixCSC) = Transpose(A)
-Base.copy(A::Adjoint{<:Any,<:SparseMatrixCSC}) = ftranspose(A.parent, x -> copy(adjoint(x)))
-Base.copy(A::Transpose{<:Any,<:SparseMatrixCSC}) = ftranspose(A.parent, x -> copy(transpose(x)))
-function Base.permutedims(A::SparseMatrixCSC, (a,b))
+adjoint(A::AbstractSparseMatrixCSC) = Adjoint(A)
+transpose(A::AbstractSparseMatrixCSC) = Transpose(A)
+Base.copy(A::Adjoint{<:Any,<:AbstractSparseMatrixCSC}) =
+    ftranspose(A.parent, x -> adjoint(copy(x)), eltype(A))
+Base.copy(A::Transpose{<:Any,<:AbstractSparseMatrixCSC}) =
+    ftranspose(A.parent, x -> transpose(copy(x)), eltype(A))
+function Base.permutedims(A::AbstractSparseMatrixCSC, (a,b))
     (a, b) == (2, 1) && return ftranspose(A, identity)
     (a, b) == (1, 2) && return copy(A)
     throw(ArgumentError("no valid permutation of dimensions"))
 end
 
 """
-    unchecked_noalias_permute!(X::SparseMatrixCSC{Tv,Ti},
-        A::SparseMatrixCSC{Tv,Ti}, p::AbstractVector{<:Integer},
-        q::AbstractVector{<:Integer}, C::SparseMatrixCSC{Tv,Ti}) where {Tv,Ti}
+    unchecked_noalias_permute!(X::AbstractSparseMatrixCSC{Tv,Ti},
+        A::AbstractSparseMatrixCSC{Tv,Ti}, p::AbstractVector{<:Integer},
+        q::AbstractVector{<:Integer}, C::AbstractSparseMatrixCSC{Tv,Ti}) where {Tv,Ti}
 
 See [`permute!`](@ref) for basic usage. Parent of `permute[!]`
 methods operating on `SparseMatrixCSC`s that assume none of `X`, `A`, and `C` alias each
@@ -982,29 +987,29 @@ information.
 
 See also: `unchecked_aliasing_permute!`
 """
-function unchecked_noalias_permute!(X::SparseMatrixCSC{Tv,Ti},
-        A::SparseMatrixCSC{Tv,Ti}, p::AbstractVector{<:Integer},
-        q::AbstractVector{<:Integer}, C::SparseMatrixCSC{Tv,Ti}) where {Tv,Ti}
+function unchecked_noalias_permute!(X::AbstractSparseMatrixCSC{Tv,Ti},
+        A::AbstractSparseMatrixCSC{Tv,Ti}, p::AbstractVector{<:Integer},
+        q::AbstractVector{<:Integer}, C::AbstractSparseMatrixCSC{Tv,Ti}) where {Tv,Ti}
     halfperm!(C, A, q)
-    _computecolptrs_permute!(X, A, q, X.colptr)
+    _computecolptrs_permute!(X, A, q, getcolptr(X))
     _distributevals_halfperm!(X, C, p, identity)
     return X
 end
 """
-    unchecked_aliasing_permute!(A::SparseMatrixCSC{Tv,Ti},
+    unchecked_aliasing_permute!(A::AbstractSparseMatrixCSC{Tv,Ti},
         p::AbstractVector{<:Integer}, q::AbstractVector{<:Integer},
-        C::SparseMatrixCSC{Tv,Ti}, workcolptr::Vector{Ti}) where {Tv,Ti}
+        C::AbstractSparseMatrixCSC{Tv,Ti}, workcolptr::Vector{Ti}) where {Tv,Ti}
 
 See [`permute!`](@ref) for basic usage. Parent of `permute!`
 methods operating on [`SparseMatrixCSC`](@ref)s where the source and destination matrices
 are the same. See `unchecked_noalias_permute!`
 for additional information; these methods are identical but for this method's requirement of
-the additional `workcolptr`, `length(workcolptr) >= A.n + 1`, which enables efficient
+the additional `workcolptr`, `length(workcolptr) >= size(A, 2) + 1`, which enables efficient
 handling of the source-destination aliasing.
 """
-function unchecked_aliasing_permute!(A::SparseMatrixCSC{Tv,Ti},
+function unchecked_aliasing_permute!(A::AbstractSparseMatrixCSC{Tv,Ti},
         p::AbstractVector{<:Integer}, q::AbstractVector{<:Integer},
-        C::SparseMatrixCSC{Tv,Ti}, workcolptr::Vector{Ti}) where {Tv,Ti}
+        C::AbstractSparseMatrixCSC{Tv,Ti}, workcolptr::Vector{Ti}) where {Tv,Ti}
     halfperm!(C, A, q)
     _computecolptrs_permute!(A, A, q, workcolptr)
     _distributevals_halfperm!(A, C, p, identity)
@@ -1012,22 +1017,22 @@ function unchecked_aliasing_permute!(A::
 end
 """
 Helper method for `unchecked_noalias_permute!` and `unchecked_aliasing_permute!`.
-Computes `PAQ`'s column pointers, storing them shifted one position forward in `X.colptr`;
+Computes `PAQ`'s column pointers, storing them shifted one position forward in `getcolptr(X)`;
 `_distributevals_halfperm!` fixes this shift. Saves some work relative to
 `_computecolptrs_halfperm!` as described in `uncheckednoalias_permute!`'s documentation.
 """
-function _computecolptrs_permute!(X::SparseMatrixCSC{Tv,Ti},
-        A::SparseMatrixCSC{Tv,Ti}, q::AbstractVector{<:Integer}, workcolptr::Vector{Ti}) where {Tv,Ti}
+function _computecolptrs_permute!(X::AbstractSparseMatrixCSC{Tv,Ti},
+        A::AbstractSparseMatrixCSC{Tv,Ti}, q::AbstractVector{<:Integer}, workcolptr::Vector{Ti}) where {Tv,Ti}
     # Compute `A[p,q]`'s column counts. Store shifted forward one position in workcolptr.
-    @inbounds for k in 1:A.n
-        workcolptr[k+1] = A.colptr[q[k] + 1] - A.colptr[q[k]]
+    @inbounds for k in 1:size(A, 2)
+        workcolptr[k+1] = getcolptr(A)[q[k] + 1] - getcolptr(A)[q[k]]
     end
-    # Compute `A[p,q]`'s column pointers. Store shifted forward one position in X.colptr.
-    X.colptr[1] = 1
+    # Compute `A[p,q]`'s column pointers. Store shifted forward one position in getcolptr(X).
+    getcolptr(X)[1] = 1
     countsum = 1
-    @inbounds for k in 2:(X.n + 1)
+    @inbounds for k in 2:(size(X, 2) + 1)
         overwritten = workcolptr[k]
-        X.colptr[k] = countsum
+        getcolptr(X)[k] = countsum
         countsum += overwritten
     end
 end
@@ -1037,17 +1042,17 @@ Helper method for `permute` and `permute
 Checks compatibility of source argument `A`, row-permutation argument `p`, and
 column-permutation argument `q`.
 """
-function _checkargs_sourcecompatperms_permute!(A::SparseMatrixCSC,
+function _checkargs_sourcecompatperms_permute!(A::AbstractSparseMatrixCSC,
         p::AbstractVector{<:Integer}, q::AbstractVector{<:Integer})
     require_one_based_indexing(p, q)
-    if length(q) != A.n
+    if length(q) != size(A, 2)
          throw(DimensionMismatch(string("the length of column-permutation argument `q`, ",
              "`length(q) (= $(length(q)))`, must match source argument `A`'s column ",
-             "count, `A.n (= $(A.n))`")))
-     elseif length(p) != A.m
+             "count, `size(A, 2) (= $(size(A, 2)))`")))
+     elseif length(p) != size(A, 1)
          throw(DimensionMismatch(string("the length of row-permutation argument `p`, ",
              "`length(p) (= $(length(p)))`, must match source argument `A`'s row count, ",
-             "`A.m (= $(A.m))`")))
+             "`size(A, 1) (= $(size(A, 1)))`")))
      end
 end
 """
@@ -1077,21 +1082,21 @@ end
 Helper method for `permute` and `permute!` methods operating on `SparseMatrixCSC`s.
 Checks compatibility of source argument `A` and destination argument `X`.
 """
-function _checkargs_sourcecompatdest_permute!(A::SparseMatrixCSC{Tv,Ti},
-        X::SparseMatrixCSC{Tv,Ti}) where {Tv,Ti}
-    if X.m != A.m
+function _checkargs_sourcecompatdest_permute!(A::AbstractSparseMatrixCSC{Tv,Ti},
+        X::AbstractSparseMatrixCSC{Tv,Ti}) where {Tv,Ti}
+    if size(X, 1) != size(A, 1)
         throw(DimensionMismatch(string("destination argument `X`'s row count, ",
-            "`X.m (= $(X.m))`, must match source argument `A`'s row count, `A.m (= $(A.m))`")))
-    elseif X.n != A.n
+            "`size(X, 1) (= $(size(X, 1)))`, must match source argument `A`'s row count, `size(A, 1) (= $(size(A, 1)))`")))
+    elseif size(X, 2) != size(A, 2)
         throw(DimensionMismatch(string("destination argument `X`'s column count, ",
-            "`X.n (= $(X.n))`, must match source argument `A`'s column count, `A.n (= $(A.n))`")))
-    elseif length(X.rowval) < nnz(A)
+            "`size(X, 2) (= $(size(X, 2)))`, must match source argument `A`'s column count, `size(A, 2) (= $(size(A, 2)))`")))
+    elseif length(rowvals(X)) < nnz(A)
         throw(ArgumentError(string("the length of destination argument `X`'s `rowval` ",
-            "array, `length(X.rowval) (= $(length(X.rowval)))`, must be greater than or ",
+            "array, `length(rowvals(X)) (= $(length(rowvals(X))))`, must be greater than or ",
             "equal to source argument `A`'s allocated entry count, `nnz(A) (= $(nnz(A)))`")))
-    elseif length(X.nzval) < nnz(A)
+    elseif length(nonzeros(X)) < nnz(A)
         throw(ArgumentError(string("the length of destination argument `X`'s `nzval` ",
-            "array, `length(X.nzval) (= $(length(X.nzval)))`, must be greater than or ",
+            "array, `length(nonzeros(X)) (= $(length(nonzeros(X))))`, must be greater than or ",
             "equal to source argument `A`'s allocated entry count, `nnz(A) (= $(nnz(A)))`")))
     end
 end
@@ -1099,21 +1104,21 @@ end
 Helper method for `permute` and `permute!` methods operating on `SparseMatrixCSC`s.
 Checks compatibility of source argument `A` and intermediate result argument `C`.
 """
-function _checkargs_sourcecompatworkmat_permute!(A::SparseMatrixCSC{Tv,Ti},
-        C::SparseMatrixCSC{Tv,Ti}) where {Tv,Ti}
-    if C.n != A.m
+function _checkargs_sourcecompatworkmat_permute!(A::AbstractSparseMatrixCSC{Tv,Ti},
+        C::AbstractSparseMatrixCSC{Tv,Ti}) where {Tv,Ti}
+    if size(C, 2) != size(A, 1)
         throw(DimensionMismatch(string("intermediate result argument `C`'s column count, ",
-            "`C.n (= $(C.n))`, must match source argument `A`'s row count, `A.m (= $(A.m))`")))
-    elseif C.m != A.n
+            "`size(C, 2) (= $(size(C, 2)))`, must match source argument `A`'s row count, `size(A, 1) (= $(size(A, 1)))`")))
+    elseif size(C, 1) != size(A, 2)
         throw(DimensionMismatch(string("intermediate result argument `C`'s row count, ",
-            "`C.m (= $(C.m))`, must match source argument `A`'s column count, `A.n (= $(A.n))`")))
-    elseif length(C.rowval) < nnz(A)
+            "`size(C, 1) (= $(size(C, 1)))`, must match source argument `A`'s column count, `size(A, 2) (= $(size(A, 2)))`")))
+    elseif length(rowvals(C)) < nnz(A)
         throw(ArgumentError(string("the length of intermediate result argument `C`'s ",
-            "`rowval` array, `length(C.rowval) (= $(length(C.rowval)))`, must be greater than ",
+            "`rowval` array, `length(rowvals(C)) (= $(length(rowvals(C))))`, must be greater than ",
             "or equal to source argument `A`'s allocated entry count, `nnz(A) (= $(nnz(A)))`")))
-    elseif length(C.nzval) < nnz(A)
+    elseif length(nonzeros(C)) < nnz(A)
         throw(ArgumentError(string("the length of intermediate result argument `C`'s ",
-            "`rowval` array, `length(C.nzval) (= $(length(C.nzval)))`, must be greater than ",
+            "`rowval` array, `length(nonzeros(C)) (= $(length(nonzeros(C))))`, must be greater than ",
             "or equal to source argument `A`'s allocated entry count, `nnz(A)` (= $(nnz(A)))")))
     end
 end
@@ -1121,37 +1126,37 @@ end
 Helper method for `permute` and `permute!` methods operating on `SparseMatrixCSC`s.
 Checks compatibility of source argument `A` and workspace argument `workcolptr`.
 """
-function _checkargs_sourcecompatworkcolptr_permute!(A::SparseMatrixCSC{Tv,Ti},
+function _checkargs_sourcecompatworkcolptr_permute!(A::AbstractSparseMatrixCSC{Tv,Ti},
         workcolptr::Vector{Ti}) where {Tv,Ti}
-    if length(workcolptr) <= A.n
+    if length(workcolptr) <= size(A, 2)
         throw(DimensionMismatch(string("argument `workcolptr`'s length, ",
             "`length(workcolptr) (= $(length(workcolptr)))`, must exceed source argument ",
-            "`A`'s column count, `A.n (= $(A.n))`")))
+            "`A`'s column count, `size(A, 2) (= $(size(A, 2)))`")))
     end
 end
 """
-    permute!(X::SparseMatrixCSC{Tv,Ti}, A::SparseMatrixCSC{Tv,Ti},
+    permute!(X::AbstractSparseMatrixCSC{Tv,Ti}, A::AbstractSparseMatrixCSC{Tv,Ti},
              p::AbstractVector{<:Integer}, q::AbstractVector{<:Integer},
-             [C::SparseMatrixCSC{Tv,Ti}]) where {Tv,Ti}
+             [C::AbstractSparseMatrixCSC{Tv,Ti}]) where {Tv,Ti}
 
 Bilaterally permute `A`, storing result `PAQ` (`A[p,q]`) in `X`. Stores intermediate result
 `(AQ)^T` (`transpose(A[:,q])`) in optional argument `C` if present. Requires that none of
 `X`, `A`, and, if present, `C` alias each other; to store result `PAQ` back into `A`, use
 the following method lacking `X`:
 
-    permute!(A::SparseMatrixCSC{Tv,Ti}, p::AbstractVector{<:Integer},
-             q::AbstractVector{<:Integer}[, C::SparseMatrixCSC{Tv,Ti},
+    permute!(A::AbstractSparseMatrixCSC{Tv,Ti}, p::AbstractVector{<:Integer},
+             q::AbstractVector{<:Integer}[, C::AbstractSparseMatrixCSC{Tv,Ti},
              [workcolptr::Vector{Ti}]]) where {Tv,Ti}
 
-`X`'s dimensions must match those of `A` (`X.m == A.m` and `X.n == A.n`), and `X` must
-have enough storage to accommodate all allocated entries in `A` (`length(X.rowval) >= nnz(A)`
-and `length(X.nzval) >= nnz(A)`). Column-permutation `q`'s length must match `A`'s column
-count (`length(q) == A.n`). Row-permutation `p`'s length must match `A`'s row count
-(`length(p) == A.m`).
-
-`C`'s dimensions must match those of `transpose(A)` (`C.m == A.n` and `C.n == A.m`), and `C`
-must have enough storage to accommodate all allocated entries in `A` (`length(C.rowval) >= nnz(A)`
-and `length(C.nzval) >= nnz(A)`).
+`X`'s dimensions must match those of `A` (`size(X, 1) == size(A, 1)` and `size(X, 2) == size(A, 2)`), and `X` must
+have enough storage to accommodate all allocated entries in `A` (`length(rowvals(X)) >= nnz(A)`
+and `length(nonzeros(X)) >= nnz(A)`). Column-permutation `q`'s length must match `A`'s column
+count (`length(q) == size(A, 2)`). Row-permutation `p`'s length must match `A`'s row count
+(`length(p) == size(A, 1)`).
+
+`C`'s dimensions must match those of `transpose(A)` (`size(C, 1) == size(A, 2)` and `size(C, 2) == size(A, 1)`), and `C`
+must have enough storage to accommodate all allocated entries in `A` (`length(rowvals(C)) >= nnz(A)`
+and `length(nonzeros(C)) >= nnz(A)`).
 
 For additional (algorithmic) information, and for versions of these methods that forgo
 argument checking, see (unexported) parent methods `unchecked_noalias_permute!`
@@ -1159,61 +1164,61 @@ and `unchecked_aliasing_permute!`.
 
 See also: [`permute`](@ref).
 """
-function permute!(X::SparseMatrixCSC{Tv,Ti}, A::SparseMatrixCSC{Tv,Ti},
+function permute!(X::AbstractSparseMatrixCSC{Tv,Ti}, A::AbstractSparseMatrixCSC{Tv,Ti},
         p::AbstractVector{<:Integer}, q::AbstractVector{<:Integer}) where {Tv,Ti}
     _checkargs_sourcecompatdest_permute!(A, X)
     _checkargs_sourcecompatperms_permute!(A, p, q)
-    C = SparseMatrixCSC(A.n, A.m,
-                        ones(Ti, A.m + 1),
+    C = SparseMatrixCSC(size(A, 2), size(A, 1),
+                        ones(Ti, size(A, 1) + 1),
                         Vector{Ti}(undef, nnz(A)),
                         Vector{Tv}(undef, nnz(A)))
-    _checkargs_permutationsvalid_permute!(p, C.colptr, q, X.colptr)
+    _checkargs_permutationsvalid_permute!(p, getcolptr(C), q, getcolptr(X))
     unchecked_noalias_permute!(X, A, p, q, C)
 end
-function permute!(X::SparseMatrixCSC{Tv,Ti}, A::SparseMatrixCSC{Tv,Ti},
+function permute!(X::AbstractSparseMatrixCSC{Tv,Ti}, A::AbstractSparseMatrixCSC{Tv,Ti},
         p::AbstractVector{<:Integer}, q::AbstractVector{<:Integer},
-        C::SparseMatrixCSC{Tv,Ti}) where {Tv,Ti}
+        C::AbstractSparseMatrixCSC{Tv,Ti}) where {Tv,Ti}
     _checkargs_sourcecompatdest_permute!(A, X)
     _checkargs_sourcecompatperms_permute!(A, p, q)
     _checkargs_sourcecompatworkmat_permute!(A, C)
-    _checkargs_permutationsvalid_permute!(p, C.colptr, q, X.colptr)
+    _checkargs_permutationsvalid_permute!(p, getcolptr(C), q, getcolptr(X))
     unchecked_noalias_permute!(X, A, p, q, C)
 end
-function permute!(A::SparseMatrixCSC{Tv,Ti}, p::AbstractVector{<:Integer},
+function permute!(A::AbstractSparseMatrixCSC{Tv,Ti}, p::AbstractVector{<:Integer},
         q::AbstractVector{<:Integer}) where {Tv,Ti}
     _checkargs_sourcecompatperms_permute!(A, p, q)
-    C = SparseMatrixCSC(A.n, A.m,
-                        ones(Ti, A.m + 1),
+    C = SparseMatrixCSC(size(A, 2), size(A, 1),
+                        ones(Ti, size(A, 1) + 1),
                         Vector{Ti}(undef, nnz(A)),
                         Vector{Tv}(undef, nnz(A)))
-    workcolptr = Vector{Ti}(undef, A.n + 1)
-    _checkargs_permutationsvalid_permute!(p, C.colptr, q, workcolptr)
+    workcolptr = Vector{Ti}(undef, size(A, 2) + 1)
+    _checkargs_permutationsvalid_permute!(p, getcolptr(C), q, workcolptr)
     unchecked_aliasing_permute!(A, p, q, C, workcolptr)
 end
-function permute!(A::SparseMatrixCSC{Tv,Ti}, p::AbstractVector{<:Integer},
-        q::AbstractVector{<:Integer}, C::SparseMatrixCSC{Tv,Ti}) where {Tv,Ti}
+function permute!(A::AbstractSparseMatrixCSC{Tv,Ti}, p::AbstractVector{<:Integer},
+        q::AbstractVector{<:Integer}, C::AbstractSparseMatrixCSC{Tv,Ti}) where {Tv,Ti}
     _checkargs_sourcecompatperms_permute!(A, p, q)
     _checkargs_sourcecompatworkmat_permute!(A, C)
-    workcolptr = Vector{Ti}(undef, A.n + 1)
-    _checkargs_permutationsvalid_permute!(p, C.colptr, q, workcolptr)
+    workcolptr = Vector{Ti}(undef, size(A, 2) + 1)
+    _checkargs_permutationsvalid_permute!(p, getcolptr(C), q, workcolptr)
     unchecked_aliasing_permute!(A, p, q, C, workcolptr)
 end
-function permute!(A::SparseMatrixCSC{Tv,Ti}, p::AbstractVector{<:Integer},
-        q::AbstractVector{<:Integer}, C::SparseMatrixCSC{Tv,Ti},
+function permute!(A::AbstractSparseMatrixCSC{Tv,Ti}, p::AbstractVector{<:Integer},
+        q::AbstractVector{<:Integer}, C::AbstractSparseMatrixCSC{Tv,Ti},
         workcolptr::Vector{Ti}) where {Tv,Ti}
     _checkargs_sourcecompatperms_permute!(A, p, q)
     _checkargs_sourcecompatworkmat_permute!(A, C)
     _checkargs_sourcecompatworkcolptr_permute!(A, workcolptr)
-    _checkargs_permutationsvalid_permute!(p, C.colptr, q, workcolptr)
+    _checkargs_permutationsvalid_permute!(p, getcolptr(C), q, workcolptr)
     unchecked_aliasing_permute!(A, p, q, C, workcolptr)
 end
 """
-    permute(A::SparseMatrixCSC{Tv,Ti}, p::AbstractVector{<:Integer},
+    permute(A::AbstractSparseMatrixCSC{Tv,Ti}, p::AbstractVector{<:Integer},
             q::AbstractVector{<:Integer}) where {Tv,Ti}
 
 Bilaterally permute `A`, returning `PAQ` (`A[p,q]`). Column-permutation `q`'s length must
-match `A`'s column count (`length(q) == A.n`). Row-permutation `p`'s length must match `A`'s
-row count (`length(p) == A.m`).
+match `A`'s column count (`length(q) == size(A, 2)`). Row-permutation `p`'s length must match `A`'s
+row count (`length(p) == size(A, 1)`).
 
 For expert drivers and additional information, see [`permute!`](@ref).
 
@@ -1250,18 +1255,18 @@ julia> permute(A, [1, 2, 3, 4], [4, 3, 2
   [1, 4]  =  1
 ```
 """
-function permute(A::SparseMatrixCSC{Tv,Ti}, p::AbstractVector{<:Integer},
+function permute(A::AbstractSparseMatrixCSC{Tv,Ti}, p::AbstractVector{<:Integer},
         q::AbstractVector{<:Integer}) where {Tv,Ti}
     _checkargs_sourcecompatperms_permute!(A, p, q)
-    X = SparseMatrixCSC(A.m, A.n,
-                        ones(Ti, A.n + 1),
+    X = SparseMatrixCSC(size(A, 1), size(A, 2),
+                        ones(Ti, size(A, 2) + 1),
                         Vector{Ti}(undef, nnz(A)),
                         Vector{Tv}(undef, nnz(A)))
-    C = SparseMatrixCSC(A.n, A.m,
-                        ones(Ti, A.m + 1),
+    C = SparseMatrixCSC(size(A, 2), size(A, 1),
+                        ones(Ti, size(A, 1) + 1),
                         Vector{Ti}(undef, nnz(A)),
                         Vector{Tv}(undef, nnz(A)))
-    _checkargs_permutationsvalid_permute!(p, C.colptr, q, X.colptr)
+    _checkargs_permutationsvalid_permute!(p, getcolptr(C), q, getcolptr(X))
     unchecked_noalias_permute!(X, A, p, q, C)
 end
 
@@ -1276,9 +1281,9 @@ Keep elements of `A` for which test `f`
 
 where `i` and `j` are an element's row and column indices and `x` is the element's
 value. This method makes a single sweep
-through `A`, requiring `O(A.n, nnz(A))`-time for matrices and `O(nnz(A))`-time for vectors
-and no space beyond that passed in. If `trim` is `true`, this method trims `A.rowval` or `A.nzind` and
-`A.nzval` to length `nnz(A)` after dropping elements.
+through `A`, requiring `O(size(A, 2), nnz(A))`-time for matrices and `O(nnz(A))`-time for vectors
+and no space beyond that passed in. If `trim` is `true`, this method trims `rowvals(A)` or `nonzeroinds(A)` and
+`nonzeros(A)` to length `nnz(A)` after dropping elements.
 
 # Examples
 ```jldoctest
@@ -1295,11 +1300,11 @@ julia> SparseArrays.fkeep!(A, (i, j, v)
   [3, 3]  =  3
 ```
 """
-function fkeep!(A::SparseMatrixCSC, f, trim::Bool = true)
-    An = A.n
-    Acolptr = A.colptr
-    Arowval = A.rowval
-    Anzval = A.nzval
+function fkeep!(A::AbstractSparseMatrixCSC, f, trim::Bool = true)
+    An = size(A, 2)
+    Acolptr = getcolptr(A)
+    Arowval = rowvals(A)
+    Anzval = nonzeros(A)
 
     # Sweep through columns, rewriting kept elements in their new positions
     # and updating the column pointers accordingly as we go.
@@ -1336,33 +1341,33 @@ function fkeep!(A::SparseMatrixCSC, f, t
     A
 end
 
-tril!(A::SparseMatrixCSC, k::Integer = 0, trim::Bool = true) =
+tril!(A::AbstractSparseMatrixCSC, k::Integer = 0, trim::Bool = true) =
     fkeep!(A, (i, j, x) -> i + k >= j, trim)
-triu!(A::SparseMatrixCSC, k::Integer = 0, trim::Bool = true) =
+triu!(A::AbstractSparseMatrixCSC, k::Integer = 0, trim::Bool = true) =
     fkeep!(A, (i, j, x) -> j >= i + k, trim)
 
 """
-    droptol!(A::SparseMatrixCSC, tol; trim::Bool = true)
+    droptol!(A::AbstractSparseMatrixCSC, tol; trim::Bool = true)
 
 Removes stored values from `A` whose absolute value is less than or equal to `tol`,
-optionally trimming resulting excess space from `A.rowval` and `A.nzval` when `trim`
+optionally trimming resulting excess space from `rowvals(A)` and `nonzeros(A)` when `trim`
 is `true`.
 """
-droptol!(A::SparseMatrixCSC, tol; trim::Bool = true) =
+droptol!(A::AbstractSparseMatrixCSC, tol; trim::Bool = true) =
     fkeep!(A, (i, j, x) -> abs(x) > tol, trim)
 
 """
-    dropzeros!(A::SparseMatrixCSC; trim::Bool = true)
+    dropzeros!(A::AbstractSparseMatrixCSC; trim::Bool = true)
 
 Removes stored numerical zeros from `A`, optionally trimming resulting excess space from
-`A.rowval` and `A.nzval` when `trim` is `true`.
+`rowvals(A)` and `nonzeros(A)` when `trim` is `true`.
 
 For an out-of-place version, see [`dropzeros`](@ref). For
 algorithmic information, see `fkeep!`.
 """
-dropzeros!(A::SparseMatrixCSC; trim::Bool = true) = fkeep!(A, (i, j, x) -> !iszero(x), trim)
+dropzeros!(A::AbstractSparseMatrixCSC; trim::Bool = true) = fkeep!(A, (i, j, x) -> !iszero(x), trim)
 """
-    dropzeros(A::SparseMatrixCSC; trim::Bool = true)
+    dropzeros(A::AbstractSparseMatrixCSC; trim::Bool = true)
 
 Generates a copy of `A` and removes stored numerical zeros from that copy, optionally
 trimming excess space from the result's `rowval` and `nzval` arrays when `trim` is `true`.
@@ -1383,15 +1388,15 @@ julia> dropzeros(A)
   [3, 3]  =  1.0
 ```
 """
-dropzeros(A::SparseMatrixCSC; trim::Bool = true) = dropzeros!(copy(A), trim = trim)
+dropzeros(A::AbstractSparseMatrixCSC; trim::Bool = true) = dropzeros!(copy(A), trim = trim)
 
 ## Find methods
 
-function findall(S::SparseMatrixCSC)
+function findall(S::AbstractSparseMatrixCSC)
     return findall(identity, S)
 end
 
-function findall(p::Function, S::SparseMatrixCSC)
+function findall(p::Function, S::AbstractSparseMatrixCSC)
     if p(zero(eltype(S)))
         return invoke(findall, Tuple{Function, Any}, p, S)
     end
@@ -1400,10 +1405,10 @@ function findall(p::Function, S::SparseM
     inds = Vector{CartesianIndex{2}}(undef, numnz)
 
     count = 0
-    @inbounds for col = 1 : S.n, k = S.colptr[col] : (S.colptr[col+1]-1)
-        if p(S.nzval[k])
+    @inbounds for col = 1 : size(S, 2), k = getcolptr(S)[col] : (getcolptr(S)[col+1]-1)
+        if p(nonzeros(S)[k])
             count += 1
-            inds[count] = CartesianIndex(S.rowval[k], col)
+            inds[count] = CartesianIndex(rowvals(S)[k], col)
         end
     end
 
@@ -1411,54 +1416,54 @@ function findall(p::Function, S::SparseM
 
     return inds
 end
-findall(p::Base.Fix2{typeof(in)}, x::SparseMatrixCSC) =
+findall(p::Base.Fix2{typeof(in)}, x::AbstractSparseMatrixCSC) =
     invoke(findall, Tuple{Base.Fix2{typeof(in)}, AbstractArray}, p, x)
 
-function findnz(S::SparseMatrixCSC{Tv,Ti}) where {Tv,Ti}
+function findnz(S::AbstractSparseMatrixCSC{Tv,Ti}) where {Tv,Ti}
     numnz = nnz(S)
     I = Vector{Ti}(undef, numnz)
     J = Vector{Ti}(undef, numnz)
     V = Vector{Tv}(undef, numnz)
 
     count = 1
-    @inbounds for col = 1 : S.n, k = S.colptr[col] : (S.colptr[col+1]-1)
-        I[count] = S.rowval[k]
+    @inbounds for col = 1 : size(S, 2), k = getcolptr(S)[col] : (getcolptr(S)[col+1]-1)
+        I[count] = rowvals(S)[k]
         J[count] = col
-        V[count] = S.nzval[k]
+        V[count] = nonzeros(S)[k]
         count += 1
     end
 
     return (I, J, V)
 end
 
-function _sparse_findnextnz(m::SparseMatrixCSC, ij::CartesianIndex{2})
+function _sparse_findnextnz(m::AbstractSparseMatrixCSC, ij::CartesianIndex{2})
     row, col = Tuple(ij)
-    col > m.n && return nothing
+    col > size(m, 2) && return nothing
 
-    lo, hi = m.colptr[col], m.colptr[col+1]
-    n = searchsortedfirst(m.rowval, row, lo, hi-1, Base.Order.Forward)
+    lo, hi = getcolptr(m)[col], getcolptr(m)[col+1]
+    n = searchsortedfirst(rowvals(m), row, lo, hi-1, Base.Order.Forward)
     if lo <= n <= hi-1
-        return CartesianIndex(m.rowval[n], col)
+        return CartesianIndex(rowvals(m)[n], col)
     end
-    nextcol = searchsortedfirst(m.colptr, hi + 1, col + 1, length(m.colptr), Base.Order.Forward)
-    nextcol > length(m.colptr) && return nothing
-    nextlo = m.colptr[nextcol-1]
-    return CartesianIndex(m.rowval[nextlo], nextcol - 1)
+    nextcol = searchsortedfirst(getcolptr(m), hi + 1, col + 1, length(getcolptr(m)), Base.Order.Forward)
+    nextcol > length(getcolptr(m)) && return nothing
+    nextlo = getcolptr(m)[nextcol-1]
+    return CartesianIndex(rowvals(m)[nextlo], nextcol - 1)
 end
 
-function _sparse_findprevnz(m::SparseMatrixCSC, ij::CartesianIndex{2})
+function _sparse_findprevnz(m::AbstractSparseMatrixCSC, ij::CartesianIndex{2})
     row, col = Tuple(ij)
     iszero(col) && return nothing
 
-    lo, hi = m.colptr[col], m.colptr[col+1]
-    n = searchsortedlast(m.rowval, row, lo, hi-1, Base.Order.Forward)
+    lo, hi = getcolptr(m)[col], getcolptr(m)[col+1]
+    n = searchsortedlast(rowvals(m), row, lo, hi-1, Base.Order.Forward)
     if lo <= n <= hi-1
-        return CartesianIndex(m.rowval[n], col)
+        return CartesianIndex(rowvals(m)[n], col)
     end
-    prevcol = searchsortedlast(m.colptr, lo - 1, 1, col - 1, Base.Order.Forward)
+    prevcol = searchsortedlast(getcolptr(m), lo - 1, 1, col - 1, Base.Order.Forward)
     prevcol < 1 && return nothing
-    prevhi = m.colptr[prevcol+1]
-    return CartesianIndex(m.rowval[prevhi-1], prevcol)
+    prevhi = getcolptr(m)[prevcol+1]
+    return CartesianIndex(rowvals(m)[prevhi-1], prevcol)
 end
 
 
@@ -1551,7 +1556,7 @@ sprandn(r::AbstractRNG, ::Type{T}, m::In
 sprandn(::Type{T}, m::Integer, n::Integer, density::AbstractFloat) where {T} =
     sprandn(default_rng(), T, m, n, density)
 
-LinearAlgebra.fillstored!(S::SparseMatrixCSC, x) = (fill!(nzvalview(S), x); S)
+LinearAlgebra.fillstored!(S::AbstractSparseMatrixCSC, x) = (fill!(nzvalview(S), x); S)
 
 """
     spzeros([type,]m[,n])
@@ -1582,9 +1587,9 @@ function spzeros(::Type{Tv}, ::Type{Ti},
 end
 
 import Base._one
-function Base._one(unit::T, S::SparseMatrixCSC) where T
-    S.m == S.n || throw(DimensionMismatch("multiplicative identity only defined for square matrices"))
-    return SparseMatrixCSC{T}(I, S.m, S.n)
+function Base._one(unit::T, S::AbstractSparseMatrixCSC) where T
+    size(S, 1) == size(S, 2) || throw(DimensionMismatch("multiplicative identity only defined for square matrices"))
+    return SparseMatrixCSC{T}(I, size(S, 1), size(S, 2))
 end
 
 ## SparseMatrixCSC construction from UniformScaling
@@ -1605,13 +1610,13 @@ function SparseMatrixCSC{Tv,Ti}(s::Unifo
     SparseMatrixCSC{Tv,Ti}(dims..., colptr, rowval, nzval)
 end
 
-Base.iszero(A::SparseMatrixCSC) = iszero(nzvalview(A))
+Base.iszero(A::AbstractSparseMatrixCSC) = iszero(nzvalview(A))
 
-function Base.isone(A::SparseMatrixCSC)
+function Base.isone(A::AbstractSparseMatrixCSC)
     m, n = size(A)
-    m == n && A.colptr[n+1] >= n+1 || return false
-    for j in 1:n, k in A.colptr[j]:(A.colptr[j+1] - 1)
-        i, x = A.rowval[k], A.nzval[k]
+    m == n && getcolptr(A)[n+1] >= n+1 || return false
+    for j in 1:n, k in getcolptr(A)[j]:(getcolptr(A)[j+1] - 1)
+        i, x = rowvals(A)[k], nonzeros(A)[k]
         ifelse(i == j, isone(x), iszero(x)) || return false
     end
     return true
@@ -1621,35 +1626,35 @@ sparse(s::UniformScaling, dims::Dims{2})
 sparse(s::UniformScaling, m::Integer, n::Integer) = sparse(s, Dims((m, n)))
 
 # TODO: More appropriate location?
-function conj!(A::SparseMatrixCSC)
+function conj!(A::AbstractSparseMatrixCSC)
     map!(conj, nzvalview(A), nzvalview(A))
     return A
 end
-function (-)(A::SparseMatrixCSC)
-    nzval = similar(A.nzval)
+function (-)(A::AbstractSparseMatrixCSC)
+    nzval = similar(nonzeros(A))
     map!(-, view(nzval, 1:nnz(A)), nzvalview(A))
-    return SparseMatrixCSC(A.m, A.n, copy(A.colptr), copy(A.rowval), nzval)
+    return SparseMatrixCSC(size(A, 1), size(A, 2), copy(getcolptr(A)), copy(rowvals(A)), nzval)
 end
 
 # the rest of real, conj, imag are handled correctly via AbstractArray methods
-function conj(A::SparseMatrixCSC{<:Complex})
-    nzval = similar(A.nzval)
+function conj(A::AbstractSparseMatrixCSC{<:Complex})
+    nzval = similar(nonzeros(A))
     map!(conj, view(nzval, 1:nnz(A)), nzvalview(A))
-    return SparseMatrixCSC(A.m, A.n, copy(A.colptr), copy(A.rowval), nzval)
+    return SparseMatrixCSC(size(A, 1), size(A, 2), copy(getcolptr(A)), copy(rowvals(A)), nzval)
 end
-imag(A::SparseMatrixCSC{Tv,Ti}) where {Tv<:Real,Ti} = spzeros(Tv, Ti, A.m, A.n)
+imag(A::AbstractSparseMatrixCSC{Tv,Ti}) where {Tv<:Real,Ti} = spzeros(Tv, Ti, size(A, 1), size(A, 2))
 
 ## Binary arithmetic and boolean operators
-(+)(A::SparseMatrixCSC, B::SparseMatrixCSC) = map(+, A, B)
-(-)(A::SparseMatrixCSC, B::SparseMatrixCSC) = map(-, A, B)
+(+)(A::AbstractSparseMatrixCSC, B::AbstractSparseMatrixCSC) = map(+, A, B)
+(-)(A::AbstractSparseMatrixCSC, B::AbstractSparseMatrixCSC) = map(-, A, B)
 
-(+)(A::SparseMatrixCSC, B::Array) = Array(A) + B
-(+)(A::Array, B::SparseMatrixCSC) = A + Array(B)
-(-)(A::SparseMatrixCSC, B::Array) = Array(A) - B
-(-)(A::Array, B::SparseMatrixCSC) = A - Array(B)
+(+)(A::AbstractSparseMatrixCSC, B::Array) = Array(A) + B
+(+)(A::Array, B::AbstractSparseMatrixCSC) = A + Array(B)
+(-)(A::AbstractSparseMatrixCSC, B::Array) = Array(A) - B
+(-)(A::Array, B::AbstractSparseMatrixCSC) = A - Array(B)
 
 ## full equality
-function ==(A1::SparseMatrixCSC, A2::SparseMatrixCSC)
+function ==(A1::AbstractSparseMatrixCSC, A2::AbstractSparseMatrixCSC)
     size(A1) != size(A2) && return false
     vals1, vals2 = nonzeros(A1), nonzeros(A2)
     rows1, rows2 = rowvals(A1), rowvals(A2)
@@ -1690,7 +1695,7 @@ end
 # In general, output of sparse matrix reductions will not be sparse,
 # and computing reductions along columns into SparseMatrixCSC is
 # non-trivial, so use Arrays for output. Array element type is given by `R`.
-function Base.reducedim_initarray(A::SparseMatrixCSC, region, v0, ::Type{R}) where {R}
+function Base.reducedim_initarray(A::AbstractSparseMatrixCSC, region, v0, ::Type{R}) where {R}
     fill!(Array{R}(undef, Base.to_shape(Base.reduced_indices(A, region))), v0)
 end
 
@@ -1714,7 +1719,7 @@ function _mapreducezeros(f, op, ::Type{T
     v
 end
 
-function Base._mapreduce(f, op, ::Base.IndexCartesian, A::SparseMatrixCSC{T}) where T
+function Base._mapreduce(f, op, ::Base.IndexCartesian, A::AbstractSparseMatrixCSC{T}) where T
     z = nnz(A)
     n = length(A)
     if z == 0
@@ -1734,7 +1739,7 @@ _mapreducezeros(f, ::typeof(+), ::Type{T
 _mapreducezeros(f, ::typeof(*), ::Type{T}, nzeros::Integer, v0) where {T} =
     nzeros == 0 ? v0 : f(zero(T))^nzeros * v0
 
-function Base._mapreduce(f, op::typeof(*), A::SparseMatrixCSC{T}) where T
+function Base._mapreduce(f, op::typeof(*), A::AbstractSparseMatrixCSC{T}) where T
     nzeros = length(A)-nnz(A)
     if nzeros == 0
         # No zeros, so don't compute f(0) since it might throw
@@ -1747,11 +1752,11 @@ function Base._mapreduce(f, op::typeof(*
 end
 
 # General mapreducedim
-function _mapreducerows!(f, op, R::AbstractArray, A::SparseMatrixCSC{T}) where T
+function _mapreducerows!(f, op, R::AbstractArray, A::AbstractSparseMatrixCSC{T}) where T
     require_one_based_indexing(A, R)
-    colptr = A.colptr
-    rowval = A.rowval
-    nzval = A.nzval
+    colptr = getcolptr(A)
+    rowval = rowvals(A)
+    nzval = nonzeros(A)
     m, n = size(A)
     @inbounds for col = 1:n
         r = R[1, col]
@@ -1763,11 +1768,11 @@ function _mapreducerows!(f, op, R::Abstr
     R
 end
 
-function _mapreducecols!(f, op, R::AbstractArray, A::SparseMatrixCSC{Tv,Ti}) where {Tv,Ti}
+function _mapreducecols!(f, op, R::AbstractArray, A::AbstractSparseMatrixCSC{Tv,Ti}) where {Tv,Ti}
     require_one_based_indexing(A, R)
-    colptr = A.colptr
-    rowval = A.rowval
-    nzval = A.nzval
+    colptr = getcolptr(A)
+    rowval = rowvals(A)
+    nzval = nonzeros(A)
     m, n = size(A)
     rownz = fill(convert(Ti, n), m)
     @inbounds for col = 1:n
@@ -1783,7 +1788,7 @@ function _mapreducecols!(f, op, R::Abstr
     R
 end
 
-function Base._mapreducedim!(f, op, R::AbstractArray, A::SparseMatrixCSC{T}) where T
+function Base._mapreducedim!(f, op, R::AbstractArray, A::AbstractSparseMatrixCSC{T}) where T
     require_one_based_indexing(A, R)
     lsiz = Base.check_reducedims(R,A)
     isempty(A) && return R
@@ -1801,7 +1806,7 @@ function Base._mapreducedim!(f, op, R::A
         # Reduction along a dimension > 2
         # Compute op(R, f(A))
         m, n = size(A)
-        nzval = A.nzval
+        nzval = nonzeros(A)
         if length(nzval) == m*n
             # No zeros, so don't compute f(0) since it might throw
             for col = 1:n
@@ -1810,8 +1815,8 @@ function Base._mapreducedim!(f, op, R::A
                 end
             end
         else
-            colptr = A.colptr
-            rowval = A.rowval
+            colptr = getcolptr(A)
+            rowval = rowvals(A)
             zeroval = f(zero(T))
             @inbounds for col = 1:n
                 lastrow = 0
@@ -1834,9 +1839,9 @@ end
 
 # Specialized mapreducedim for + cols to avoid allocating a
 # temporary array when f(0) == 0
-function _mapreducecols!(f, op::typeof(+), R::AbstractArray, A::SparseMatrixCSC{Tv,Ti}) where {Tv,Ti}
+function _mapreducecols!(f, op::typeof(+), R::AbstractArray, A::AbstractSparseMatrixCSC{Tv,Ti}) where {Tv,Ti}
     require_one_based_indexing(A, R)
-    nzval = A.nzval
+    nzval = nonzeros(A)
     m, n = size(A)
     if length(nzval) == m*n
         # No zeros, so don't compute f(0) since it might throw
@@ -1846,8 +1851,8 @@ function _mapreducecols!(f, op::typeof(+
             end
         end
     else
-        colptr = A.colptr
-        rowval = A.rowval
+        colptr = getcolptr(A)
+        rowval = rowvals(A)
         zeroval = f(zero(Tv))
         if isequal(zeroval, zero(Tv))
             # Case where f(0) == 0
@@ -1877,12 +1882,12 @@ end
 # findmax/min and argmax/min methods
 # find first zero value in sparse matrix - return linear index in full matrix
 # non-structural zeros are identified by x == 0 in line with the sparse constructors.
-function _findz(A::SparseMatrixCSC{Tv,Ti}, rows=1:A.m, cols=1:A.n) where {Tv,Ti}
-    colptr = A.colptr; rowval = A.rowval; nzval = A.nzval
+function _findz(A::AbstractSparseMatrixCSC{Tv,Ti}, rows=1:size(A, 1), cols=1:size(A, 2)) where {Tv,Ti}
+    colptr = getcolptr(A); rowval = rowvals(A); nzval = nonzeros(A)
     zval = 0
     row = 0
     rowmin = rows[1]; rowmax = rows[end]
-    allrows = (rows == 1:A.m)
+    allrows = (rows == 1:size(A, 1))
     @inbounds for col in cols
         r1::Int = colptr[col]
         r2::Int = colptr[col+1] - 1
@@ -1915,7 +1920,7 @@ function _findr(op, A, region, Tv)
         end
     end
 
-    colptr = A.colptr; rowval = A.rowval; nzval = A.nzval; m = A.m; n = A.n
+    colptr = getcolptr(A); rowval = rowvals(A); nzval = nonzeros(A); m = size(A, 1); n = size(A, 2)
     zval = zero(Tv)
     szA = size(A)
 
@@ -1962,7 +1967,7 @@ function _findr(op, A, region, Tv)
         hasz = nnz(A) != length(A)
         Sv = hasz ? zval : nzval[1]
         Iv::(Ti) = hasz ? _findz(A) : i1
-        @inbounds for i = 1 : A.n, j = colptr[i] : (colptr[i+1]-1)
+        @inbounds for i = 1 : size(A, 2), j = colptr[i] : (colptr[i+1]-1)
             if op(nzval[j], Sv)
                 Sv = nzval[j]
                 Iv = CartesianIndex(rowval[j], i)
@@ -1977,13 +1982,13 @@ end
 _isless_fm(a, b)    =  b == b && ( a != a || isless(a, b) )
 _isgreater_fm(a, b) =  b == b && ( a != a || isless(b, a) )
 
-findmin(A::SparseMatrixCSC{Tv,Ti}, region) where {Tv,Ti} = _findr(_isless_fm, A, region, Tv)
-findmax(A::SparseMatrixCSC{Tv,Ti}, region) where {Tv,Ti} = _findr(_isgreater_fm, A, region, Tv)
-findmin(A::SparseMatrixCSC) = (r=findmin(A,(1,2)); (r[1][1], r[2][1]))
-findmax(A::SparseMatrixCSC) = (r=findmax(A,(1,2)); (r[1][1], r[2][1]))
+findmin(A::AbstractSparseMatrixCSC{Tv,Ti}, region) where {Tv,Ti} = _findr(_isless_fm, A, region, Tv)
+findmax(A::AbstractSparseMatrixCSC{Tv,Ti}, region) where {Tv,Ti} = _findr(_isgreater_fm, A, region, Tv)
+findmin(A::AbstractSparseMatrixCSC) = (r=findmin(A,(1,2)); (r[1][1], r[2][1]))
+findmax(A::AbstractSparseMatrixCSC) = (r=findmax(A,(1,2)); (r[1][1], r[2][1]))
 
-argmin(A::SparseMatrixCSC) = findmin(A)[2]
-argmax(A::SparseMatrixCSC) = findmax(A)[2]
+argmin(A::AbstractSparseMatrixCSC) = findmin(A)[2]
+argmax(A::AbstractSparseMatrixCSC) = findmax(A)[2]
 
 ## getindex
 function rangesearch(haystack::AbstractRange, needle)
@@ -1991,29 +1996,29 @@ function rangesearch(haystack::AbstractR
     (rem==0 && 1<=i+1<=length(haystack)) ? i+1 : 0
 end
 
-getindex(A::SparseMatrixCSC, I::Tuple{Integer,Integer}) = getindex(A, I[1], I[2])
+getindex(A::AbstractSparseMatrixCSC, I::Tuple{Integer,Integer}) = getindex(A, I[1], I[2])
 
-function getindex(A::SparseMatrixCSC{T}, i0::Integer, i1::Integer) where T
-    if !(1 <= i0 <= A.m && 1 <= i1 <= A.n); throw(BoundsError()); end
-    r1 = Int(A.colptr[i1])
-    r2 = Int(A.colptr[i1+1]-1)
+function getindex(A::AbstractSparseMatrixCSC{T}, i0::Integer, i1::Integer) where T
+    if !(1 <= i0 <= size(A, 1) && 1 <= i1 <= size(A, 2)); throw(BoundsError()); end
+    r1 = Int(getcolptr(A)[i1])
+    r2 = Int(getcolptr(A)[i1+1]-1)
     (r1 > r2) && return zero(T)
-    r1 = searchsortedfirst(A.rowval, i0, r1, r2, Forward)
-    ((r1 > r2) || (A.rowval[r1] != i0)) ? zero(T) : A.nzval[r1]
+    r1 = searchsortedfirst(rowvals(A), i0, r1, r2, Forward)
+    ((r1 > r2) || (rowvals(A)[r1] != i0)) ? zero(T) : nonzeros(A)[r1]
 end
 
 # Colon translation
-getindex(A::SparseMatrixCSC, ::Colon, ::Colon) = copy(A)
-getindex(A::SparseMatrixCSC, i, ::Colon)       = getindex(A, i, 1:size(A, 2))
-getindex(A::SparseMatrixCSC, ::Colon, i)       = getindex(A, 1:size(A, 1), i)
+getindex(A::AbstractSparseMatrixCSC, ::Colon, ::Colon) = copy(A)
+getindex(A::AbstractSparseMatrixCSC, i, ::Colon)       = getindex(A, i, 1:size(A, 2))
+getindex(A::AbstractSparseMatrixCSC, ::Colon, i)       = getindex(A, 1:size(A, 1), i)
 
-function getindex_cols(A::SparseMatrixCSC{Tv,Ti}, J::AbstractVector) where {Tv,Ti}
+function getindex_cols(A::AbstractSparseMatrixCSC{Tv,Ti}, J::AbstractVector) where {Tv,Ti}
     require_one_based_indexing(A, J)
     # for indexing whole columns
     (m, n) = size(A)
     nJ = length(J)
 
-    colptrA = A.colptr; rowvalA = A.rowval; nzvalA = A.nzval
+    colptrA = getcolptr(A); rowvalA = rowvals(A); nzvalA = nonzeros(A)
 
     colptrS = Vector{Ti}(undef, nJ+1)
     colptrS[1] = 1
@@ -2044,7 +2049,7 @@ end
 getindex_traverse_col(::AbstractUnitRange, lo::Integer, hi::Integer) = lo:hi
 getindex_traverse_col(I::StepRange, lo::Integer, hi::Integer) = step(I) > 0 ? (lo:1:hi) : (hi:-1:lo)
 
-function getindex(A::SparseMatrixCSC{Tv,Ti}, I::AbstractRange, J::AbstractVector) where {Tv,Ti<:Integer}
+function getindex(A::AbstractSparseMatrixCSC{Tv,Ti}, I::AbstractRange, J::AbstractVector) where {Tv,Ti<:Integer}
     require_one_based_indexing(A, I, J)
     # Ranges for indexing rows
     (m, n) = size(A)
@@ -2056,7 +2061,7 @@ function getindex(A::SparseMatrixCSC{Tv,
     nI = length(I)
     nI == 0 || (minimum(I) >= 1 && maximum(I) <= m) || throw(BoundsError())
     nJ = length(J)
-    colptrA = A.colptr; rowvalA = A.rowval; nzvalA = A.nzval
+    colptrA = getcolptr(A); rowvalA = rowvals(A); nzvalA = nonzeros(A)
     colptrS = Vector{Ti}(undef, nJ+1)
     colptrS[1] = 1
     nnzS = 0
@@ -2092,7 +2097,7 @@ function getindex(A::SparseMatrixCSC{Tv,
     return SparseMatrixCSC(nI, nJ, colptrS, rowvalS, nzvalS)
 end
 
-function getindex_I_sorted(A::SparseMatrixCSC{Tv,Ti}, I::AbstractVector, J::AbstractVector) where {Tv,Ti}
+function getindex_I_sorted(A::AbstractSparseMatrixCSC{Tv,Ti}, I::AbstractVector, J::AbstractVector) where {Tv,Ti}
     require_one_based_indexing(A, I, J)
     # Sorted vectors for indexing rows.
     # Similar to getindex_general but without the transpose trick.
@@ -2113,12 +2118,12 @@ function getindex_I_sorted(A::SparseMatr
     getindex_I_sorted_linear(A, I, J)
 end
 
-function getindex_I_sorted_bsearch_A(A::SparseMatrixCSC{Tv,Ti}, I::AbstractVector, J::AbstractVector) where {Tv,Ti}
+function getindex_I_sorted_bsearch_A(A::AbstractSparseMatrixCSC{Tv,Ti}, I::AbstractVector, J::AbstractVector) where {Tv,Ti}
     require_one_based_indexing(A, I, J)
     nI = length(I)
     nJ = length(J)
 
-    colptrA = A.colptr; rowvalA = A.rowval; nzvalA = A.nzval
+    colptrA = getcolptr(A); rowvalA = rowvals(A); nzvalA = nonzeros(A)
     colptrS = Vector{Ti}(undef, nJ+1)
     colptrS[1] = 1
 
@@ -2173,15 +2178,15 @@ function getindex_I_sorted_bsearch_A(A::
     return SparseMatrixCSC(nI, nJ, colptrS, rowvalS, nzvalS)
 end
 
-function getindex_I_sorted_linear(A::SparseMatrixCSC{Tv,Ti}, I::AbstractVector, J::AbstractVector) where {Tv,Ti}
+function getindex_I_sorted_linear(A::AbstractSparseMatrixCSC{Tv,Ti}, I::AbstractVector, J::AbstractVector) where {Tv,Ti}
     require_one_based_indexing(A, I, J)
     nI = length(I)
     nJ = length(J)
 
-    colptrA = A.colptr; rowvalA = A.rowval; nzvalA = A.nzval
+    colptrA = getcolptr(A); rowvalA = rowvals(A); nzvalA = nonzeros(A)
     colptrS = Vector{Ti}(undef, nJ+1)
     colptrS[1] = 1
-    cacheI = zeros(Int, A.m)
+    cacheI = zeros(Int, size(A, 1))
 
     ptrS   = 1
     # build the cache and determine result size
@@ -2233,16 +2238,16 @@ function getindex_I_sorted_linear(A::Spa
     return SparseMatrixCSC(nI, nJ, colptrS, rowvalS, nzvalS)
 end
 
-function getindex_I_sorted_bsearch_I(A::SparseMatrixCSC{Tv,Ti}, I::AbstractVector, J::AbstractVector) where {Tv,Ti}
+function getindex_I_sorted_bsearch_I(A::AbstractSparseMatrixCSC{Tv,Ti}, I::AbstractVector, J::AbstractVector) where {Tv,Ti}
     require_one_based_indexing(A, I, J)
     nI = length(I)
     nJ = length(J)
 
-    colptrA = A.colptr; rowvalA = A.rowval; nzvalA = A.nzval
+    colptrA = getcolptr(A); rowvalA = rowvals(A); nzvalA = nonzeros(A)
     colptrS = Vector{Ti}(undef, nJ+1)
     colptrS[1] = 1
 
-    m = A.m
+    m = size(A, 1)
 
     # cacheI is used first to store num occurrences of each row in columns of interest
     # and later to store position of first occurrence of each row in I
@@ -2303,9 +2308,9 @@ function getindex_I_sorted_bsearch_I(A::
     return SparseMatrixCSC(nI, nJ, colptrS, rowvalS, nzvalS)
 end
 
-function permute_rows!(S::SparseMatrixCSC{Tv,Ti}, pI::Vector{Int}) where {Tv,Ti}
+function permute_rows!(S::AbstractSparseMatrixCSC{Tv,Ti}, pI::Vector{Int}) where {Tv,Ti}
     (m, n) = size(S)
-    colptrS = S.colptr; rowvalS = S.rowval; nzvalS = S.nzval
+    colptrS = getcolptr(S); rowvalS = rowvals(S); nzvalS = nonzeros(S)
     # preallocate temporary sort space
     nr = min(nnz(S), m)
 
@@ -2349,7 +2354,7 @@ function permute_rows!(S::SparseMatrixCS
     S
 end
 
-function getindex_general(A::SparseMatrixCSC, I::AbstractVector, J::AbstractVector)
+function getindex_general(A::AbstractSparseMatrixCSC, I::AbstractVector, J::AbstractVector)
     require_one_based_indexing(A, I, J)
     pI = sortperm(I)
     @inbounds Is = I[pI]
@@ -2357,7 +2362,7 @@ function getindex_general(A::SparseMatri
 end
 
 # the general case:
-function getindex(A::SparseMatrixCSC{Tv,Ti}, I::AbstractVector, J::AbstractVector) where {Tv,Ti}
+function getindex(A::AbstractSparseMatrixCSC{Tv,Ti}, I::AbstractVector, J::AbstractVector) where {Tv,Ti}
     require_one_based_indexing(A, I, J)
     (m, n) = size(A)
 
@@ -2382,13 +2387,13 @@ function getindex(A::SparseMatrixCSC{Tv,
     end
 end
 
-function getindex(A::SparseMatrixCSC{Tv,Ti}, I::AbstractArray) where {Tv,Ti}
+function getindex(A::AbstractSparseMatrixCSC{Tv,Ti}, I::AbstractArray) where {Tv,Ti}
     require_one_based_indexing(A, I)
     szA = size(A)
     nA = szA[1]*szA[2]
-    colptrA = A.colptr
-    rowvalA = A.rowval
-    nzvalA = A.nzval
+    colptrA = getcolptr(A)
+    rowvalA = rowvals(A)
+    nzvalA = nonzeros(A)
 
     n = length(I)
     outm = size(I,1)
@@ -2426,49 +2431,49 @@ function getindex(A::SparseMatrixCSC{Tv,
 end
 
 # logical getindex
-getindex(A::SparseMatrixCSC{<:Any,<:Integer}, I::AbstractRange{Bool}, J::AbstractVector{Bool}) = error("Cannot index with AbstractRange{Bool}")
-getindex(A::SparseMatrixCSC{<:Any,<:Integer}, I::AbstractRange{Bool}, J::AbstractVector{<:Integer}) = error("Cannot index with AbstractRange{Bool}")
+getindex(A::AbstractSparseMatrixCSC{<:Any,<:Integer}, I::AbstractRange{Bool}, J::AbstractVector{Bool}) = error("Cannot index with AbstractRange{Bool}")
+getindex(A::AbstractSparseMatrixCSC{<:Any,<:Integer}, I::AbstractRange{Bool}, J::AbstractVector{<:Integer}) = error("Cannot index with AbstractRange{Bool}")
 
-getindex(A::SparseMatrixCSC, I::AbstractRange{<:Integer}, J::AbstractVector{Bool}) = A[I,findall(J)]
-getindex(A::SparseMatrixCSC, I::Integer, J::AbstractVector{Bool}) = A[I,findall(J)]
-getindex(A::SparseMatrixCSC, I::AbstractVector{Bool}, J::Integer) = A[findall(I),J]
-getindex(A::SparseMatrixCSC, I::AbstractVector{Bool}, J::AbstractVector{Bool}) = A[findall(I),findall(J)]
-getindex(A::SparseMatrixCSC, I::AbstractVector{<:Integer}, J::AbstractVector{Bool}) = A[I,findall(J)]
-getindex(A::SparseMatrixCSC, I::AbstractVector{Bool}, J::AbstractVector{<:Integer}) = A[findall(I),J]
+getindex(A::AbstractSparseMatrixCSC, I::AbstractRange{<:Integer}, J::AbstractVector{Bool}) = A[I,findall(J)]
+getindex(A::AbstractSparseMatrixCSC, I::Integer, J::AbstractVector{Bool}) = A[I,findall(J)]
+getindex(A::AbstractSparseMatrixCSC, I::AbstractVector{Bool}, J::Integer) = A[findall(I),J]
+getindex(A::AbstractSparseMatrixCSC, I::AbstractVector{Bool}, J::AbstractVector{Bool}) = A[findall(I),findall(J)]
+getindex(A::AbstractSparseMatrixCSC, I::AbstractVector{<:Integer}, J::AbstractVector{Bool}) = A[I,findall(J)]
+getindex(A::AbstractSparseMatrixCSC, I::AbstractVector{Bool}, J::AbstractVector{<:Integer}) = A[findall(I),J]
 
 ## setindex!
 
 # dispatch helper for #29034
-setindex!(A::SparseMatrixCSC, _v, _i::Integer, _j::Integer) = _setindex_scalar!(A, _v, _i, _j)
+setindex!(A::AbstractSparseMatrixCSC, _v, _i::Integer, _j::Integer) = _setindex_scalar!(A, _v, _i, _j)
 
-function _setindex_scalar!(A::SparseMatrixCSC{Tv,Ti}, _v, _i::Integer, _j::Integer) where {Tv,Ti<:Integer}
+function _setindex_scalar!(A::AbstractSparseMatrixCSC{Tv,Ti}, _v, _i::Integer, _j::Integer) where {Tv,Ti<:Integer}
     v = convert(Tv, _v)
     i = convert(Ti, _i)
     j = convert(Ti, _j)
-    if !((1 <= i <= A.m) & (1 <= j <= A.n))
+    if !((1 <= i <= size(A, 1)) & (1 <= j <= size(A, 2)))
         throw(BoundsError(A, (i,j)))
     end
-    coljfirstk = Int(A.colptr[j])
-    coljlastk = Int(A.colptr[j+1] - 1)
-    searchk = searchsortedfirst(A.rowval, i, coljfirstk, coljlastk, Base.Order.Forward)
-    if searchk <= coljlastk && A.rowval[searchk] == i
+    coljfirstk = Int(getcolptr(A)[j])
+    coljlastk = Int(getcolptr(A)[j+1] - 1)
+    searchk = searchsortedfirst(rowvals(A), i, coljfirstk, coljlastk, Base.Order.Forward)
+    if searchk <= coljlastk && rowvals(A)[searchk] == i
         # Column j contains entry A[i,j]. Update and return
-        A.nzval[searchk] = v
+        nonzeros(A)[searchk] = v
         return A
     end
     # Column j does not contain entry A[i,j]. If v is nonzero, insert entry A[i,j] = v
     # and return. If to the contrary v is zero, then simply return.
     if !iszero(v)
-        nz = A.colptr[A.n+1]
+        nz = getcolptr(A)[size(A, 2)+1]
         # throw exception before state is partially modified
         !isbitstype(Ti) || nz < typemax(Ti) ||
             throw(ArgumentError("nnz(A) going to exceed typemax(Ti) = $(typemax(Ti))"))
 
         # if nnz(A) < length(rowval/nzval): no need to grow rowval and preserve values
-        _insert!(A.rowval, searchk, i, nz)
-        _insert!(A.nzval, searchk, v, nz)
-        @simd for m in (j + 1):(A.n + 1)
-            @inbounds A.colptr[m] += Ti(1)
+        _insert!(rowvals(A), searchk, i, nz)
+        _insert!(nonzeros(A), searchk, v, nz)
+        @simd for m in (j + 1):(size(A, 2) + 1)
+            @inbounds getcolptr(A)[m] += Ti(1)
         end
     end
     return A
@@ -2485,14 +2490,14 @@ function _insert!(v::Vector, pos::Intege
     end
 end
 
-function Base.fill!(V::SubArray{Tv, <:Any, <:SparseMatrixCSC, Tuple{Vararg{Union{Integer, AbstractVector{<:Integer}},2}}}, x) where Tv
+function Base.fill!(V::SubArray{Tv, <:Any, <:AbstractSparseMatrixCSC, Tuple{Vararg{Union{Integer, AbstractVector{<:Integer}},2}}}, x) where Tv
     A = V.parent
     I, J = V.indices
     if isempty(I) || isempty(J); return A; end
     # lt=≤ to check for strict sorting
     if !issorted(I, lt=≤); I = sort!(unique(I)); end
     if !issorted(J, lt=≤); J = sort!(unique(J)); end
-    if (I[1] < 1 || I[end] > A.m) || (J[1] < 1 || J[end] > A.n)
+    if (I[1] < 1 || I[end] > size(A, 1)) || (J[1] < 1 || J[end] > size(A, 2))
         throw(BoundsError(A, (I, J)))
     end
     if x == 0
@@ -2505,33 +2510,33 @@ end
 Helper method for immediately preceding setindex! method. For all (i,j) such that i in I and
 j in J, assigns zero to A[i,j] if A[i,j] is a presently-stored entry, and otherwise does nothing.
 """
-function _spsetz_setindex!(A::SparseMatrixCSC,
+function _spsetz_setindex!(A::AbstractSparseMatrixCSC,
         I::Union{Integer, AbstractVector{<:Integer}}, J::Union{Integer, AbstractVector{<:Integer}})
     require_one_based_indexing(A, I, J)
     lengthI = length(I)
     for j in J
-        coljAfirstk = A.colptr[j]
-        coljAlastk = A.colptr[j+1] - 1
+        coljAfirstk = getcolptr(A)[j]
+        coljAlastk = getcolptr(A)[j+1] - 1
         coljAfirstk > coljAlastk && continue
         kA = coljAfirstk
         kI = 1
-        entrykArow = A.rowval[kA]
+        entrykArow = rowvals(A)[kA]
         entrykIrow = I[kI]
         while true
             if entrykArow < entrykIrow
                 kA += 1
                 kA > coljAlastk && break
-                entrykArow = A.rowval[kA]
+                entrykArow = rowvals(A)[kA]
             elseif entrykArow > entrykIrow
                 kI += 1
                 kI > lengthI && break
                 entrykIrow = I[kI]
             else # entrykArow == entrykIrow
-                A.nzval[kA] = 0
+                nonzeros(A)[kA] = 0
                 kA += 1
                 kI += 1
                 (kA > coljAlastk || kI > lengthI) && break
-                entrykArow = A.rowval[kA]
+                entrykArow = rowvals(A)[kA]
                 entrykIrow = I[kI]
             end
         end
@@ -2542,7 +2547,7 @@ Helper method for immediately preceding
 and j in J, assigns x to A[i,j] if A[i,j] is a presently-stored entry, and allocates and
 assigns x to A[i,j] if A[i,j] is not presently stored.
 """
-function _spsetnz_setindex!(A::SparseMatrixCSC{Tv}, x::Tv,
+function _spsetnz_setindex!(A::AbstractSparseMatrixCSC{Tv}, x::Tv,
         I::Union{Integer, AbstractVector{<:Integer}}, J::Union{Integer, AbstractVector{<:Integer}}) where Tv
     require_one_based_indexing(A, I, J)
     m, n = size(A)
@@ -2550,15 +2555,15 @@ function _spsetnz_setindex!(A::SparseMat
 
     nnzA = nnz(A) + lenI * length(J)
 
-    rowvalA = rowval = A.rowval
-    nzvalA = nzval = A.nzval
+    rowvalA = rowval = rowvals(A)
+    nzvalA = nzval = nonzeros(A)
 
     rowidx = 1
     nadd = 0
     @inbounds for col in 1:n
         rrange = nzrange(A, col)
         if nadd > 0
-            A.colptr[col] = A.colptr[col] + nadd
+            getcolptr(A)[col] = getcolptr(A)[col] + nadd
         end
 
         if col in J
@@ -2642,7 +2647,7 @@ function _spsetnz_setindex!(A::SparseMat
     end
 
     if nadd > 0
-        A.colptr[n+1] = rowidx
+        getcolptr(A)[n+1] = rowidx
         deleteat!(rowvalA, rowidx:nnzA)
         deleteat!(nzvalA, rowidx:nnzA)
     end
@@ -2650,12 +2655,12 @@ function _spsetnz_setindex!(A::SparseMat
 end
 
 # Nonscalar A[I,J] = B: Convert B to a SparseMatrixCSC of the appropriate shape first
-_to_same_csc(::SparseMatrixCSC{Tv, Ti}, V::AbstractMatrix, I...) where {Tv,Ti} = convert(SparseMatrixCSC{Tv,Ti}, V)
-_to_same_csc(::SparseMatrixCSC{Tv, Ti}, V::AbstractVector, I...) where {Tv,Ti} = convert(SparseMatrixCSC{Tv,Ti}, reshape(V, map(length, I)))
+_to_same_csc(::AbstractSparseMatrixCSC{Tv, Ti}, V::AbstractMatrix, I...) where {Tv,Ti} = convert(SparseMatrixCSC{Tv,Ti}, V)
+_to_same_csc(::AbstractSparseMatrixCSC{Tv, Ti}, V::AbstractVector, I...) where {Tv,Ti} = convert(SparseMatrixCSC{Tv,Ti}, reshape(V, map(length, I)))
 
-setindex!(A::SparseMatrixCSC{Tv}, B::AbstractVecOrMat, I::Integer, J::Integer) where {Tv} = _setindex_scalar!(A, B, I, J)
+setindex!(A::AbstractSparseMatrixCSC{Tv}, B::AbstractVecOrMat, I::Integer, J::Integer) where {Tv} = _setindex_scalar!(A, B, I, J)
 
-function setindex!(A::SparseMatrixCSC{Tv,Ti}, V::AbstractVecOrMat, Ix::Union{Integer, AbstractVector{<:Integer}, Colon}, Jx::Union{Integer, AbstractVector{<:Integer}, Colon}) where {Tv,Ti<:Integer}
+function setindex!(A::AbstractSparseMatrixCSC{Tv,Ti}, V::AbstractVecOrMat, Ix::Union{Integer, AbstractVector{<:Integer}, Colon}, Jx::Union{Integer, AbstractVector{<:Integer}, Colon}) where {Tv,Ti<:Integer}
     require_one_based_indexing(A, V, Ix, Jx)
     (I, J) = Base.ensure_indexable(to_indices(A, (Ix, Jx)))
     checkbounds(A, I, J)
@@ -2691,14 +2696,14 @@ function setindex!(A::SparseMatrixCSC{Tv
     nI = length(I)
     nJ = length(J)
 
-    colptrA = A.colptr; rowvalA = A.rowval; nzvalA = A.nzval
-    colptrB = B.colptr; rowvalB = B.rowval; nzvalB = B.nzval
+    colptrA = getcolptr(A); rowvalA = rowvals(A); nzvalA = nonzeros(A)
+    colptrB = getcolptr(B); rowvalB = rowvals(B); nzvalB = nonzeros(B)
 
     nnzS = nnz(A) + nnz(B)
 
-    colptrS = copy(A.colptr)
-    rowvalS = copy(A.rowval)
-    nzvalS = copy(A.nzval)
+    colptrS = copy(getcolptr(A))
+    rowvalS = copy(rowvals(A))
+    nzvalS = copy(nonzeros(A))
 
     resize!(rowvalA, nnzS)
     resize!(nzvalA, nnzS)
@@ -2784,29 +2789,29 @@ end
 
 # Logical setindex!
 
-setindex!(A::Matrix, x::SparseMatrixCSC, I::Integer, J::AbstractVector{Bool}) = setindex!(A, Array(x), I, findall(J))
-setindex!(A::Matrix, x::SparseMatrixCSC, I::AbstractVector{Bool}, J::Integer) = setindex!(A, Array(x), findall(I), J)
-setindex!(A::Matrix, x::SparseMatrixCSC, I::AbstractVector{Bool}, J::AbstractVector{Bool}) = setindex!(A, Array(x), findall(I), findall(J))
-setindex!(A::Matrix, x::SparseMatrixCSC, I::AbstractVector{<:Integer}, J::AbstractVector{Bool}) = setindex!(A, Array(x), I, findall(J))
-setindex!(A::Matrix, x::SparseMatrixCSC, I::AbstractVector{Bool}, J::AbstractVector{<:Integer}) = setindex!(A, Array(x), findall(I), J)
+setindex!(A::Matrix, x::AbstractSparseMatrixCSC, I::Integer, J::AbstractVector{Bool}) = setindex!(A, Array(x), I, findall(J))
+setindex!(A::Matrix, x::AbstractSparseMatrixCSC, I::AbstractVector{Bool}, J::Integer) = setindex!(A, Array(x), findall(I), J)
+setindex!(A::Matrix, x::AbstractSparseMatrixCSC, I::AbstractVector{Bool}, J::AbstractVector{Bool}) = setindex!(A, Array(x), findall(I), findall(J))
+setindex!(A::Matrix, x::AbstractSparseMatrixCSC, I::AbstractVector{<:Integer}, J::AbstractVector{Bool}) = setindex!(A, Array(x), I, findall(J))
+setindex!(A::Matrix, x::AbstractSparseMatrixCSC, I::AbstractVector{Bool}, J::AbstractVector{<:Integer}) = setindex!(A, Array(x), findall(I), J)
 
-function setindex!(A::SparseMatrixCSC, x::AbstractArray, I::AbstractMatrix{Bool})
+function setindex!(A::AbstractSparseMatrixCSC, x::AbstractArray, I::AbstractMatrix{Bool})
     require_one_based_indexing(A, x, I)
     checkbounds(A, I)
     n = sum(I)
     (n == 0) && (return A)
 
-    colptrA = A.colptr; rowvalA = A.rowval; nzvalA = A.nzval
+    colptrA = getcolptr(A); rowvalA = rowvals(A); nzvalA = nonzeros(A)
     colptrB = colptrA; rowvalB = rowvalA; nzvalB = nzvalA
     nadd = 0
     bidx = xidx = 1
     r1 = r2 = 0
 
-    @inbounds for col in 1:A.n
+    @inbounds for col in 1:size(A, 2)
         r1 = Int(colptrA[col])
         r2 = Int(colptrA[col+1]-1)
 
-        for row in 1:A.m
+        for row in 1:size(A, 1)
             if I[row, col]
                 v = x[xidx]
                 xidx += 1
@@ -2852,7 +2857,7 @@ function setindex!(A::SparseMatrixCSC, x
                 end
                 (xidx > n) && break
             end # if I[row, col]
-        end # for row in 1:A.m
+        end # for row in 1:size(A, 1)
 
         if (nadd != 0)
             l = r2-r1+1
@@ -2879,7 +2884,7 @@ function setindex!(A::SparseMatrixCSC, x
             bidx = colptrA[col+1]
         end
         (xidx > n) && break
-    end # for col in 1:A.n
+    end # for col in 1:size(A, 2)
 
     if (nadd != 0)
         n = length(nzvalB)
@@ -2891,14 +2896,14 @@ function setindex!(A::SparseMatrixCSC, x
     A
 end
 
-function setindex!(A::SparseMatrixCSC, x::AbstractArray, Ix::AbstractVector{<:Integer})
+function setindex!(A::AbstractSparseMatrixCSC, x::AbstractArray, Ix::AbstractVector{<:Integer})
     require_one_based_indexing(A, x, Ix)
     (I,) = Base.ensure_indexable(to_indices(A, (Ix,)))
     # We check bounds after sorting I
     n = length(I)
     (n == 0) && (return A)
 
-    colptrA = A.colptr; rowvalA = A.rowval; nzvalA = A.nzval; szA = size(A)
+    colptrA = getcolptr(A); rowvalA = rowvals(A); nzvalA = nonzeros(A); szA = size(A)
     colptrB = colptrA; rowvalB = rowvalA; nzvalB = nzvalA
     nadd = 0
     bidx = aidx = 1
@@ -3004,7 +3009,7 @@ end
 
 ## dropstored! methods
 """
-    dropstored!(A::SparseMatrixCSC, i::Integer, j::Integer)
+    dropstored!(A::AbstractSparseMatrixCSC, i::Integer, j::Integer)
 
 Drop entry `A[i,j]` from `A` if `A[i,j]` is stored, and otherwise do nothing.
 
@@ -3019,31 +3024,31 @@ julia> SparseArrays.dropstored!(A, 1, 2)
   [1, 1]  =  1
 ```
 """
-function dropstored!(A::SparseMatrixCSC, i::Integer, j::Integer)
-    if !((1 <= i <= A.m) & (1 <= j <= A.n))
+function dropstored!(A::AbstractSparseMatrixCSC, i::Integer, j::Integer)
+    if !((1 <= i <= size(A, 1)) & (1 <= j <= size(A, 2)))
         throw(BoundsError(A, (i,j)))
     end
-    coljfirstk = Int(A.colptr[j])
-    coljlastk = Int(A.colptr[j+1] - 1)
-    searchk = searchsortedfirst(A.rowval, i, coljfirstk, coljlastk, Base.Order.Forward)
-    if searchk <= coljlastk && A.rowval[searchk] == i
+    coljfirstk = Int(getcolptr(A)[j])
+    coljlastk = Int(getcolptr(A)[j+1] - 1)
+    searchk = searchsortedfirst(rowvals(A), i, coljfirstk, coljlastk, Base.Order.Forward)
+    if searchk <= coljlastk && rowvals(A)[searchk] == i
         # Entry A[i,j] is stored. Drop and return.
-        deleteat!(A.rowval, searchk)
-        deleteat!(A.nzval, searchk)
-        @simd for m in (j+1):(A.n + 1)
-            @inbounds A.colptr[m] -= 1
+        deleteat!(rowvals(A), searchk)
+        deleteat!(nonzeros(A), searchk)
+        @simd for m in (j+1):(size(A, 2) + 1)
+            @inbounds getcolptr(A)[m] -= 1
         end
     end
     return A
 end
 """
-    dropstored!(A::SparseMatrixCSC, I::AbstractVector{<:Integer}, J::AbstractVector{<:Integer})
+    dropstored!(A::AbstractSparseMatrixCSC, I::AbstractVector{<:Integer}, J::AbstractVector{<:Integer})
 
 For each `(i,j)` where `i in I` and `j in J`, drop entry `A[i,j]` from `A` if `A[i,j]` is
 stored and otherwise do nothing. Derivative forms:
 
-    dropstored!(A::SparseMatrixCSC, i::Integer, J::AbstractVector{<:Integer})
-    dropstored!(A::SparseMatrixCSC, I::AbstractVector{<:Integer}, j::Integer)
+    dropstored!(A::AbstractSparseMatrixCSC, i::Integer, J::AbstractVector{<:Integer})
+    dropstored!(A::AbstractSparseMatrixCSC, I::AbstractVector{<:Integer}, j::Integer)
 
 # Examples
 ```jldoctest
@@ -3061,7 +3066,7 @@ julia> SparseArrays.dropstored!(A, [1, 2
   [4, 4]  =  4
 ```
 """
-function dropstored!(A::SparseMatrixCSC,
+function dropstored!(A::AbstractSparseMatrixCSC,
         I::AbstractVector{<:Integer}, J::AbstractVector{<:Integer})
     require_one_based_indexing(A, I, J)
     m, n = size(A)
@@ -3079,14 +3084,14 @@ function dropstored!(A::SparseMatrixCSC,
         return A
     end
 
-    rowval = rowvalA = A.rowval
-    nzval = nzvalA = A.nzval
+    rowval = rowvalA = rowvals(A)
+    nzval = nzvalA = nonzeros(A)
     rowidx = 1
     ndel = 0
     @inbounds for col in 1:n
         rrange = nzrange(A, col)
         if ndel > 0
-            A.colptr[col] = A.colptr[col] - ndel
+            getcolptr(A)[col] = getcolptr(A)[col] - ndel
         end
 
         if isempty(rrange) || !(col in J)
@@ -3116,25 +3121,25 @@ function dropstored!(A::SparseMatrixCSC,
     end
 
     if ndel > 0
-        A.colptr[n+1] = rowidx
+        getcolptr(A)[n+1] = rowidx
         deleteat!(rowvalA, rowidx:nnzA)
         deleteat!(nzvalA, rowidx:nnzA)
     end
     return A
 end
-dropstored!(A::SparseMatrixCSC, i::Integer, J::AbstractVector{<:Integer}) = dropstored!(A, [i], J)
-dropstored!(A::SparseMatrixCSC, I::AbstractVector{<:Integer}, j::Integer) = dropstored!(A, I, [j])
-dropstored!(A::SparseMatrixCSC, ::Colon, j::Union{Integer,AbstractVector}) = dropstored!(A, 1:size(A,1), j)
-dropstored!(A::SparseMatrixCSC, i::Union{Integer,AbstractVector}, ::Colon) = dropstored!(A, i, 1:size(A,2))
-dropstored!(A::SparseMatrixCSC, ::Colon, ::Colon) = dropstored!(A, 1:size(A,1), 1:size(A,2))
-dropstored!(A::SparseMatrixCSC, ::Colon) = dropstored!(A, :, :)
+dropstored!(A::AbstractSparseMatrixCSC, i::Integer, J::AbstractVector{<:Integer}) = dropstored!(A, [i], J)
+dropstored!(A::AbstractSparseMatrixCSC, I::AbstractVector{<:Integer}, j::Integer) = dropstored!(A, I, [j])
+dropstored!(A::AbstractSparseMatrixCSC, ::Colon, j::Union{Integer,AbstractVector}) = dropstored!(A, 1:size(A,1), j)
+dropstored!(A::AbstractSparseMatrixCSC, i::Union{Integer,AbstractVector}, ::Colon) = dropstored!(A, i, 1:size(A,2))
+dropstored!(A::AbstractSparseMatrixCSC, ::Colon, ::Colon) = dropstored!(A, 1:size(A,1), 1:size(A,2))
+dropstored!(A::AbstractSparseMatrixCSC, ::Colon) = dropstored!(A, :, :)
 # TODO: Several of the preceding methods are optimization candidates.
 # TODO: Implement linear indexing methods for dropstored! ?
 # TODO: Implement logical indexing methods for dropstored! ?
 
 # Sparse concatenation
 
-function vcat(X::SparseMatrixCSC...)
+function vcat(X::AbstractSparseMatrixCSC...)
     num = length(X)
     mX = Int[ size(x, 1) for x in X ]
     nX = Int[ size(x, 2) for x in X ]
@@ -3148,7 +3153,7 @@ function vcat(X::SparseMatrixCSC...)
     end
 
     Tv = promote_eltype(X...)
-    Ti = promote_eltype(map(x->x.rowval, X)...)
+    Ti = promote_eltype(map(x->rowvals(x), X)...)
 
     nnzX = Int[ nnz(x) for x in X ]
     nnz_res = sum(nnzX)
@@ -3161,7 +3166,7 @@ function vcat(X::SparseMatrixCSC...)
         mX_sofar = 0
         ptr_res = colptr[c]
         for i = 1 : num
-            colptrXi = X[i].colptr
+            colptrXi = getcolptr(X[i])
             col_length = (colptrXi[c + 1] - 1) - colptrXi[c]
             ptr_Xi = colptrXi[c]
 
@@ -3176,11 +3181,11 @@ function vcat(X::SparseMatrixCSC...)
     SparseMatrixCSC(m, n, colptr, rowval, nzval)
 end
 
-@inline function stuffcol!(Xi::SparseMatrixCSC, colptr, rowval, nzval,
+@inline function stuffcol!(Xi::AbstractSparseMatrixCSC, colptr, rowval, nzval,
                            ptr_res, ptr_Xi, col_length, mX_sofar)
-    colptrXi = Xi.colptr
-    rowvalXi = Xi.rowval
-    nzvalXi  = Xi.nzval
+    colptrXi = getcolptr(Xi)
+    rowvalXi = rowvals(Xi)
+    nzvalXi  = nonzeros(Xi)
 
     for k=ptr_res:(ptr_res + col_length)
         @inbounds rowval[k] = rowvalXi[ptr_Xi] + mX_sofar
@@ -3189,7 +3194,7 @@ end
     end
 end
 
-function hcat(X::SparseMatrixCSC...)
+function hcat(X::AbstractSparseMatrixCSC...)
     num = length(X)
     mX = Int[ size(x, 1) for x in X ]
     nX = Int[ size(x, 2) for x in X ]
@@ -3200,7 +3205,7 @@ function hcat(X::SparseMatrixCSC...)
     n = sum(nX)
 
     Tv = promote_eltype(X...)
-    Ti = promote_eltype(map(x->x.rowval, X)...)
+    Ti = promote_eltype(map(x->rowvals(x), X)...)
 
     colptr = Vector{Ti}(undef, n+1)
     nnzX = Int[ nnz(x) for x in X ]
@@ -3212,13 +3217,13 @@ function hcat(X::SparseMatrixCSC...)
     nX_sofar = 0
     @inbounds for i = 1 : num
         XI = X[i]
-        colptr[(1 : nX[i] + 1) .+ nX_sofar] = XI.colptr .+ nnz_sofar
-        if nnzX[i] == length(XI.rowval)
-            rowval[(1 : nnzX[i]) .+ nnz_sofar] = XI.rowval
-            nzval[(1 : nnzX[i]) .+ nnz_sofar] = XI.nzval
+        colptr[(1 : nX[i] + 1) .+ nX_sofar] = getcolptr(XI) .+ nnz_sofar
+        if nnzX[i] == length(rowvals(XI))
+            rowval[(1 : nnzX[i]) .+ nnz_sofar] = rowvals(XI)
+            nzval[(1 : nnzX[i]) .+ nnz_sofar] = nonzeros(XI)
         else
-            rowval[(1 : nnzX[i]) .+ nnz_sofar] = XI.rowval[1:nnzX[i]]
-            nzval[(1 : nnzX[i]) .+ nnz_sofar] = XI.nzval[1:nnzX[i]]
+            rowval[(1 : nnzX[i]) .+ nnz_sofar] = rowvals(XI)[1:nnzX[i]]
+            nzval[(1 : nnzX[i]) .+ nnz_sofar] = nonzeros(XI)[1:nnzX[i]]
         end
         nnz_sofar += nnzX[i]
         nX_sofar += nX[i]
@@ -3243,15 +3248,15 @@ julia> blockdiag(sparse(2I, 3, 3), spars
   [5, 5]  =  4
 ```
 """
-function blockdiag(X::SparseMatrixCSC...)
+function blockdiag(X::AbstractSparseMatrixCSC...)
     num = length(X)
     mX = Int[ size(x, 1) for x in X ]
     nX = Int[ size(x, 2) for x in X ]
     m = sum(mX)
     n = sum(nX)
 
-    Tv = promote_type(map(x->eltype(x.nzval), X)...)
-    Ti = isempty(X) ? Int : promote_type(map(x->eltype(x.rowval), X)...)
+    Tv = promote_type(map(x->eltype(nonzeros(x)), X)...)
+    Ti = isempty(X) ? Int : promote_type(map(x->eltype(rowvals(x)), X)...)
 
     colptr = Vector{Ti}(undef, n+1)
     nnzX = Int[ nnz(x) for x in X ]
@@ -3263,9 +3268,9 @@ function blockdiag(X::SparseMatrixCSC...
     nX_sofar = 0
     mX_sofar = 0
     for i = 1 : num
-        colptr[(1 : nX[i] + 1) .+ nX_sofar] = X[i].colptr .+ nnz_sofar
-        rowval[(1 : nnzX[i]) .+ nnz_sofar] = X[i].rowval .+ mX_sofar
-        nzval[(1 : nnzX[i]) .+ nnz_sofar] = X[i].nzval
+        colptr[(1 : nX[i] + 1) .+ nX_sofar] = getcolptr(X[i]) .+ nnz_sofar
+        rowval[(1 : nnzX[i]) .+ nnz_sofar] = rowvals(X[i]) .+ mX_sofar
+        nzval[(1 : nnzX[i]) .+ nnz_sofar] = nonzeros(X[i])
         nnz_sofar += nnzX[i]
         nX_sofar += nX[i]
         mX_sofar += mX[i]
@@ -3276,19 +3281,19 @@ function blockdiag(X::SparseMatrixCSC...
 end
 
 ## Structure query functions
-issymmetric(A::SparseMatrixCSC) = is_hermsym(A, identity)
+issymmetric(A::AbstractSparseMatrixCSC) = is_hermsym(A, identity)
 
-ishermitian(A::SparseMatrixCSC) = is_hermsym(A, conj)
+ishermitian(A::AbstractSparseMatrixCSC) = is_hermsym(A, conj)
 
-function is_hermsym(A::SparseMatrixCSC, check::Function)
+function is_hermsym(A::AbstractSparseMatrixCSC, check::Function)
     m, n = size(A)
     if m != n; return false; end
 
-    colptr = A.colptr
-    rowval = A.rowval
-    nzval = A.nzval
-    tracker = copy(A.colptr)
-    for col = 1:A.n
+    colptr = getcolptr(A)
+    rowval = rowvals(A)
+    nzval = nonzeros(A)
+    tracker = copy(getcolptr(A))
+    for col = 1:size(A, 2)
         # `tracker` is updated such that, for symmetric matrices,
         # the loop below starts from an element at or below the
         # diagonal element of column `col`"
@@ -3355,11 +3360,11 @@ function is_hermsym(A::SparseMatrixCSC,
     return true
 end
 
-function istriu(A::SparseMatrixCSC)
+function istriu(A::AbstractSparseMatrixCSC)
     m, n = size(A)
-    colptr = A.colptr
-    rowval = A.rowval
-    nzval  = A.nzval
+    colptr = getcolptr(A)
+    rowval = rowvals(A)
+    nzval  = nonzeros(A)
 
     for col = 1:min(n, m-1)
         l1 = colptr[col+1]-1
@@ -3375,11 +3380,11 @@ function istriu(A::SparseMatrixCSC)
     return true
 end
 
-function istril(A::SparseMatrixCSC)
+function istril(A::AbstractSparseMatrixCSC)
     m, n = size(A)
-    colptr = A.colptr
-    rowval = A.rowval
-    nzval  = A.nzval
+    colptr = getcolptr(A)
+    rowval = rowvals(A)
+    nzval  = nonzeros(A)
 
     for col = 2:n
         for i = colptr[col] : (colptr[col+1]-1)
@@ -3471,7 +3476,7 @@ function expandptr(V::Vector{<:Integer})
 end
 
 
-function diag(A::SparseMatrixCSC{Tv,Ti}, d::Integer=0) where {Tv,Ti}
+function diag(A::AbstractSparseMatrixCSC{Tv,Ti}, d::Integer=0) where {Tv,Ti}
     m, n = size(A)
     k = Int(d)
     l = k < 0 ? min(m+k,n) : min(n-k,m)
@@ -3480,18 +3485,18 @@ function diag(A::SparseMatrixCSC{Tv,Ti},
     val = Vector{Tv}()
     for i in 1:l
         r += 1; c += 1
-        r1 = Int(A.colptr[c])
-        r2 = Int(A.colptr[c+1]-1)
+        r1 = Int(getcolptr(A)[c])
+        r2 = Int(getcolptr(A)[c+1]-1)
         r1 > r2 && continue
-        r1 = searchsortedfirst(A.rowval, r, r1, r2, Forward)
-        ((r1 > r2) || (A.rowval[r1] != r)) && continue
+        r1 = searchsortedfirst(rowvals(A), r, r1, r2, Forward)
+        ((r1 > r2) || (rowvals(A)[r1] != r)) && continue
         push!(ind, i)
-        push!(val, A.nzval[r1])
+        push!(val, nonzeros(A)[r1])
     end
     return SparseVector{Tv,Ti}(l, ind, val)
 end
 
-function tr(A::SparseMatrixCSC{Tv}) where Tv
+function tr(A::AbstractSparseMatrixCSC{Tv}) where Tv
     n = checksquare(A)
     s = zero(Tv)
     for i in 1:n
@@ -3504,17 +3509,17 @@ end
 # Sort all the indices in each column of a CSC sparse matrix
 # sortSparseMatrixCSC!(A, sortindices = :sortcols)        # Sort each column with sort()
 # sortSparseMatrixCSC!(A, sortindices = :doubletranspose) # Sort with a double transpose
-function sortSparseMatrixCSC!(A::SparseMatrixCSC{Tv,Ti}; sortindices::Symbol = :sortcols) where {Tv,Ti}
+function sortSparseMatrixCSC!(A::AbstractSparseMatrixCSC{Tv,Ti}; sortindices::Symbol = :sortcols) where {Tv,Ti}
     if sortindices === :doubletranspose
         nB, mB = size(A)
-        B = SparseMatrixCSC(mB, nB, Vector{Ti}(undef, nB+1), similar(A.rowval), similar(A.nzval))
+        B = SparseMatrixCSC(mB, nB, Vector{Ti}(undef, nB+1), similar(rowvals(A)), similar(nonzeros(A)))
         transpose!(B, A)
         transpose!(A, B)
         return A
     end
 
     m, n = size(A)
-    colptr = A.colptr; rowval = A.rowval; nzval = A.nzval
+    colptr = getcolptr(A); rowval = rowvals(A); nzval = nonzeros(A)
 
     index = zeros(Ti, m)
     row = zeros(Ti, m)
@@ -3570,7 +3575,7 @@ end
 
 ## rotations
 
-function rot180(A::SparseMatrixCSC)
+function rot180(A::AbstractSparseMatrixCSC)
     I,J,V = findnz(A)
     m,n = size(A)
     for i=1:length(I)
@@ -3580,7 +3585,7 @@ function rot180(A::SparseMatrixCSC)
     return sparse(I,J,V,m,n)
 end
 
-function rotr90(A::SparseMatrixCSC)
+function rotr90(A::AbstractSparseMatrixCSC)
     I,J,V = findnz(A)
     m,n = size(A)
     #old col inds are new row inds
@@ -3590,7 +3595,7 @@ function rotr90(A::SparseMatrixCSC)
     return sparse(J, I, V, n, m)
 end
 
-function rotl90(A::SparseMatrixCSC)
+function rotl90(A::AbstractSparseMatrixCSC)
     I,J,V = findnz(A)
     m,n = size(A)
     #old row inds are new col inds
@@ -3602,49 +3607,49 @@ end
 
 ## Uniform matrix arithmetic
 
-(+)(A::SparseMatrixCSC, J::UniformScaling) = A + sparse(J, size(A)...)
-(-)(A::SparseMatrixCSC, J::UniformScaling) = A - sparse(J, size(A)...)
-(-)(J::UniformScaling, A::SparseMatrixCSC) = sparse(J, size(A)...) - A
+(+)(A::AbstractSparseMatrixCSC, J::UniformScaling) = A + sparse(J, size(A)...)
+(-)(A::AbstractSparseMatrixCSC, J::UniformScaling) = A - sparse(J, size(A)...)
+(-)(J::UniformScaling, A::AbstractSparseMatrixCSC) = sparse(J, size(A)...) - A
 
 ## circular shift
 
-function circshift!(O::SparseMatrixCSC, X::SparseMatrixCSC, (r,c)::Base.DimsInteger{2})
-    nnz = length(X.nzval)
+function circshift!(O::AbstractSparseMatrixCSC, X::AbstractSparseMatrixCSC, (r,c)::Base.DimsInteger{2})
+    nnz = length(nonzeros(X))
 
     iszero(nnz) && return copy!(O, X)
 
     ##### column shift
-    c = mod(c, X.n)
+    c = mod(c, size(X, 2))
     if iszero(c)
         copy!(O, X)
     else
         ##### readjust output
-        resize!(O.colptr, X.n + 1)
-        resize!(O.rowval, nnz)
-        resize!(O.nzval, nnz)
-        O.colptr[X.n + 1] = nnz + 1
+        resize!(getcolptr(O), size(X, 2) + 1)
+        resize!(rowvals(O), nnz)
+        resize!(nonzeros(O), nnz)
+        getcolptr(O)[size(X, 2) + 1] = nnz + 1
 
         # exchange left and right blocks
-        nleft = X.colptr[X.n - c + 1] - 1
+        nleft = getcolptr(X)[size(X, 2) - c + 1] - 1
         nright = nnz - nleft
-        @inbounds for i=c+1:X.n
-            O.colptr[i] = X.colptr[i-c] + nright
+        @inbounds for i=c+1:size(X, 2)
+            getcolptr(O)[i] = getcolptr(X)[i-c] + nright
         end
         @inbounds for i=1:c
-            O.colptr[i] = X.colptr[X.n - c + i] - nleft
+            getcolptr(O)[i] = getcolptr(X)[size(X, 2) - c + i] - nleft
         end
         # rotate rowval and nzval by the right number of elements
-        circshift!(O.rowval, X.rowval, (nright,))
-        circshift!(O.nzval, X.nzval, (nright,))
+        circshift!(rowvals(O), rowvals(X), (nright,))
+        circshift!(nonzeros(O), nonzeros(X), (nright,))
     end
     ##### row shift
-    r = mod(r, X.m)
+    r = mod(r, size(X, 1))
     iszero(r) && return O
-    @inbounds for i=1:O.n
-        subvector_shifter!(O.rowval, O.nzval, O.colptr[i], O.colptr[i+1]-1, O.m, r)
+    @inbounds for i=1:size(O, 2)
+        subvector_shifter!(rowvals(O), nonzeros(O), getcolptr(O)[i], getcolptr(O)[i+1]-1, size(O, 1), r)
     end
     return O
 end
 
-circshift!(O::SparseMatrixCSC, X::SparseMatrixCSC, (r,)::Base.DimsInteger{1}) = circshift!(O, X, (r,0))
-circshift!(O::SparseMatrixCSC, X::SparseMatrixCSC, r::Real) = circshift!(O, X, (Integer(r),0))
+circshift!(O::AbstractSparseMatrixCSC, X::AbstractSparseMatrixCSC, (r,)::Base.DimsInteger{1}) = circshift!(O, X, (r,0))
+circshift!(O::AbstractSparseMatrixCSC, X::AbstractSparseMatrixCSC, r::Real) = circshift!(O, X, (Integer(r),0))
diff -pruN 1.3.1+dfsg-1/stdlib/SparseArrays/src/sparsevector.jl 1.4.0+dfsg-1/stdlib/SparseArrays/src/sparsevector.jl
--- 1.3.1+dfsg-1/stdlib/SparseArrays/src/sparsevector.jl	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/stdlib/SparseArrays/src/sparsevector.jl	2020-03-21 16:36:32.000000000 +0000
@@ -32,30 +32,29 @@ SparseVector(n::Integer, nzind::Vector{T
 
 # Define an alias for a view of a whole column of a SparseMatrixCSC. Many methods can be written for the
 # union of such a view and a SparseVector so we define an alias for such a union as well
-const SparseColumnView{T}  = SubArray{T,1,<:SparseMatrixCSC,Tuple{Base.Slice{Base.OneTo{Int}},Int},false}
+const SparseColumnView{T}  = SubArray{T,1,<:AbstractSparseMatrixCSC,Tuple{Base.Slice{Base.OneTo{Int}},Int},false}
 const SparseVectorUnion{T} = Union{SparseVector{T}, SparseColumnView{T}}
 const AdjOrTransSparseVectorUnion{T} = LinearAlgebra.AdjOrTrans{T, <:SparseVectorUnion{T}}
 
 ### Basic properties
 
-length(x::SparseVector)   = x.n
-size(x::SparseVector)     = (x.n,)
-nnz(x::SparseVector)      = length(x.nzval)
-count(f, x::SparseVector) = count(f, x.nzval) + f(zero(eltype(x)))*(length(x) - nnz(x))
+size(x::SparseVector)     = (getfield(x, :n),)
+nnz(x::SparseVector)      = length(nonzeros(x))
+count(f, x::SparseVector) = count(f, nonzeros(x)) + f(zero(eltype(x)))*(length(x) - nnz(x))
 
-nonzeros(x::SparseVector) = x.nzval
+nonzeros(x::SparseVector) = getfield(x, :nzval)
 function nonzeros(x::SparseColumnView)
     rowidx, colidx = parentindices(x)
     A = parent(x)
-    @inbounds y = view(A.nzval, nzrange(A, colidx))
+    @inbounds y = view(nonzeros(A), nzrange(A, colidx))
     return y
 end
 
-nonzeroinds(x::SparseVector) = x.nzind
+nonzeroinds(x::SparseVector) = getfield(x, :nzind)
 function nonzeroinds(x::SparseColumnView)
     rowidx, colidx = parentindices(x)
     A = parent(x)
-    @inbounds y = view(A.rowval, nzrange(A, colidx))
+    @inbounds y = view(rowvals(A), nzrange(A, colidx))
     return y
 end
 
@@ -69,13 +68,13 @@ end
 #
 # parent method for similar that preserves stored-entry structure (for when new and old dims match)
 _sparsesimilar(S::SparseVector, ::Type{TvNew}, ::Type{TiNew}) where {TvNew,TiNew} =
-    SparseVector(S.n, copyto!(similar(S.nzind, TiNew), S.nzind), similar(S.nzval, TvNew))
+    SparseVector(length(S), copyto!(similar(nonzeroinds(S), TiNew), nonzeroinds(S)), similar(nonzeros(S), TvNew))
 # parent method for similar that preserves nothing (for when old and new dims differ, and new is 1d)
 _sparsesimilar(S::SparseVector, ::Type{TvNew}, ::Type{TiNew}, dims::Dims{1}) where {TvNew,TiNew} =
-    SparseVector(dims..., similar(S.nzind, TiNew, 0), similar(S.nzval, TvNew, 0))
+    SparseVector(dims..., similar(nonzeroinds(S), TiNew, 0), similar(nonzeros(S), TvNew, 0))
 # parent method for similar that preserves storage space (for old and new dims differ, and new is 2d)
 _sparsesimilar(S::SparseVector, ::Type{TvNew}, ::Type{TiNew}, dims::Dims{2}) where {TvNew,TiNew} =
-    SparseMatrixCSC(dims..., fill(one(TiNew), last(dims)+1), similar(S.nzind, TiNew), similar(S.nzval, TvNew))
+    SparseMatrixCSC(dims..., fill(one(TiNew), last(dims)+1), similar(nonzeroinds(S), TiNew), similar(nonzeros(S), TvNew))
 # The following methods hook into the AbstractArray similar hierarchy. The first method
 # covers similar(A[, Tv]) calls, which preserve stored-entry structure, and the latter
 # methods cover similar(A[, Tv], shape...) calls, which preserve nothing if the dims
@@ -100,8 +99,8 @@ similar(S::SparseVector, ::Type{TvNew},
 
 ## Alias detection and prevention
 using Base: dataids, unaliascopy
-Base.dataids(S::SparseVector) = (dataids(S.nzind)..., dataids(S.nzval)...)
-Base.unaliascopy(S::SparseVector) = typeof(S)(S.n, unaliascopy(S.nzind), unaliascopy(S.nzval))
+Base.dataids(S::SparseVector) = (dataids(nonzeroinds(S))..., dataids(nonzeros(S))...)
+Base.unaliascopy(S::SparseVector) = typeof(S)(length(S), unaliascopy(nonzeroinds(S)), unaliascopy(nonzeros(S)))
 
 ### Construct empty sparse vector
 
@@ -109,7 +108,7 @@ spzeros(len::Integer) = spzeros(Float64,
 spzeros(::Type{T}, len::Integer) where {T} = SparseVector(len, Int[], T[])
 spzeros(::Type{Tv}, ::Type{Ti}, len::Integer) where {Tv,Ti<:Integer} = SparseVector(len, Ti[], Tv[])
 
-LinearAlgebra.fillstored!(x::SparseVector, y) = (fill!(x.nzval, y); x)
+LinearAlgebra.fillstored!(x::SparseVector, y) = (fill!(nonzeros(x), y); x)
 
 ### Construction from lists of indices and values
 
@@ -335,14 +334,14 @@ julia> SparseArrays.dropstored!(x, 2)
 ```
 """
 function dropstored!(x::SparseVector, i::Integer)
-    if !(1 <= i <= x.n)
+    if !(1 <= i <= length(x::SparseVector))
         throw(BoundsError(x, i))
     end
-    searchk = searchsortedfirst(x.nzind, i)
-    if searchk <= length(x.nzind) && x.nzind[searchk] == i
+    searchk = searchsortedfirst(nonzeroinds(x), i)
+    if searchk <= length(nonzeroinds(x)) && nonzeroinds(x)[searchk] == i
         # Entry x[i] is stored. Drop and return.
-        deleteat!(x.nzind, searchk)
-        deleteat!(x.nzval, searchk)
+        deleteat!(nonzeroinds(x), searchk)
+        deleteat!(nonzeros(x), searchk)
     end
     return x
 end
@@ -353,14 +352,14 @@ end
 ### Conversion
 
 # convert SparseMatrixCSC to SparseVector
-function SparseVector{Tv,Ti}(s::SparseMatrixCSC{Tv,Ti}) where {Tv,Ti<:Integer}
+function SparseVector{Tv,Ti}(s::AbstractSparseMatrixCSC{Tv,Ti}) where {Tv,Ti<:Integer}
     size(s, 2) == 1 || throw(ArgumentError("The input argument must have a single-column."))
-    SparseVector(s.m, s.rowval, s.nzval)
+    SparseVector(size(s, 1), rowvals(s), nonzeros(s))
 end
 
-SparseVector{Tv}(s::SparseMatrixCSC{Tv,Ti}) where {Tv,Ti} = SparseVector{Tv,Ti}(s)
+SparseVector{Tv}(s::AbstractSparseMatrixCSC{Tv,Ti}) where {Tv,Ti} = SparseVector{Tv,Ti}(s)
 
-SparseVector(s::SparseMatrixCSC{Tv,Ti}) where {Tv,Ti} = SparseVector{Tv,Ti}(s)
+SparseVector(s::AbstractSparseMatrixCSC{Tv,Ti}) where {Tv,Ti} = SparseVector{Tv,Ti}(s)
 
 # convert Vector to SparseVector
 
@@ -427,15 +426,15 @@ SparseVector(s::AbstractVector{Tv}) wher
 SparseVector{Tv}(s::SparseVector{Tv}) where {Tv} = s
 SparseVector{Tv,Ti}(s::SparseVector{Tv,Ti}) where {Tv,Ti} = s
 SparseVector{Tv,Ti}(s::SparseVector) where {Tv,Ti} =
-    SparseVector{Tv,Ti}(s.n, convert(Vector{Ti}, s.nzind), convert(Vector{Tv}, s.nzval))
+    SparseVector{Tv,Ti}(length(s::SparseVector), convert(Vector{Ti}, nonzeroinds(s)), convert(Vector{Tv}, nonzeros(s)))
 
 SparseVector{Tv}(s::SparseVector{<:Any,Ti}) where {Tv,Ti} =
-    SparseVector{Tv,Ti}(s.n, s.nzind, convert(Vector{Tv}, s.nzval))
+    SparseVector{Tv,Ti}(length(s::SparseVector), nonzeroinds(s), convert(Vector{Tv}, nonzeros(s)))
 
 convert(T::Type{<:SparseVector}, m::AbstractVector) = m isa T ? m : T(m)
 
-convert(T::Type{<:SparseVector}, m::SparseMatrixCSC) = T(m)
-convert(T::Type{<:SparseMatrixCSC}, v::SparseVector) = T(v)
+convert(T::Type{<:SparseVector}, m::AbstractSparseMatrixCSC) = T(m)
+convert(T::Type{<:AbstractSparseMatrixCSC}, v::SparseVector) = T(v)
 
 ### copying
 function prep_sparsevec_copy_dest!(A::SparseVector, lB, nnzB)
@@ -443,54 +442,54 @@ function prep_sparsevec_copy_dest!(A::Sp
     lA >= lB || throw(BoundsError())
     # If the two vectors have the same length then all the elements in A will be overwritten.
     if length(A) == lB
-        resize!(A.nzval, nnzB)
-        resize!(A.nzind, nnzB)
+        resize!(nonzeros(A), nnzB)
+        resize!(nonzeroinds(A), nnzB)
     else
         nnzA = nnz(A)
 
-        lastmodindA = searchsortedlast(A.nzind, lB)
+        lastmodindA = searchsortedlast(nonzeroinds(A), lB)
         if lastmodindA >= nnzB
             # A will have fewer non-zero elements; unmodified elements are kept at the end.
-            deleteat!(A.nzind, nnzB+1:lastmodindA)
-            deleteat!(A.nzval, nnzB+1:lastmodindA)
+            deleteat!(nonzeroinds(A), nnzB+1:lastmodindA)
+            deleteat!(nonzeros(A), nnzB+1:lastmodindA)
         else
             # A will have more non-zero elements; unmodified elements are kept at the end.
-            resize!(A.nzind, nnzB + nnzA - lastmodindA)
-            resize!(A.nzval, nnzB + nnzA - lastmodindA)
-            copyto!(A.nzind, nnzB+1, A.nzind, lastmodindA+1, nnzA-lastmodindA)
-            copyto!(A.nzval, nnzB+1, A.nzval, lastmodindA+1, nnzA-lastmodindA)
+            resize!(nonzeroinds(A), nnzB + nnzA - lastmodindA)
+            resize!(nonzeros(A), nnzB + nnzA - lastmodindA)
+            copyto!(nonzeroinds(A), nnzB+1, nonzeroinds(A), lastmodindA+1, nnzA-lastmodindA)
+            copyto!(nonzeros(A), nnzB+1, nonzeros(A), lastmodindA+1, nnzA-lastmodindA)
         end
     end
 end
 
 function copyto!(A::SparseVector, B::SparseVector)
     prep_sparsevec_copy_dest!(A, length(B), nnz(B))
-    copyto!(A.nzind, B.nzind)
-    copyto!(A.nzval, B.nzval)
+    copyto!(nonzeroinds(A), nonzeroinds(B))
+    copyto!(nonzeros(A), nonzeros(B))
     return A
 end
 
 copyto!(A::SparseVector, B::AbstractVector) = copyto!(A, sparsevec(B))
 
-function copyto!(A::SparseVector, B::SparseMatrixCSC)
+function copyto!(A::SparseVector, B::AbstractSparseMatrixCSC)
     prep_sparsevec_copy_dest!(A, length(B), nnz(B))
 
     ptr = 1
-    @assert length(A.nzind) >= length(B.rowval)
-    maximum(B.colptr)-1 <= length(B.rowval) || throw(BoundsError())
-    @inbounds for col=1:length(B.colptr)-1
-        offsetA = (col - 1) * B.m
-        while ptr <= B.colptr[col+1]-1
-            A.nzind[ptr] = B.rowval[ptr] + offsetA
+    @assert length(nonzeroinds(A)) >= length(rowvals(B))
+    maximum(getcolptr(B))-1 <= length(rowvals(B)) || throw(BoundsError())
+    @inbounds for col=1:length(getcolptr(B))-1
+        offsetA = (col - 1) * size(B, 1)
+        while ptr <= getcolptr(B)[col+1]-1
+            nonzeroinds(A)[ptr] = rowvals(B)[ptr] + offsetA
             ptr += 1
         end
     end
-    copyto!(A.nzval, B.nzval)
+    copyto!(nonzeros(A), nonzeros(B))
     return A
 end
 
-copyto!(A::SparseMatrixCSC, B::SparseVector{TvB,TiB}) where {TvB,TiB} =
-    copyto!(A, SparseMatrixCSC{TvB,TiB}(B.n, 1, TiB[1, length(B.nzind)+1], B.nzind, B.nzval))
+copyto!(A::AbstractSparseMatrixCSC, B::SparseVector{TvB,TiB}) where {TvB,TiB} =
+    copyto!(A, SparseMatrixCSC{TvB,TiB}(length(B), 1, TiB[1, length(nonzeroinds(B))+1], nonzeroinds(B), nonzeros(B)))
 
 
 ### Rand Construction
@@ -523,37 +522,37 @@ sprandn(r::AbstractRNG, ::Type{T}, n::In
 ## Indexing into Matrices can return SparseVectors
 
 # Column slices
-function getindex(x::SparseMatrixCSC, ::Colon, j::Integer)
+function getindex(x::AbstractSparseMatrixCSC, ::Colon, j::Integer)
     checkbounds(x, :, j)
-    r1 = convert(Int, x.colptr[j])
-    r2 = convert(Int, x.colptr[j+1]) - 1
-    SparseVector(x.m, x.rowval[r1:r2], x.nzval[r1:r2])
+    r1 = convert(Int, getcolptr(x)[j])
+    r2 = convert(Int, getcolptr(x)[j+1]) - 1
+    SparseVector(size(x, 1), rowvals(x)[r1:r2], nonzeros(x)[r1:r2])
 end
 
-function getindex(x::SparseMatrixCSC, I::AbstractUnitRange, j::Integer)
+function getindex(x::AbstractSparseMatrixCSC, I::AbstractUnitRange, j::Integer)
     checkbounds(x, I, j)
     # Get the selected column
-    c1 = convert(Int, x.colptr[j])
-    c2 = convert(Int, x.colptr[j+1]) - 1
+    c1 = convert(Int, getcolptr(x)[j])
+    c2 = convert(Int, getcolptr(x)[j+1]) - 1
     # Restrict to the selected rows
-    r1 = searchsortedfirst(x.rowval, first(I), c1, c2, Forward)
-    r2 = searchsortedlast(x.rowval, last(I), c1, c2, Forward)
-    SparseVector(length(I), [x.rowval[i] - first(I) + 1 for i = r1:r2], x.nzval[r1:r2])
+    r1 = searchsortedfirst(rowvals(x), first(I), c1, c2, Forward)
+    r2 = searchsortedlast(rowvals(x), last(I), c1, c2, Forward)
+    SparseVector(length(I), [rowvals(x)[i] - first(I) + 1 for i = r1:r2], nonzeros(x)[r1:r2])
 end
 
 # In the general case, we piggy back upon SparseMatrixCSC's optimized solution
-@inline function getindex(A::SparseMatrixCSC, I::AbstractVector, J::Integer)
+@inline function getindex(A::AbstractSparseMatrixCSC, I::AbstractVector, J::Integer)
     M = A[I, [J]]
-    SparseVector(M.m, M.rowval, M.nzval)
+    SparseVector(size(M, 1), rowvals(M), nonzeros(M))
 end
 
 # Row slices
-getindex(A::SparseMatrixCSC, i::Integer, ::Colon) = A[i, 1:end]
-function Base.getindex(A::SparseMatrixCSC{Tv,Ti}, i::Integer, J::AbstractVector) where {Tv,Ti}
+getindex(A::AbstractSparseMatrixCSC, i::Integer, ::Colon) = A[i, 1:end]
+function Base.getindex(A::AbstractSparseMatrixCSC{Tv,Ti}, i::Integer, J::AbstractVector) where {Tv,Ti}
     require_one_based_indexing(A, J)
     checkbounds(A, i, J)
     nJ = length(J)
-    colptrA = A.colptr; rowvalA = A.rowval; nzvalA = A.nzval
+    colptrA = getcolptr(A); rowvalA = rowvals(A); nzvalA = nonzeros(A)
 
     nzinds = Vector{Ti}()
     nzvals = Vector{Tv}()
@@ -581,25 +580,25 @@ end
 
 
 # Logical and linear indexing into SparseMatrices
-getindex(A::SparseMatrixCSC, I::AbstractVector{Bool}) = _logical_index(A, I) # Ambiguities
-getindex(A::SparseMatrixCSC, I::AbstractArray{Bool}) = _logical_index(A, I)
-function _logical_index(A::SparseMatrixCSC{Tv}, I::AbstractArray{Bool}) where Tv
+getindex(A::AbstractSparseMatrixCSC, I::AbstractVector{Bool}) = _logical_index(A, I) # Ambiguities
+getindex(A::AbstractSparseMatrixCSC, I::AbstractArray{Bool}) = _logical_index(A, I)
+function _logical_index(A::AbstractSparseMatrixCSC{Tv}, I::AbstractArray{Bool}) where Tv
     require_one_based_indexing(A, I)
     checkbounds(A, I)
     n = sum(I)
     nnzB = min(n, nnz(A))
 
-    colptrA = A.colptr; rowvalA = A.rowval; nzvalA = A.nzval
+    colptrA = getcolptr(A); rowvalA = rowvals(A); nzvalA = nonzeros(A)
     rowvalB = Vector{Int}(undef, nnzB)
     nzvalB = Vector{Tv}(undef, nnzB)
     c = 1
     rowB = 1
 
-    @inbounds for col in 1:A.n
+    @inbounds for col in 1:size(A, 2)
         r1 = colptrA[col]
         r2 = colptrA[col+1]-1
 
-        for row in 1:A.m
+        for row in 1:size(A, 1)
             if I[row, col]
                 while (r1 <= r2) && (rowvalA[r1] < row)
                     r1 += 1
@@ -623,16 +622,16 @@ function _logical_index(A::SparseMatrixC
 end
 
 # TODO: further optimizations are available for ::Colon and other types of AbstractRange
-getindex(A::SparseMatrixCSC, ::Colon) = A[1:end]
+getindex(A::AbstractSparseMatrixCSC, ::Colon) = A[1:end]
 
-function getindex(A::SparseMatrixCSC{Tv}, I::AbstractUnitRange) where Tv
+function getindex(A::AbstractSparseMatrixCSC{Tv}, I::AbstractUnitRange) where Tv
     require_one_based_indexing(A, I)
     checkbounds(A, I)
     szA = size(A)
     nA = szA[1]*szA[2]
-    colptrA = A.colptr
-    rowvalA = A.rowval
-    nzvalA = A.nzval
+    colptrA = getcolptr(A)
+    rowvalA = rowvals(A)
+    nzvalA = nonzeros(A)
 
     n = length(I)
     nnzB = min(n, nnz(A))
@@ -662,13 +661,14 @@ function getindex(A::SparseMatrixCSC{Tv}
     SparseVector(n, rowvalB, nzvalB)
 end
 
-function getindex(A::SparseMatrixCSC{Tv,Ti}, I::AbstractVector) where {Tv,Ti}
+function getindex(A::AbstractSparseMatrixCSC{Tv,Ti}, I::AbstractVector) where {Tv,Ti}
     require_one_based_indexing(A, I)
+    @boundscheck checkbounds(A, I)
     szA = size(A)
     nA = szA[1]*szA[2]
-    colptrA = A.colptr
-    rowvalA = A.rowval
-    nzvalA = A.nzval
+    colptrA = getcolptr(A)
+    rowvalA = rowvals(A)
+    nzvalA = nonzeros(A)
 
     n = length(I)
     nnzB = min(n, nnz(A))
@@ -677,7 +677,6 @@ function getindex(A::SparseMatrixCSC{Tv,
 
     idxB = 1
     for i in 1:n
-        ((I[i] < 1) | (I[i] > nA)) && throw(BoundsError(A, I))
         row,col = Base._ind2sub(szA, I[i])
         for r in colptrA[col]:(colptrA[col+1]-1)
             @inbounds if rowvalA[r] == row
@@ -700,7 +699,7 @@ function getindex(A::SparseMatrixCSC{Tv,
     SparseVector(n, rowvalB, nzvalB)
 end
 
-Base.copy(a::SubArray{<:Any,<:Any,<:Union{SparseVector, SparseMatrixCSC}}) = a.parent[a.indices...]
+Base.copy(a::SubArray{<:Any,<:Any,<:Union{SparseVector, AbstractSparseMatrixCSC}}) = a.parent[a.indices...]
 
 function findall(x::SparseVector)
     return findall(identity, x)
@@ -713,8 +712,8 @@ function findall(p::Function, x::SparseV
     numnz = nnz(x)
     I = Vector{Ti}(undef, numnz)
 
-    nzind = x.nzind
-    nzval = x.nzval
+    nzind = nonzeroinds(x)
+    nzval = nonzeros(x)
 
     count = 1
     @inbounds for i = 1 : numnz
@@ -740,8 +739,8 @@ function findnz(x::SparseVector{Tv,Ti})
     I = Vector{Ti}(undef, numnz)
     V = Vector{Tv}(undef, numnz)
 
-    nzind = x.nzind
-    nzval = x.nzval
+    nzind = nonzeroinds(x)
+    nzval = nonzeros(x)
 
     @inbounds for i = 1 : numnz
         I[i] = nzind[i]
@@ -752,20 +751,20 @@ function findnz(x::SparseVector{Tv,Ti})
 end
 
 function _sparse_findnextnz(v::SparseVector, i::Integer)
-    n = searchsortedfirst(v.nzind, i)
-    if n > length(v.nzind)
+    n = searchsortedfirst(nonzeroinds(v), i)
+    if n > length(nonzeroinds(v))
         return nothing
     else
-        return v.nzind[n]
+        return nonzeroinds(v)[n]
     end
 end
 
 function _sparse_findprevnz(v::SparseVector, i::Integer)
-    n = searchsortedlast(v.nzind, i)
+    n = searchsortedlast(nonzeroinds(v), i)
     if iszero(n)
         return nothing
     else
-        return v.nzind[n]
+        return nonzeroinds(v)[n]
     end
 end
 
@@ -818,13 +817,13 @@ getindex(x::AbstractSparseVector, I::Abs
 getindex(x::AbstractSparseVector, I::AbstractArray{Bool}) = x[findall(I)]
 @inline function getindex(x::AbstractSparseVector{Tv,Ti}, I::AbstractVector) where {Tv,Ti}
     # SparseMatrixCSC has a nicely optimized routine for this; punt
-    S = SparseMatrixCSC(x.n, 1, Ti[1,length(x.nzind)+1], x.nzind, x.nzval)
+    S = SparseMatrixCSC(length(x::SparseVector), 1, Ti[1,length(nonzeroinds(x))+1], nonzeroinds(x), nonzeros(x))
     S[I, 1]
 end
 
 function getindex(x::AbstractSparseVector{Tv,Ti}, I::AbstractArray) where {Tv,Ti}
     # punt to SparseMatrixCSC
-    S = SparseMatrixCSC(x.n, 1, Ti[1,length(x.nzind)+1], x.nzind, x.nzval)
+    S = SparseMatrixCSC(length(x::SparseVector), 1, Ti[1,length(nonzeroinds(x))+1], nonzeroinds(x), nonzeros(x))
     S[I]
 end
 
@@ -1017,7 +1016,7 @@ vcat(X::Union{Vector,SparseVector}...) =
 
 # TODO: A definition similar to the third exists in base/linalg/bidiag.jl. These definitions
 # should be consolidated in a more appropriate location, e.g. base/linalg/special.jl.
-const _SparseArrays = Union{SparseVector, SparseMatrixCSC, Adjoint{<:Any,<:SparseVector}, Transpose{<:Any,<:SparseVector}}
+const _SparseArrays = Union{SparseVector, AbstractSparseMatrixCSC, Adjoint{<:Any,<:SparseVector}, Transpose{<:Any,<:SparseVector}}
 const _SpecialArrays = Union{Diagonal, Bidiagonal, Tridiagonal, SymTridiagonal}
 const _SparseConcatArrays = Union{_SpecialArrays, _SparseArrays}
 
@@ -1439,7 +1438,7 @@ function _spdot(f::Function,
                 xj::Int, xj_last::Int, xnzind, xnzval,
                 yj::Int, yj_last::Int, ynzind, ynzval)
     # dot product between ranges of non-zeros,
-    s = zero(eltype(xnzval)) * zero(eltype(ynzval))
+    s = f(zero(eltype(xnzval)), zero(eltype(ynzval)))
     @inbounds while xj <= xj_last && yj <= yj_last
         ix = xnzind[xj]
         iy = ynzind[yj]
@@ -1490,19 +1489,21 @@ end
 
 # * and mul!
 
-function (*)(A::StridedMatrix{Ta}, x::AbstractSparseVector{Tx}) where {Ta,Tx}
+const _StridedOrTriangularMatrix{T} = Union{StridedMatrix{T}, LowerTriangular{T}, UnitLowerTriangular{T}, UpperTriangular{T}, UnitUpperTriangular{T}}
+
+function (*)(A::_StridedOrTriangularMatrix{Ta}, x::AbstractSparseVector{Tx}) where {Ta,Tx}
     require_one_based_indexing(A, x)
     m, n = size(A)
     length(x) == n || throw(DimensionMismatch())
-    Ty = promote_op(matprod, Ta, Tx)
+    Ty = promote_op(matprod, eltype(A), eltype(x))
     y = Vector{Ty}(undef, m)
     mul!(y, A, x)
 end
 
-mul!(y::AbstractVector{Ty}, A::StridedMatrix, x::AbstractSparseVector{Tx}) where {Tx,Ty} =
-    mul!(y, A, x, one(Tx), zero(Ty))
+mul!(y::AbstractVector{Ty}, A::_StridedOrTriangularMatrix, x::AbstractSparseVector{Tx}) where {Tx,Ty} =
+    mul!(y, A, x, true, false)
 
-function mul!(y::AbstractVector, A::StridedMatrix, x::AbstractSparseVector, α::Number, β::Number)
+function mul!(y::AbstractVector, A::_StridedOrTriangularMatrix, x::AbstractSparseVector, α::Number, β::Number)
     require_one_based_indexing(y, A, x)
     m, n = size(A)
     length(x) == n && length(y) == m || throw(DimensionMismatch())
@@ -1529,19 +1530,19 @@ end
 
 # * and mul!(C, transpose(A), B)
 
-function *(transA::Transpose{<:Any,<:StridedMatrix{Ta}}, x::AbstractSparseVector{Tx}) where {Ta,Tx}
+function *(transA::Transpose{<:Any,<:_StridedOrTriangularMatrix{Ta}}, x::AbstractSparseVector{Tx}) where {Ta,Tx}
     require_one_based_indexing(transA, x)
     m, n = size(transA)
     length(x) == n || throw(DimensionMismatch())
-    Ty = promote_op(matprod, Ta, Tx)
+    Ty = promote_op(matprod, eltype(transA), eltype(x))
     y = Vector{Ty}(undef, m)
     mul!(y, transA, x)
 end
 
-mul!(y::AbstractVector{Ty}, transA::Transpose{<:Any,<:StridedMatrix}, x::AbstractSparseVector{Tx}) where {Tx,Ty} =
-    mul!(y, transA, x, one(Tx), zero(Ty))
+mul!(y::AbstractVector{Ty}, transA::Transpose{<:Any,<:_StridedOrTriangularMatrix}, x::AbstractSparseVector{Tx}) where {Tx,Ty} =
+    mul!(y, transA, x, true, false)
 
-function mul!(y::AbstractVector, transA::Transpose{<:Any,<:StridedMatrix}, x::AbstractSparseVector, α::Number, β::Number)
+function mul!(y::AbstractVector, transA::Transpose{<:Any,<:_StridedOrTriangularMatrix}, x::AbstractSparseVector, α::Number, β::Number)
     require_one_based_indexing(y, transA, x)
     m, n = size(transA)
     length(x) == n && length(y) == m || throw(DimensionMismatch())
@@ -1570,19 +1571,19 @@ end
 
 # * and mul!(C, adjoint(A), B)
 
-function *(adjA::Adjoint{<:Any,<:StridedMatrix{Ta}}, x::AbstractSparseVector{Tx}) where {Ta,Tx}
+function *(adjA::Adjoint{<:Any,<:_StridedOrTriangularMatrix{Ta}}, x::AbstractSparseVector{Tx}) where {Ta,Tx}
     require_one_based_indexing(adjA, x)
     m, n = size(adjA)
     length(x) == n || throw(DimensionMismatch())
-    Ty = promote_op(matprod, Ta, Tx)
+    Ty = promote_op(matprod, eltype(adjA), eltype(x))
     y = Vector{Ty}(undef, m)
     mul!(y, adjA, x)
 end
 
-mul!(y::AbstractVector{Ty}, adjA::Adjoint{<:Any,<:StridedMatrix}, x::AbstractSparseVector{Tx}) where {Tx,Ty} =
-    mul!(y, adjA, x, one(Tx), zero(Ty))
+mul!(y::AbstractVector{Ty}, adjA::Adjoint{<:Any,<:_StridedOrTriangularMatrix}, x::AbstractSparseVector{Tx}) where {Tx,Ty} =
+    mul!(y, adjA, x, true, false)
 
-function mul!(y::AbstractVector, adjA::Adjoint{<:Any,<:StridedMatrix}, x::AbstractSparseVector, α::Number, β::Number)
+function mul!(y::AbstractVector, adjA::Adjoint{<:Any,<:_StridedOrTriangularMatrix}, x::AbstractSparseVector, α::Number, β::Number)
     require_one_based_indexing(y, adjA, x)
     m, n = size(adjA)
     length(x) == n && length(y) == m || throw(DimensionMismatch())
@@ -1612,7 +1613,7 @@ end
 
 ### BLAS-2 / sparse A * sparse x -> dense y
 
-function densemv(A::SparseMatrixCSC, x::AbstractSparseVector; trans::AbstractChar='N')
+function densemv(A::AbstractSparseMatrixCSC, x::AbstractSparseVector; trans::AbstractChar='N')
     local xlen::Int, ylen::Int
     require_one_based_indexing(A, x)
     m, n = size(A)
@@ -1640,10 +1641,10 @@ end
 
 # * and mul!
 
-mul!(y::AbstractVector{Ty}, A::SparseMatrixCSC, x::AbstractSparseVector{Tx}) where {Tx,Ty} =
-    mul!(y, A, x, one(Tx), zero(Ty))
+mul!(y::AbstractVector{Ty}, A::AbstractSparseMatrixCSC, x::AbstractSparseVector{Tx}) where {Tx,Ty} =
+    mul!(y, A, x, true, false)
 
-function mul!(y::AbstractVector, A::SparseMatrixCSC, x::AbstractSparseVector, α::Number, β::Number)
+function mul!(y::AbstractVector, A::AbstractSparseMatrixCSC, x::AbstractSparseVector, α::Number, β::Number)
     require_one_based_indexing(y, A, x)
     m, n = size(A)
     length(x) == n && length(y) == m || throw(DimensionMismatch())
@@ -1655,9 +1656,9 @@ function mul!(y::AbstractVector, A::Spar
 
     xnzind = nonzeroinds(x)
     xnzval = nonzeros(x)
-    Acolptr = A.colptr
-    Arowval = A.rowval
-    Anzval = A.nzval
+    Acolptr = getcolptr(A)
+    Arowval = rowvals(A)
+    Anzval = nonzeros(A)
 
     @inbounds for i = 1:length(xnzind)
         v = xnzval[i]
@@ -1674,20 +1675,20 @@ end
 
 # * and *(Tranpose(A), B)
 
-mul!(y::AbstractVector{Ty}, transA::Transpose{<:Any,<:SparseMatrixCSC}, x::AbstractSparseVector{Tx}) where {Tx,Ty} =
-    (A = transA.parent; mul!(y, transpose(A), x, one(Tx), zero(Ty)))
+mul!(y::AbstractVector{Ty}, transA::Transpose{<:Any,<:AbstractSparseMatrixCSC}, x::AbstractSparseVector{Tx}) where {Tx,Ty} =
+    (A = transA.parent; mul!(y, transpose(A), x, true, false))
 
-mul!(y::AbstractVector, transA::Transpose{<:Any,<:SparseMatrixCSC}, x::AbstractSparseVector, α::Number, β::Number) =
-    (A = transA.parent; _At_or_Ac_mul_B!(*, y, A, x, α, β))
+mul!(y::AbstractVector, transA::Transpose{<:Any,<:AbstractSparseMatrixCSC}, x::AbstractSparseVector, α::Number, β::Number) =
+    (A = transA.parent; _At_or_Ac_mul_B!((a,b) -> transpose(a) * b, y, A, x, α, β))
 
-mul!(y::AbstractVector{Ty}, adjA::Adjoint{<:Any,<:SparseMatrixCSC}, x::AbstractSparseVector{Tx}) where {Tx,Ty} =
-    (A = adjA.parent; mul!(y, adjoint(A), x, one(Tx), zero(Ty)))
+mul!(y::AbstractVector{Ty}, adjA::Adjoint{<:Any,<:AbstractSparseMatrixCSC}, x::AbstractSparseVector{Tx}) where {Tx,Ty} =
+    (A = adjA.parent; mul!(y, adjoint(A), x, true, false))
 
-mul!(y::AbstractVector, adjA::Adjoint{<:Any,<:SparseMatrixCSC}, x::AbstractSparseVector, α::Number, β::Number) =
-    (A = adjA.parent; _At_or_Ac_mul_B!(dot, y, A, x, α, β))
+mul!(y::AbstractVector, adjA::Adjoint{<:Any,<:AbstractSparseMatrixCSC}, x::AbstractSparseVector, α::Number, β::Number) =
+    (A = adjA.parent; _At_or_Ac_mul_B!((a,b) -> adjoint(a) * b, y, A, x, α, β))
 
 function _At_or_Ac_mul_B!(tfun::Function,
-                          y::AbstractVector, A::SparseMatrixCSC, x::AbstractSparseVector,
+                          y::AbstractVector, A::AbstractSparseMatrixCSC, x::AbstractSparseVector,
                           α::Number, β::Number)
     require_one_based_indexing(y, A, x)
     m, n = size(A)
@@ -1700,9 +1701,9 @@ function _At_or_Ac_mul_B!(tfun::Function
 
     xnzind = nonzeroinds(x)
     xnzval = nonzeros(x)
-    Acolptr = A.colptr
-    Arowval = A.rowval
-    Anzval = A.nzval
+    Acolptr = getcolptr(A)
+    Arowval = rowvals(A)
+    Anzval = nonzeros(A)
     mx = length(xnzind)
 
     for j = 1:n
@@ -1717,31 +1718,31 @@ end
 
 ### BLAS-2 / sparse A * sparse x -> dense y
 
-function *(A::SparseMatrixCSC, x::AbstractSparseVector)
+function *(A::AbstractSparseMatrixCSC, x::AbstractSparseVector)
     require_one_based_indexing(A, x)
     y = densemv(A, x)
     initcap = min(nnz(A), size(A,1))
     _dense2sparsevec(y, initcap)
 end
 
-*(transA::Transpose{<:Any,<:SparseMatrixCSC}, x::AbstractSparseVector) =
-    (A = transA.parent; _At_or_Ac_mul_B(*, A, x))
+*(transA::Transpose{<:Any,<:AbstractSparseMatrixCSC}, x::AbstractSparseVector) =
+    (A = transA.parent; _At_or_Ac_mul_B((a,b) -> transpose(a) * b, A, x, promote_op(matprod, eltype(transA), eltype(x))))
 
-*(adjA::Adjoint{<:Any,<:SparseMatrixCSC}, x::AbstractSparseVector) =
-    (A = adjA.parent; _At_or_Ac_mul_B(dot, A, x))
+*(adjA::Adjoint{<:Any,<:AbstractSparseMatrixCSC}, x::AbstractSparseVector) =
+    (A = adjA.parent; _At_or_Ac_mul_B((a,b) -> adjoint(a) * b, A, x, promote_op(matprod, eltype(adjA), eltype(x))))
 
-function _At_or_Ac_mul_B(tfun::Function, A::SparseMatrixCSC{TvA,TiA}, x::AbstractSparseVector{TvX,TiX}) where {TvA,TiA,TvX,TiX}
+function _At_or_Ac_mul_B(tfun::Function, A::AbstractSparseMatrixCSC{TvA,TiA}, x::AbstractSparseVector{TvX,TiX},
+                         Tv = promote_op(matprod, TvA, TvX)) where {TvA,TiA,TvX,TiX}
     require_one_based_indexing(A, x)
     m, n = size(A)
     length(x) == m || throw(DimensionMismatch())
-    Tv = promote_op(matprod, TvA, TvX)
     Ti = promote_type(TiA, TiX)
 
     xnzind = nonzeroinds(x)
     xnzval = nonzeros(x)
-    Acolptr = A.colptr
-    Arowval = A.rowval
-    Anzval = A.nzval
+    Acolptr = getcolptr(A)
+    Arowval = rowvals(A)
+    Anzval = nonzeros(A)
     mx = length(xnzind)
 
     ynzind = Vector{Ti}(undef, n)
@@ -1806,8 +1807,8 @@ for isunittri in (true, false), islowert
             # operate on solely b[nzrange] for efficiency.
             if nnz(b) != 0
                 nzrange = $( (islowertri && !istrans) || (!islowertri && istrans) ?
-                    :(b.nzind[1]:b.n) :
-                    :(1:b.nzind[end]) )
+                    :(nonzeroinds(b)[1]:length(b::SparseVector)) :
+                    :(1:nonzeroinds(b)[end]) )
                 nzrangeviewr = view(r, nzrange)
                 nzrangeviewA = $tritype(view(A.data, nzrange, nzrange))
                 LinearAlgebra.ldiv!($xformop(convert(AbstractArray{TAb}, nzrangeviewA)), nzrangeviewr)
@@ -1849,9 +1850,9 @@ for isunittri in (true, false), islowert
                 # furthermore we operate on that section as a dense vector
                 # such that dispatch has a chance to exploit, e.g., tuned BLAS
                 nzrange = $( (islowertri && !istrans) || (!islowertri && istrans) ?
-                    :(b.nzind[1]:b.n) :
-                    :(1:b.nzind[end]) )
-                nzrangeviewbnz = view(b.nzval, nzrange .- (b.nzind[1] - 1))
+                    :(nonzeroinds(b)[1]:length(b::SparseVector)) :
+                    :(1:nonzeroinds(b)[end]) )
+                nzrangeviewbnz = view(nonzeros(b), nzrange .- (nonzeroinds(b)[1] - 1))
                 nzrangeviewA = $tritype(view(A.data, nzrange, nzrange))
                 LinearAlgebra.ldiv!($xformop(nzrangeviewA), nzrangeviewbnz)
             end
@@ -1861,50 +1862,50 @@ for isunittri in (true, false), islowert
 end
 
 # helper functions for in-place matrix division operations defined above
-"Densifies `x::SparseVector` from its first nonzero (`x[x.nzind[1]]`) through its end (`x[x.n]`)."
+"Densifies `x::SparseVector` from its first nonzero (`x[nonzeroinds(x)[1]]`) through its end (`x[length(x::SparseVector)]`)."
 function _densifyfirstnztoend!(x::SparseVector)
     # lengthen containers
     oldnnz = nnz(x)
-    newnnz = x.n - x.nzind[1] + 1
-    resize!(x.nzval, newnnz)
-    resize!(x.nzind, newnnz)
+    newnnz = length(x::SparseVector) - nonzeroinds(x)[1] + 1
+    resize!(nonzeros(x), newnnz)
+    resize!(nonzeroinds(x), newnnz)
     # redistribute nonzero values over lengthened container
     # initialize now-allocated zero values simultaneously
     nextpos = newnnz
     @inbounds for oldpos in oldnnz:-1:1
-        nzi = x.nzind[oldpos]
-        nzv = x.nzval[oldpos]
-        newpos = nzi - x.nzind[1] + 1
-        newpos < nextpos && (x.nzval[newpos+1:nextpos] .= 0)
+        nzi = nonzeroinds(x)[oldpos]
+        nzv = nonzeros(x)[oldpos]
+        newpos = nzi - nonzeroinds(x)[1] + 1
+        newpos < nextpos && (nonzeros(x)[newpos+1:nextpos] .= 0)
         newpos == oldpos && break
-        x.nzval[newpos] = nzv
+        nonzeros(x)[newpos] = nzv
         nextpos = newpos - 1
     end
     # finally update lengthened nzinds
-    x.nzind[2:end] = (x.nzind[1]+1):x.n
+    nonzeroinds(x)[2:end] = (nonzeroinds(x)[1]+1):length(x::SparseVector)
     x
 end
-"Densifies `x::SparseVector` from its beginning (`x[1]`) through its last nonzero (`x[x.nzind[end]]`)."
+"Densifies `x::SparseVector` from its beginning (`x[1]`) through its last nonzero (`x[nonzeroinds(x)[end]]`)."
 function _densifystarttolastnz!(x::SparseVector)
     # lengthen containers
     oldnnz = nnz(x)
-    newnnz = x.nzind[end]
-    resize!(x.nzval, newnnz)
-    resize!(x.nzind, newnnz)
+    newnnz = nonzeroinds(x)[end]
+    resize!(nonzeros(x), newnnz)
+    resize!(nonzeroinds(x), newnnz)
     # redistribute nonzero values over lengthened container
     # initialize now-allocated zero values simultaneously
     nextpos = newnnz
     @inbounds for oldpos in oldnnz:-1:1
-        nzi = x.nzind[oldpos]
-        nzv = x.nzval[oldpos]
-        nzi < nextpos && (x.nzval[nzi+1:nextpos] .= 0)
+        nzi = nonzeroinds(x)[oldpos]
+        nzv = nonzeros(x)[oldpos]
+        nzi < nextpos && (nonzeros(x)[nzi+1:nextpos] .= 0)
         nzi == oldpos && (nextpos = 0; break)
-        x.nzval[nzi] = nzv
+        nonzeros(x)[nzi] = nzv
         nextpos = nzi - 1
     end
-    nextpos > 0 && (x.nzval[1:nextpos] .= 0)
+    nextpos > 0 && (nonzeros(x)[1:nextpos] .= 0)
     # finally update lengthened nzinds
-    x.nzind[1:newnnz] = 1:newnnz
+    nonzeroinds(x)[1:newnnz] = 1:newnnz
     x
 end
 
@@ -1921,9 +1922,9 @@ function sort(x::SparseVector{Tv,Ti}; kw
 end
 
 function fkeep!(x::SparseVector, f, trim::Bool = true)
-    n = x.n
-    nzind = x.nzind
-    nzval = x.nzval
+    n = length(x::SparseVector)
+    nzind = nonzeroinds(x)
+    nzval = nonzeros(x)
 
     x_writepos = 1
     @inbounds for xk in 1:nnz(x)
@@ -1955,7 +1956,7 @@ end
     droptol!(x::SparseVector, tol; trim::Bool = true)
 
 Removes stored values from `x` whose absolute value is less than or equal to `tol`,
-optionally trimming resulting excess space from `A.rowval` and `A.nzval` when `trim`
+optionally trimming resulting excess space from `nonzeroinds(x)` and `nonzeros(x)` when `trim`
 is `true`.
 """
 droptol!(x::SparseVector, tol; trim::Bool = true) = fkeep!(x, (i, x) -> abs(x) > tol, trim)
@@ -1964,7 +1965,7 @@ droptol!(x::SparseVector, tol; trim::Boo
     dropzeros!(x::SparseVector; trim::Bool = true)
 
 Removes stored numerical zeros from `x`, optionally trimming resulting excess space from
-`x.nzind` and `x.nzval` when `trim` is `true`.
+`nonzeroinds(x)` and `nonzeros(x)` when `trim` is `true`.
 
 For an out-of-place version, see [`dropzeros`](@ref). For
 algorithmic information, see `fkeep!`.
@@ -1996,29 +1997,29 @@ julia> dropzeros(A)
 dropzeros(x::SparseVector; trim::Bool = true) = dropzeros!(copy(x), trim = trim)
 
 function copy!(dst::SparseVector, src::SparseVector)
-    dst.n == src.n || throw(ArgumentError("Sparse vectors should have the same length for copy!"))
-    copy!(dst.nzval, src.nzval)
-    copy!(dst.nzind, src.nzind)
+    length(dst::SparseVector) == length(src::SparseVector) || throw(ArgumentError("Sparse vectors should have the same length for copy!"))
+    copy!(nonzeros(dst), nonzeros(src))
+    copy!(nonzeroinds(dst), nonzeroinds(src))
     return dst
 end
 
 function copy!(dst::SparseVector, src::AbstractVector)
-    dst.n == length(src) || throw(ArgumentError("Sparse vector should have the same length as source for copy!"))
-    _dense2indval!(dst.nzind, dst.nzval, src)
+    length(dst::SparseVector) == length(src) || throw(ArgumentError("Sparse vector should have the same length as source for copy!"))
+    _dense2indval!(nonzeroinds(dst), nonzeros(dst), src)
     return dst
 end
 
-function _fillnonzero!(arr::SparseMatrixCSC{Tv, Ti}, val) where {Tv,Ti}
+function _fillnonzero!(arr::AbstractSparseMatrixCSC{Tv, Ti}, val) where {Tv,Ti}
     m, n = size(arr)
-    resize!(arr.colptr, n+1)
-    resize!(arr.rowval, m*n)
-    resize!(arr.nzval, m*n)
-    copyto!(arr.colptr, 1:m:n*m+1)
-    fill!(arr.nzval, val)
+    resize!(getcolptr(arr), n+1)
+    resize!(rowvals(arr), m*n)
+    resize!(nonzeros(arr), m*n)
+    copyto!(getcolptr(arr), 1:m:n*m+1)
+    fill!(nonzeros(arr), val)
     index = 1
     @inbounds for _ in 1:n
         for i in 1:m
-            arr.rowval[index] = Ti(i)
+            rowvals(arr)[index] = Ti(i)
             index += 1
         end
     end
@@ -2026,22 +2027,22 @@ function _fillnonzero!(arr::SparseMatrix
 end
 
 function _fillnonzero!(arr::SparseVector{Tv,Ti}, val) where {Tv,Ti}
-    n = arr.n
-    resize!(arr.nzind, n)
-    resize!(arr.nzval, n)
+    n = length(arr::SparseVector)
+    resize!(nonzeroinds(arr), n)
+    resize!(nonzeros(arr), n)
     @inbounds for i in 1:n
-        arr.nzind[i] = Ti(i)
+        nonzeroinds(arr)[i] = Ti(i)
     end
-    fill!(arr.nzval, val)
+    fill!(nonzeros(arr), val)
     arr
 end
 
 import Base.fill!
-function fill!(A::Union{SparseVector, SparseMatrixCSC}, x)
+function fill!(A::Union{SparseVector, AbstractSparseMatrixCSC}, x)
     T = eltype(A)
     xT = convert(T, x)
     if xT == zero(T)
-        fill!(A.nzval, xT)
+        fill!(nonzeros(A), xT)
     else
         _fillnonzero!(A, xT)
     end
@@ -2080,7 +2081,7 @@ end
 
 function circshift!(O::SparseVector, X::SparseVector, (r,)::Base.DimsInteger{1})
     copy!(O, X)
-    subvector_shifter!(O.nzind, O.nzval, 1, length(O.nzind), O.n, mod(r, X.n))
+    subvector_shifter!(nonzeroinds(O), nonzeros(O), 1, length(nonzeroinds(O)), length(O), mod(r, length(X)))
     return O
 end
 
diff -pruN 1.3.1+dfsg-1/stdlib/SparseArrays/test/forbidproperties.jl 1.4.0+dfsg-1/stdlib/SparseArrays/test/forbidproperties.jl
--- 1.3.1+dfsg-1/stdlib/SparseArrays/test/forbidproperties.jl	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/stdlib/SparseArrays/test/forbidproperties.jl	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1,5 @@
+# This file is a part of Julia. License is MIT: https://julialang.org/license
+
+using SparseArrays
+Base.getproperty(S::SparseMatrixCSC, ::Symbol) = error("use accessor function")
+Base.getproperty(S::SparseVector, ::Symbol) = error("use accessor function")
diff -pruN 1.3.1+dfsg-1/stdlib/SparseArrays/test/higherorderfns.jl 1.4.0+dfsg-1/stdlib/SparseArrays/test/higherorderfns.jl
--- 1.3.1+dfsg-1/stdlib/SparseArrays/test/higherorderfns.jl	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/stdlib/SparseArrays/test/higherorderfns.jl	2020-03-21 16:36:32.000000000 +0000
@@ -10,6 +10,7 @@ using Test
 using SparseArrays
 using LinearAlgebra
 using Random
+include("forbidproperties.jl")
 
 @testset "map[!] implementation specialized for a single (input) sparse vector/matrix" begin
     N, M = 10, 12
@@ -44,11 +45,11 @@ end
         # --> test map! entry point
         fX = map(+, fA, fB); X = sparse(fX)
         map!(+, X, A, B); X = sparse(fX) # warmup for @allocated
-        @test (@allocated map!(+, X, A, B)) == 0
+        @test (@allocated map!(+, X, A, B)) < 300
         @test map!(+, X, A, B) == sparse(map!(+, fX, fA, fB))
         fX = map(*, fA, fB); X = sparse(fX)
         map!(*, X, A, B); X = sparse(fX) # warmup for @allocated
-        @test (@allocated map!(*, X, A, B)) == 0
+        @test (@allocated map!(*, X, A, B)) < 300
         @test map!(*, X, A, B) == sparse(map!(*, fX, fA, fB))
         @test map!(f, X, A, B) == sparse(map!(f, fX, fA, fB))
         @test_throws DimensionMismatch map!(f, X, A, spzeros((shapeA .- 1)...))
@@ -71,11 +72,11 @@ end
         # --> test map! entry point
         fX = map(+, fA, fB, fC); X = sparse(fX)
         map!(+, X, A, B, C); X = sparse(fX) # warmup for @allocated
-        @test (@allocated map!(+, X, A, B, C)) == 0
+        @test (@allocated map!(+, X, A, B, C)) < 300
         @test map!(+, X, A, B, C) == sparse(map!(+, fX, fA, fB, fC))
         fX = map(*, fA, fB, fC); X = sparse(fX)
         map!(*, X, A, B, C); X = sparse(fX) # warmup for @allocated
-        @test (@allocated map!(*, X, A, B, C)) == 0
+        @test (@allocated map!(*, X, A, B, C)) < 300
         @test map!(*, X, A, B, C) == sparse(map!(*, fX, fA, fB, fC))
         @test map!(f, X, A, B, C) == sparse(map!(f, fX, fA, fB, fC))
         @test_throws DimensionMismatch map!(f, X, A, B, spzeros((shapeA .- 1)...))
@@ -118,12 +119,12 @@ end
         # --> test broadcast! entry point / zero-preserving op
         broadcast!(sin, fZ, fX); Z = sparse(fZ)
         broadcast!(sin, Z, X); Z = sparse(fZ) # warmup for @allocated
-        @test (@allocated broadcast!(sin, Z, X)) == 0
+        @test (@allocated broadcast!(sin, Z, X)) < 300
         @test broadcast!(sin, Z, X) == sparse(broadcast!(sin, fZ, fX))
         # --> test broadcast! entry point / not-zero-preserving op
         broadcast!(cos, fZ, fX); Z = sparse(fZ)
         broadcast!(cos, Z, X); Z = sparse(fZ) # warmup for @allocated
-        @test (@allocated broadcast!(cos, Z, X)) == 0
+        @test (@allocated broadcast!(cos, Z, X)) < 300
         @test broadcast!(cos, Z, X) == sparse(broadcast!(cos, fZ, fX))
         # --> test shape checks for broadcast! entry point
         # TODO strengthen this test, avoiding dependence on checking whether
@@ -142,12 +143,12 @@ end
         # --> test broadcast! entry point / zero-preserving op
         broadcast!(sin, fV, fX); V = sparse(fV)
         broadcast!(sin, V, X); V = sparse(fV) # warmup for @allocated
-        @test (@allocated broadcast!(sin, V, X)) == 0
+        @test (@allocated broadcast!(sin, V, X)) < 300
         @test broadcast!(sin, V, X) == sparse(broadcast!(sin, fV, fX))
         # --> test broadcast! entry point / not-zero-preserving
         broadcast!(cos, fV, fX); V = sparse(fV)
         broadcast!(cos, V, X); V = sparse(fV) # warmup for @allocated
-        @test (@allocated broadcast!(cos, V, X)) == 0
+        @test (@allocated broadcast!(cos, V, X)) < 300
         @test broadcast!(cos, V, X) == sparse(broadcast!(cos, fV, fX))
         # --> test shape checks for broadcast! entry point
         # TODO strengthen this test, avoiding dependence on checking whether
@@ -195,17 +196,17 @@ end
             # --> test broadcast! entry point / +-like zero-preserving op
             broadcast!(+, fZ, fX, fY); Z = sparse(fZ)
             broadcast!(+, Z, X, Y); Z = sparse(fZ) # warmup for @allocated
-            @test (@allocated broadcast!(+, Z, X, Y)) == 0
+            @test (@allocated broadcast!(+, Z, X, Y)) < 300
             @test broadcast!(+, Z, X, Y) == sparse(broadcast!(+, fZ, fX, fY))
             # --> test broadcast! entry point / *-like zero-preserving op
             broadcast!(*, fZ, fX, fY); Z = sparse(fZ)
             broadcast!(*, Z, X, Y); Z = sparse(fZ) # warmup for @allocated
-            @test (@allocated broadcast!(*, Z, X, Y)) == 0
+            @test (@allocated broadcast!(*, Z, X, Y)) < 300
             @test broadcast!(*, Z, X, Y) == sparse(broadcast!(*, fZ, fX, fY))
             # --> test broadcast! entry point / not zero-preserving op
             broadcast!(f, fZ, fX, fY); Z = sparse(fZ)
             broadcast!(f, Z, X, Y); Z = sparse(fZ) # warmup for @allocated
-            @test (@allocated broadcast!(f, Z, X, Y)) == 0
+            @test (@allocated broadcast!(f, Z, X, Y)) < 300
             @test broadcast!(f, Z, X, Y) == sparse(broadcast!(f, fZ, fX, fY))
             # --> test shape checks for both broadcast and broadcast! entry points
             # TODO strengthen this test, avoiding dependence on checking whether
@@ -258,17 +259,17 @@ end
             # --> test broadcast! entry point / +-like zero-preserving op
             fQ = broadcast(+, fX, fY, fZ); Q = sparse(fQ)
             broadcast!(+, Q, X, Y, Z); Q = sparse(fQ) # warmup for @allocated
-            @test (@allocated broadcast!(+, Q, X, Y, Z)) == 0
+            @test (@allocated broadcast!(+, Q, X, Y, Z)) < 300
             @test broadcast!(+, Q, X, Y, Z) == sparse(broadcast!(+, fQ, fX, fY, fZ))
             # --> test broadcast! entry point / *-like zero-preserving op
             fQ = broadcast(*, fX, fY, fZ); Q = sparse(fQ)
             broadcast!(*, Q, X, Y, Z); Q = sparse(fQ) # warmup for @allocated
-            @test (@allocated broadcast!(*, Q, X, Y, Z)) == 0
+            @test (@allocated broadcast!(*, Q, X, Y, Z)) < 300
             @test broadcast!(*, Q, X, Y, Z) == sparse(broadcast!(*, fQ, fX, fY, fZ))
             # --> test broadcast! entry point / not zero-preserving op
             fQ = broadcast(f, fX, fY, fZ); Q = sparse(fQ)
             broadcast!(f, Q, X, Y, Z); Q = sparse(fQ) # warmup for @allocated
-            @test (@allocated broadcast!(f, Q, X, Y, Z)) == 0
+            @test (@allocated broadcast!(f, Q, X, Y, Z)) < 300
             @test broadcast!(f, Q, X, Y, Z) == sparse(broadcast!(f, fQ, fX, fY, fZ))
             # --> test shape checks for both broadcast and broadcast! entry points
             # TODO strengthen this test, avoiding dependence on checking whether
@@ -342,11 +343,8 @@ end
             @test broadcast!(*, X, sparseargs...) == sparse(broadcast!(*, fX, denseargs...))
             @test isa(@inferred(broadcast!(*, X, sparseargs...)), SparseMatrixCSC{elT})
             X = sparse(fX) # reset / warmup for @allocated test
-            # It'd be nice for this to be zero, but there's currently some constant overhead
-            @test_broken (@allocated broadcast!(*, X, sparseargs...)) == 0
-            X = sparse(fX) # reset / warmup for @allocated test
             # And broadcasting over Transposes currently requires making a CSC copy, so we must account for that in the bounds
-            @test (@allocated broadcast!(*, X, sparseargs...)) <= (sum(x->isa(x, Transpose) ? @allocated(SparseMatrixCSC(x))+128 : 0, sparseargs) + 128)
+            @test (@allocated broadcast!(*, X, sparseargs...)) <= (sum(x->isa(x, Transpose) ? @allocated(SparseMatrixCSC(x)) + 128 : 0, sparseargs) + 128 + 900) # about zero to 3k bytes
         end
     end
     # test combinations at the limit of inference (eight arguments net)
@@ -366,9 +364,7 @@ end
         @test broadcast!(*, X, sparseargs...) == sparse(broadcast!(*, fX, denseargs...))
         @test isa(@inferred(broadcast!(*, X, sparseargs...)), SparseMatrixCSC{elT})
         X = sparse(fX) # reset / warmup for @allocated test
-        @test_broken (@allocated broadcast!(*, X, sparseargs...)) == 0
-        X = sparse(fX) # reset / warmup for @allocated test
-        @test (@allocated broadcast!(*, X, sparseargs...)) <= 128
+        @test (@allocated broadcast!(*, X, sparseargs...)) <= 900
     end
 end
 
diff -pruN 1.3.1+dfsg-1/stdlib/SparseArrays/test/simplesmatrix.jl 1.4.0+dfsg-1/stdlib/SparseArrays/test/simplesmatrix.jl
--- 1.3.1+dfsg-1/stdlib/SparseArrays/test/simplesmatrix.jl	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/stdlib/SparseArrays/test/simplesmatrix.jl	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1,52 @@
+# This file is a part of Julia. License is MIT: https://julialang.org/license
+
+struct SimpleSMatrix{N,M,T} <: AbstractMatrix{T}
+    m::Matrix{T}
+end
+
+SimpleSMatrix{N,M}(m::AbstractMatrix{T}) where {N,M,T} =
+    size(m) == (N, M) ? SimpleSMatrix{N,M,T}(m) : throw(error("Wrong matrix size"))
+
+Base.:*(a::SimpleSMatrix{N,O}, b::SimpleSMatrix{O,M}) where {N,O,M} =
+    SimpleSMatrix{N,M}(a.m * b.m)
+
+Base.:*(a::LinearAlgebra.Adjoint{<:Any, <:SimpleSMatrix{O,N}}, b::SimpleSMatrix{O,M}) where {N,O,M} =
+    SimpleSMatrix{N,M}(adjoint(a.parent.m) * b.m)
+
+Base.:*(a::SimpleSMatrix{N,O}, b::LinearAlgebra.Adjoint{<:Any, <:SimpleSMatrix{M,O}}) where {N,O,M} =
+    SimpleSMatrix{N,M}(a.m * adjoint(b.parent.m))
+
+Base.:+(a::SimpleSMatrix{N,M}, b::SimpleSMatrix{N,M}) where {N,M} =
+    SimpleSMatrix{N,M}(a.m + b.m)
+
+Base.:+(a::LinearAlgebra.Adjoint{<:Any, <:SimpleSMatrix{M,N}}, b::SimpleSMatrix{N,M}) where {N,M} =
+    SimpleSMatrix{N,M}(adjoint(a.parent.m) + b.m)
+
+Base.:+(a::LinearAlgebra.Adjoint{<:Any, <:SimpleSMatrix}, b::LinearAlgebra.Adjoint{<:Any, <:SimpleSMatrix}) =
+    (a' + b')'
+
+Base.:+(a::SimpleSMatrix{N,M}, b::LinearAlgebra.Adjoint{<:Any, <:SimpleSMatrix{M,N}}) where {N,M} =
+    SimpleSMatrix{N,M}(a.m + adjoint(b.parent.m))
+
+Base.:-(a::SimpleSMatrix{N,M}, b::SimpleSMatrix{N,M}) where {N,M} =
+    SimpleSMatrix{N,M}(a.m - b.m)
+
+Base.:-(a::LinearAlgebra.Adjoint{<:Any, <:SimpleSMatrix{M,N}}, b::SimpleSMatrix{N,M}) where {N,M} =
+    SimpleSMatrix{N,M}(adjoint(a.parent.m) - b.m)
+
+Base.:-(a::LinearAlgebra.Adjoint{<:Any, <:SimpleSMatrix}, b::LinearAlgebra.Adjoint{<:Any, <:SimpleSMatrix}) =
+    (a' - b')'
+
+Base.:-(a::SimpleSMatrix{N,M}, b::LinearAlgebra.Adjoint{<:Any, <:SimpleSMatrix{M,N}}) where {N,M} =
+    SimpleSMatrix{N,M}(a.m - adjoint(b.parent.m))
+
+Base.size(a::SimpleSMatrix{N,M}) where {N,M} = (N, M)
+
+Base.length(a::SimpleSMatrix{N,M}) where {N,M} = N * M
+
+Base.zero(::Type{S}) where {N,M,T,S<:SimpleSMatrix{N,M,T}} = SimpleSMatrix{N,M}(zeros(T, N, M))
+
+Base.getindex(s::SimpleSMatrix, inds...) = getindex(s.m, inds...)
+
+Base.convert(::Type{S}, value::Matrix) where {N,M,T,S<:SimpleSMatrix{N,M,T}} =
+    SimpleSMatrix{N,M}(T.(value))
diff -pruN 1.3.1+dfsg-1/stdlib/SparseArrays/test/sparse.jl 1.4.0+dfsg-1/stdlib/SparseArrays/test/sparse.jl
--- 1.3.1+dfsg-1/stdlib/SparseArrays/test/sparse.jl	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/stdlib/SparseArrays/test/sparse.jl	2020-03-21 16:36:32.000000000 +0000
@@ -4,16 +4,39 @@ module SparseTests
 
 using Test
 using SparseArrays
+using SparseArrays: getcolptr, nonzeroinds
 using LinearAlgebra
-using Base.Printf: @printf
+using Printf: @printf # for debug
 using Random
 using Test: guardseed
 using InteractiveUtils: @which
 using Dates
+include("forbidproperties.jl")
+include("simplesmatrix.jl")
+
+@testset "Issue #33169" begin
+    m21 = sparse([1, 2], [2, 2], SimpleSMatrix{2,1}.([rand(2, 1), rand(2, 1)]), 2, 2)
+    m12 = sparse([1, 2], [2, 2], SimpleSMatrix{1,2}.([rand(1, 2), rand(1, 2)]), 2, 2)
+    m22 = sparse([1, 2], [2, 2], SimpleSMatrix{2,2}.([rand(2, 2), rand(2, 2)]), 2, 2)
+    m23 = sparse([1, 2], [2, 2], SimpleSMatrix{2,3}.([rand(2, 3), rand(2, 3)]), 2, 2)
+    v12 = sparsevec([2], SimpleSMatrix{1,2}.([rand(1, 2)]))
+    v21 = sparsevec([2], SimpleSMatrix{2,1}.([rand(2, 1)]))
+    @test m22 * m21 ≈ Matrix(m22) * Matrix(m21)
+    @test m22' * m21 ≈ Matrix(m22') * Matrix(m21)
+    @test m21' * m22 ≈ Matrix(m21') * Matrix(m22)
+    @test m23' * m22 * m21 ≈ Matrix(m23') * Matrix(m22) * Matrix(m21)
+    @test m21 * v12 ≈ Matrix(m21) * Vector(v12)
+    @test m12' * v12 ≈ Matrix(m12') * Vector(v12)
+    @test v21' * m22 ≈ Vector(v21)' * Matrix(m22)
+    @test v12' * m21' ≈ Vector(v12)' * Matrix(m21)'
+    @test v21' * v21 ≈ Vector(v21)' * Vector(v21)
+    @test v21' * m22 * v21 ≈ Vector(v21)' * Matrix(m22) * Vector(v21)
+end
 
 @testset "issparse" begin
     @test issparse(sparse(fill(1,5,5)))
     @test !issparse(fill(1,5,5))
+    @test nnz(zero(sparse(fill(1,5,5)))) == 0
 end
 
 @testset "iszero specialization for SparseMatrixCSC" begin
@@ -114,14 +137,14 @@ end
 
     @testset "horizontal concatenation" begin
         @test [se33 se33] == [Array(se33) Array(se33)]
-        @test length(([sp33 0I]).nzval) == 3
+        @test length(nonzeros([sp33 0I])) == 3
     end
 
     @testset "vertical concatenation" begin
         @test [se33; se33] == [Array(se33); Array(se33)]
         se33_32bit = convert(SparseMatrixCSC{Float32,Int32}, se33)
         @test [se33; se33_32bit] == [Array(se33); Array(se33_32bit)]
-        @test length(([sp33; 0I]).nzval) == 3
+        @test length(nonzeros([sp33; 0I])) == 3
     end
 
     se44 = sparse(1.0I, 4, 4)
@@ -131,7 +154,7 @@ end
     se77 = sparse(1.0I, 7, 7)
     @testset "h+v concatenation" begin
         @test [se44 sz42 sz41; sz34 se33] == se77
-        @test length(([sp33 0I; 1I 0I]).nzval) == 6
+        @test length(nonzeros([sp33 0I; 1I 0I])) == 6
     end
 
     @testset "blockdiag concatenation" begin
@@ -362,6 +385,29 @@ end
     end
 end
 
+@testset "multiplication of sparse matrix and triangular matrix" begin
+    _sparse_test_matrix(n, T) =  T == Int ? sparse(rand(0:4, n, n)) : sprandn(T, n, n, 0.6)
+    _triangular_test_matrix(n, TA, T) = T == Int ? TA(rand(0:9, n, n)) : TA(randn(T, n, n))
+
+    n = 5
+    for T1 in (Int, Float64, ComplexF32)
+        S = _sparse_test_matrix(n, T1)
+        MS = Matrix(S)
+        for T2 in (Int, Float64, ComplexF32)
+            for TM in (LowerTriangular, UnitLowerTriangular, UpperTriangular, UnitLowerTriangular)
+                T = _triangular_test_matrix(n, TM, T2)
+                MT = Matrix(T)
+                @test isa(T * S, DenseMatrix)
+                @test isa(S * T, DenseMatrix)
+                for transT in (identity, adjoint, transpose), transS in (identity, adjoint, transpose)
+                    @test transT(T) * transS(S) ≈ transT(MT) * transS(MS)
+                    @test transS(S) * transT(T) ≈ transS(MS) * transT(MT)
+                end
+            end
+        end
+    end
+end
+
 @testset "Issue #30502" begin
     @test nnz(sprand(UInt8(16), UInt8(16), 1.0)) == 256
     @test nnz(sprand(UInt8(16), UInt8(16), 1.0, ones)) == 256
@@ -422,6 +468,17 @@ end
     @test_throws DimensionMismatch dot(sprand(5,5,0.2),sprand(5,6,0.2))
 end
 
+@testset "generalized dot product" begin
+    for i = 1:5
+        A = sprand(ComplexF64, 10, 15, 0.4)
+        Av = view(A, :, :)
+        x = sprand(ComplexF64, 10, 0.5)
+        y = sprand(ComplexF64, 15, 0.5)
+        @test dot(x, A, y) ≈ dot(Vector(x), A, Vector(y)) ≈ (Vector(x)' * Matrix(A)) * Vector(y)
+        @test dot(x, A, y) ≈ dot(x, Av, y)
+    end
+end
+
 const BASE_TEST_PATH = joinpath(Sys.BINDIR, "..", "share", "julia", "test")
 isdefined(Main, :Quaternions) || @eval Main include(joinpath($(BASE_TEST_PATH), "testhelpers", "Quaternions.jl"))
 using .Main.Quaternions
@@ -491,9 +548,9 @@ end
     B = sprand(5, 5, 0.2)
     copyto!(A, B)
     @test A == B
-    @test pointer(A.nzval) != pointer(B.nzval)
-    @test pointer(A.rowval) != pointer(B.rowval)
-    @test pointer(A.colptr) != pointer(B.colptr)
+    @test pointer(nonzeros(A)) != pointer(nonzeros(B))
+    @test pointer(rowvals(A)) != pointer(rowvals(B))
+    @test pointer(getcolptr(A)) != pointer(getcolptr(B))
     # Test size(A) != size(B), but length(A) == length(B)
     B = sprand(25, 1, 0.2)
     copyto!(A, B)
@@ -544,8 +601,8 @@ end
     @testset "common error checking of [c]transpose! methods (ftranspose!)" begin
         @test_throws DimensionMismatch transpose!(A[:, 1:(smalldim - 1)], A)
         @test_throws DimensionMismatch transpose!(A[1:(smalldim - 1), 1], A)
-        @test_throws ArgumentError transpose!((B = similar(A); resize!(B.rowval, nnz(A) - 1); B), A)
-        @test_throws ArgumentError transpose!((B = similar(A); resize!(B.nzval, nnz(A) - 1); B), A)
+        @test_throws ArgumentError transpose!((B = similar(A); resize!(rowvals(B), nnz(A) - 1); B), A)
+        @test_throws ArgumentError transpose!((B = similar(A); resize!(nonzeros(B), nnz(A) - 1); B), A)
     end
     @testset "common error checking of permute[!] methods / source-perm compat" begin
         @test_throws DimensionMismatch permute(A, p[1:(end - 1)], q)
@@ -554,17 +611,17 @@ end
     @testset "common error checking of permute[!] methods / source-dest compat" begin
         @test_throws DimensionMismatch permute!(A[1:(m - 1), :], A, p, q)
         @test_throws DimensionMismatch permute!(A[:, 1:(m - 1)], A, p, q)
-        @test_throws ArgumentError permute!((Y = copy(X); resize!(Y.rowval, nnz(A) - 1); Y), A, p, q)
-        @test_throws ArgumentError permute!((Y = copy(X); resize!(Y.nzval, nnz(A) - 1); Y), A, p, q)
+        @test_throws ArgumentError permute!((Y = copy(X); resize!(rowvals(Y), nnz(A) - 1); Y), A, p, q)
+        @test_throws ArgumentError permute!((Y = copy(X); resize!(nonzeros(Y), nnz(A) - 1); Y), A, p, q)
     end
     @testset "common error checking of permute[!] methods / source-workmat compat" begin
         @test_throws DimensionMismatch permute!(X, A, p, q, C[1:(m - 1), :])
         @test_throws DimensionMismatch permute!(X, A, p, q, C[:, 1:(m - 1)])
-        @test_throws ArgumentError permute!(X, A, p, q, (D = copy(C); resize!(D.rowval, nnz(A) - 1); D))
-        @test_throws ArgumentError permute!(X, A, p, q, (D = copy(C); resize!(D.nzval, nnz(A) - 1); D))
+        @test_throws ArgumentError permute!(X, A, p, q, (D = copy(C); resize!(rowvals(D), nnz(A) - 1); D))
+        @test_throws ArgumentError permute!(X, A, p, q, (D = copy(C); resize!(nonzeros(D), nnz(A) - 1); D))
     end
     @testset "common error checking of permute[!] methods / source-workcolptr compat" begin
-        @test_throws DimensionMismatch permute!(A, p, q, C, Vector{eltype(A.rowval)}(undef, length(A.colptr) - 1))
+        @test_throws DimensionMismatch permute!(A, p, q, C, Vector{eltype(rowvals(A))}(undef, length(getcolptr(A)) - 1))
     end
     @testset "common error checking of permute[!] methods / permutation validity" begin
         @test_throws ArgumentError permute!(A, (r = copy(p); r[2] = r[1]; r), q)
@@ -594,7 +651,7 @@ end
             @test permute!(similar(A), A, p, q, similar(At)) == fullPAQ
             @test permute!(copy(A), p, q) == fullPAQ
             @test permute!(copy(A), p, q, similar(At)) == fullPAQ
-            @test permute!(copy(A), p, q, similar(At), similar(A.colptr)) == fullPAQ
+            @test permute!(copy(A), p, q, similar(At), similar(getcolptr(A))) == fullPAQ
         end
     end
 end
@@ -857,6 +914,21 @@ end
         end
     end
 
+    # indexing by array of CartesianIndex (issue #30981)
+    S = sprand(10, 10, 0.4)
+    inds_sparse = S[findall(S .> 0.2)]
+    M = Matrix(S)
+    inds_dense = M[findall(M .> 0.2)]
+    @test Array(inds_sparse) == inds_dense
+    inds_out = Array([CartesianIndex(1, 1), CartesianIndex(0, 1)])
+    @test_throws BoundsError S[inds_out]
+    pop!(inds_out); push!(inds_out, CartesianIndex(1, 0))
+    @test_throws BoundsError S[inds_out]
+    pop!(inds_out); push!(inds_out, CartesianIndex(11, 1))
+    @test_throws BoundsError S[inds_out]
+    pop!(inds_out); push!(inds_out, CartesianIndex(1, 11))
+    @test_throws BoundsError S[inds_out]
+
     # workaround issue #7197: comment out let-block
     #let S = SparseMatrixCSC(3, 3, UInt8[1,1,1,1], UInt8[], Int64[])
     S1290 = SparseMatrixCSC(3, 3, UInt8[1,1,1,1], UInt8[], Int64[])
@@ -922,7 +994,7 @@ end
     @test nnz(a) == 20
     @test count(!iszero, a) == 11
     a = copy(b)
-    a[1:2,:] = let c = sparse(fill(1,2,10)); fill!(c.nzval, 0); c; end
+    a[1:2,:] = let c = sparse(fill(1,2,10)); fill!(nonzeros(c), 0); c; end
     @test nnz(a) == 19
     @test count(!iszero, a) == 8
     a[1:2,1:3] = let c = sparse(fill(1,2,3)); c[1,2] = c[2,1] = c[2,2] = 0; c; end
@@ -1346,7 +1418,7 @@ end
     debug = false
 
     if debug
-        println("row sizes: $([round(Int,nnz(S)/S.n) for S in SA])")
+        println("row sizes: $([round(Int,nnz(S)/size(S, 2)) for S in SA])")
         println("I sizes: $([length(I) for I in IA])")
         @printf("    S    |    I    | binary S | binary I |  linear  | best\n")
     end
@@ -1369,7 +1441,7 @@ end
             end
 
             if debug
-                @printf(" %7d | %7d | %4.2e | %4.2e | %4.2e | %s\n", round(Int,nnz(S)/S.n), length(I), times[1], times[2], times[3],
+                @printf(" %7d | %7d | %4.2e | %4.2e | %4.2e | %s\n", round(Int,nnz(S)/size(S, 2)), length(I), times[1], times[2], times[3],
                             (0 == best[2]) ? "binary S" : (1 == best[2]) ? "binary I" : "linear")
             end
             if res[1] != res[2]
@@ -1419,7 +1491,7 @@ end
             GC.gc()
             rs = @timed S[Isorted, Jsorted]
             if debug
-                @printf(" %7d | %7d | %7d | %4.2e | %4.2e | %4.2e | %4.2e |\n", round(Int,nnz(S)/S.n), length(I), length(J), rs[2], ru[2], rs[3], ru[3])
+                @printf(" %7d | %7d | %7d | %4.2e | %4.2e | %4.2e | %4.2e |\n", round(Int,nnz(S)/size(S, 2)), length(I), length(J), rs[2], ru[2], rs[3], ru[3])
             end
         end
     end
@@ -1554,7 +1626,7 @@ end
     local A = guardseed(1234321) do
         triu(sprand(10, 10, 0.2))
     end
-    @test SparseArrays.droptol!(A, 0.01).colptr ==  [1, 2, 2, 3, 4, 5, 5, 6, 8, 10, 13]
+    @test getcolptr(SparseArrays.droptol!(A, 0.01)) == [1, 2, 2, 3, 4, 5, 5, 6, 8, 10, 13]
     @test isequal(SparseArrays.droptol!(sparse([1], [1], [1]), 1), SparseMatrixCSC(1, 1, Int[1, 1], Int[], Int[]))
 end
 
@@ -1575,9 +1647,9 @@ end
         Anegzeros[negzerosinds] .= -2
         Abothsigns = copy(Aposzeros)
         Abothsigns[negzerosinds] .= -2
-        map!(x -> x == 2 ? 0.0 : x, Aposzeros.nzval, Aposzeros.nzval)
-        map!(x -> x == -2 ? -0.0 : x, Anegzeros.nzval, Anegzeros.nzval)
-        map!(x -> x == 2 ? 0.0 : x == -2 ? -0.0 : x, Abothsigns.nzval, Abothsigns.nzval)
+        map!(x -> x == 2 ? 0.0 : x, nonzeros(Aposzeros), nonzeros(Aposzeros))
+        map!(x -> x == -2 ? -0.0 : x, nonzeros(Anegzeros), nonzeros(Anegzeros))
+        map!(x -> x == 2 ? 0.0 : x == -2 ? -0.0 : x, nonzeros(Abothsigns), nonzeros(Abothsigns))
         for Awithzeros in (Aposzeros, Anegzeros, Abothsigns)
             # Basic functionality / dropzeros!
             @test dropzeros!(copy(Awithzeros)) == A
@@ -1586,16 +1658,16 @@ end
             @test dropzeros(Awithzeros) == A
             @test dropzeros(Awithzeros, trim = false) == A
             # Check trimming works as expected
-            @test length(dropzeros!(copy(Awithzeros)).nzval) == length(A.nzval)
-            @test length(dropzeros!(copy(Awithzeros)).rowval) == length(A.rowval)
-            @test length(dropzeros!(copy(Awithzeros), trim = false).nzval) == length(Awithzeros.nzval)
-            @test length(dropzeros!(copy(Awithzeros), trim = false).rowval) == length(Awithzeros.rowval)
+            @test length(nonzeros(dropzeros!(copy(Awithzeros)))) == length(nonzeros(A))
+            @test length(rowvals(dropzeros!(copy(Awithzeros)))) == length(rowvals(A))
+            @test length(nonzeros(dropzeros!(copy(Awithzeros), trim = false))) == length(nonzeros(Awithzeros))
+            @test length(rowvals(dropzeros!(copy(Awithzeros), trim = false))) == length(rowvals(Awithzeros))
         end
     end
     # original lone dropzeros test
     local A = sparse([1 2 3; 4 5 6; 7 8 9])
-    A.nzval[2] = A.nzval[6] = A.nzval[7] = 0
-    @test dropzeros!(A).colptr == [1, 3, 5, 7]
+    nonzeros(A)[2] = nonzeros(A)[6] = nonzeros(A)[7] = 0
+    @test getcolptr(dropzeros!(A)) == [1, 3, 5, 7]
     # test for issue #5169, modified for new behavior following #15242/#14798
     @test nnz(sparse([1, 1], [1, 2], [0.0, -0.0])) == 2
     @test nnz(dropzeros!(sparse([1, 1], [1, 2], [0.0, -0.0]))) == 0
@@ -1653,15 +1725,15 @@ end
     end
     # test that stored zeros are still stored zeros in the diagonal
     S = sparse([1,3],[1,3],[0.0,0.0]); V = diag(S)
-    @test V.nzind == [1,3]
-    @test V.nzval == [0.0,0.0]
+    @test nonzeroinds(V) == [1,3]
+    @test nonzeros(V) == [0.0,0.0]
 end
 
 @testset "expandptr" begin
     local A = sparse(1.0I, 5, 5)
-    @test SparseArrays.expandptr(A.colptr) == 1:5
+    @test SparseArrays.expandptr(getcolptr(A)) == 1:5
     A[1,2] = 1
-    @test SparseArrays.expandptr(A.colptr) == [1; 2; 2; 3; 4; 5]
+    @test SparseArrays.expandptr(getcolptr(A)) == [1; 2; 2; 3; 4; 5]
     @test_throws ArgumentError SparseArrays.expandptr([2; 3])
 end
 
@@ -1679,7 +1751,7 @@ end
     @test triu(A, n + 2) == zero(A)
 
     # fkeep trim option
-    @test isequal(length(tril!(sparse([1,2,3], [1,2,3], [1,2,3], 3, 4), -1).rowval), 0)
+    @test isequal(length(rowvals(tril!(sparse([1,2,3], [1,2,3], [1,2,3], 3, 4), -1))), 0)
 end
 
 @testset "norm" begin
@@ -1728,7 +1800,7 @@ end
     # explicit zeros
     A = sparse(ComplexF64(1)I, 5, 5)
     A[3,1] = 2
-    A.nzval[2] = 0.0
+    nonzeros(A)[2] = 0.0
     @test ishermitian(A) == true
     @test issymmetric(A) == true
 
@@ -1739,7 +1811,7 @@ end
     nzval = [0.0, 0.0, 0.0, 0.0, 0.0, 1.0, 1.0, 1.0, 0.0, 1.0, 1.0, 1.0, 0.0, 1.0, 1.0, 1.0]
     A = SparseMatrixCSC(m, n, colptr, rowval, nzval)
     @test issymmetric(A) == true
-    A.nzval[end - 3]  = 2.0
+    nonzeros(A)[end - 3]  = 2.0
     @test issymmetric(A) == false
 
     # 16521
@@ -1832,8 +1904,8 @@ end
     # the range specified in colptr do not
     # impact norm of a sparse matrix
     foo = sparse(1.0I, 4, 4)
-    resize!(foo.nzval, 5)
-    setindex!(foo.nzval, NaN, 5)
+    resize!(nonzeros(foo), 5)
+    setindex!(nonzeros(foo), NaN, 5)
     @test norm(foo) == 2.0
 
     # Test (m x 1) sparse matrix
@@ -2103,15 +2175,15 @@ end
     x = sparse(rand(3,3))
     SparseArrays.dropstored!(x, 1, 1)
     @test x[1, 1] == 0.0
-    @test x.colptr == [1, 3, 6, 9]
+    @test getcolptr(x) == [1, 3, 6, 9]
     SparseArrays.dropstored!(x, 2, 1)
-    @test x.colptr == [1, 2, 5, 8]
+    @test getcolptr(x) == [1, 2, 5, 8]
     @test x[2, 1] == 0.0
     SparseArrays.dropstored!(x, 2, 2)
-    @test x.colptr == [1, 2, 4, 7]
+    @test getcolptr(x) == [1, 2, 4, 7]
     @test x[2, 2] == 0.0
     SparseArrays.dropstored!(x, 2, 3)
-    @test x.colptr == [1, 2, 4, 6]
+    @test getcolptr(x) == [1, 2, 4, 6]
     @test x[2, 3] == 0.0
 end
 
@@ -2211,8 +2283,8 @@ end
     b = similar(a, Float32, Int32)
     c = similar(b, Float32, Int32)
     SparseArrays.dropstored!(b, 1, 1)
-    @test length(c.rowval) == 9
-    @test length(c.nzval) == 9
+    @test length(rowvals(c)) == 9
+    @test length(nonzeros(c)) == 9
 end
 
 @testset "similar with type conversion" begin
@@ -2231,62 +2303,62 @@ end
     simA = similar(A)
     @test typeof(simA) == typeof(A)
     @test size(simA) == size(A)
-    @test simA.colptr == A.colptr
-    @test simA.rowval == A.rowval
-    @test length(simA.nzval) == length(A.nzval)
+    @test getcolptr(simA) == getcolptr(A)
+    @test rowvals(simA) == rowvals(A)
+    @test length(nonzeros(simA)) == length(nonzeros(A))
     # test similar with entry type specification (preserves stored-entry structure)
     simA = similar(A, Float32)
-    @test typeof(simA) == SparseMatrixCSC{Float32,eltype(A.colptr)}
+    @test typeof(simA) == SparseMatrixCSC{Float32,eltype(getcolptr(A))}
     @test size(simA) == size(A)
-    @test simA.colptr == A.colptr
-    @test simA.rowval == A.rowval
-    @test length(simA.nzval) == length(A.nzval)
+    @test getcolptr(simA) == getcolptr(A)
+    @test rowvals(simA) == rowvals(A)
+    @test length(nonzeros(simA)) == length(nonzeros(A))
     # test similar with entry and index type specification (preserves stored-entry structure)
     simA = similar(A, Float32, Int8)
     @test typeof(simA) == SparseMatrixCSC{Float32,Int8}
     @test size(simA) == size(A)
-    @test simA.colptr == A.colptr
-    @test simA.rowval == A.rowval
-    @test length(simA.nzval) == length(A.nzval)
+    @test getcolptr(simA) == getcolptr(A)
+    @test rowvals(simA) == rowvals(A)
+    @test length(nonzeros(simA)) == length(nonzeros(A))
     # test similar with Dims{2} specification (preserves storage space only, not stored-entry structure)
     simA = similar(A, (6,6))
     @test typeof(simA) == typeof(A)
     @test size(simA) == (6,6)
-    @test simA.colptr == fill(1, 6+1)
-    @test length(simA.rowval) == length(A.rowval)
-    @test length(simA.nzval) == length(A.nzval)
+    @test getcolptr(simA) == fill(1, 6+1)
+    @test length(rowvals(simA)) == length(rowvals(A))
+    @test length(nonzeros(simA)) == length(nonzeros(A))
     # test similar with entry type and Dims{2} specification (preserves storage space only)
     simA = similar(A, Float32, (6,6))
-    @test typeof(simA) == SparseMatrixCSC{Float32,eltype(A.colptr)}
+    @test typeof(simA) == SparseMatrixCSC{Float32,eltype(getcolptr(A))}
     @test size(simA) == (6,6)
-    @test simA.colptr == fill(1, 6+1)
-    @test length(simA.rowval) == length(A.rowval)
-    @test length(simA.nzval) == length(A.nzval)
+    @test getcolptr(simA) == fill(1, 6+1)
+    @test length(rowvals(simA)) == length(rowvals(A))
+    @test length(nonzeros(simA)) == length(nonzeros(A))
     # test similar with entry type, index type, and Dims{2} specification (preserves storage space only)
     simA = similar(A, Float32, Int8, (6,6))
     @test typeof(simA) == SparseMatrixCSC{Float32, Int8}
     @test size(simA) == (6,6)
-    @test simA.colptr == fill(1, 6+1)
-    @test length(simA.rowval) == length(A.rowval)
-    @test length(simA.nzval) == length(A.nzval)
+    @test getcolptr(simA) == fill(1, 6+1)
+    @test length(rowvals(simA)) == length(rowvals(A))
+    @test length(nonzeros(simA)) == length(nonzeros(A))
     # test similar with Dims{1} specification (preserves nothing)
     simA = similar(A, (6,))
-    @test typeof(simA) == SparseVector{eltype(A.nzval),eltype(A.colptr)}
+    @test typeof(simA) == SparseVector{eltype(nonzeros(A)),eltype(getcolptr(A))}
     @test size(simA) == (6,)
-    @test length(simA.nzind) == 0
-    @test length(simA.nzval) == 0
+    @test length(nonzeroinds(simA)) == 0
+    @test length(nonzeros(simA)) == 0
     # test similar with entry type and Dims{1} specification (preserves nothing)
     simA = similar(A, Float32, (6,))
-    @test typeof(simA) == SparseVector{Float32,eltype(A.colptr)}
+    @test typeof(simA) == SparseVector{Float32,eltype(getcolptr(A))}
     @test size(simA) == (6,)
-    @test length(simA.nzind) == 0
-    @test length(simA.nzval) == 0
+    @test length(nonzeroinds(simA)) == 0
+    @test length(nonzeros(simA)) == 0
     # test similar with entry type, index type, and Dims{1} specification (preserves nothing)
     simA = similar(A, Float32, Int8, (6,))
     @test typeof(simA) == SparseVector{Float32,Int8}
     @test size(simA) == (6,)
-    @test length(simA.nzind) == 0
-    @test length(simA.nzval) == 0
+    @test length(nonzeroinds(simA)) == 0
+    @test length(nonzeros(simA)) == 0
     # test entry points to similar with entry type, index type, and non-Dims shape specification
     @test similar(A, Float32, Int8, 6, 6) == similar(A, Float32, Int8, (6, 6))
     @test similar(A, Float32, Int8, 6) == similar(A, Float32, Int8, (6,))
@@ -2296,7 +2368,7 @@ end
     # count should throw for sparse arrays for which zero(eltype) does not exist
     @test_throws MethodError count(SparseMatrixCSC(2, 2, Int[1, 2, 3], Int[1, 2], Any[true, true]))
     @test_throws MethodError count(SparseVector(2, Int[1], Any[true]))
-    # count should run only over S.nzval[1:nnz(S)], not S.nzval in full
+    # count should run only over nonzeros(S)[1:nnz(S)], not nonzeros(S) in full
     @test count(SparseMatrixCSC(2, 2, Int[1, 2, 3], Int[1, 2], Bool[true, true, true])) == 2
 end
 
@@ -2629,8 +2701,8 @@ end
     A = SparseMatrixCSC(Complex{BigInt}[1+im 2+2im]')'[1:1, 2:2]
     # ...ensure it does! If necessary, the test needs to be updated to use
     # another mechanism to create a suitable A.
-    resize!(A.nzval, 2)
-    @assert length(A.nzval) > nnz(A)
+    resize!(nonzeros(A), 2)
+    @assert length(nonzeros(A)) > nnz(A)
     @test -A == fill(-2-2im, 1, 1)
     @test conj(A) == fill(2-2im, 1, 1)
     conj!(A)
@@ -2705,7 +2777,7 @@ end
     @test sparse(UInt8.(1:254), fill(UInt8(1), 254), fill(1, 254), 255, 255) !== nothing
 end
 
-@testset "sppromote and sparse matmul" begin
+@testset "Sparse promotion in sparse matmul" begin
     A = SparseMatrixCSC{Float32, Int8}(2, 2, Int8[1, 2, 3], Int8[1, 2], Float32[1., 2.])
     B = SparseMatrixCSC{ComplexF32, Int32}(2, 2, Int32[1, 2, 3], Int32[1, 2], ComplexF32[1. + im, 2. - im])
     @test A*transpose(B)                  ≈ Array(A) * transpose(Array(B))
diff -pruN 1.3.1+dfsg-1/stdlib/SparseArrays/test/sparsevector.jl 1.4.0+dfsg-1/stdlib/SparseArrays/test/sparsevector.jl
--- 1.3.1+dfsg-1/stdlib/SparseArrays/test/sparsevector.jl	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/stdlib/SparseArrays/test/sparsevector.jl	2020-03-21 16:36:32.000000000 +0000
@@ -4,8 +4,10 @@ module SparseVectorTests
 
 using Test
 using SparseArrays
+using SparseArrays: nonzeroinds, getcolptr
 using LinearAlgebra
 using Random
+include("forbidproperties.jl")
 
 ### Data
 
@@ -315,8 +317,8 @@ end
     let x = spv_x1
         xc = copy(x)
         @test isa(xc, SparseVector{Float64,Int})
-        @test x.nzind !== xc.nzval
-        @test x.nzval !== xc.nzval
+        @test nonzeroinds(x) !== nonzeros(xc)
+        @test nonzeros(x) !== nonzeros(xc)
         @test exact_equal(x, xc)
     end
 
@@ -707,7 +709,7 @@ end
         for op in operations
             spresvec = op.(spvec)
             @test spresvec == op.(densevec)
-            @test all(!iszero, spresvec.nzval)
+            @test all(!iszero, nonzeros(spresvec))
             resvaltype = typeof(op(zero(eltype(spvec))))
             resindtype = SparseArrays.indtype(spvec)
             @test isa(spresvec, SparseVector{resvaltype,resindtype})
@@ -794,7 +796,7 @@ end
         end
         @testset "scale" begin
             α = 2.5
-            sx = SparseVector(x.n, x.nzind, x.nzval * α)
+            sx = SparseVector(length(x::SparseVector), nonzeroinds(x), nonzeros(x) * α)
             @test exact_equal(x * α, sx)
             @test exact_equal(x * (α + 0.0*im), complex(sx))
             @test exact_equal(α * x, sx)
@@ -803,7 +805,7 @@ end
             @test exact_equal(α * x, sx)
             @test exact_equal(x .* α, sx)
             @test exact_equal(α .* x, sx)
-            @test exact_equal(x / α, SparseVector(x.n, x.nzind, x.nzval / α))
+            @test exact_equal(x / α, SparseVector(length(x::SparseVector), nonzeroinds(x), nonzeros(x) / α))
 
             xc = copy(x)
             @test rmul!(xc, α) === xc
@@ -1001,13 +1003,13 @@ end
     @testset "ldiv ops with triangular matrices and sparse vecs (#14005)" begin
         m = 10
         sparsefloatvecs = SparseVector[sprand(m, 0.4) for k in 1:3]
-        sparseintvecs = SparseVector[SparseVector(m, sprvec.nzind, round.(Int, sprvec.nzval*10)) for sprvec in sparsefloatvecs]
-        sparsecomplexvecs = SparseVector[SparseVector(m, sprvec.nzind, complex.(sprvec.nzval, sprvec.nzval)) for sprvec in sparsefloatvecs]
+        sparseintvecs = SparseVector[SparseVector(m, nonzeroinds(sprvec), round.(Int, nonzeros(sprvec)*10)) for sprvec in sparsefloatvecs]
+        sparsecomplexvecs = SparseVector[SparseVector(m, nonzeroinds(sprvec), complex.(nonzeros(sprvec), nonzeros(sprvec))) for sprvec in sparsefloatvecs]
 
         sprmat = sprand(m, m, 0.2)
         sparsefloatmat = I + sprmat/(2m)
-        sparsecomplexmat = I + SparseMatrixCSC(m, m, sprmat.colptr, sprmat.rowval, complex.(sprmat.nzval, sprmat.nzval)/(4m))
-        sparseintmat = 10m*I + SparseMatrixCSC(m, m, sprmat.colptr, sprmat.rowval, round.(Int, sprmat.nzval*10))
+        sparsecomplexmat = I + SparseMatrixCSC(m, m, getcolptr(sprmat), rowvals(sprmat), complex.(nonzeros(sprmat), nonzeros(sprmat))/(4m))
+        sparseintmat = 10m*I + SparseMatrixCSC(m, m, getcolptr(sprmat), rowvals(sprmat), round.(Int, nonzeros(sprmat)*10))
 
         denseintmat = I*10m + rand(1:m, m, m)
         densefloatmat = I + randn(m, m)/(2m)
@@ -1033,7 +1035,7 @@ end
                 spvecs = eltypevec in inttypes ? sparseintvecs :
                          eltypevec in floattypes ? sparsefloatvecs :
                          eltypevec in complextypes && sparsecomplexvecs
-                spvecs = SparseVector[SparseVector(m, spvec.nzind, convert(Vector{eltypevec}, spvec.nzval)) for spvec in spvecs]
+                spvecs = SparseVector[SparseVector(m, nonzeroinds(spvec), convert(Vector{eltypevec}, nonzeros(spvec))) for spvec in spvecs]
 
                 for spvec in spvecs
                     fspvec = convert(Array, spvec)
@@ -1084,6 +1086,45 @@ end
             @test isequal(ldiv!(transpose(mat), copy(zerospvec)), zerospvec)
         end
     end
+    @testset "Triangular and SparseVector multiplications" begin
+        n = 10
+        types = (Int, Float64, ComplexF64)
+        tritypes = (LowerTriangular, UnitUpperTriangular)
+        for ta in types
+            for tri in tritypes
+                if ta == Int
+                    T = tri(rand(1:9, n, n))
+                else
+                    T = tri(randn(ta, n, n))
+                end
+                for tb in types
+                    if tb == Int
+                        x = sparse(rand(0:4, n))
+                    else
+                        x = sprandn(tb, n, 0.6)
+                    end
+                    @test T * x ≈ Array(T) * Array(x)
+                    @test T' * x ≈ Array(T)' * Array(x)
+                    @test transpose(T) * x ≈ transpose(Array(T)) * Array(x)
+                    @test x' * T ≈ Array(x)' * Array(T)
+                    @test x' * T' ≈ Array(x)' * Array(T)'
+                    @test x' * transpose(T) ≈ Array(x)' * transpose(Array(T))
+                end
+            end
+        end
+
+        # 0-dimensional case
+        x = sparse(zeros(0))
+        for tri in tritypes
+            T = tri(zeros(0, 0))
+            @test T*x == Array(T) * Array(x)
+            @test T' * x == Array(T)' * Array(x)
+            @test transpose(T) * x == transpose(Array(T)) * Array(x)
+            @test x' * T == Array(x)' * Array(T)
+            @test x' * T' == Array(x)' * Array(T)'
+            @test x' * transpose(T) == Array(x)' * transpose(Array(T))
+        end
+    end
 end
 
 @testset "fkeep!" begin
@@ -1116,9 +1157,9 @@ end
     vnegzeros[negzerosinds] .= -2
     vbothsigns = copy(vposzeros)
     vbothsigns[negzerosinds] .= -2
-    map!(x -> x == 2 ? 0.0 : x, vposzeros.nzval, vposzeros.nzval)
-    map!(x -> x == -2 ? -0.0 : x, vnegzeros.nzval, vnegzeros.nzval)
-    map!(x -> x == 2 ? 0.0 : x == -2 ? -0.0 : x, vbothsigns.nzval, vbothsigns.nzval)
+    map!(x -> x == 2 ? 0.0 : x, nonzeros(vposzeros), nonzeros(vposzeros))
+    map!(x -> x == -2 ? -0.0 : x, nonzeros(vnegzeros), nonzeros(vnegzeros))
+    map!(x -> x == 2 ? 0.0 : x == -2 ? -0.0 : x, nonzeros(vbothsigns), nonzeros(vbothsigns))
     for vwithzeros in (vposzeros, vnegzeros, vbothsigns)
         # Basic functionality / dropzeros!
         @test dropzeros!(copy(vwithzeros)) == v
@@ -1127,16 +1168,16 @@ end
         @test dropzeros(vwithzeros) == v
         @test dropzeros(vwithzeros, trim = false) == v
         # Check trimming works as expected
-        @test length(dropzeros!(copy(vwithzeros)).nzval) == length(v.nzval)
-        @test length(dropzeros!(copy(vwithzeros)).nzind) == length(v.nzind)
-        @test length(dropzeros!(copy(vwithzeros), trim = false).nzval) == length(vwithzeros.nzval)
-        @test length(dropzeros!(copy(vwithzeros), trim = false).nzind) == length(vwithzeros.nzind)
+        @test length(nonzeros(dropzeros!(copy(vwithzeros)))) == length(nonzeros(v))
+        @test length(nonzeroinds(dropzeros!(copy(vwithzeros)))) == length(nonzeroinds(v))
+        @test length(nonzeros(dropzeros!(copy(vwithzeros), trim = false))) == length(nonzeros(vwithzeros))
+        @test length(nonzeroinds(dropzeros!(copy(vwithzeros), trim = false))) == length(nonzeroinds(vwithzeros))
     end
 end
 
 @testset "original dropzeros! test" begin
     xdrop = sparsevec(1:7, [3., 2., -1., 1., -2., -3., 3.], 7)
-    xdrop.nzval[[2, 4, 6]] .= 0.0
+    nonzeros(xdrop)[[2, 4, 6]] .= 0.0
     SparseArrays.dropzeros!(xdrop)
     @test exact_equal(xdrop, SparseVector(7, [1, 3, 5, 7], [3, -1., -2., 3.]))
 end
@@ -1261,62 +1302,62 @@ end
     simA = similar(A)
     @test typeof(simA) == typeof(A)
     @test size(simA) == size(A)
-    @test simA.nzind == A.nzind
-    @test length(simA.nzval) == length(A.nzval)
+    @test nonzeroinds(simA) == nonzeroinds(A)
+    @test length(nonzeros(simA)) == length(nonzeros(A))
     # test similar with entry type specification (preserves stored-entry structure)
     simA = similar(A, Float32)
-    @test typeof(simA) == SparseVector{Float32,eltype(A.nzind)}
+    @test typeof(simA) == SparseVector{Float32,eltype(nonzeroinds(A))}
     @test size(simA) == size(A)
-    @test simA.nzind == A.nzind
-    @test length(simA.nzval) == length(A.nzval)
+    @test nonzeroinds(simA) == nonzeroinds(A)
+    @test length(nonzeros(simA)) == length(nonzeros(A))
     # test similar with entry and index type specification (preserves stored-entry structure)
     simA = similar(A, Float32, Int8)
     @test typeof(simA) == SparseVector{Float32,Int8}
     @test size(simA) == size(A)
-    @test simA.nzind == A.nzind
-    @test length(simA.nzval) == length(A.nzval)
+    @test nonzeroinds(simA) == nonzeroinds(A)
+    @test length(nonzeros(simA)) == length(nonzeros(A))
     # test similar with Dims{1} specification (preserves nothing)
     simA = similar(A, (6,))
     @test typeof(simA) == typeof(A)
     @test size(simA) == (6,)
-    @test length(simA.nzind) == 0
-    @test length(simA.nzval) == 0
+    @test length(nonzeroinds(simA)) == 0
+    @test length(nonzeros(simA)) == 0
     # test similar with entry type and Dims{1} specification (preserves nothing)
     simA = similar(A, Float32, (6,))
-    @test typeof(simA) == SparseVector{Float32,eltype(A.nzind)}
+    @test typeof(simA) == SparseVector{Float32,eltype(nonzeroinds(A))}
     @test size(simA) == (6,)
-    @test length(simA.nzind) == 0
-    @test length(simA.nzval) == 0
+    @test length(nonzeroinds(simA)) == 0
+    @test length(nonzeros(simA)) == 0
     # test similar with entry type, index type, and Dims{1} specification (preserves nothing)
     simA = similar(A, Float32, Int8, (6,))
     @test typeof(simA) == SparseVector{Float32,Int8}
     @test size(simA) == (6,)
-    @test length(simA.nzind) == 0
-    @test length(simA.nzval) == 0
+    @test length(nonzeroinds(simA)) == 0
+    @test length(nonzeros(simA)) == 0
     # test entry points to similar with entry type, index type, and non-Dims shape specification
     @test similar(A, Float32, Int8, 6, 6) == similar(A, Float32, Int8, (6, 6))
     @test similar(A, Float32, Int8, 6) == similar(A, Float32, Int8, (6,))
     # test similar with Dims{2} specification (preserves storage space only, not stored-entry structure)
     simA = similar(A, (6,6))
-    @test typeof(simA) == SparseMatrixCSC{eltype(A.nzval),eltype(A.nzind)}
+    @test typeof(simA) == SparseMatrixCSC{eltype(nonzeros(A)),eltype(nonzeroinds(A))}
     @test size(simA) == (6,6)
-    @test simA.colptr == fill(1, 6+1)
-    @test length(simA.rowval) == length(A.nzind)
-    @test length(simA.nzval) == length(A.nzval)
+    @test getcolptr(simA) == fill(1, 6+1)
+    @test length(rowvals(simA)) == length(nonzeroinds(A))
+    @test length(nonzeros(simA)) == length(nonzeros(A))
     # test similar with entry type and Dims{2} specification (preserves storage space only)
     simA = similar(A, Float32, (6,6))
-    @test typeof(simA) == SparseMatrixCSC{Float32,eltype(A.nzind)}
+    @test typeof(simA) == SparseMatrixCSC{Float32,eltype(nonzeroinds(A))}
     @test size(simA) == (6,6)
-    @test simA.colptr == fill(1, 6+1)
-    @test length(simA.rowval) == length(A.nzind)
-    @test length(simA.nzval) == length(A.nzval)
+    @test getcolptr(simA) == fill(1, 6+1)
+    @test length(rowvals(simA)) == length(nonzeroinds(A))
+    @test length(nonzeros(simA)) == length(nonzeros(A))
     # test similar with entry type, index type, and Dims{2} specification (preserves storage space only)
     simA = similar(A, Float32, Int8, (6,6))
     @test typeof(simA) == SparseMatrixCSC{Float32, Int8}
     @test size(simA) == (6,6)
-    @test simA.colptr == fill(1, 6+1)
-    @test length(simA.rowval) == length(A.nzind)
-    @test length(simA.nzval) == length(A.nzval)
+    @test getcolptr(simA) == fill(1, 6+1)
+    @test length(rowvals(simA)) == length(nonzeroinds(A))
+    @test length(nonzeros(simA)) == length(nonzeros(A))
 end
 
 @testset "Fast operations on full column views" begin
diff -pruN 1.3.1+dfsg-1/stdlib/Statistics/docs/src/index.md 1.4.0+dfsg-1/stdlib/Statistics/docs/src/index.md
--- 1.3.1+dfsg-1/stdlib/Statistics/docs/src/index.md	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/stdlib/Statistics/docs/src/index.md	1970-01-01 00:00:00.000000000 +0000
@@ -1,19 +0,0 @@
-# Statistics
-
-The Statistics module contains basic statistics functionality.
-
-```@docs
-Statistics.std
-Statistics.stdm
-Statistics.var
-Statistics.varm
-Statistics.cor
-Statistics.cov
-Statistics.mean!
-Statistics.mean
-Statistics.median!
-Statistics.median
-Statistics.middle
-Statistics.quantile!
-Statistics.quantile
-```
diff -pruN 1.3.1+dfsg-1/stdlib/Statistics/Project.toml 1.4.0+dfsg-1/stdlib/Statistics/Project.toml
--- 1.3.1+dfsg-1/stdlib/Statistics/Project.toml	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/stdlib/Statistics/Project.toml	1970-01-01 00:00:00.000000000 +0000
@@ -1,13 +0,0 @@
-name = "Statistics"
-uuid = "10745b16-79ce-11e8-11f9-7d13ad32a3b2"
-
-[deps]
-LinearAlgebra = "37e2e46d-f89d-539d-b4ee-838fcccc9c8e"
-SparseArrays = "2f01184e-e22b-5df5-ae63-d93ebab69eaf"
-
-[extras]
-Random = "9a3f8284-a2c9-5f02-9a11-845980a1fd5c"
-Test = "8dfed614-e22c-5e08-85e1-65c5234f0b40"
-
-[targets]
-test = ["Random", "Test"]
diff -pruN 1.3.1+dfsg-1/stdlib/Statistics/src/Statistics.jl 1.4.0+dfsg-1/stdlib/Statistics/src/Statistics.jl
--- 1.3.1+dfsg-1/stdlib/Statistics/src/Statistics.jl	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/stdlib/Statistics/src/Statistics.jl	1970-01-01 00:00:00.000000000 +0000
@@ -1,1058 +0,0 @@
-# This file is a part of Julia. License is MIT: https://julialang.org/license
-
-"""
-    Statistics
-
-Standard library module for basic statistics functionality.
-"""
-module Statistics
-
-using LinearAlgebra, SparseArrays
-
-using Base: has_offset_axes, require_one_based_indexing
-
-export cor, cov, std, stdm, var, varm, mean!, mean,
-    median!, median, middle, quantile!, quantile
-
-##### mean #####
-
-"""
-    mean(itr)
-
-Compute the mean of all elements in a collection.
-
-!!! note
-    If `itr` contains `NaN` or [`missing`](@ref) values, the result is also
-    `NaN` or `missing` (`missing` takes precedence if array contains both).
-    Use the [`skipmissing`](@ref) function to omit `missing` entries and compute the
-    mean of non-missing values.
-
-# Examples
-```jldoctest
-julia> mean(1:20)
-10.5
-
-julia> mean([1, missing, 3])
-missing
-
-julia> mean(skipmissing([1, missing, 3]))
-2.0
-```
-"""
-mean(itr) = mean(identity, itr)
-
-"""
-    mean(f::Function, itr)
-
-Apply the function `f` to each element of collection `itr` and take the mean.
-
-```jldoctest
-julia> mean(√, [1, 2, 3])
-1.3820881233139908
-
-julia> mean([√1, √2, √3])
-1.3820881233139908
-```
-"""
-function mean(f, itr)
-    y = iterate(itr)
-    if y === nothing
-        return Base.mapreduce_empty_iter(f, Base.add_sum, itr,
-                                         Base.IteratorEltype(itr)) / 0
-    end
-    count = 1
-    value, state = y
-    f_value = f(value)
-    total = Base.reduce_first(Base.add_sum, f_value)
-    y = iterate(itr, state)
-    while y !== nothing
-        value, state = y
-        total += f(value)
-        count += 1
-        y = iterate(itr, state)
-    end
-    return total/count
-end
-
-"""
-    mean(f::Function, A::AbstractArray; dims)
-
-Apply the function `f` to each element of array `A` and take the mean over dimensions `dims`.
-
-!!! compat "Julia 1.3"
-    This method requires at least Julia 1.3.
-
-```jldoctest
-julia> mean(√, [1, 2, 3])
-1.3820881233139908
-
-julia> mean([√1, √2, √3])
-1.3820881233139908
-
-julia> mean(√, [1 2 3; 4 5 6], dims=2)
-2×1 Array{Float64,2}:
- 1.3820881233139908
- 2.2285192400943226
-```
-"""
-mean(f, A::AbstractArray; dims=:) = _mean(f, A, dims)
-
-_mean(f, A::AbstractArray, ::Colon) = sum(f, A) / length(A)
-_mean(f, A::AbstractArray, dims) = sum(f, A, dims=dims) / mapreduce(i -> size(A, i), *, unique(dims); init=1)
-
-"""
-    mean!(r, v)
-
-Compute the mean of `v` over the singleton dimensions of `r`, and write results to `r`.
-
-# Examples
-```jldoctest
-julia> v = [1 2; 3 4]
-2×2 Array{Int64,2}:
- 1  2
- 3  4
-
-julia> mean!([1., 1.], v)
-2-element Array{Float64,1}:
- 1.5
- 3.5
-
-julia> mean!([1. 1.], v)
-1×2 Array{Float64,2}:
- 2.0  3.0
-```
-"""
-function mean!(R::AbstractArray, A::AbstractArray)
-    sum!(R, A; init=true)
-    x = max(1, length(R)) // length(A)
-    R .= R .* x
-    return R
-end
-
-"""
-    mean(A::AbstractArray; dims)
-
-Compute the mean of an array over the given dimensions.
-
-!!! compat "Julia 1.1"
-    `mean` for empty arrays requires at least Julia 1.1.
-
-# Examples
-```jldoctest
-julia> A = [1 2; 3 4]
-2×2 Array{Int64,2}:
- 1  2
- 3  4
-
-julia> mean(A, dims=1)
-1×2 Array{Float64,2}:
- 2.0  3.0
-
-julia> mean(A, dims=2)
-2×1 Array{Float64,2}:
- 1.5
- 3.5
-```
-"""
-mean(A::AbstractArray; dims=:) = _mean(A, dims)
-
-_mean(A::AbstractArray{T}, region) where {T} = mean!(Base.reducedim_init(t -> t/2, +, A, region), A)
-_mean(A::AbstractArray, ::Colon) = sum(A) / length(A)
-
-function mean(r::AbstractRange{<:Real})
-    isempty(r) && return oftype((first(r) + last(r)) / 2, NaN)
-    (first(r) + last(r)) / 2
-end
-
-median(r::AbstractRange{<:Real}) = mean(r)
-
-##### variances #####
-
-# faster computation of real(conj(x)*y)
-realXcY(x::Real, y::Real) = x*y
-realXcY(x::Complex, y::Complex) = real(x)*real(y) + imag(x)*imag(y)
-
-var(iterable; corrected::Bool=true, mean=nothing) = _var(iterable, corrected, mean)
-
-function _var(iterable, corrected::Bool, mean)
-    y = iterate(iterable)
-    if y === nothing
-        T = eltype(iterable)
-        return oftype((abs2(zero(T)) + abs2(zero(T)))/2, NaN)
-    end
-    count = 1
-    value, state = y
-    y = iterate(iterable, state)
-    if mean === nothing
-        # Use Welford algorithm as seen in (among other places)
-        # Knuth's TAOCP, Vol 2, page 232, 3rd edition.
-        M = value / 1
-        S = real(zero(M))
-        while y !== nothing
-            value, state = y
-            y = iterate(iterable, state)
-            count += 1
-            new_M = M + (value - M) / count
-            S = S + realXcY(value - M, value - new_M)
-            M = new_M
-        end
-        return S / (count - Int(corrected))
-    elseif isa(mean, Number) # mean provided
-        # Cannot use a compensated version, e.g. the one from
-        # "Updating Formulae and a Pairwise Algorithm for Computing Sample Variances."
-        # by Chan, Golub, and LeVeque, Technical Report STAN-CS-79-773,
-        # Department of Computer Science, Stanford University,
-        # because user can provide mean value that is different to mean(iterable)
-        sum2 = abs2(value - mean::Number)
-        while y !== nothing
-            value, state = y
-            y = iterate(iterable, state)
-            count += 1
-            sum2 += abs2(value - mean)
-        end
-        return sum2 / (count - Int(corrected))
-    else
-        throw(ArgumentError("invalid value of mean, $(mean)::$(typeof(mean))"))
-    end
-end
-
-centralizedabs2fun(m) = x -> abs2.(x - m)
-centralize_sumabs2(A::AbstractArray, m) =
-    mapreduce(centralizedabs2fun(m), +, A)
-centralize_sumabs2(A::AbstractArray, m, ifirst::Int, ilast::Int) =
-    Base.mapreduce_impl(centralizedabs2fun(m), +, A, ifirst, ilast)
-
-function centralize_sumabs2!(R::AbstractArray{S}, A::AbstractArray, means::AbstractArray) where S
-    # following the implementation of _mapreducedim! at base/reducedim.jl
-    lsiz = Base.check_reducedims(R,A)
-    isempty(R) || fill!(R, zero(S))
-    isempty(A) && return R
-
-    if Base.has_fast_linear_indexing(A) && lsiz > 16 && !has_offset_axes(R, means)
-        nslices = div(length(A), lsiz)
-        ibase = first(LinearIndices(A))-1
-        for i = 1:nslices
-            @inbounds R[i] = centralize_sumabs2(A, means[i], ibase+1, ibase+lsiz)
-            ibase += lsiz
-        end
-        return R
-    end
-    indsAt, indsRt = Base.safe_tail(axes(A)), Base.safe_tail(axes(R)) # handle d=1 manually
-    keep, Idefault = Broadcast.shapeindexer(indsRt)
-    if Base.reducedim1(R, A)
-        i1 = first(Base.axes1(R))
-        @inbounds for IA in CartesianIndices(indsAt)
-            IR = Broadcast.newindex(IA, keep, Idefault)
-            r = R[i1,IR]
-            m = means[i1,IR]
-            @simd for i in axes(A, 1)
-                r += abs2(A[i,IA] - m)
-            end
-            R[i1,IR] = r
-        end
-    else
-        @inbounds for IA in CartesianIndices(indsAt)
-            IR = Broadcast.newindex(IA, keep, Idefault)
-            @simd for i in axes(A, 1)
-                R[i,IR] += abs2(A[i,IA] - means[i,IR])
-            end
-        end
-    end
-    return R
-end
-
-function varm!(R::AbstractArray{S}, A::AbstractArray, m::AbstractArray; corrected::Bool=true) where S
-    if isempty(A)
-        fill!(R, convert(S, NaN))
-    else
-        rn = div(length(A), length(R)) - Int(corrected)
-        centralize_sumabs2!(R, A, m)
-        R .= R .* (1 // rn)
-    end
-    return R
-end
-
-"""
-    varm(itr, m; dims, corrected::Bool=true)
-
-Compute the sample variance of collection `itr`, with known mean(s) `m`.
-
-The algorithm returns an estimator of the generative distribution's variance
-under the assumption that each entry of `itr` is an IID drawn from that generative
-distribution. For arrays, this computation is equivalent to calculating
-`sum((itr .- mean(itr)).^2) / (length(itr) - 1)`.
-If `corrected` is `true`, then the sum is scaled with `n-1`,
-whereas the sum is scaled with `n` if `corrected` is
-`false` with `n` the number of elements in `itr`.
-
-If `itr` is an `AbstractArray`, `dims` can be provided to compute the variance
-over dimensions, and `m` may contain means for each dimension of `itr`.
-
-!!! note
-    If array contains `NaN` or [`missing`](@ref) values, the result is also
-    `NaN` or `missing` (`missing` takes precedence if array contains both).
-    Use the [`skipmissing`](@ref) function to omit `missing` entries and compute the
-    variance of non-missing values.
-"""
-varm(A::AbstractArray, m::AbstractArray; corrected::Bool=true, dims=:) = _varm(A, m, corrected, dims)
-
-_varm(A::AbstractArray{T}, m, corrected::Bool, region) where {T} =
-    varm!(Base.reducedim_init(t -> abs2(t)/2, +, A, region), A, m; corrected=corrected)
-
-varm(A::AbstractArray, m; corrected::Bool=true) = _varm(A, m, corrected, :)
-
-function _varm(A::AbstractArray{T}, m, corrected::Bool, ::Colon) where T
-    n = length(A)
-    n == 0 && return oftype((abs2(zero(T)) + abs2(zero(T)))/2, NaN)
-    return centralize_sumabs2(A, m) / (n - Int(corrected))
-end
-
-
-"""
-    var(itr; dims, corrected::Bool=true, mean=nothing)
-
-Compute the sample variance of collection `itr`.
-
-The algorithm returns an estimator of the generative distribution's variance
-under the assumption that each entry of `itr` is an IID drawn from that generative
-distribution. For arrays, this computation is equivalent to calculating
-`sum((itr .- mean(itr)).^2) / (length(itr) - 1)).
-If `corrected` is `true`, then the sum is scaled with `n-1`,
-whereas the sum is scaled with `n` if `corrected` is
-`false` with `n` the number of elements in `itr`.
-
-A pre-computed `mean` may be provided.
-
-If `itr` is an `AbstractArray`, `dims` can be provided to compute the variance
-over dimensions, and `mean` may contain means for each dimension of `itr`.
-
-!!! note
-    If array contains `NaN` or [`missing`](@ref) values, the result is also
-    `NaN` or `missing` (`missing` takes precedence if array contains both).
-    Use the [`skipmissing`](@ref) function to omit `missing` entries and compute the
-    variance of non-missing values.
-"""
-var(A::AbstractArray; corrected::Bool=true, mean=nothing, dims=:) = _var(A, corrected, mean, dims)
-
-_var(A::AbstractArray, corrected::Bool, mean, dims) =
-    varm(A, something(mean, Statistics.mean(A, dims=dims)); corrected=corrected, dims=dims)
-
-_var(A::AbstractArray, corrected::Bool, mean, ::Colon) =
-    real(varm(A, something(mean, Statistics.mean(A)); corrected=corrected))
-
-varm(iterable, m; corrected::Bool=true) = _var(iterable, corrected, m)
-
-## variances over ranges
-
-varm(v::AbstractRange, m::AbstractArray) = range_varm(v, m)
-varm(v::AbstractRange, m) = range_varm(v, m)
-
-function range_varm(v::AbstractRange, m)
-    f  = first(v) - m
-    s  = step(v)
-    l  = length(v)
-    vv = f^2 * l / (l - 1) + f * s * l + s^2 * l * (2 * l - 1) / 6
-    if l == 0 || l == 1
-        return typeof(vv)(NaN)
-    end
-    return vv
-end
-
-function var(v::AbstractRange)
-    s  = step(v)
-    l  = length(v)
-    vv = abs2(s) * (l + 1) * l / 12
-    if l == 0 || l == 1
-        return typeof(vv)(NaN)
-    end
-    return vv
-end
-
-
-##### standard deviation #####
-
-function sqrt!(A::AbstractArray)
-    for i in eachindex(A)
-        @inbounds A[i] = sqrt(A[i])
-    end
-    A
-end
-
-stdm(A::AbstractArray, m; corrected::Bool=true) =
-    sqrt.(varm(A, m; corrected=corrected))
-
-"""
-    std(itr; corrected::Bool=true, mean=nothing[, dims])
-
-Compute the sample standard deviation of collection `itr`.
-
-The algorithm returns an estimator of the generative distribution's standard
-deviation under the assumption that each entry of `itr` is an IID drawn from that generative
-distribution. For arrays, this computation is equivalent to calculating
-`sqrt(sum((itr .- mean(itr)).^2) / (length(itr) - 1))`.
-If `corrected` is `true`, then the sum is scaled with `n-1`,
-whereas the sum is scaled with `n` if `corrected` is
-`false` with `n` the number of elements in `itr`.
-
-A pre-computed `mean` may be provided.
-
-If `itr` is an `AbstractArray`, `dims` can be provided to compute the standard deviation
-over dimensions, and `means` may contain means for each dimension of `itr`.
-
-!!! note
-    If array contains `NaN` or [`missing`](@ref) values, the result is also
-    `NaN` or `missing` (`missing` takes precedence if array contains both).
-    Use the [`skipmissing`](@ref) function to omit `missing` entries and compute the
-    standard deviation of non-missing values.
-"""
-std(A::AbstractArray; corrected::Bool=true, mean=nothing, dims=:) = _std(A, corrected, mean, dims)
-
-_std(A::AbstractArray, corrected::Bool, mean, dims) =
-    sqrt.(var(A; corrected=corrected, mean=mean, dims=dims))
-
-_std(A::AbstractArray, corrected::Bool, mean, ::Colon) =
-    sqrt.(var(A; corrected=corrected, mean=mean))
-
-_std(A::AbstractArray{<:AbstractFloat}, corrected::Bool, mean, dims) =
-    sqrt!(var(A; corrected=corrected, mean=mean, dims=dims))
-
-_std(A::AbstractArray{<:AbstractFloat}, corrected::Bool, mean, ::Colon) =
-    sqrt.(var(A; corrected=corrected, mean=mean))
-
-std(iterable; corrected::Bool=true, mean=nothing) =
-    sqrt(var(iterable, corrected=corrected, mean=mean))
-
-"""
-    stdm(itr, m; corrected::Bool=true)
-
-Compute the sample standard deviation of collection `itr`, with known mean(s) `m`.
-
-The algorithm returns an estimator of the generative distribution's standard
-deviation under the assumption that each entry of `itr` is an IID drawn from that generative
-distribution. For arrays, this computation is equivalent to calculating
-`sqrt(sum((itr .- mean(itr)).^2) / (length(itr) - 1))`.
-If `corrected` is `true`, then the sum is scaled with `n-1`,
-whereas the sum is scaled with `n` if `corrected` is
-`false` with `n` the number of elements in `itr`.
-
-A pre-computed `mean` may be provided.
-
-If `itr` is an `AbstractArray`, `dims` can be provided to compute the standard deviation
-over dimensions, and `m` may contain means for each dimension of `itr`.
-
-!!! note
-    If array contains `NaN` or [`missing`](@ref) values, the result is also
-    `NaN` or `missing` (`missing` takes precedence if array contains both).
-    Use the [`skipmissing`](@ref) function to omit `missing` entries and compute the
-    standard deviation of non-missing values.
-"""
-stdm(iterable, m; corrected::Bool=true) =
-    std(iterable, corrected=corrected, mean=m)
-
-
-###### covariance ######
-
-# auxiliary functions
-
-_conj(x::AbstractArray{<:Real}) = x
-_conj(x::AbstractArray) = conj(x)
-
-_getnobs(x::AbstractVector, vardim::Int) = length(x)
-_getnobs(x::AbstractMatrix, vardim::Int) = size(x, vardim)
-
-function _getnobs(x::AbstractVecOrMat, y::AbstractVecOrMat, vardim::Int)
-    n = _getnobs(x, vardim)
-    _getnobs(y, vardim) == n || throw(DimensionMismatch("dimensions of x and y mismatch"))
-    return n
-end
-
-_vmean(x::AbstractVector, vardim::Int) = mean(x)
-_vmean(x::AbstractMatrix, vardim::Int) = mean(x, dims=vardim)
-
-# core functions
-
-unscaled_covzm(x::AbstractVector{<:Number})    = sum(abs2, x)
-unscaled_covzm(x::AbstractVector)              = sum(t -> t*t', x)
-unscaled_covzm(x::AbstractMatrix, vardim::Int) = (vardim == 1 ? _conj(x'x) : x * x')
-
-unscaled_covzm(x::AbstractVector, y::AbstractVector) = sum(conj(y[i])*x[i] for i in eachindex(y, x))
-unscaled_covzm(x::AbstractVector, y::AbstractMatrix, vardim::Int) =
-    (vardim == 1 ? *(transpose(x), _conj(y)) : *(transpose(x), transpose(_conj(y))))
-unscaled_covzm(x::AbstractMatrix, y::AbstractVector, vardim::Int) =
-    (c = vardim == 1 ? *(transpose(x), _conj(y)) :  x * _conj(y); reshape(c, length(c), 1))
-unscaled_covzm(x::AbstractMatrix, y::AbstractMatrix, vardim::Int) =
-    (vardim == 1 ? *(transpose(x), _conj(y)) : *(x, adjoint(y)))
-
-# covzm (with centered data)
-
-covzm(x::AbstractVector; corrected::Bool=true) = unscaled_covzm(x) / (length(x) - Int(corrected))
-function covzm(x::AbstractMatrix, vardim::Int=1; corrected::Bool=true)
-    C = unscaled_covzm(x, vardim)
-    T = promote_type(typeof(first(C) / 1), eltype(C))
-    A = convert(AbstractMatrix{T}, C)
-    b = 1//(size(x, vardim) - corrected)
-    A .= A .* b
-    return A
-end
-covzm(x::AbstractVector, y::AbstractVector; corrected::Bool=true) =
-    unscaled_covzm(x, y) / (length(x) - Int(corrected))
-function covzm(x::AbstractVecOrMat, y::AbstractVecOrMat, vardim::Int=1; corrected::Bool=true)
-    C = unscaled_covzm(x, y, vardim)
-    T = promote_type(typeof(first(C) / 1), eltype(C))
-    A = convert(AbstractArray{T}, C)
-    b = 1//(_getnobs(x, y, vardim) - corrected)
-    A .= A .* b
-    return A
-end
-
-# covm (with provided mean)
-## Use map(t -> t - xmean, x) instead of x .- xmean to allow for Vector{Vector}
-## which can't be handled by broadcast
-covm(x::AbstractVector, xmean; corrected::Bool=true) =
-    covzm(map(t -> t - xmean, x); corrected=corrected)
-covm(x::AbstractMatrix, xmean, vardim::Int=1; corrected::Bool=true) =
-    covzm(x .- xmean, vardim; corrected=corrected)
-covm(x::AbstractVector, xmean, y::AbstractVector, ymean; corrected::Bool=true) =
-    covzm(map(t -> t - xmean, x), map(t -> t - ymean, y); corrected=corrected)
-covm(x::AbstractVecOrMat, xmean, y::AbstractVecOrMat, ymean, vardim::Int=1; corrected::Bool=true) =
-    covzm(x .- xmean, y .- ymean, vardim; corrected=corrected)
-
-# cov (API)
-"""
-    cov(x::AbstractVector; corrected::Bool=true)
-
-Compute the variance of the vector `x`. If `corrected` is `true` (the default) then the sum
-is scaled with `n-1`, whereas the sum is scaled with `n` if `corrected` is `false` where `n = length(x)`.
-"""
-cov(x::AbstractVector; corrected::Bool=true) = covm(x, mean(x); corrected=corrected)
-
-"""
-    cov(X::AbstractMatrix; dims::Int=1, corrected::Bool=true)
-
-Compute the covariance matrix of the matrix `X` along the dimension `dims`. If `corrected`
-is `true` (the default) then the sum is scaled with `n-1`, whereas the sum is scaled with `n`
-if `corrected` is `false` where `n = size(X, dims)`.
-"""
-cov(X::AbstractMatrix; dims::Int=1, corrected::Bool=true) =
-    covm(X, _vmean(X, dims), dims; corrected=corrected)
-
-"""
-    cov(x::AbstractVector, y::AbstractVector; corrected::Bool=true)
-
-Compute the covariance between the vectors `x` and `y`. If `corrected` is `true` (the
-default), computes ``\\frac{1}{n-1}\\sum_{i=1}^n (x_i-\\bar x) (y_i-\\bar y)^*`` where
-``*`` denotes the complex conjugate and `n = length(x) = length(y)`. If `corrected` is
-`false`, computes ``\\frac{1}{n}\\sum_{i=1}^n (x_i-\\bar x) (y_i-\\bar y)^*``.
-"""
-cov(x::AbstractVector, y::AbstractVector; corrected::Bool=true) =
-    covm(x, mean(x), y, mean(y); corrected=corrected)
-
-"""
-    cov(X::AbstractVecOrMat, Y::AbstractVecOrMat; dims::Int=1, corrected::Bool=true)
-
-Compute the covariance between the vectors or matrices `X` and `Y` along the dimension
-`dims`. If `corrected` is `true` (the default) then the sum is scaled with `n-1`, whereas
-the sum is scaled with `n` if `corrected` is `false` where `n = size(X, dims) = size(Y, dims)`.
-"""
-cov(X::AbstractVecOrMat, Y::AbstractVecOrMat; dims::Int=1, corrected::Bool=true) =
-    covm(X, _vmean(X, dims), Y, _vmean(Y, dims), dims; corrected=corrected)
-
-##### correlation #####
-
-"""
-    clampcor(x)
-
-Clamp a real correlation to between -1 and 1, leaving complex correlations unchanged
-"""
-clampcor(x::Real) = clamp(x, -1, 1)
-clampcor(x) = x
-
-# cov2cor!
-
-function cov2cor!(C::AbstractMatrix{T}, xsd::AbstractArray) where T
-    require_one_based_indexing(C, xsd)
-    nx = length(xsd)
-    size(C) == (nx, nx) || throw(DimensionMismatch("inconsistent dimensions"))
-    for j = 1:nx
-        for i = 1:j-1
-            C[i,j] = adjoint(C[j,i])
-        end
-        C[j,j] = oneunit(T)
-        for i = j+1:nx
-            C[i,j] = clampcor(C[i,j] / (xsd[i] * xsd[j]))
-        end
-    end
-    return C
-end
-function cov2cor!(C::AbstractMatrix, xsd, ysd::AbstractArray)
-    require_one_based_indexing(C, ysd)
-    nx, ny = size(C)
-    length(ysd) == ny || throw(DimensionMismatch("inconsistent dimensions"))
-    for (j, y) in enumerate(ysd)   # fixme (iter): here and in all `cov2cor!` we assume that `C` is efficiently indexed by integers
-        for i in 1:nx
-            C[i,j] = clampcor(C[i, j] / (xsd * y))
-        end
-    end
-    return C
-end
-function cov2cor!(C::AbstractMatrix, xsd::AbstractArray, ysd)
-    require_one_based_indexing(C, xsd)
-    nx, ny = size(C)
-    length(xsd) == nx || throw(DimensionMismatch("inconsistent dimensions"))
-    for j in 1:ny
-        for (i, x) in enumerate(xsd)
-            C[i,j] = clampcor(C[i,j] / (x * ysd))
-        end
-    end
-    return C
-end
-function cov2cor!(C::AbstractMatrix, xsd::AbstractArray, ysd::AbstractArray)
-    require_one_based_indexing(C, xsd, ysd)
-    nx, ny = size(C)
-    (length(xsd) == nx && length(ysd) == ny) ||
-        throw(DimensionMismatch("inconsistent dimensions"))
-    for (i, x) in enumerate(xsd)
-        for (j, y) in enumerate(ysd)
-            C[i,j] = clampcor(C[i,j] / (x * y))
-        end
-    end
-    return C
-end
-
-# corzm (non-exported, with centered data)
-
-corzm(x::AbstractVector{T}) where {T} = one(real(T))
-function corzm(x::AbstractMatrix, vardim::Int=1)
-    c = unscaled_covzm(x, vardim)
-    return cov2cor!(c, collect(sqrt(c[i,i]) for i in 1:min(size(c)...)))
-end
-corzm(x::AbstractVector, y::AbstractMatrix, vardim::Int=1) =
-    cov2cor!(unscaled_covzm(x, y, vardim), sqrt(sum(abs2, x)), sqrt!(sum(abs2, y, dims=vardim)))
-corzm(x::AbstractMatrix, y::AbstractVector, vardim::Int=1) =
-    cov2cor!(unscaled_covzm(x, y, vardim), sqrt!(sum(abs2, x, dims=vardim)), sqrt(sum(abs2, y)))
-corzm(x::AbstractMatrix, y::AbstractMatrix, vardim::Int=1) =
-    cov2cor!(unscaled_covzm(x, y, vardim), sqrt!(sum(abs2, x, dims=vardim)), sqrt!(sum(abs2, y, dims=vardim)))
-
-# corm
-
-corm(x::AbstractVector{T}, xmean) where {T} = one(real(T))
-corm(x::AbstractMatrix, xmean, vardim::Int=1) = corzm(x .- xmean, vardim)
-function corm(x::AbstractVector, mx, y::AbstractVector, my)
-    require_one_based_indexing(x, y)
-    n = length(x)
-    length(y) == n || throw(DimensionMismatch("inconsistent lengths"))
-    n > 0 || throw(ArgumentError("correlation only defined for non-empty vectors"))
-
-    @inbounds begin
-        # Initialize the accumulators
-        xx = zero(sqrt(abs2(one(x[1]))))
-        yy = zero(sqrt(abs2(one(y[1]))))
-        xy = zero(x[1] * y[1]')
-
-        @simd for i in eachindex(x, y)
-            xi = x[i] - mx
-            yi = y[i] - my
-            xx += abs2(xi)
-            yy += abs2(yi)
-            xy += xi * yi'
-        end
-    end
-    return clampcor(xy / max(xx, yy) / sqrt(min(xx, yy) / max(xx, yy)))
-end
-
-corm(x::AbstractVecOrMat, xmean, y::AbstractVecOrMat, ymean, vardim::Int=1) =
-    corzm(x .- xmean, y .- ymean, vardim)
-
-# cor
-"""
-    cor(x::AbstractVector)
-
-Return the number one.
-"""
-cor(x::AbstractVector) = one(real(eltype(x)))
-
-"""
-    cor(X::AbstractMatrix; dims::Int=1)
-
-Compute the Pearson correlation matrix of the matrix `X` along the dimension `dims`.
-"""
-cor(X::AbstractMatrix; dims::Int=1) = corm(X, _vmean(X, dims), dims)
-
-"""
-    cor(x::AbstractVector, y::AbstractVector)
-
-Compute the Pearson correlation between the vectors `x` and `y`.
-"""
-cor(x::AbstractVector, y::AbstractVector) = corm(x, mean(x), y, mean(y))
-
-"""
-    cor(X::AbstractVecOrMat, Y::AbstractVecOrMat; dims=1)
-
-Compute the Pearson correlation between the vectors or matrices `X` and `Y` along the dimension `dims`.
-"""
-cor(x::AbstractVecOrMat, y::AbstractVecOrMat; dims::Int=1) =
-    corm(x, _vmean(x, dims), y, _vmean(y, dims), dims)
-
-##### median & quantiles #####
-
-"""
-    middle(x)
-
-Compute the middle of a scalar value, which is equivalent to `x` itself, but of the type of `middle(x, x)` for consistency.
-"""
-middle(x::Union{Bool,Int8,Int16,Int32,Int64,Int128,UInt8,UInt16,UInt32,UInt64,UInt128}) = Float64(x)
-# Specialized functions for real types allow for improved performance
-middle(x::AbstractFloat) = x
-middle(x::Real) = (x + zero(x)) / 1
-
-"""
-    middle(x, y)
-
-Compute the middle of two reals `x` and `y`, which is
-equivalent in both value and type to computing their mean (`(x + y) / 2`).
-"""
-middle(x::Real, y::Real) = x/2 + y/2
-
-"""
-    middle(range)
-
-Compute the middle of a range, which consists of computing the mean of its extrema.
-Since a range is sorted, the mean is performed with the first and last element.
-
-```jldoctest
-julia> middle(1:10)
-5.5
-```
-"""
-middle(a::AbstractRange) = middle(a[1], a[end])
-
-"""
-    middle(a)
-
-Compute the middle of an array `a`, which consists of finding its
-extrema and then computing their mean.
-
-```jldoctest
-julia> a = [1,2,3.6,10.9]
-4-element Array{Float64,1}:
-  1.0
-  2.0
-  3.6
- 10.9
-
-julia> middle(a)
-5.95
-```
-"""
-middle(a::AbstractArray) = ((v1, v2) = extrema(a); middle(v1, v2))
-
-"""
-    median!(v)
-
-Like [`median`](@ref), but may overwrite the input vector.
-"""
-function median!(v::AbstractVector)
-    isempty(v) && throw(ArgumentError("median of an empty array is undefined, $(repr(v))"))
-    eltype(v)>:Missing && any(ismissing, v) && return missing
-    (eltype(v)<:AbstractFloat || eltype(v)>:AbstractFloat) && any(isnan, v) && return convert(eltype(v), NaN)
-    inds = axes(v, 1)
-    n = length(inds)
-    mid = div(first(inds)+last(inds),2)
-    if isodd(n)
-        return middle(partialsort!(v,mid))
-    else
-        m = partialsort!(v, mid:mid+1)
-        return middle(m[1], m[2])
-    end
-end
-median!(v::AbstractArray) = median!(vec(v))
-
-"""
-    median(itr)
-
-Compute the median of all elements in a collection.
-For an even number of elements no exact median element exists, so the result is
-equivalent to calculating mean of two median elements.
-
-!!! note
-    If `itr` contains `NaN` or [`missing`](@ref) values, the result is also
-    `NaN` or `missing` (`missing` takes precedence if `itr` contains both).
-    Use the [`skipmissing`](@ref) function to omit `missing` entries and compute the
-    median of non-missing values.
-
-# Examples
-```jldoctest
-julia> median([1, 2, 3])
-2.0
-
-julia> median([1, 2, 3, 4])
-2.5
-
-julia> median([1, 2, missing, 4])
-missing
-
-julia> median(skipmissing([1, 2, missing, 4]))
-2.0
-```
-"""
-median(itr) = median!(collect(itr))
-
-"""
-    median(A::AbstractArray; dims)
-
-Compute the median of an array along the given dimensions.
-
-# Examples
-```jldoctest
-julia> median([1 2; 3 4], dims=1)
-1×2 Array{Float64,2}:
- 2.0  3.0
-```
-"""
-median(v::AbstractArray; dims=:) = _median(v, dims)
-
-_median(v::AbstractArray, dims) = mapslices(median!, v, dims = dims)
-
-_median(v::AbstractArray{T}, ::Colon) where {T} = median!(copyto!(Array{T,1}(undef, length(v)), v))
-
-# for now, use the R/S definition of quantile; may want variants later
-# see ?quantile in R -- this is type 7
-"""
-    quantile!([q::AbstractArray, ] v::AbstractVector, p; sorted=false)
-
-Compute the quantile(s) of a vector `v` at a specified probability or vector or tuple of
-probabilities `p` on the interval [0,1]. If `p` is a vector, an optional
-output array `q` may also be specified. (If not provided, a new output array is created.)
-The keyword argument `sorted` indicates whether `v` can be assumed to be sorted; if
-`false` (the default), then the elements of `v` will be partially sorted in-place.
-
-Quantiles are computed via linear interpolation between the points `((k-1)/(n-1), v[k])`,
-for `k = 1:n` where `n = length(v)`. This corresponds to Definition 7 of Hyndman and Fan
-(1996), and is the same as the R default.
-
-!!! note
-    An `ArgumentError` is thrown if `v` contains `NaN` or [`missing`](@ref) values.
-
-* Hyndman, R.J and Fan, Y. (1996) "Sample Quantiles in Statistical Packages",
-  *The American Statistician*, Vol. 50, No. 4, pp. 361-365
-
-# Examples
-```jldoctest
-julia> x = [3, 2, 1];
-
-julia> quantile!(x, 0.5)
-2.0
-
-julia> x
-3-element Array{Int64,1}:
- 1
- 2
- 3
-
-julia> y = zeros(3);
-
-julia> quantile!(y, x, [0.1, 0.5, 0.9]) === y
-true
-
-julia> y
-3-element Array{Float64,1}:
- 1.2
- 2.0
- 2.8
-```
-"""
-function quantile!(q::AbstractArray, v::AbstractVector, p::AbstractArray;
-                   sorted::Bool=false)
-    require_one_based_indexing(q, v, p)
-    if size(p) != size(q)
-        throw(DimensionMismatch("size of p, $(size(p)), must equal size of q, $(size(q))"))
-    end
-    isempty(q) && return q
-
-    minp, maxp = extrema(p)
-    _quantilesort!(v, sorted, minp, maxp)
-
-    for (i, j) in zip(eachindex(p), eachindex(q))
-        @inbounds q[j] = _quantile(v,p[i])
-    end
-    return q
-end
-
-function quantile!(v::AbstractVector, p::Union{AbstractArray, Tuple{Vararg{Real}}};
-                   sorted::Bool=false)
-    if !isempty(p)
-        minp, maxp = extrema(p)
-        _quantilesort!(v, sorted, minp, maxp)
-    end
-    return map(x->_quantile(v, x), p)
-end
-
-quantile!(v::AbstractVector, p::Real; sorted::Bool=false) =
-    _quantile(_quantilesort!(v, sorted, p, p), p)
-
-# Function to perform partial sort of v for quantiles in given range
-function _quantilesort!(v::AbstractArray, sorted::Bool, minp::Real, maxp::Real)
-    isempty(v) && throw(ArgumentError("empty data vector"))
-    require_one_based_indexing(v)
-
-    if !sorted
-        lv = length(v)
-        lo = floor(Int,1+minp*(lv-1))
-        hi = ceil(Int,1+maxp*(lv-1))
-
-        # only need to perform partial sort
-        sort!(v, 1, lv, Base.Sort.PartialQuickSort(lo:hi), Base.Sort.Forward)
-    end
-    ismissing(v[end]) && throw(ArgumentError("quantiles are undefined in presence of missing values"))
-    isnan(v[end]) && throw(ArgumentError("quantiles are undefined in presence of NaNs"))
-    return v
-end
-
-# Core quantile lookup function: assumes `v` sorted
-@inline function _quantile(v::AbstractVector, p::Real)
-    0 <= p <= 1 || throw(ArgumentError("input probability out of [0,1] range"))
-    require_one_based_indexing(v)
-
-    lv = length(v)
-    f0 = (lv - 1)*p # 0-based interpolated index
-    t0 = trunc(f0)
-    h  = f0 - t0
-    i  = trunc(Int,t0) + 1
-
-    a = v[i]
-    b = v[i + (h > 0)]
-    if isfinite(a) && isfinite(b)
-        return a + h*(b-a)
-    else
-        return (1-h)*a + h*b
-    end
-end
-
-
-"""
-    quantile(itr, p; sorted=false)
-
-Compute the quantile(s) of a collection `itr` at a specified probability or vector or tuple of
-probabilities `p` on the interval [0,1]. The keyword argument `sorted` indicates whether
-`itr` can be assumed to be sorted.
-
-Quantiles are computed via linear interpolation between the points `((k-1)/(n-1), v[k])`,
-for `k = 1:n` where `n = length(itr)`. This corresponds to Definition 7 of Hyndman and Fan
-(1996), and is the same as the R default.
-
-!!! note
-    An `ArgumentError` is thrown if `itr` contains `NaN` or [`missing`](@ref) values.
-    Use the [`skipmissing`](@ref) function to omit `missing` entries and compute the
-    quantiles of non-missing values.
-
-- Hyndman, R.J and Fan, Y. (1996) "Sample Quantiles in Statistical Packages",
-  *The American Statistician*, Vol. 50, No. 4, pp. 361-365
-
-# Examples
-```jldoctest
-julia> quantile(0:20, 0.5)
-10.0
-
-julia> quantile(0:20, [0.1, 0.5, 0.9])
-3-element Array{Float64,1}:
-  2.0
- 10.0
- 18.0
-
-julia> quantile(skipmissing([1, 10, missing]), 0.5)
-5.5
-```
-"""
-quantile(itr, p; sorted::Bool=false) = quantile!(collect(itr), p, sorted=sorted)
-
-quantile(v::AbstractVector, p; sorted::Bool=false) =
-    quantile!(sorted ? v : Base.copymutable(v), p; sorted=sorted)
-
-
-##### SparseArrays optimizations #####
-
-function cov(X::SparseMatrixCSC; dims::Int=1, corrected::Bool=true)
-    vardim = dims
-    a, b = size(X)
-    n, p = vardim == 1 ? (a, b) : (b, a)
-
-    # The covariance can be decomposed into two terms
-    # 1/(n - 1) ∑ (x_i - x̄)*(x_i - x̄)' = 1/(n - 1) (∑ x_i*x_i' - n*x̄*x̄')
-    # which can be evaluated via a sparse matrix-matrix product
-
-    # Compute ∑ x_i*x_i' = X'X using sparse matrix-matrix product
-    out = Matrix(unscaled_covzm(X, vardim))
-
-    # Compute x̄
-    x̄ᵀ = mean(X, dims=vardim)
-
-    # Subtract n*x̄*x̄' from X'X
-    @inbounds for j in 1:p, i in 1:p
-        out[i,j] -= x̄ᵀ[i] * x̄ᵀ[j]' * n
-    end
-
-    # scale with the sample size n or the corrected sample size n - 1
-    return rmul!(out, inv(n - corrected))
-end
-
-# This is the function that does the reduction underlying var/std
-function centralize_sumabs2!(R::AbstractArray{S}, A::SparseMatrixCSC{Tv,Ti}, means::AbstractArray) where {S,Tv,Ti}
-    require_one_based_indexing(R, A, means)
-    lsiz = Base.check_reducedims(R,A)
-    size(means) == size(R) || error("size of means must match size of R")
-    isempty(R) || fill!(R, zero(S))
-    isempty(A) && return R
-
-    colptr = A.colptr
-    rowval = A.rowval
-    nzval = A.nzval
-    m = size(A, 1)
-    n = size(A, 2)
-
-    if size(R, 1) == size(R, 2) == 1
-        # Reduction along both columns and rows
-        R[1, 1] = centralize_sumabs2(A, means[1])
-    elseif size(R, 1) == 1
-        # Reduction along rows
-        @inbounds for col = 1:n
-            mu = means[col]
-            r = convert(S, (m-colptr[col+1]+colptr[col])*abs2(mu))
-            @simd for j = colptr[col]:colptr[col+1]-1
-                r += abs2(nzval[j] - mu)
-            end
-            R[1, col] = r
-        end
-    elseif size(R, 2) == 1
-        # Reduction along columns
-        rownz = fill(convert(Ti, n), m)
-        @inbounds for col = 1:n
-            @simd for j = colptr[col]:colptr[col+1]-1
-                row = rowval[j]
-                R[row, 1] += abs2(nzval[j] - means[row])
-                rownz[row] -= 1
-            end
-        end
-        for i = 1:m
-            R[i, 1] += rownz[i]*abs2(means[i])
-        end
-    else
-        # Reduction along a dimension > 2
-        @inbounds for col = 1:n
-            lastrow = 0
-            @simd for j = colptr[col]:colptr[col+1]-1
-                row = rowval[j]
-                for i = lastrow+1:row-1
-                    R[i, col] = abs2(means[i, col])
-                end
-                R[row, col] = abs2(nzval[j] - means[row, col])
-                lastrow = row
-            end
-            for i = lastrow+1:m
-                R[i, col] = abs2(means[i, col])
-            end
-        end
-    end
-    return R
-end
-
-end # module
diff -pruN 1.3.1+dfsg-1/stdlib/Statistics/test/runtests.jl 1.4.0+dfsg-1/stdlib/Statistics/test/runtests.jl
--- 1.3.1+dfsg-1/stdlib/Statistics/test/runtests.jl	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/stdlib/Statistics/test/runtests.jl	1970-01-01 00:00:00.000000000 +0000
@@ -1,728 +0,0 @@
-# This file is a part of Julia. License is MIT: https://julialang.org/license
-
-using Statistics, Test, Random, LinearAlgebra, SparseArrays
-using Test: guardseed
-
-@testset "middle" begin
-    @test middle(3) === 3.0
-    @test middle(2, 3) === 2.5
-    let x = ((floatmax(1.0)/4)*3)
-        @test middle(x, x) === x
-    end
-    @test middle(1:8) === 4.5
-    @test middle([1:8;]) === 4.5
-
-    # ensure type-correctness
-    for T in [Bool,Int8,Int16,Int32,Int64,Int128,UInt8,UInt16,UInt32,UInt64,UInt128,Float16,Float32,Float64]
-        @test middle(one(T)) === middle(one(T), one(T))
-    end
-end
-
-@testset "median" begin
-    @test median([1.]) === 1.
-    @test median([1.,3]) === 2.
-    @test median([1.,3,2]) === 2.
-
-    @test median([1,3,2]) === 2.0
-    @test median([1,3,2,4]) === 2.5
-
-    @test median([0.0,Inf]) == Inf
-    @test median([0.0,-Inf]) == -Inf
-    @test median([0.,Inf,-Inf]) == 0.0
-    @test median([1.,-1.,Inf,-Inf]) == 0.0
-    @test isnan(median([-Inf,Inf]))
-
-    X = [2 3 1 -1; 7 4 5 -4]
-    @test all(median(X, dims=2) .== [1.5, 4.5])
-    @test all(median(X, dims=1) .== [4.5 3.5 3.0 -2.5])
-    @test X == [2 3 1 -1; 7 4 5 -4] # issue #17153
-
-    @test_throws ArgumentError median([])
-    @test isnan(median([NaN]))
-    @test isnan(median([0.0,NaN]))
-    @test isnan(median([NaN,0.0]))
-    @test isnan(median([NaN,0.0,1.0]))
-    @test isnan(median(Any[NaN,0.0,1.0]))
-    @test isequal(median([NaN 0.0; 1.2 4.5], dims=2), reshape([NaN; 2.85], 2, 1))
-
-    @test ismissing(median([1, missing]))
-    @test ismissing(median([1, 2, missing]))
-    @test ismissing(median([NaN, 2.0, missing]))
-    @test ismissing(median([NaN, missing]))
-    @test ismissing(median([missing, NaN]))
-    @test ismissing(median(Any[missing, 2.0, 3.0, 4.0, NaN]))
-    @test median(skipmissing([1, missing, 2])) === 1.5
-
-    @test median!([1 2 3 4]) == 2.5
-    @test median!([1 2; 3 4]) == 2.5
-
-    @test invoke(median, Tuple{AbstractVector}, 1:10) == median(1:10) == 5.5
-
-    @test @inferred(median(Float16[1, 2, NaN])) === Float16(NaN)
-    @test @inferred(median(Float16[1, 2, 3]))   === Float16(2)
-    @test @inferred(median(Float32[1, 2, NaN])) === NaN32
-    @test @inferred(median(Float32[1, 2, 3]))   === 2.0f0
-end
-
-@testset "mean" begin
-    @test_throws MethodError mean(())
-    @test mean((1,2,3)) === 2.
-    @test mean([0]) === 0.
-    @test mean([1.]) === 1.
-    @test mean([1.,3]) == 2.
-    @test mean([1,2,3]) == 2.
-    @test mean([0 1 2; 4 5 6], dims=1) == [2.  3.  4.]
-    @test mean([1 2 3; 4 5 6], dims=1) == [2.5 3.5 4.5]
-    @test mean(-, [1 2 3 ; 4 5 6], dims=1) == [-2.5 -3.5 -4.5]
-    @test mean(-, [1 2 3 ; 4 5 6], dims=2) == transpose([-2.0 -5.0])
-    @test mean(-, [1 2 3 ; 4 5 6], dims=(1, 2)) == -3.5 .* ones(1, 1)
-    @test mean(-, [1 2 3 ; 4 5 6], dims=(1, 1)) == [-2.5 -3.5 -4.5]
-    @test mean(-, [1 2 3 ; 4 5 6], dims=()) == Float64[-1 -2 -3 ; -4 -5 -6]
-    @test mean(i->i+1, 0:2) === 2.
-    @test mean(isodd, [3]) === 1.
-    @test mean(x->3x, (1,1)) === 3.
-
-    @test isnan(mean([NaN]))
-    @test isnan(mean([0.0,NaN]))
-    @test isnan(mean([NaN,0.0]))
-
-    @test isnan(mean([0.,Inf,-Inf]))
-    @test isnan(mean([1.,-1.,Inf,-Inf]))
-    @test isnan(mean([-Inf,Inf]))
-    @test isequal(mean([NaN 0.0; 1.2 4.5], dims=2), reshape([NaN; 2.85], 2, 1))
-
-    @test ismissing(mean([1, missing]))
-    @test ismissing(mean([NaN, missing]))
-    @test ismissing(mean([missing, NaN]))
-    @test isequal(mean([missing 1.0; 2.0 3.0], dims=1), [missing 2.0])
-    @test mean(skipmissing([1, missing, 2])) === 1.5
-    @test isequal(mean(Complex{Float64}[]), NaN+NaN*im)
-    @test mean(Complex{Float64}[]) isa Complex{Float64}
-    @test isequal(mean(skipmissing(Complex{Float64}[])), NaN+NaN*im)
-    @test mean(skipmissing(Complex{Float64}[])) isa Complex{Float64}
-    @test isequal(mean(abs, Complex{Float64}[]), NaN)
-    @test mean(abs, Complex{Float64}[]) isa Float64
-    @test isequal(mean(abs, skipmissing(Complex{Float64}[])), NaN)
-    @test mean(abs, skipmissing(Complex{Float64}[])) isa Float64
-    @test isequal(mean(Int[]), NaN)
-    @test mean(Int[]) isa Float64
-    @test isequal(mean(skipmissing(Int[])), NaN)
-    @test mean(skipmissing(Int[])) isa Float64
-    @test_throws MethodError mean([])
-    @test_throws MethodError mean(skipmissing([]))
-    @test_throws ArgumentError mean((1 for i in 2:1))
-
-    # Check that small types are accumulated using wider type
-    for T in (Int8, UInt8)
-        x = [typemax(T) typemax(T)]
-        g = (v for v in x)
-        @test mean(x) == mean(g) == typemax(T)
-        @test mean(identity, x) == mean(identity, g) == typemax(T)
-        @test mean(x, dims=2) == [typemax(T)]'
-    end
-end
-
-@testset "mean/median for ranges" begin
-    for f in (mean, median)
-        for n = 2:5
-            @test f(2:n) == f([2:n;])
-            @test f(2:0.1:n) ≈ f([2:0.1:n;])
-        end
-    end
-    @test mean(2:1) === NaN
-    @test mean(big(2):1) isa BigFloat
-end
-
-@testset "var & std" begin
-    # edge case: empty vector
-    # iterable; this has to throw for type stability
-    @test_throws MethodError var(())
-    @test_throws MethodError var((); corrected=false)
-    @test_throws MethodError var((); mean=2)
-    @test_throws MethodError var((); mean=2, corrected=false)
-    # reduction
-    @test isnan(var(Int[]))
-    @test isnan(var(Int[]; corrected=false))
-    @test isnan(var(Int[]; mean=2))
-    @test isnan(var(Int[]; mean=2, corrected=false))
-    # reduction across dimensions
-    @test isequal(var(Int[], dims=1), [NaN])
-    @test isequal(var(Int[], dims=1; corrected=false), [NaN])
-    @test isequal(var(Int[], dims=1; mean=[2]), [NaN])
-    @test isequal(var(Int[], dims=1; mean=[2], corrected=false), [NaN])
-
-    # edge case: one-element vector
-    # iterable
-    @test isnan(@inferred(var((1,))))
-    @test var((1,); corrected=false) === 0.0
-    @test var((1,); mean=2) === Inf
-    @test var((1,); mean=2, corrected=false) === 1.0
-    # reduction
-    @test isnan(@inferred(var([1])))
-    @test var([1]; corrected=false) === 0.0
-    @test var([1]; mean=2) === Inf
-    @test var([1]; mean=2, corrected=false) === 1.0
-    # reduction across dimensions
-    @test isequal(@inferred(var([1], dims=1)), [NaN])
-    @test var([1], dims=1; corrected=false) ≈ [0.0]
-    @test var([1], dims=1; mean=[2]) ≈ [Inf]
-    @test var([1], dims=1; mean=[2], corrected=false) ≈ [1.0]
-
-    @test var(1:8) == 6.
-    @test varm(1:8,1) == varm(Vector(1:8),1)
-    @test isnan(varm(1:1,1))
-    @test isnan(var(1:1))
-    @test isnan(var(1:-1))
-
-    @test @inferred(var(1.0:8.0)) == 6.
-    @test varm(1.0:8.0,1.0) == varm(Vector(1.0:8.0),1)
-    @test isnan(varm(1.0:1.0,1.0))
-    @test isnan(var(1.0:1.0))
-    @test isnan(var(1.0:-1.0))
-
-    @test @inferred(var(1.0f0:8.0f0)) === 6.f0
-    @test varm(1.0f0:8.0f0,1.0f0) == varm(Vector(1.0f0:8.0f0),1)
-    @test isnan(varm(1.0f0:1.0f0,1.0f0))
-    @test isnan(var(1.0f0:1.0f0))
-    @test isnan(var(1.0f0:-1.0f0))
-
-    @test varm([1,2,3], 2) ≈ 1.
-    @test var([1,2,3]) ≈ 1.
-    @test var([1,2,3]; corrected=false) ≈ 2.0/3
-    @test var([1,2,3]; mean=0) ≈ 7.
-    @test var([1,2,3]; mean=0, corrected=false) ≈ 14.0/3
-
-    @test varm((1,2,3), 2) ≈ 1.
-    @test var((1,2,3)) ≈ 1.
-    @test var((1,2,3); corrected=false) ≈ 2.0/3
-    @test var((1,2,3); mean=0) ≈ 7.
-    @test var((1,2,3); mean=0, corrected=false) ≈ 14.0/3
-    @test_throws ArgumentError var((1,2,3); mean=())
-
-    @test var([1 2 3 4 5; 6 7 8 9 10], dims=2) ≈ [2.5 2.5]'
-    @test var([1 2 3 4 5; 6 7 8 9 10], dims=2; corrected=false) ≈ [2.0 2.0]'
-
-    @test var(collect(1:99), dims=1) ≈ [825]
-    @test var(Matrix(transpose(collect(1:99))), dims=2) ≈ [825]
-
-    @test stdm([1,2,3], 2) ≈ 1.
-    @test std([1,2,3]) ≈ 1.
-    @test std([1,2,3]; corrected=false) ≈ sqrt(2.0/3)
-    @test std([1,2,3]; mean=0) ≈ sqrt(7.0)
-    @test std([1,2,3]; mean=0, corrected=false) ≈ sqrt(14.0/3)
-
-    @test stdm([1.0,2,3], 2) ≈ 1.
-    @test std([1.0,2,3]) ≈ 1.
-    @test std([1.0,2,3]; corrected=false) ≈ sqrt(2.0/3)
-    @test std([1.0,2,3]; mean=0) ≈ sqrt(7.0)
-    @test std([1.0,2,3]; mean=0, corrected=false) ≈ sqrt(14.0/3)
-
-    @test std([1.0,2,3]; dims=1)[] ≈ 1.
-    @test std([1.0,2,3]; dims=1, corrected=false)[] ≈ sqrt(2.0/3)
-    @test std([1.0,2,3]; dims=1, mean=[0])[] ≈ sqrt(7.0)
-    @test std([1.0,2,3]; dims=1, mean=[0], corrected=false)[] ≈ sqrt(14.0/3)
-
-    @test stdm((1,2,3), 2) ≈ 1.
-    @test std((1,2,3)) ≈ 1.
-    @test std((1,2,3); corrected=false) ≈ sqrt(2.0/3)
-    @test std((1,2,3); mean=0) ≈ sqrt(7.0)
-    @test std((1,2,3); mean=0, corrected=false) ≈ sqrt(14.0/3)
-
-    @test std([1 2 3 4 5; 6 7 8 9 10], dims=2) ≈ sqrt.([2.5 2.5]')
-    @test std([1 2 3 4 5; 6 7 8 9 10], dims=2; corrected=false) ≈ sqrt.([2.0 2.0]')
-
-    let A = ComplexF64[exp(i*im) for i in 1:10^4]
-        @test varm(A, 0.) ≈ sum(map(abs2, A)) / (length(A) - 1)
-        @test varm(A, mean(A)) ≈ var(A)
-    end
-
-    @test var([1//1, 2//1]) isa Rational{Int}
-    @test var([1//1, 2//1], dims=1) isa Vector{Rational{Int}}
-
-    @test std([1//1, 2//1]) isa Float64
-    @test std([1//1, 2//1], dims=1) isa Vector{Float64}
-
-    @testset "var: empty cases" begin
-        A = Matrix{Int}(undef, 0,1)
-        @test var(A) === NaN
-
-        @test isequal(var(A, dims=1), fill(NaN, 1, 1))
-        @test isequal(var(A, dims=2), fill(NaN, 0, 1))
-        @test isequal(var(A, dims=(1, 2)), fill(NaN, 1, 1))
-        @test isequal(var(A, dims=3), fill(NaN, 0, 1))
-    end
-
-    # issue #6672
-    @test std(AbstractFloat[1,2,3], dims=1) == [1.0]
-
-    for f in (var, std)
-        @test ismissing(f([1, missing]))
-        @test ismissing(f([NaN, missing]))
-        @test ismissing(f([missing, NaN]))
-        @test isequal(f([missing 1.0; 2.0 3.0], dims=1), [missing f([1.0, 3.0])])
-        @test f(skipmissing([1, missing, 2])) === f([1, 2])
-    end
-    for f in (varm, stdm)
-        @test ismissing(f([1, missing], 0))
-        @test ismissing(f([1, 2], missing))
-        @test ismissing(f([1, NaN], missing))
-        @test ismissing(f([NaN, missing], 0))
-        @test ismissing(f([missing, NaN], 0))
-        @test ismissing(f([NaN, missing], missing))
-        @test ismissing(f([missing, NaN], missing))
-        @test f(skipmissing([1, missing, 2]), 0) === f([1, 2], 0)
-    end
-
-    @test isequal(var(Complex{Float64}[]), NaN)
-    @test var(Complex{Float64}[]) isa Float64
-    @test isequal(var(skipmissing(Complex{Float64}[])), NaN)
-    @test var(skipmissing(Complex{Float64}[])) isa Float64
-    @test_throws MethodError var([])
-    @test_throws MethodError var(skipmissing([]))
-    @test_throws MethodError var((1 for i in 2:1))
-    @test isequal(var(Int[]), NaN)
-    @test var(Int[]) isa Float64
-    @test isequal(var(skipmissing(Int[])), NaN)
-    @test var(skipmissing(Int[])) isa Float64
-end
-
-function safe_cov(x, y, zm::Bool, cr::Bool)
-    n = length(x)
-    if !zm
-        x = x .- mean(x)
-        y = y .- mean(y)
-    end
-    dot(vec(x), vec(y)) / (n - Int(cr))
-end
-X = [1.0  5.0;
-     2.0  4.0;
-     3.0  6.0;
-     4.0  2.0;
-     5.0  1.0]
-Y = [6.0  2.0;
-     1.0  7.0;
-     5.0  8.0;
-     3.0  4.0;
-     2.0  3.0]
-
-@testset "covariance" begin
-    for vd in [1, 2], zm in [true, false], cr in [true, false]
-        # println("vd = $vd: zm = $zm, cr = $cr")
-        if vd == 1
-            k = size(X, 2)
-            Cxx = zeros(k, k)
-            Cxy = zeros(k, k)
-            for i = 1:k, j = 1:k
-                Cxx[i,j] = safe_cov(X[:,i], X[:,j], zm, cr)
-                Cxy[i,j] = safe_cov(X[:,i], Y[:,j], zm, cr)
-            end
-            x1 = vec(X[:,1])
-            y1 = vec(Y[:,1])
-        else
-            k = size(X, 1)
-            Cxx = zeros(k, k)
-            Cxy = zeros(k, k)
-            for i = 1:k, j = 1:k
-                Cxx[i,j] = safe_cov(X[i,:], X[j,:], zm, cr)
-                Cxy[i,j] = safe_cov(X[i,:], Y[j,:], zm, cr)
-            end
-            x1 = vec(X[1,:])
-            y1 = vec(Y[1,:])
-        end
-
-        c = zm ? Statistics.covm(x1, 0, corrected=cr) :
-                 cov(x1, corrected=cr)
-        @test isa(c, Float64)
-        @test c ≈ Cxx[1,1]
-        @inferred cov(x1, corrected=cr)
-
-        @test cov(X) == Statistics.covm(X, mean(X, dims=1))
-        C = zm ? Statistics.covm(X, 0, vd, corrected=cr) :
-                 cov(X, dims=vd, corrected=cr)
-        @test size(C) == (k, k)
-        @test C ≈ Cxx
-        @inferred cov(X, dims=vd, corrected=cr)
-
-        @test cov(x1, y1) == Statistics.covm(x1, mean(x1), y1, mean(y1))
-        c = zm ? Statistics.covm(x1, 0, y1, 0, corrected=cr) :
-                 cov(x1, y1, corrected=cr)
-        @test isa(c, Float64)
-        @test c ≈ Cxy[1,1]
-        @inferred cov(x1, y1, corrected=cr)
-
-        if vd == 1
-            @test cov(x1, Y) == Statistics.covm(x1, mean(x1), Y, mean(Y, dims=1))
-        end
-        C = zm ? Statistics.covm(x1, 0, Y, 0, vd, corrected=cr) :
-                 cov(x1, Y, dims=vd, corrected=cr)
-        @test size(C) == (1, k)
-        @test vec(C) ≈ Cxy[1,:]
-        @inferred cov(x1, Y, dims=vd, corrected=cr)
-
-        if vd == 1
-            @test cov(X, y1) == Statistics.covm(X, mean(X, dims=1), y1, mean(y1))
-        end
-        C = zm ? Statistics.covm(X, 0, y1, 0, vd, corrected=cr) :
-                 cov(X, y1, dims=vd, corrected=cr)
-        @test size(C) == (k, 1)
-        @test vec(C) ≈ Cxy[:,1]
-        @inferred cov(X, y1, dims=vd, corrected=cr)
-
-        @test cov(X, Y) == Statistics.covm(X, mean(X, dims=1), Y, mean(Y, dims=1))
-        C = zm ? Statistics.covm(X, 0, Y, 0, vd, corrected=cr) :
-                 cov(X, Y, dims=vd, corrected=cr)
-        @test size(C) == (k, k)
-        @test C ≈ Cxy
-        @inferred cov(X, Y, dims=vd, corrected=cr)
-    end
-
-    @testset "floating point accuracy for `cov` of large numbers" begin
-        A = [4.0, 7.0, 13.0, 16.0]
-        C = A .+ 1.0e10
-        @test cov(A, A) ≈ cov(C, C)
-    end
-end
-
-function safe_cor(x, y, zm::Bool)
-    if !zm
-        x = x .- mean(x)
-        y = y .- mean(y)
-    end
-    x = vec(x)
-    y = vec(y)
-    dot(x, y) / (sqrt(dot(x, x)) * sqrt(dot(y, y)))
-end
-@testset "correlation" begin
-    for vd in [1, 2], zm in [true, false]
-        # println("vd = $vd: zm = $zm")
-        if vd == 1
-            k = size(X, 2)
-            Cxx = zeros(k, k)
-            Cxy = zeros(k, k)
-            for i = 1:k, j = 1:k
-                Cxx[i,j] = safe_cor(X[:,i], X[:,j], zm)
-                Cxy[i,j] = safe_cor(X[:,i], Y[:,j], zm)
-            end
-            x1 = vec(X[:,1])
-            y1 = vec(Y[:,1])
-        else
-            k = size(X, 1)
-            Cxx = zeros(k, k)
-            Cxy = zeros(k, k)
-            for i = 1:k, j = 1:k
-                Cxx[i,j] = safe_cor(X[i,:], X[j,:], zm)
-                Cxy[i,j] = safe_cor(X[i,:], Y[j,:], zm)
-            end
-            x1 = vec(X[1,:])
-            y1 = vec(Y[1,:])
-        end
-
-        c = zm ? Statistics.corm(x1, 0) : cor(x1)
-        @test isa(c, Float64)
-        @test c ≈ Cxx[1,1]
-        @inferred cor(x1)
-
-        @test cor(X) == Statistics.corm(X, mean(X, dims=1))
-        C = zm ? Statistics.corm(X, 0, vd) : cor(X, dims=vd)
-        @test size(C) == (k, k)
-        @test C ≈ Cxx
-        @inferred cor(X, dims=vd)
-
-        @test cor(x1, y1) == Statistics.corm(x1, mean(x1), y1, mean(y1))
-        c = zm ? Statistics.corm(x1, 0, y1, 0) : cor(x1, y1)
-        @test isa(c, Float64)
-        @test c ≈ Cxy[1,1]
-        @inferred cor(x1, y1)
-
-        if vd == 1
-            @test cor(x1, Y) == Statistics.corm(x1, mean(x1), Y, mean(Y, dims=1))
-        end
-        C = zm ? Statistics.corm(x1, 0, Y, 0, vd) : cor(x1, Y, dims=vd)
-        @test size(C) == (1, k)
-        @test vec(C) ≈ Cxy[1,:]
-        @inferred cor(x1, Y, dims=vd)
-
-        if vd == 1
-            @test cor(X, y1) == Statistics.corm(X, mean(X, dims=1), y1, mean(y1))
-        end
-        C = zm ? Statistics.corm(X, 0, y1, 0, vd) : cor(X, y1, dims=vd)
-        @test size(C) == (k, 1)
-        @test vec(C) ≈ Cxy[:,1]
-        @inferred cor(X, y1, dims=vd)
-
-        @test cor(X, Y) == Statistics.corm(X, mean(X, dims=1), Y, mean(Y, dims=1))
-        C = zm ? Statistics.corm(X, 0, Y, 0, vd) : cor(X, Y, dims=vd)
-        @test size(C) == (k, k)
-        @test C ≈ Cxy
-        @inferred cor(X, Y, dims=vd)
-    end
-
-    @test cor(repeat(1:17, 1, 17))[2] <= 1.0
-    @test cor(1:17, 1:17) <= 1.0
-    @test cor(1:17, 18:34) <= 1.0
-    @test cor(Any[1, 2], Any[1, 2]) == 1.0
-    @test isnan(cor([0], Int8[81]))
-    let tmp = range(1, stop=85, length=100)
-        tmp2 = Vector(tmp)
-        @test cor(tmp, tmp) <= 1.0
-        @test cor(tmp, tmp2) <= 1.0
-    end
-end
-
-@testset "quantile" begin
-    @test quantile([1,2,3,4],0.5) == 2.5
-    @test quantile([1,2,3,4],[0.5]) == [2.5]
-    @test quantile([1., 3],[.25,.5,.75])[2] == median([1., 3])
-    @test quantile(100.0:-1.0:0.0, 0.0:0.1:1.0) == 0.0:10.0:100.0
-    @test quantile(0.0:100.0, 0.0:0.1:1.0, sorted=true) == 0.0:10.0:100.0
-    @test quantile(100f0:-1f0:0.0, 0.0:0.1:1.0) == 0f0:10f0:100f0
-    @test quantile([Inf,Inf],0.5) == Inf
-    @test quantile([-Inf,1],0.5) == -Inf
-    @test quantile([0,1],1e-18) == 1e-18
-    @test quantile([1, 2, 3, 4],[]) == []
-    @test quantile([1, 2, 3, 4], (0.5,)) == (2.5,)
-    @test quantile([4, 9, 1, 5, 7, 8, 2, 3, 5, 17, 11],
-                   (0.1, 0.2, 0.4, 0.9)) == (2.0, 3.0, 5.0, 11.0)
-    @test quantile(Union{Int, Missing}[4, 9, 1, 5, 7, 8, 2, 3, 5, 17, 11],
-                   [0.1, 0.2, 0.4, 0.9]) == [2.0, 3.0, 5.0, 11.0]
-    @test quantile(Any[4, 9, 1, 5, 7, 8, 2, 3, 5, 17, 11],
-                   [0.1, 0.2, 0.4, 0.9]) == [2.0, 3.0, 5.0, 11.0]
-    @test quantile([4, 9, 1, 5, 7, 8, 2, 3, 5, 17, 11],
-                   Any[0.1, 0.2, 0.4, 0.9]) == [2.0, 3.0, 5.0, 11.0]
-    @test quantile([4, 9, 1, 5, 7, 8, 2, 3, 5, 17, 11],
-                   Any[0.1, 0.2, 0.4, 0.9]) isa Vector{Float64}
-    @test quantile(Any[4, 9, 1, 5, 7, 8, 2, 3, 5, 17, 11],
-                   Any[0.1, 0.2, 0.4, 0.9]) == [2, 3, 5, 11]
-    @test quantile(Any[4, 9, 1, 5, 7, 8, 2, 3, 5, 17, 11],
-                   Any[0.1, 0.2, 0.4, 0.9]) isa Vector{Float64}
-    @test quantile([1, 2, 3, 4], ()) == ()
-    @test isempty(quantile([1, 2, 3, 4], Float64[]))
-    @test quantile([1, 2, 3, 4], Float64[]) isa Vector{Float64}
-    @test quantile([1, 2, 3, 4], []) isa Vector{Any}
-    @test quantile([1, 2, 3, 4], [0, 1]) isa Vector{Int}
-
-    @test quantile(Any[1, 2, 3], 0.5) isa Float64
-    @test quantile(Any[1, big(2), 3], 0.5) isa BigFloat
-    @test quantile(Any[1, 2, 3], Float16(0.5)) isa Float16
-    @test quantile(Any[1, Float16(2), 3], Float16(0.5)) isa Float16
-    @test quantile(Any[1, big(2), 3], Float16(0.5)) isa BigFloat
-
-    @test_throws ArgumentError quantile([1, missing], 0.5)
-    @test_throws ArgumentError quantile([1, NaN], 0.5)
-    @test quantile(skipmissing([1, missing, 2]), 0.5) === 1.5
-
-    # make sure that type inference works correctly in normal cases
-    for T in [Int, BigInt, Float64, Float16, BigFloat, Rational{Int}, Rational{BigInt}]
-        for S in [Float64, Float16, BigFloat, Rational{Int}, Rational{BigInt}]
-            @inferred quantile(T[1, 2, 3], S(0.5))
-            @inferred quantile(T[1, 2, 3], S(0.6))
-            @inferred quantile(T[1, 2, 3], S[0.5, 0.6])
-            @inferred quantile(T[1, 2, 3], (S(0.5), S(0.6)))
-        end
-    end
-    x = [3; 2; 1]
-    y = zeros(3)
-    @test quantile!(y, x, [0.1, 0.5, 0.9]) === y
-    @test y == [1.2, 2.0, 2.8]
-end
-
-# StatsBase issue 164
-let y = [0.40003674665581906, 0.4085630862624367, 0.41662034698690303, 0.41662034698690303, 0.42189053966652057, 0.42189053966652057, 0.42553514344518345, 0.43985732442991354]
-    @test issorted(quantile(y, range(0.01, stop=0.99, length=17)))
-end
-
-@testset "variance of complex arrays (#13309)" begin
-    z = rand(ComplexF64, 10)
-    @test var(z) ≈ invoke(var, Tuple{Any}, z) ≈ cov(z) ≈ var(z,dims=1)[1] ≈ sum(abs2, z .- mean(z))/9
-    @test isa(var(z), Float64)
-    @test isa(invoke(var, Tuple{Any}, z), Float64)
-    @test isa(cov(z), Float64)
-    @test isa(var(z,dims=1), Vector{Float64})
-    @test varm(z, 0.0) ≈ invoke(varm, Tuple{Any,Float64}, z, 0.0) ≈ sum(abs2, z)/9
-    @test isa(varm(z, 0.0), Float64)
-    @test isa(invoke(varm, Tuple{Any,Float64}, z, 0.0), Float64)
-    @test cor(z) === 1.0
-    v = varm([1.0+2.0im], 0; corrected = false)
-    @test v ≈ 5
-    @test isa(v, Float64)
-end
-
-@testset "cov and cor of complex arrays (issue #21093)" begin
-    x = [2.7 - 3.3im, 0.9 + 5.4im, 0.1 + 0.2im, -1.7 - 5.8im, 1.1 + 1.9im]
-    y = [-1.7 - 1.6im, -0.2 + 6.5im, 0.8 - 10.0im, 9.1 - 3.4im, 2.7 - 5.5im]
-    @test cov(x, y) ≈ 4.8365 - 12.119im
-    @test cov(y, x) ≈ 4.8365 + 12.119im
-    @test cov(x, reshape(y, :, 1)) ≈ reshape([4.8365 - 12.119im], 1, 1)
-    @test cov(reshape(x, :, 1), y) ≈ reshape([4.8365 - 12.119im], 1, 1)
-    @test cov(reshape(x, :, 1), reshape(y, :, 1)) ≈ reshape([4.8365 - 12.119im], 1, 1)
-    @test cov([x y]) ≈ [21.779 4.8365-12.119im;
-                        4.8365+12.119im 54.548]
-    @test cor(x, y) ≈ 0.14032104449218274 - 0.35160772008699703im
-    @test cor(y, x) ≈ 0.14032104449218274 + 0.35160772008699703im
-    @test cor(x, reshape(y, :, 1)) ≈ reshape([0.14032104449218274 - 0.35160772008699703im], 1, 1)
-    @test cor(reshape(x, :, 1), y) ≈ reshape([0.14032104449218274 - 0.35160772008699703im], 1, 1)
-    @test cor(reshape(x, :, 1), reshape(y, :, 1)) ≈ reshape([0.14032104449218274 - 0.35160772008699703im], 1, 1)
-    @test cor([x y]) ≈ [1.0                                          0.14032104449218274-0.35160772008699703im
-                        0.14032104449218274+0.35160772008699703im  1.0]
-end
-
-@testset "Issue #17153 and PR #17154" begin
-    a = rand(10,10)
-    b = copy(a)
-    x = median(a, dims=1)
-    @test b == a
-    x = median(a, dims=2)
-    @test b == a
-    x = mean(a, dims=1)
-    @test b == a
-    x = mean(a, dims=2)
-    @test b == a
-    x = var(a, dims=1)
-    @test b == a
-    x = var(a, dims=2)
-    @test b == a
-    x = std(a, dims=1)
-    @test b == a
-    x = std(a, dims=2)
-    @test b == a
-end
-
-# dimensional correctness
-const BASE_TEST_PATH = joinpath(Sys.BINDIR, "..", "share", "julia", "test")
-isdefined(Main, :Furlongs) || @eval Main include(joinpath($(BASE_TEST_PATH), "testhelpers", "Furlongs.jl"))
-using .Main.Furlongs
-
-Statistics.middle(x::Furlong{p}) where {p} = Furlong{p}(middle(x.val))
-Statistics.middle(x::Furlong{p}, y::Furlong{p}) where {p} = Furlong{p}(middle(x.val, y.val))
-
-@testset "Unitful elements" begin
-    r = Furlong(1):Furlong(1):Furlong(2)
-    a = Vector(r)
-    @test sum(r) == sum(a) == Furlong(3)
-    @test cumsum(r) == Furlong.([1,3])
-    @test mean(r) == mean(a) == median(a) == median(r) == Furlong(1.5)
-    @test var(r) == var(a) == Furlong{2}(0.5)
-    @test std(r) == std(a) == Furlong{1}(sqrt(0.5))
-
-    # Issue #21786
-    A = [Furlong{1}(rand(-5:5)) for i in 1:2, j in 1:2]
-    @test mean(mean(A, dims=1), dims=2)[1] === mean(A)
-    @test var(A, dims=1)[1] === var(A[:, 1])
-    @test std(A, dims=1)[1] === std(A[:, 1])
-end
-
-# Issue #22901
-@testset "var and quantile of Any arrays" begin
-    x = Any[1, 2, 4, 10]
-    y = Any[1, 2, 4, 10//1]
-    @test var(x) === 16.25
-    @test var(y) === 65//4
-    @test std(x) === sqrt(16.25)
-    @test quantile(x, 0.5)  === 3.0
-    @test quantile(x, 1//2) === 3//1
-end
-
-@testset "Promotion in covzm. Issue #8080" begin
-    A = [1 -1 -1; -1 1 1; -1 1 -1; 1 -1 -1; 1 -1 1]
-    @test Statistics.covzm(A) - mean(A, dims=1)'*mean(A, dims=1)*size(A, 1)/(size(A, 1) - 1) ≈ cov(A)
-    A = [1//1 -1 -1; -1 1 1; -1 1 -1; 1 -1 -1; 1 -1 1]
-    @test (A'A - size(A, 1)*mean(A, dims=1)'*mean(A, dims=1))/4 == cov(A)
-end
-
-@testset "Mean along dimension of empty array" begin
-    a0  = zeros(0)
-    a00 = zeros(0, 0)
-    a01 = zeros(0, 1)
-    a10 = zeros(1, 0)
-    @test isequal(mean(a0, dims=1)      , fill(NaN, 1))
-    @test isequal(mean(a00, dims=(1, 2)), fill(NaN, 1, 1))
-    @test isequal(mean(a01, dims=1)     , fill(NaN, 1, 1))
-    @test isequal(mean(a10, dims=2)     , fill(NaN, 1, 1))
-end
-
-@testset "cov/var/std of Vector{Vector}" begin
-    x = [[2,4,6],[4,6,8]]
-    @test var(x) ≈ vec(var([x[1] x[2]], dims=2))
-    @test std(x) ≈ vec(std([x[1] x[2]], dims=2))
-    @test cov(x) ≈ cov([x[1] x[2]], dims=2)
-end
-
-@testset "var of sparse array" begin
-    se33 = SparseMatrixCSC{Float64}(I, 3, 3)
-    sA = sprandn(3, 7, 0.5)
-    pA = sparse(rand(3, 7))
-
-    for arr in (se33, sA, pA)
-        farr = Array(arr)
-        @test var(arr) ≈ var(farr)
-        @test var(arr, dims=1) ≈ var(farr, dims=1)
-        @test var(arr, dims=2) ≈ var(farr, dims=2)
-        @test var(arr, dims=(1, 2)) ≈ [var(farr)]
-        @test isequal(var(arr, dims=3), var(farr, dims=3))
-    end
-
-    @testset "empty cases" begin
-        @test var(sparse(Int[])) === NaN
-        @test isequal(var(spzeros(0, 1), dims=1), var(Matrix{Int}(I, 0, 1), dims=1))
-        @test isequal(var(spzeros(0, 1), dims=2), var(Matrix{Int}(I, 0, 1), dims=2))
-        @test isequal(var(spzeros(0, 1), dims=(1, 2)), var(Matrix{Int}(I, 0, 1), dims=(1, 2)))
-        @test isequal(var(spzeros(0, 1), dims=3), var(Matrix{Int}(I, 0, 1), dims=3))
-    end
-end
-
-# Faster covariance function for sparse matrices
-# Prevents densifying the input matrix when subtracting the mean
-# Test against dense implementation
-# PR https://github.com/JuliaLang/julia/pull/22735
-# Part of this test needed to be hacked due to the treatment
-# of Inf in sparse matrix algebra
-# https://github.com/JuliaLang/julia/issues/22921
-# The issue will be resolved in
-# https://github.com/JuliaLang/julia/issues/22733
-@testset "optimizing sparse $elty covariance" for elty in (Float64, Complex{Float64})
-    n = 10
-    p = 5
-    np2 = div(n*p, 2)
-    nzvals, x_sparse = guardseed(1) do
-        if elty <: Real
-            nzvals = randn(np2)
-        else
-            nzvals = complex.(randn(np2), randn(np2))
-        end
-        nzvals, sparse(rand(1:n, np2), rand(1:p, np2), nzvals, n, p)
-    end
-    x_dense  = convert(Matrix{elty}, x_sparse)
-    @testset "Test with no Infs and NaNs, vardim=$vardim, corrected=$corrected" for vardim in (1, 2),
-                                                                                 corrected in (true, false)
-        @test cov(x_sparse, dims=vardim, corrected=corrected) ≈
-              cov(x_dense , dims=vardim, corrected=corrected)
-    end
-
-    @testset "Test with $x11, vardim=$vardim, corrected=$corrected" for x11 in (NaN, Inf),
-                                                                     vardim in (1, 2),
-                                                                  corrected in (true, false)
-        x_sparse[1,1] = x11
-        x_dense[1 ,1] = x11
-
-        cov_sparse = cov(x_sparse, dims=vardim, corrected=corrected)
-        cov_dense  = cov(x_dense , dims=vardim, corrected=corrected)
-        @test cov_sparse[2:end, 2:end] ≈ cov_dense[2:end, 2:end]
-        @test isfinite.(cov_sparse) == isfinite.(cov_dense)
-        @test isfinite.(cov_sparse) == isfinite.(cov_dense)
-    end
-
-    @testset "Test with NaN and Inf, vardim=$vardim, corrected=$corrected" for vardim in (1, 2),
-                                                                            corrected in (true, false)
-        x_sparse[1,1] = Inf
-        x_dense[1 ,1] = Inf
-        x_sparse[2,1] = NaN
-        x_dense[2 ,1] = NaN
-
-        cov_sparse = cov(x_sparse, dims=vardim, corrected=corrected)
-        cov_dense  = cov(x_dense , dims=vardim, corrected=corrected)
-        @test cov_sparse[(1 + vardim):end, (1 + vardim):end] ≈
-              cov_dense[ (1 + vardim):end, (1 + vardim):end]
-        @test isfinite.(cov_sparse) == isfinite.(cov_dense)
-        @test isfinite.(cov_sparse) == isfinite.(cov_dense)
-    end
-end
diff -pruN 1.3.1+dfsg-1/stdlib/Statistics.version 1.4.0+dfsg-1/stdlib/Statistics.version
--- 1.3.1+dfsg-1/stdlib/Statistics.version	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/stdlib/Statistics.version	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1,2 @@
+STATISTICS_BRANCH = master
+STATISTICS_SHA1 = a2203d3b67f7413701be5de251622cb85c9cc69d
diff -pruN 1.3.1+dfsg-1/stdlib/SuiteSparse/Project.toml 1.4.0+dfsg-1/stdlib/SuiteSparse/Project.toml
--- 1.3.1+dfsg-1/stdlib/SuiteSparse/Project.toml	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/stdlib/SuiteSparse/Project.toml	2020-03-21 16:36:32.000000000 +0000
@@ -9,9 +9,10 @@ SparseArrays = "2f01184e-e22b-5df5-ae63-
 
 [extras]
 DelimitedFiles = "8bb1440f-4735-579b-a4ab-409b98df4dab"
+Printf = "de0858da-6303-5e67-8744-51eddeeeb8d7"
 Random = "9a3f8284-a2c9-5f02-9a11-845980a1fd5c"
 Serialization = "9e88b42a-f829-5b0c-bbe9-9e923198166b"
 Test = "8dfed614-e22c-5e08-85e1-65c5234f0b40"
 
 [targets]
-test = ["Test", "Random", "DelimitedFiles", "Serialization"]
+test = ["Test", "Printf", "Random", "DelimitedFiles", "Serialization"]
diff -pruN 1.3.1+dfsg-1/stdlib/SuiteSparse/src/cholmod.jl 1.4.0+dfsg-1/stdlib/SuiteSparse/src/cholmod.jl
--- 1.3.1+dfsg-1/stdlib/SuiteSparse/src/cholmod.jl	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/stdlib/SuiteSparse/src/cholmod.jl	2020-03-21 16:36:32.000000000 +0000
@@ -20,6 +20,7 @@ import LinearAlgebra: (\),
                  issuccess, issymmetric, ldlt, ldlt!, logdet
 
 using SparseArrays
+using SparseArrays: getcolptr
 import Libdl
 
 export
@@ -39,15 +40,15 @@ include("cholmod_h.jl")
 
 const CHOLMOD_MIN_VERSION = v"2.1.1"
 
-const common_struct = Vector{UInt8}()
+const common_struct = Vector{Vector{UInt8}}()
 
-const common_supernodal = Ref{Ptr{Cint}}()
-const common_final_ll = Ref{Ptr{Cint}}()
-const common_print = Ref{Ptr{Cint}}()
-const common_itype = Ref{Ptr{Cint}}()
-const common_dtype = Ref{Ptr{Cint}}()
-const common_nmethods = Ref{Ptr{Cint}}()
-const common_postorder = Ref{Ptr{Cint}}()
+const common_supernodal = Vector{Ptr{Cint}}()
+const common_final_ll   = Vector{Ptr{Cint}}()
+const common_print      = Vector{Ptr{Cint}}()
+const common_itype      = Vector{Ptr{Cint}}()
+const common_dtype      = Vector{Ptr{Cint}}()
+const common_nmethods   = Vector{Ptr{Cint}}()
+const common_postorder  = Vector{Ptr{Cint}}()
 
 ### These offsets are defined in SuiteSparse_wrapper.c
 const common_size = ccall((:jl_cholmod_common_size,:libsuitesparse_wrapper),Int,())
@@ -148,20 +149,30 @@ function __init__()
 
         ### Initiate CHOLMOD
         ### common_struct controls the type of factorization and keeps pointers
-        ### to temporary memory.
-        resize!(common_struct, common_size)
-        fill!(common_struct, 0xff)
-
-        common_supernodal[] = pointer(common_struct, cholmod_com_offsets[4] + 1)
-        common_final_ll[] = pointer(common_struct, cholmod_com_offsets[7] + 1)
-        common_print[] = pointer(common_struct, cholmod_com_offsets[13] + 1)
-        common_itype[] = pointer(common_struct, cholmod_com_offsets[18] + 1)
-        common_dtype[] = pointer(common_struct, cholmod_com_offsets[19] + 1)
-        common_nmethods[] = pointer(common_struct, cholmod_com_offsets[15] + 1)
-        common_postorder[] = pointer(common_struct, cholmod_com_offsets[17] + 1)
+        ### to temporary memory. We need to manage a copy for each thread.
+        nt = Threads.nthreads()
+        resize!(common_struct    , nt)
+        resize!(common_supernodal, nt)
+        resize!(common_final_ll  , nt)
+        resize!(common_print     , nt)
+        resize!(common_itype     , nt)
+        resize!(common_dtype     , nt)
+        resize!(common_nmethods  , nt)
+        resize!(common_postorder , nt)
+        for i in 1:nt
+            common_struct[i] = fill(0xff, common_size)
+
+            common_supernodal[i] = pointer(common_struct[i], cholmod_com_offsets[4] + 1)
+            common_final_ll[i]   = pointer(common_struct[i], cholmod_com_offsets[7] + 1)
+            common_print[i]      = pointer(common_struct[i], cholmod_com_offsets[13] + 1)
+            common_itype[i]      = pointer(common_struct[i], cholmod_com_offsets[18] + 1)
+            common_dtype[i]      = pointer(common_struct[i], cholmod_com_offsets[19] + 1)
+            common_nmethods[i]   = pointer(common_struct[i], cholmod_com_offsets[15] + 1)
+            common_postorder[i]  = pointer(common_struct[i], cholmod_com_offsets[17] + 1)
 
-        start(common_struct)              # initializes CHOLMOD
-        set_print_level(common_struct, 0) # no printing from CHOLMOD by default
+            start(common_struct[i])              # initializes CHOLMOD
+            set_print_level(common_struct[i], 0) # no printing from CHOLMOD by default
+        end
 
         # Register gc tracked allocator if CHOLMOD is new enough
         if current_version >= v"3.0.0"
@@ -178,7 +189,7 @@ function __init__()
 end
 
 function set_print_level(cm::Vector{UInt8}, lev::Integer)
-    unsafe_store!(common_print[], lev)
+    unsafe_store!(common_print[Threads.threadid()], lev)
 end
 
 ####################
@@ -402,32 +413,32 @@ Factor(FC::FactorComponent) = Factor(FC.
 function allocate_dense(m::Integer, n::Integer, d::Integer, ::Type{Tv}) where {Tv<:VTypes}
     Dense(ccall((@cholmod_name("allocate_dense"), :libcholmod), Ptr{C_Dense{Tv}},
                 (Csize_t, Csize_t, Csize_t, Cint, Ptr{Cvoid}),
-                m, n, d, xtyp(Tv), common_struct))
+                m, n, d, xtyp(Tv), common_struct[Threads.threadid()]))
 end
 
 function free!(p::Ptr{C_Dense{Tv}}) where {Tv<:VTypes}
     @isok ccall((@cholmod_name("free_dense"), :libcholmod), Cint,
                 (Ref{Ptr{C_Dense{Tv}}}, Ptr{Cvoid}),
-                p, common_struct)
+                p, common_struct[Threads.threadid()])
 end
 function zeros(m::Integer, n::Integer, ::Type{Tv}) where Tv<:VTypes
     Dense(ccall((@cholmod_name("zeros"), :libcholmod), Ptr{C_Dense{Tv}},
                 (Csize_t, Csize_t, Cint, Ptr{UInt8}),
-                m, n, xtyp(Tv), common_struct))
+                m, n, xtyp(Tv), common_struct[Threads.threadid()]))
 end
 zeros(m::Integer, n::Integer) = zeros(m, n, Float64)
 
 function ones(m::Integer, n::Integer, ::Type{Tv}) where Tv<:VTypes
     Dense(ccall((@cholmod_name("ones"), :libcholmod), Ptr{C_Dense{Tv}},
                 (Csize_t, Csize_t, Cint, Ptr{UInt8}),
-                m, n, xtyp(Tv), common_struct))
+                m, n, xtyp(Tv), common_struct[Threads.threadid()]))
 end
 ones(m::Integer, n::Integer) = ones(m, n, Float64)
 
 function eye(m::Integer, n::Integer, ::Type{Tv}) where Tv<:VTypes
     Dense(ccall((@cholmod_name("eye"), :libcholmod), Ptr{C_Dense{Tv}},
                 (Csize_t, Csize_t, Cint, Ptr{UInt8}),
-                m, n, xtyp(Tv), common_struct))
+                m, n, xtyp(Tv), common_struct[Threads.threadid()]))
 end
 eye(m::Integer, n::Integer) = eye(m, n, Float64)
 eye(n::Integer) = eye(n, n, Float64)
@@ -435,13 +446,13 @@ eye(n::Integer) = eye(n, n, Float64)
 function copy(A::Dense{Tv}) where Tv<:VTypes
     Dense(ccall((@cholmod_name("copy_dense"), :libcholmod), Ptr{C_Dense{Tv}},
                 (Ptr{C_Dense{Tv}}, Ptr{UInt8}),
-                A, common_struct))
+                A, common_struct[Threads.threadid()]))
 end
 
 function sort!(S::Sparse{Tv}) where Tv<:VTypes
     @isok ccall((@cholmod_name("sort"), :libcholmod), Cint,
                 (Ptr{C_Sparse{Tv}}, Ptr{UInt8}),
-                S, common_struct)
+                S, common_struct[Threads.threadid()])
     return S
 end
 
@@ -457,14 +468,14 @@ function norm_dense(D::Dense{Tv}, p::Int
     end
     ccall((@cholmod_name("norm_dense"), :libcholmod), Cdouble,
         (Ptr{C_Dense{Tv}}, Cint, Ptr{UInt8}),
-          D, p, common_struct)
+          D, p, common_struct[Threads.threadid()])
 end
 
 ### cholmod_check.h ###
 function check_dense(A::Dense{Tv}) where Tv<:VTypes
     ccall((@cholmod_name("check_dense"), :libcholmod), Cint,
           (Ptr{C_Dense{Tv}}, Ptr{UInt8}),
-          pointer(A), common_struct) != 0
+          pointer(A), common_struct[Threads.threadid()]) != 0
 end
 
 # Non-Dense wrappers
@@ -476,40 +487,40 @@ function allocate_sparse(nrow::Integer,
                 (Csize_t, Csize_t, Csize_t, Cint,
                  Cint, Cint, Cint, Ptr{Cvoid}),
                 nrow, ncol, nzmax, sorted,
-                packed, stype, xtyp(Tv), common_struct))
+                packed, stype, xtyp(Tv), common_struct[Threads.threadid()]))
 end
 
 function free!(ptr::Ptr{C_Sparse{Tv}}) where Tv<:VTypes
     @isok ccall((@cholmod_name("free_sparse"), :libcholmod), Cint,
             (Ref{Ptr{C_Sparse{Tv}}}, Ptr{UInt8}),
-                ptr, common_struct)
+                ptr, common_struct[Threads.threadid()])
 end
 
 function free!(ptr::Ptr{C_Factor{Tv}}) where Tv<:VTypes
     # Warning! Important that finalizer doesn't modify the global Common struct.
     @isok ccall((@cholmod_name("free_factor"), :libcholmod), Cint,
             (Ref{Ptr{C_Factor{Tv}}}, Ptr{Cvoid}),
-                ptr, common_struct)
+                ptr, common_struct[Threads.threadid()])
 end
 
 function aat(A::Sparse{Tv}, fset::Vector{SuiteSparse_long}, mode::Integer) where Tv<:VRealTypes
     Sparse(ccall((@cholmod_name("aat"), :libcholmod),
         Ptr{C_Sparse{Tv}},
             (Ptr{C_Sparse{Tv}}, Ptr{SuiteSparse_long}, Csize_t, Cint, Ptr{UInt8}),
-                A, fset, length(fset), mode, common_struct))
+                A, fset, length(fset), mode, common_struct[Threads.threadid()]))
 end
 
 function sparse_to_dense(A::Sparse{Tv}) where Tv<:VTypes
     Dense(ccall((@cholmod_name("sparse_to_dense"),:libcholmod),
         Ptr{C_Dense{Tv}},
             (Ptr{C_Sparse{Tv}}, Ptr{UInt8}),
-                A, common_struct))
+                A, common_struct[Threads.threadid()]))
 end
 function dense_to_sparse(D::Dense{Tv}, ::Type{SuiteSparse_long}) where Tv<:VTypes
     Sparse(ccall((@cholmod_name("dense_to_sparse"),:libcholmod),
         Ptr{C_Sparse{Tv}},
             (Ptr{C_Dense{Tv}}, Cint, Ptr{UInt8}),
-                D, true, common_struct))
+                D, true, common_struct[Threads.threadid()]))
 end
 
 function factor_to_sparse!(F::Factor{Tv}) where Tv<:VTypes
@@ -518,88 +529,88 @@ function factor_to_sparse!(F::Factor{Tv}
     Sparse(ccall((@cholmod_name("factor_to_sparse"),:libcholmod),
         Ptr{C_Sparse{Tv}},
             (Ptr{C_Factor{Tv}}, Ptr{UInt8}),
-                F, common_struct))
+                F, common_struct[Threads.threadid()]))
 end
 
 function change_factor!(F::Factor{Tv}, to_ll::Bool, to_super::Bool, to_packed::Bool,
                         to_monotonic::Bool) where Tv<:VTypes
     @isok ccall((@cholmod_name("change_factor"),:libcholmod), Cint,
             (Cint, Cint, Cint, Cint, Cint, Ptr{C_Factor{Tv}}, Ptr{UInt8}),
-                xtyp(Tv), to_ll, to_super, to_packed, to_monotonic, F, common_struct)
+                xtyp(Tv), to_ll, to_super, to_packed, to_monotonic, F, common_struct[Threads.threadid()])
 end
 
 function check_sparse(A::Sparse{Tv}) where Tv<:VTypes
     ccall((@cholmod_name("check_sparse"),:libcholmod), Cint,
           (Ptr{C_Sparse{Tv}}, Ptr{UInt8}),
-           A, common_struct) != 0
+           A, common_struct[Threads.threadid()]) != 0
 end
 
 function check_factor(F::Factor{Tv}) where Tv<:VTypes
     ccall((@cholmod_name("check_factor"),:libcholmod), Cint,
           (Ptr{C_Factor{Tv}}, Ptr{UInt8}),
-           F, common_struct) != 0
+           F, common_struct[Threads.threadid()]) != 0
 end
 
 function nnz(A::Sparse{Tv}) where Tv<:VTypes
     ccall((@cholmod_name("nnz"),:libcholmod), Int,
             (Ptr{C_Sparse{Tv}}, Ptr{UInt8}),
-                A, common_struct)
+                A, common_struct[Threads.threadid()])
 end
 
 function speye(m::Integer, n::Integer, ::Type{Tv}) where Tv<:VTypes
     Sparse(ccall((@cholmod_name("speye"), :libcholmod),
         Ptr{C_Sparse{Tv}},
             (Csize_t, Csize_t, Cint, Ptr{UInt8}),
-                m, n, xtyp(Tv), common_struct))
+                m, n, xtyp(Tv), common_struct[Threads.threadid()]))
 end
 
 function spzeros(m::Integer, n::Integer, nzmax::Integer, ::Type{Tv}) where Tv<:VTypes
     Sparse(ccall((@cholmod_name("spzeros"), :libcholmod),
         Ptr{C_Sparse{Tv}},
             (Csize_t, Csize_t, Csize_t, Cint, Ptr{UInt8}),
-             m, n, nzmax, xtyp(Tv), common_struct))
+             m, n, nzmax, xtyp(Tv), common_struct[Threads.threadid()]))
 end
 
 function transpose_(A::Sparse{Tv}, values::Integer) where Tv<:VTypes
     Sparse(ccall((@cholmod_name("transpose"),:libcholmod),
         Ptr{C_Sparse{Tv}},
             (Ptr{C_Sparse{Tv}}, Cint, Ptr{UInt8}),
-                A, values, common_struct))
+                A, values, common_struct[Threads.threadid()]))
 end
 
 function copy(F::Factor{Tv}) where Tv<:VTypes
     Factor(ccall((@cholmod_name("copy_factor"),:libcholmod),
         Ptr{C_Factor{Tv}},
             (Ptr{C_Factor{Tv}}, Ptr{UInt8}),
-                F, common_struct))
+                F, common_struct[Threads.threadid()]))
 end
 function copy(A::Sparse{Tv}) where Tv<:VTypes
     Sparse(ccall((@cholmod_name("copy_sparse"),:libcholmod),
         Ptr{C_Sparse{Tv}},
             (Ptr{C_Sparse{Tv}}, Ptr{UInt8}),
-                A, common_struct))
+                A, common_struct[Threads.threadid()]))
 end
 function copy(A::Sparse{Tv}, stype::Integer, mode::Integer) where Tv<:VRealTypes
     Sparse(ccall((@cholmod_name("copy"),:libcholmod),
         Ptr{C_Sparse{Tv}},
             (Ptr{C_Sparse{Tv}}, Cint, Cint, Ptr{UInt8}),
-                A, stype, mode, common_struct))
+                A, stype, mode, common_struct[Threads.threadid()]))
 end
 
 ### cholmod_check.h ###
 function print_sparse(A::Sparse{Tv}, name::String) where Tv<:VTypes
     isascii(name) || error("non-ASCII name: $name")
-    set_print_level(common_struct, 3)
+    set_print_level(common_struct[Threads.threadid()], 3)
     @isok ccall((@cholmod_name("print_sparse"),:libcholmod), Cint,
             (Ptr{C_Sparse{Tv}}, Ptr{UInt8}, Ptr{UInt8}),
-                 A, name, common_struct)
+                 A, name, common_struct[Threads.threadid()])
     nothing
 end
 function print_factor(F::Factor{Tv}, name::String) where Tv<:VTypes
-    set_print_level(common_struct, 3)
+    set_print_level(common_struct[Threads.threadid()], 3)
     @isok ccall((@cholmod_name("print_factor"),:libcholmod), Cint,
             (Ptr{C_Factor{Tv}}, Ptr{UInt8}, Ptr{UInt8}),
-                F, name, common_struct)
+                F, name, common_struct[Threads.threadid()])
     nothing
 end
 
@@ -616,7 +627,7 @@ function ssmult(A::Sparse{Tv}, B::Sparse
             (Ptr{C_Sparse{Tv}}, Ptr{C_Sparse{Tv}}, Cint, Cint,
                 Cint, Ptr{UInt8}),
              A, B, stype, values,
-                sorted, common_struct))
+                sorted, common_struct[Threads.threadid()]))
 end
 
 function norm_sparse(A::Sparse{Tv}, norm::Integer) where Tv<:VTypes
@@ -625,14 +636,14 @@ function norm_sparse(A::Sparse{Tv}, norm
     end
     ccall((@cholmod_name("norm_sparse"), :libcholmod), Cdouble,
             (Ptr{C_Sparse{Tv}}, Cint, Ptr{UInt8}),
-                A, norm, common_struct)
+                A, norm, common_struct[Threads.threadid()])
 end
 
 function horzcat(A::Sparse{Tv}, B::Sparse{Tv}, values::Bool) where Tv<:VRealTypes
     Sparse(ccall((@cholmod_name("horzcat"), :libcholmod),
         Ptr{C_Sparse{Tv}},
             (Ptr{C_Sparse{Tv}}, Ptr{C_Sparse{Tv}}, Cint, Ptr{UInt8}),
-             A, B, values, common_struct))
+             A, B, values, common_struct[Threads.threadid()]))
 end
 
 function scale!(S::Dense{Tv}, scale::Integer, A::Sparse{Tv}) where Tv<:VRealTypes
@@ -661,7 +672,7 @@ function scale!(S::Dense{Tv}, scale::Int
     sA = unsafe_load(pointer(A))
     @isok ccall((@cholmod_name("scale"),:libcholmod), Cint,
             (Ptr{C_Dense{Tv}}, Cint, Ptr{C_Sparse{Tv}}, Ptr{UInt8}),
-                S, scale, A, common_struct)
+                S, scale, A, common_struct[Threads.threadid()])
     A
 end
 
@@ -677,7 +688,7 @@ function sdmult!(A::Sparse{Tv}, transpos
             (Ptr{C_Sparse{Tv}}, Cint,
              Ref{ComplexF64}, Ref{ComplexF64},
              Ptr{C_Dense{Tv}}, Ptr{C_Dense{Tv}}, Ptr{UInt8}),
-                A, transpose, α, β, X, Y, common_struct)
+                A, transpose, α, β, X, Y, common_struct[Threads.threadid()])
     Y
 end
 
@@ -685,7 +696,7 @@ function vertcat(A::Sparse{Tv}, B::Spars
     Sparse(ccall((@cholmod_name("vertcat"), :libcholmod),
             Ptr{C_Sparse{Tv}},
             (Ptr{C_Sparse{Tv}}, Ptr{C_Sparse{Tv}}, Cint, Ptr{UInt8}),
-                A, B, values, common_struct))
+                A, B, values, common_struct[Threads.threadid()]))
 end
 
 function symmetry(A::Sparse{Tv}, option::Integer) where Tv<:VTypes
@@ -697,7 +708,7 @@ function symmetry(A::Sparse{Tv}, option:
             (Ptr{C_Sparse{Tv}}, Cint, Ptr{SuiteSparse_long}, Ptr{SuiteSparse_long},
                 Ptr{SuiteSparse_long}, Ptr{SuiteSparse_long}, Ptr{UInt8}),
                     A, option, xmatched, pmatched,
-                        nzoffdiag, nzdiag, common_struct)
+                        nzoffdiag, nzdiag, common_struct[Threads.threadid()])
     rv, xmatched[], pmatched[], nzoffdiag[], nzdiag[]
 end
 
@@ -745,12 +756,12 @@ function solve(sys::Integer, F::Factor{T
         if s.is_ll == 1
             throw(LinearAlgebra.PosDefException(s.minor))
         else
-            throw(ArgumentError("factorized matrix has one or more zero pivots. Try using `lu` instead."))
+            throw(LinearAlgebra.ZeroPivotException(s.minor))
         end
     end
     Dense(ccall((@cholmod_name("solve"),:libcholmod), Ptr{C_Dense{Tv}},
             (Cint, Ptr{C_Factor{Tv}}, Ptr{C_Dense{Tv}}, Ptr{UInt8}),
-                sys, F, B, common_struct))
+                sys, F, B, common_struct[Threads.threadid()]))
 end
 
 function spsolve(sys::Integer, F::Factor{Tv}, B::Sparse{Tv}) where Tv<:VTypes
@@ -761,7 +772,7 @@ function spsolve(sys::Integer, F::Factor
     Sparse(ccall((@cholmod_name("spsolve"),:libcholmod),
         Ptr{C_Sparse{Tv}},
             (Cint, Ptr{C_Factor{Tv}}, Ptr{C_Sparse{Tv}}, Ptr{UInt8}),
-                sys, F, B, common_struct))
+                sys, F, B, common_struct[Threads.threadid()]))
 end
 
 # Autodetects the types
@@ -769,7 +780,7 @@ function read_sparse(file::Libc.FILE, ::
     ptr = ccall((@cholmod_name("read_sparse"), :libcholmod),
         Ptr{C_Sparse{Cvoid}},
             (Ptr{Cvoid}, Ptr{UInt8}),
-                file.ptr, common_struct)
+                file.ptr, common_struct[Threads.threadid()])
     if ptr == C_NULL
         throw(ArgumentError("sparse matrix construction failed. Check that input file is valid."))
     end
@@ -797,13 +808,25 @@ get_perm(FC::FactorComponent) = get_perm
 # Conversion/construction
 function Dense{T}(A::StridedVecOrMat) where T<:VTypes
     d = allocate_dense(size(A, 1), size(A, 2), stride(A, 2), T)
-    s = unsafe_load(pointer(d))
-    for i in eachindex(A)
-        unsafe_store!(s.x, A[i], i)
+    GC.@preserve d begin
+        s = unsafe_load(pointer(d))
+        for (i, c) in enumerate(eachindex(A))
+            unsafe_store!(s.x, A[c], i)
+        end
     end
     d
 end
-function Dense(A::StridedVecOrMat)
+function Dense{T}(A::Union{Adjoint{<:Any, <:StridedVecOrMat}, Transpose{<:Any, <:StridedVecOrMat}}) where T<:VTypes
+    d = allocate_dense(size(A, 1), size(A, 2), size(A, 1), T)
+    GC.@preserve d begin
+        s = unsafe_load(pointer(d))
+        for (i, c) in enumerate(eachindex(A))
+            unsafe_store!(s.x, A[c], i)
+        end
+    end
+    d
+end
+function Dense(A::Union{StridedVecOrMat, Adjoint{<:Any, <:StridedVecOrMat}, Transpose{<:Any, <:StridedVecOrMat}})
     T = promote_type(eltype(A), Float64)
     return Dense{T}(A)
 end
@@ -863,39 +886,39 @@ end
 
 function Sparse{Tv}(A::SparseMatrixCSC, stype::Integer) where Tv<:VTypes
     ## Check length of input. This should never fail but see #20024
-    if length(A.colptr) <= A.n
-        throw(ArgumentError("length of colptr must be at least size(A,2) + 1 = $(A.n + 1) but was $(length(A.colptr))"))
+    if length(getcolptr(A)) <= size(A, 2)
+        throw(ArgumentError("length of colptr must be at least size(A,2) + 1 = $(size(A, 2) + 1) but was $(length(getcolptr(A)))"))
     end
-    if nnz(A) > length(A.rowval)
-        throw(ArgumentError("length of rowval is $(length(A.rowval)) but value of colptr requires length to be at least $(nnz(A))"))
+    if nnz(A) > length(rowvals(A))
+        throw(ArgumentError("length of rowval is $(length(rowvals(A))) but value of colptr requires length to be at least $(nnz(A))"))
     end
-    if nnz(A) > length(A.nzval)
-        throw(ArgumentError("length of nzval is $(length(A.nzval)) but value of colptr requires length to be at least $(nnz(A))"))
+    if nnz(A) > length(nonzeros(A))
+        throw(ArgumentError("length of nzval is $(length(nonzeros(A))) but value of colptr requires length to be at least $(nnz(A))"))
     end
 
-    o = allocate_sparse(A.m, A.n, nnz(A), true, true, stype, Tv)
+    o = allocate_sparse(size(A, 1), size(A, 2), nnz(A), true, true, stype, Tv)
     s = unsafe_load(pointer(o))
-    for i = 1:(A.n + 1)
-        unsafe_store!(s.p, A.colptr[i] - 1, i)
+    for i = 1:(size(A, 2) + 1)
+        unsafe_store!(s.p, getcolptr(A)[i] - 1, i)
     end
     for i = 1:nnz(A)
-        unsafe_store!(s.i, A.rowval[i] - 1, i)
+        unsafe_store!(s.i, rowvals(A)[i] - 1, i)
     end
     if Tv <: Complex && stype != 0
         # Need to remove any non real elements in the diagonal because, in contrast to
         # BLAS/LAPACK these are not ignored by CHOLMOD. If even tiny imaginary parts are
         # present CHOLMOD will fail with a non-positive definite/zero pivot error.
-        for j = 1:A.n
-            for ip = A.colptr[j]:A.colptr[j + 1] - 1
-                v = A.nzval[ip]
-                unsafe_store!(s.x, A.rowval[ip] == j ? Complex(real(v)) : v, ip)
+        for j = 1:size(A, 2)
+            for ip = getcolptr(A)[j]:getcolptr(A)[j + 1] - 1
+                v = nonzeros(A)[ip]
+                unsafe_store!(s.x, rowvals(A)[ip] == j ? Complex(real(v)) : v, ip)
             end
         end
-    elseif Tv == eltype(A.nzval)
-        unsafe_copyto!(s.x, pointer(A.nzval), nnz(A))
+    elseif Tv == eltype(nonzeros(A))
+        unsafe_copyto!(s.x, pointer(nonzeros(A)), nnz(A))
     else
         for i = 1:nnz(A)
-            unsafe_store!(s.x, A.nzval[i], i)
+            unsafe_store!(s.x, nonzeros(A)[i], i)
         end
     end
 
@@ -1195,12 +1218,12 @@ function getLd!(S::SparseMatrixCSC)
     fill!(d, 0)
     col = 1
     for k = 1:nnz(S)
-        while k >= S.colptr[col+1]
+        while k >= getcolptr(S)[col+1]
             col += 1
         end
-        if S.rowval[k] == col
-            d[col] = S.nzval[k]
-            S.nzval[k] = 1
+        if rowvals(S)[k] == col
+            d[col] = nonzeros(S)[k]
+            nonzeros(S)[k] = 1
         end
     end
     S, d
@@ -1223,11 +1246,12 @@ function *(A::Sparse{Tv}, adjB::Adjoint{
     ## A->stype == 0 (storage of upper and lower parts). If necessary
     ## the matrix A is first converted to stype == 0
     s = unsafe_load(pointer(A))
+    fset = s.ncol == 0 ? SuiteSparse_long[] : SuiteSparse_long[0:s.ncol-1;]
     if s.stype != 0
         aa1 = copy(A, 0, 1)
-        return aat(aa1, SuiteSparse_long[0:s.ncol-1;], 1)
+        return aat(aa1, fset, 1)
     else
-        return aat(A, SuiteSparse_long[0:s.ncol-1;], 1)
+        return aat(A, fset, 1)
     end
 end
 
@@ -1258,14 +1282,14 @@ function fact_(A::Sparse{<:VTypes}, cm::
     sA.stype == 0 && throw(ArgumentError("sparse matrix is not symmetric/Hermitian"))
 
     if !postorder
-        unsafe_store!(common_postorder[], 0)
+        unsafe_store!(common_postorder[Threads.threadid()], 0)
     end
 
     if perm === nothing || isempty(perm) # TODO: deprecate empty perm
         F = analyze(A, cm)
     else # user permutation provided
         if userperm_only # use perm even if it is worse than AMD
-            unsafe_store!(common_nmethods[], 1)
+            unsafe_store!(common_nmethods[Threads.threadid()], 1)
         end
         F = analyze_p(A, SuiteSparse_long[p-1 for p in perm], cm)
     end
@@ -1276,10 +1300,10 @@ end
 function cholesky!(F::Factor{Tv}, A::Sparse{Tv};
                    shift::Real=0.0, check::Bool = true) where Tv
     # Makes it an LLt
-    unsafe_store!(common_final_ll[], 1)
+    unsafe_store!(common_final_ll[Threads.threadid()], 1)
 
     # Compute the numerical factorization
-    factorize_p!(A, shift, F, common_struct)
+    factorize_p!(A, shift, F, common_struct[Threads.threadid()])
 
     check && (issuccess(F) || throw(LinearAlgebra.PosDefException(1)))
     return F
@@ -1312,7 +1336,7 @@ cholesky!(F::Factor, A::Union{SparseMatr
 function cholesky(A::Sparse; shift::Real=0.0, check::Bool = true,
     perm::Union{Nothing,AbstractVector{SuiteSparse_long}}=nothing)
 
-    cm = defaults(common_struct)
+    cm = defaults(common_struct[Threads.threadid()])
     set_print_level(cm, 0)
 
     # Compute the symbolic factorization
@@ -1436,7 +1460,7 @@ cholesky(A::Union{SparseMatrixCSC{T}, Sp
 
 function ldlt!(F::Factor{Tv}, A::Sparse{Tv};
                shift::Real=0.0, check::Bool = true) where Tv
-    cm = defaults(common_struct)
+    cm = defaults(common_struct[Threads.threadid()])
     set_print_level(cm, 0)
 
     # Makes it an LDLt
@@ -1445,7 +1469,7 @@ function ldlt!(F::Factor{Tv}, A::Sparse{
     # Compute the numerical factorization
     factorize_p!(A, shift, F, cm)
 
-    check && (issuccess(F) || throw(LinearAlgebra.PosDefException(1)))
+    check && (issuccess(F) || throw(LinearAlgebra.ZeroPivotException(1)))
     return F
 end
 
@@ -1476,13 +1500,13 @@ ldlt!(F::Factor, A::Union{SparseMatrixCS
 function ldlt(A::Sparse; shift::Real=0.0, check::Bool = true,
     perm::Union{Nothing,AbstractVector{SuiteSparse_long}}=nothing)
 
-    cm = defaults(common_struct)
+    cm = defaults(common_struct[Threads.threadid()])
     set_print_level(cm, 0)
 
     # Makes it an LDLt
-    unsafe_store!(common_final_ll[], 0)
+    unsafe_store!(common_final_ll[Threads.threadid()], 0)
     # Really make sure it's an LDLt by avoiding supernodal factorization
-    unsafe_store!(common_supernodal[], 0)
+    unsafe_store!(common_supernodal[Threads.threadid()], 0)
 
     # Compute the symbolic factorization
     F = fact_(A, cm; perm = perm)
@@ -1557,7 +1581,7 @@ function lowrankupdowndate!(F::Factor{Tv
     end
     @isok ccall((@cholmod_name("updown"), :libcholmod), Cint,
         (Cint, Ptr{C_Sparse{Tv}}, Ptr{C_Factor{Tv}}, Ptr{Cvoid}),
-        update, C, F, common_struct)
+        update, C, F, common_struct[Threads.threadid()])
     F
 end
 
@@ -1679,8 +1703,14 @@ end
 # Likewise the two following explicit Vector and Matrix defs (rather than a single VecOrMat)
 (\)(L::Factor{T}, B::Vector{Complex{T}}) where {T<:Float64} = complex.(L\real(B), L\imag(B))
 (\)(L::Factor{T}, B::Matrix{Complex{T}}) where {T<:Float64} = complex.(L\real(B), L\imag(B))
+(\)(L::Factor{T}, B::Adjoint{<:Any, <:Matrix{Complex{T}}}) where {T<:Float64} = complex.(L\real(B), L\imag(B))
+(\)(L::Factor{T}, B::Transpose{<:Any, <:Matrix{Complex{T}}}) where {T<:Float64} = complex.(L\real(B), L\imag(B))
+
 (\)(L::Factor{T}, b::StridedVector) where {T<:VTypes} = Vector(L\Dense{T}(b))
 (\)(L::Factor{T}, B::StridedMatrix) where {T<:VTypes} = Matrix(L\Dense{T}(B))
+(\)(L::Factor{T}, B::Adjoint{<:Any, <:StridedMatrix}) where {T<:VTypes} = Matrix(L\Dense{T}(B))
+(\)(L::Factor{T}, B::Transpose{<:Any, <:StridedMatrix}) where {T<:VTypes} = Matrix(L\Dense{T}(B))
+
 (\)(L::Factor, B::Sparse) = spsolve(CHOLMOD_A, L, B)
 # When right hand side is sparse, we have to ensure that the rhs is not marked as symmetric.
 (\)(L::Factor, B::SparseVecOrMat) = sparse(spsolve(CHOLMOD_A, L, Sparse(B, 0)))
@@ -1702,7 +1732,8 @@ const RealHermSymComplexHermF64SSL = Uni
     Symmetric{Float64,SparseMatrixCSC{Float64,SuiteSparse_long}},
     Hermitian{Float64,SparseMatrixCSC{Float64,SuiteSparse_long}},
     Hermitian{Complex{Float64},SparseMatrixCSC{Complex{Float64},SuiteSparse_long}}}
-function \(A::RealHermSymComplexHermF64SSL, B::StridedVecOrMat)
+const StridedVecOrMatInclAdjAndTrans = Union{StridedVecOrMat, Adjoint{<:Any, <:StridedVecOrMat}, Transpose{<:Any, <:StridedVecOrMat}}
+function \(A::RealHermSymComplexHermF64SSL, B::StridedVecOrMatInclAdjAndTrans)
     F = cholesky(A; check = false)
     if issuccess(F)
         return \(F, B)
@@ -1715,7 +1746,7 @@ function \(A::RealHermSymComplexHermF64S
         end
     end
 end
-function \(adjA::Adjoint{<:Any,<:RealHermSymComplexHermF64SSL}, B::StridedVecOrMat)
+function \(adjA::Adjoint{<:Any,<:RealHermSymComplexHermF64SSL}, B::StridedVecOrMatInclAdjAndTrans)
     A = adjA.parent
     F = cholesky(A; check = false)
     if issuccess(F)
diff -pruN 1.3.1+dfsg-1/stdlib/SuiteSparse/src/spqr.jl 1.4.0+dfsg-1/stdlib/SuiteSparse/src/spqr.jl
--- 1.3.1+dfsg-1/stdlib/SuiteSparse/src/spqr.jl	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/stdlib/SuiteSparse/src/spqr.jl	2020-03-21 16:36:32.000000000 +0000
@@ -23,7 +23,8 @@ const ORDERING_BESTAMD = Int32(9) # try
 # tried.  If there is a high fill-in with AMD then try METIS(A'A) and take
 # the best of AMD and METIS. METIS is not tried if it isn't installed.
 
-using SparseArrays: SparseMatrixCSC, nnz
+using SparseArrays
+using SparseArrays: getcolptr
 using ..SuiteSparse.CHOLMOD
 using ..SuiteSparse.CHOLMOD: change_stype!, free!
 
@@ -62,7 +63,7 @@ function _qr!(ordering::Integer, tol::Re
         H,              # m-by-nh Householder vectors
         HPinv,          # size m row permutation
         HTau,           # 1-by-nh Householder coefficients
-        CHOLMOD.common_struct) # /* workspace and parameters */
+        CHOLMOD.common_struct[Threads.threadid()]) # /* workspace and parameters */
 
     if rnk < 0
         error("Sparse QR factorization failed")
@@ -81,7 +82,7 @@ function _qr!(ordering::Integer, tol::Re
         # the common struct is updated
         ccall((:cholmod_l_free, :libcholmod), Cvoid,
             (Csize_t, Cint, Ptr{CHOLMOD.SuiteSparse_long}, Ptr{Cvoid}),
-            n, sizeof(CHOLMOD.SuiteSparse_long), e, CHOLMOD.common_struct)
+            n, sizeof(CHOLMOD.SuiteSparse_long), e, CHOLMOD.common_struct[Threads.threadid()])
     end
     hpinv = HPinv[]
     if hpinv == C_NULL
@@ -96,7 +97,7 @@ function _qr!(ordering::Integer, tol::Re
         # the common struct is updated
         ccall((:cholmod_l_free, :libcholmod), Cvoid,
             (Csize_t, Cint, Ptr{CHOLMOD.SuiteSparse_long}, Ptr{Cvoid}),
-            m, sizeof(CHOLMOD.SuiteSparse_long), hpinv, CHOLMOD.common_struct)
+            m, sizeof(CHOLMOD.SuiteSparse_long), hpinv, CHOLMOD.common_struct[Threads.threadid()])
     end
 
     return rnk, _E, _HPinv
@@ -142,25 +143,6 @@ Matrix{T}(Q::QRSparseQ) where {T} = lmul
 _default_tol(A::SparseMatrixCSC) =
     20*sum(size(A))*eps(real(eltype(A)))*maximum(norm(view(A, :, i)) for i in 1:size(A, 2))
 
-function LinearAlgebra.qr(A::SparseMatrixCSC{Tv}; tol = _default_tol(A)) where {Tv <: CHOLMOD.VTypes}
-    R     = Ref{Ptr{CHOLMOD.C_Sparse{Tv}}}()
-    E     = Ref{Ptr{CHOLMOD.SuiteSparse_long}}()
-    H     = Ref{Ptr{CHOLMOD.C_Sparse{Tv}}}()
-    HPinv = Ref{Ptr{CHOLMOD.SuiteSparse_long}}()
-    HTau  = Ref{Ptr{CHOLMOD.C_Dense{Tv}}}(C_NULL)
-
-    # SPQR doesn't accept symmetric matrices so we explicitly set the stype
-    r, p, hpinv = _qr!(ORDERING_DEFAULT, tol, 0, 0, Sparse(A, 0),
-        C_NULL, C_NULL, C_NULL, C_NULL,
-        R, E, H, HPinv, HTau)
-
-    R_ = SparseMatrixCSC(Sparse(R[]))
-    return QRSparse(SparseMatrixCSC(Sparse(H[])),
-                    vec(Array(CHOLMOD.Dense(HTau[]))),
-                    SparseMatrixCSC(min(size(A)...), R_.n, R_.colptr, R_.rowval, R_.nzval),
-                    p, hpinv)
-end
-
 """
     qr(A) -> QRSparse
 
@@ -168,6 +150,12 @@ Compute the `QR` factorization of a spar
 are used such that `F.R = F.Q'*A[F.prow,F.pcol]`. The main application of this type is to
 solve least squares or underdetermined problems with [`\\`](@ref). The function calls the C library SPQR.
 
+!!! note
+    `qr(A::SparseMatrixCSC)` uses the SPQR library that is part of SuiteSparse.
+    As this library only supports sparse matrices with [`Float64`](@ref) or
+    `ComplexF64` elements, as of Julia v1.4 `qr` converts `A` into a copy that is
+    of type `SparseMatrixCSC{Float64}` or `SparseMatrixCSC{ComplexF64}` as appropriate.
+
 # Examples
 ```jldoctest
 julia> A = sparse([1,2,3,4], [1,1,2,2], [1.0,1.0,1.0,1.0])
@@ -201,7 +189,39 @@ Column permutation:
  2
 ```
 """
-LinearAlgebra.qr(A::SparseMatrixCSC; tol = _default_tol(A)) = qr(A, Val{true}, tol = tol)
+function LinearAlgebra.qr(A::SparseMatrixCSC{Tv}; tol=_default_tol(A)) where {Tv <: CHOLMOD.VTypes}
+    R     = Ref{Ptr{CHOLMOD.C_Sparse{Tv}}}()
+    E     = Ref{Ptr{CHOLMOD.SuiteSparse_long}}()
+    H     = Ref{Ptr{CHOLMOD.C_Sparse{Tv}}}()
+    HPinv = Ref{Ptr{CHOLMOD.SuiteSparse_long}}()
+    HTau  = Ref{Ptr{CHOLMOD.C_Dense{Tv}}}(C_NULL)
+
+    # SPQR doesn't accept symmetric matrices so we explicitly set the stype
+    r, p, hpinv = _qr!(ORDERING_DEFAULT, tol, 0, 0, Sparse(A, 0),
+        C_NULL, C_NULL, C_NULL, C_NULL,
+        R, E, H, HPinv, HTau)
+
+    R_ = SparseMatrixCSC(Sparse(R[]))
+    return QRSparse(SparseMatrixCSC(Sparse(H[])),
+                    vec(Array(CHOLMOD.Dense(HTau[]))),
+                    SparseMatrixCSC(min(size(A)...),
+                                    size(R_, 2),
+                                    getcolptr(R_),
+                                    rowvals(R_),
+                                    nonzeros(R_)),
+                    p, hpinv)
+end
+LinearAlgebra.qr(A::SparseMatrixCSC{<:Union{Float16,Float32}}; tol=_default_tol(A)) =
+    qr(convert(SparseMatrixCSC{Float64}, A); tol=tol)
+LinearAlgebra.qr(A::SparseMatrixCSC{<:Union{ComplexF16,ComplexF32}}; tol=_default_tol(A)) =
+    qr(convert(SparseMatrixCSC{ComplexF64}, A); tol=tol)
+LinearAlgebra.qr(A::Union{SparseMatrixCSC{T},SparseMatrixCSC{Complex{T}}};
+   tol=_default_tol(A)) where {T<:AbstractFloat} =
+    throw(ArgumentError(string("matrix type ", typeof(A), "not supported. ",
+    "Try qr(convert(SparseMatrixCSC{Float64/ComplexF64,Int}, A)) for ",
+    "sparse floating point QR using SPQR or qr(Array(A)) for generic ",
+    "dense QR.")))
+LinearAlgebra.qr(A::SparseMatrixCSC; tol=_default_tol(A)) = qr(float(A); tol=tol)
 
 function LinearAlgebra.lmul!(Q::QRSparseQ, A::StridedVecOrMat)
     if size(A, 1) != size(Q, 1)
@@ -345,7 +365,7 @@ end
 _ret_size(F::QRSparse, b::AbstractVector) = (size(F, 2),)
 _ret_size(F::QRSparse, B::AbstractMatrix) = (size(F, 2), size(B, 2))
 
-LinearAlgebra.rank(F::QRSparse) = reduce(max, view(F.R.rowval, 1:nnz(F.R)), init = eltype(F.R.rowval)(0))
+LinearAlgebra.rank(F::QRSparse) = reduce(max, view(rowvals(F.R), 1:nnz(F.R)), init = eltype(rowvals(F.R))(0))
 LinearAlgebra.rank(S::SparseMatrixCSC) = rank(qr(S))
 
 function (\)(F::QRSparse{T}, B::VecOrMat{Complex{T}}) where T<:LinearAlgebra.BlasReal
diff -pruN 1.3.1+dfsg-1/stdlib/SuiteSparse/src/umfpack.jl 1.4.0+dfsg-1/stdlib/SuiteSparse/src/umfpack.jl
--- 1.3.1+dfsg-1/stdlib/SuiteSparse/src/umfpack.jl	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/stdlib/SuiteSparse/src/umfpack.jl	2020-03-21 16:36:32.000000000 +0000
@@ -9,6 +9,7 @@ using LinearAlgebra
 import LinearAlgebra: Factorization, det, lu, ldiv!
 
 using SparseArrays
+using SparseArrays: getcolptr
 import SparseArrays: nnz
 
 import Serialization: AbstractSerializer, deserialize
@@ -151,11 +152,11 @@ The relation between `F` and `A` is
     `SparseMatrixCSC{Float64}` or `SparseMatrixCSC{ComplexF64}` as appropriate.
 """
 function lu(S::SparseMatrixCSC{<:UMFVTypes,<:UMFITypes}; check::Bool = true)
-    zerobased = S.colptr[1] == 0
-    res = UmfpackLU(C_NULL, C_NULL, S.m, S.n,
-                    zerobased ? copy(S.colptr) : decrement(S.colptr),
-                    zerobased ? copy(S.rowval) : decrement(S.rowval),
-                    copy(S.nzval), 0)
+    zerobased = getcolptr(S)[1] == 0
+    res = UmfpackLU(C_NULL, C_NULL, size(S, 1), size(S, 2),
+                    zerobased ? copy(getcolptr(S)) : decrement(getcolptr(S)),
+                    zerobased ? copy(rowvals(S)) : decrement(rowvals(S)),
+                    copy(nonzeros(S)), 0)
     finalizer(umfpack_free_symbolic, res)
     umfpack_numeric!(res)
     check && (issuccess(res) || throw(LinearAlgebra.SingularException(0)))
@@ -189,9 +190,18 @@ function size(F::UmfpackLU, dim::Integer
     end
 end
 
-function show(io::IO, F::UmfpackLU)
-    print(io, "UMFPACK LU Factorization of a $(size(F)) sparse matrix")
-    F.numeric != C_NULL && print(io, '\n', F.numeric)
+function show(io::IO, mime::MIME{Symbol("text/plain")}, F::UmfpackLU)
+    if F.numeric != C_NULL
+        if issuccess(F)
+            summary(io, F); println(io)
+            println(io, "L factor:")
+            show(io, mime, F.L)
+            println(io, "\nU factor:")
+            show(io, mime, F.U)
+        else
+            print(io, "Failed factorization of type $(typeof(F))")
+        end
+    end
 end
 
 function deserialize(s::AbstractSerializer, t::Type{UmfpackLU{Tv,Ti}}) where {Tv,Ti}
diff -pruN 1.3.1+dfsg-1/stdlib/SuiteSparse/test/cholmod.jl 1.4.0+dfsg-1/stdlib/SuiteSparse/test/cholmod.jl
--- 1.3.1+dfsg-1/stdlib/SuiteSparse/test/cholmod.jl	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/stdlib/SuiteSparse/test/cholmod.jl	2020-03-21 16:36:32.000000000 +0000
@@ -5,7 +5,9 @@ using DelimitedFiles
 using Test
 using Random
 using Serialization
-using LinearAlgebra: issuccess, PosDefException
+using LinearAlgebra: issuccess, PosDefException, ZeroPivotException
+using SparseArrays
+using SparseArrays: getcolptr
 
 # CHOLMOD tests
 Random.seed!(123)
@@ -232,7 +234,7 @@ end
 @testset "illegal dtype (for now but should be supported at some point)" begin
     p = ccall((:cholmod_l_allocate_sparse, :libcholmod), Ptr{CHOLMOD.C_Sparse{Cvoid}},
         (Csize_t, Csize_t, Csize_t, Cint, Cint, Cint, Cint, Ptr{Cvoid}),
-        1, 1, 1, true, true, 0, CHOLMOD.REAL, CHOLMOD.common_struct)
+        1, 1, 1, true, true, 0, CHOLMOD.REAL, CHOLMOD.common_struct[Threads.threadid()])
     puint = convert(Ptr{UInt32}, p)
     unsafe_store!(puint, CHOLMOD.SINGLE, 3*div(sizeof(Csize_t), 4) + 5*div(sizeof(Ptr{Cvoid}), 4) + 4)
     @test_throws CHOLMOD.CHOLMODException CHOLMOD.Sparse(p)
@@ -241,7 +243,7 @@ end
 @testset "illegal dtype" begin
     p = ccall((:cholmod_l_allocate_sparse, :libcholmod), Ptr{CHOLMOD.C_Sparse{Cvoid}},
         (Csize_t, Csize_t, Csize_t, Cint, Cint, Cint, Cint, Ptr{Cvoid}),
-        1, 1, 1, true, true, 0, CHOLMOD.REAL, CHOLMOD.common_struct)
+        1, 1, 1, true, true, 0, CHOLMOD.REAL, CHOLMOD.common_struct[Threads.threadid()])
     puint = convert(Ptr{UInt32}, p)
     unsafe_store!(puint, 5, 3*div(sizeof(Csize_t), 4) + 5*div(sizeof(Ptr{Cvoid}), 4) + 4)
     @test_throws CHOLMOD.CHOLMODException CHOLMOD.Sparse(p)
@@ -250,7 +252,7 @@ end
 @testset "illegal xtype" begin
     p = ccall((:cholmod_l_allocate_sparse, :libcholmod), Ptr{CHOLMOD.C_Sparse{Cvoid}},
         (Csize_t, Csize_t, Csize_t, Cint, Cint, Cint, Cint, Ptr{Cvoid}),
-        1, 1, 1, true, true, 0, CHOLMOD.REAL, CHOLMOD.common_struct)
+        1, 1, 1, true, true, 0, CHOLMOD.REAL, CHOLMOD.common_struct[Threads.threadid()])
     puint = convert(Ptr{UInt32}, p)
     unsafe_store!(puint, 3, 3*div(sizeof(Csize_t), 4) + 5*div(sizeof(Ptr{Cvoid}), 4) + 3)
     @test_throws CHOLMOD.CHOLMODException CHOLMOD.Sparse(p)
@@ -259,7 +261,7 @@ end
 @testset "illegal itype I" begin
     p = ccall((:cholmod_l_allocate_sparse, :libcholmod), Ptr{CHOLMOD.C_Sparse{Cvoid}},
         (Csize_t, Csize_t, Csize_t, Cint, Cint, Cint, Cint, Ptr{Cvoid}),
-        1, 1, 1, true, true, 0, CHOLMOD.REAL, CHOLMOD.common_struct)
+        1, 1, 1, true, true, 0, CHOLMOD.REAL, CHOLMOD.common_struct[Threads.threadid()])
     puint = convert(Ptr{UInt32}, p)
     unsafe_store!(puint, CHOLMOD.INTLONG, 3*div(sizeof(Csize_t), 4) + 5*div(sizeof(Ptr{Cvoid}), 4) + 2)
     @test_throws CHOLMOD.CHOLMODException CHOLMOD.Sparse(p)
@@ -268,7 +270,7 @@ end
 @testset "illegal itype II" begin
     p = ccall((:cholmod_l_allocate_sparse, :libcholmod), Ptr{CHOLMOD.C_Sparse{Cvoid}},
         (Csize_t, Csize_t, Csize_t, Cint, Cint, Cint, Cint, Ptr{Cvoid}),
-        1, 1, 1, true, true, 0, CHOLMOD.REAL, CHOLMOD.common_struct)
+        1, 1, 1, true, true, 0, CHOLMOD.REAL, CHOLMOD.common_struct[Threads.threadid()])
     puint = convert(Ptr{UInt32}, p)
     unsafe_store!(puint,  5, 3*div(sizeof(Csize_t), 4) + 5*div(sizeof(Ptr{Cvoid}), 4) + 2)
     @test_throws CHOLMOD.CHOLMODException CHOLMOD.Sparse(p)
@@ -319,7 +321,7 @@ end
 @testset "test free!" begin
     p = ccall((:cholmod_l_allocate_sparse, :libcholmod), Ptr{CHOLMOD.C_Sparse{Float64}},
         (Csize_t, Csize_t, Csize_t, Cint, Cint, Cint, Cint, Ptr{Cvoid}),
-        1, 1, 1, true, true, 0, CHOLMOD.REAL, CHOLMOD.common_struct)
+        1, 1, 1, true, true, 0, CHOLMOD.REAL, CHOLMOD.common_struct[Threads.threadid()])
     @test CHOLMOD.free!(p)
 end
 
@@ -330,11 +332,11 @@ end
     A1Sparse = CHOLMOD.Sparse(A1)
     A2Sparse = CHOLMOD.Sparse(A2)
     A1pdSparse = CHOLMOD.Sparse(
-        A1pd.m,
-        A1pd.n,
-        SuiteSparse.decrement(A1pd.colptr),
-        SuiteSparse.decrement(A1pd.rowval),
-        A1pd.nzval)
+        size(A1pd, 1),
+        size(A1pd, 2),
+        SuiteSparse.decrement(getcolptr(A1pd)),
+        SuiteSparse.decrement(rowvals(A1pd)),
+        nonzeros(A1pd))
 
     ## High level interface
     @test isa(CHOLMOD.Sparse(3, 3, [0,1,3,4], [0,2,1,2], fill(1., 4)), CHOLMOD.Sparse) # Sparse doesn't require columns to be sorted
@@ -382,8 +384,8 @@ end
     b = fill(1., size(A1, 1))
     @test_throws PosDefException cholesky(C - 2λmaxC*I)
     @test_throws PosDefException cholesky(C, shift=-2λmaxC)
-    @test_throws PosDefException ldlt(C - C[1,1]*I)
-    @test_throws PosDefException ldlt(C, shift=-real(C[1,1]))
+    @test_throws ZeroPivotException ldlt(C - C[1,1]*I)
+    @test_throws ZeroPivotException ldlt(C, shift=-real(C[1,1]))
     @test !isposdef(cholesky(C - 2λmaxC*I; check = false))
     @test !isposdef(cholesky(C, shift=-2λmaxC; check = false))
     @test !issuccess(ldlt(C - C[1,1]*I; check = false))
@@ -766,7 +768,8 @@ end
 @testset "Check inputs to Sparse. Related to #20024" for A_ in (
     SparseMatrixCSC(2, 2, [1, 2, 3], CHOLMOD.SuiteSparse_long[1,2], Float64[]),
     SparseMatrixCSC(2, 2, [1, 2, 3], CHOLMOD.SuiteSparse_long[1,2], Float64[1.0]))
-    @test_throws ArgumentError CHOLMOD.Sparse(size(A_)..., A_.colptr .- 1, A_.rowval .- 1, A_.nzval)
+    args = (size(A_)..., getcolptr(A_) .- 1, rowvals(A_) .- 1, nonzeros(A_))
+    @test_throws ArgumentError CHOLMOD.Sparse(args...)
     @test_throws ArgumentError CHOLMOD.Sparse(A_)
 end
 
@@ -846,9 +849,29 @@ end
     B = sparse(ComplexF64[0 0; 0 0])
     for M in (A, B, Symmetric(A), Hermitian(B))
         F = ldlt(M; check = false)
-        @test_throws PosDefException ldlt(M)
-        @test_throws PosDefException ldlt!(F, M)
+        @test_throws ZeroPivotException ldlt(M)
+        @test_throws ZeroPivotException ldlt!(F, M)
         @test !issuccess(ldlt(M; check = false))
         @test !issuccess(ldlt!(F, M; check = false))
     end
 end
+
+@testset "Issue #27860" begin
+    for typeA in (Float64, ComplexF64), typeB in (Float64, ComplexF64), transform in (adjoint, transpose)
+        A = sparse(typeA[2.0 0.1; 0.1 2.0])
+        B = randn(typeB, 2, 2)
+        @test A \ transform(B) ≈ cholesky(A) \ transform(B) ≈ Matrix(A) \ transform(B)
+    end
+end
+
+@testset "Issue #33365" begin
+    A = Sparse(spzeros(0, 0))
+    @test A * A' == A
+    @test A' * A == A
+    B = Sparse(spzeros(0, 4))
+    @test B * B' == Sparse(spzeros(0, 0))
+    @test B' * B == Sparse(spzeros(4, 4))
+    C = Sparse(spzeros(3, 0))
+    @test C * C' == Sparse(spzeros(3, 3))
+    @test C' * C == Sparse(spzeros(0, 0))
+end
diff -pruN 1.3.1+dfsg-1/stdlib/SuiteSparse/test/runtests.jl 1.4.0+dfsg-1/stdlib/SuiteSparse/test/runtests.jl
--- 1.3.1+dfsg-1/stdlib/SuiteSparse/test/runtests.jl	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/stdlib/SuiteSparse/test/runtests.jl	2020-03-21 16:36:32.000000000 +0000
@@ -4,7 +4,27 @@ using Test, Random
 using SuiteSparse, LinearAlgebra, SparseArrays
 
 if Base.USE_GPL_LIBS
-   include("umfpack.jl")
-   include("cholmod.jl")
-   include("spqr.jl")
+    include("umfpack.jl")
+    include("cholmod.jl")
+    include("spqr.jl")
+
+    # Test multithreaded execution
+    let p, cmd = `$(Base.julia_cmd()) --depwarn=error --startup-file=no threads.jl`
+        # test both nthreads==1 and nthreads>1. spawn a process to test whichever
+        # case we are not running currently.
+        other_nthreads = Threads.nthreads() == 1 ? 4 : 1
+        p = run(
+                pipeline(
+                    setenv(
+                        cmd,
+                        "JULIA_NUM_THREADS" => other_nthreads,
+                        dir=@__DIR__()),
+                    stdout = stdout,
+                    stderr = stderr),
+                wait = false)
+        include("threads.jl")
+        if !success(p)
+            error("SuiteSparse threads test failed with nthreads == $other_nthreads")
+        end
+    end
 end
diff -pruN 1.3.1+dfsg-1/stdlib/SuiteSparse/test/threads.jl 1.4.0+dfsg-1/stdlib/SuiteSparse/test/threads.jl
--- 1.3.1+dfsg-1/stdlib/SuiteSparse/test/threads.jl	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/stdlib/SuiteSparse/test/threads.jl	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1,20 @@
+using Test, LinearAlgebra, SparseArrays
+
+@testset "threaded SuiteSparse tests" begin
+    A = sprandn(200, 200, 0.2)
+    b = rand(200)
+
+    function test(n::Integer)
+        _A = A[1:n, 1:n]
+        _b = b[1:n]
+        x = qr(_A) \ _b
+        return norm(x)
+    end
+
+    res_threads = zeros(100)
+    Threads.@threads for i in 1:100
+        res_threads[i] = test(i + 100)
+    end
+
+    @test res_threads ≈ [test(i + 100) for i in 1:100]
+end
diff -pruN 1.3.1+dfsg-1/stdlib/SuiteSparse/test/umfpack.jl 1.4.0+dfsg-1/stdlib/SuiteSparse/test/umfpack.jl
--- 1.3.1+dfsg-1/stdlib/SuiteSparse/test/umfpack.jl	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/stdlib/SuiteSparse/test/umfpack.jl	2020-03-21 16:36:32.000000000 +0000
@@ -190,3 +190,19 @@ using LinearAlgebra: Adjoint, Transpose,
     end
 
 end
+
+@testset "REPL printing of UmfpackLU" begin
+    # regular matrix
+    A = sparse([1, 2], [1, 2], Float64[1.0, 1.0])
+    F = lu(A)
+    facstring = sprint((t, s) -> show(t, "text/plain", s), F)
+    lstring = sprint((t, s) -> show(t, "text/plain", s), F.L)
+    ustring = sprint((t, s) -> show(t, "text/plain", s), F.U)
+    @test facstring == "$(summary(F))\nL factor:\n$lstring\nU factor:\n$ustring"
+
+    # singular matrix
+    B = sparse(zeros(Float64, 2, 2))
+    F = lu(B; check=false)
+    facstring = sprint((t, s) -> show(t, "text/plain", s), F)
+    @test facstring == "Failed factorization of type $(summary(F))"
+end
diff -pruN 1.3.1+dfsg-1/stdlib/Test/src/logging.jl 1.4.0+dfsg-1/stdlib/Test/src/logging.jl
--- 1.3.1+dfsg-1/stdlib/Test/src/logging.jl	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/stdlib/Test/src/logging.jl	2020-03-21 16:36:32.000000000 +0000
@@ -136,6 +136,11 @@ If we also wanted to test the debug mess
 
     @test_logs (:info,"Doing foo with n=2") (:debug,"Iteration 1") (:debug,"Iteration 2") min_level=Debug foo(2)
 
+If you want to test that some particular messages are generated while ignoring the rest,
+you can set the keyword `match_mode=:any`:
+
+    @test_logs (:info,) (:debug,"Iteration 42") min_level=Debug match_mode=:any foo(100)
+
 The macro may be chained with `@test` to also test the returned value:
 
     @test (@test_logs (:info,"Doing foo with n=2") foo(2)) == 42
diff -pruN 1.3.1+dfsg-1/stdlib/Test/src/Test.jl 1.4.0+dfsg-1/stdlib/Test/src/Test.jl
--- 1.3.1+dfsg-1/stdlib/Test/src/Test.jl	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/stdlib/Test/src/Test.jl	2020-03-21 16:36:32.000000000 +0000
@@ -64,6 +64,9 @@ function scrub_exc_stack(stack)
     return Any[ (x[1], scrub_backtrace(x[2])) for x in stack ]
 end
 
+# define most of the test infrastructure without type specialization
+@nospecialize
+
 """
     Result
 
@@ -179,8 +182,7 @@ function Base.show(io::IO, t::Error)
         println(io, "  Test threw exception")
         println(io, "  Expression: ", t.orig_expr)
         # Capture error message and indent to match
-        print(io, join(map(line->string("  ",line),
-                           split(t.backtrace, "\n")), "\n"))
+        join(io, ("  " * line for line in split(t.backtrace, "\n")), "\n")
     elseif t.test_type === :test_unbroken
         # A test that was expected to fail did not
         println(io, " Unexpected Pass")
@@ -190,8 +192,7 @@ function Base.show(io::IO, t::Error)
         # we had an error outside of a @test
         println(io, "  Got exception outside of a @test")
         # Capture error message and indent to match
-        print(io, join(map(line->string("  ",line),
-                           split(t.backtrace, "\n")), "\n"))
+        join(io, ("  " * line for line in split(t.backtrace, "\n")), "\n")
     end
 end
 
@@ -362,7 +363,7 @@ Test Broken
 
 julia> @test_broken 1 == 2 atol=0.1
 Test Broken
-  Expression: ==(1, 2, atol=0.1)
+  Expression: ==(1, 2, atol = 0.1)
 ```
 """
 macro test_broken(ex, kws...)
@@ -391,7 +392,7 @@ Test Broken
 
 julia> @test_skip 1 == 2 atol=0.1
 Test Broken
-  Skipped: ==(1, 2, atol=0.1)
+  Skipped: ==(1, 2, atol = 0.1)
 ```
 """
 macro test_skip(ex, kws...)
@@ -570,7 +571,7 @@ end
 
 # An internal function, called by the code generated by @test_throws
 # to evaluate and catch the thrown exception - if it exists
-function do_test_throws(result::ExecutionResult, @nospecialize(orig_expr), @nospecialize(extype))
+function do_test_throws(result::ExecutionResult, orig_expr, extype)
     if isa(result, Threw)
         # Check that the right type of exception was thrown
         success = false
@@ -619,6 +620,9 @@ tuple or array, checks that the error ou
 Returns the result of evaluating `expr`.
 
 See also [`@test_nowarn`](@ref) to check for the absence of error output.
+
+Note: Warnings generated by `@warn` cannot be tested with this macro. Use
+`@test_logs` instead.
 """
 macro test_warn(msg, expr)
     quote
@@ -643,6 +647,9 @@ end
 
 Test whether evaluating `expr` results in empty [`stderr`](@ref) output
 (no warnings or other messages).  Returns the result of evaluating `expr`.
+
+Note: The absence of warnings generated by `@warn` cannot be tested
+with this macro. Use `@test_logs expr` instead.
 """
 macro test_nowarn(expr)
     quote
@@ -779,6 +786,8 @@ end
 # the results at the end of the tests
 record(ts::DefaultTestSet, t::AbstractTestSet) = push!(ts.results, t)
 
+@specialize
+
 function print_test_errors(ts::DefaultTestSet)
     for t in ts.results
         if (isa(t, Error) || isa(t, Fail)) && myid() == 1
@@ -1091,16 +1100,13 @@ function testset_beginend(args, tests, s
     # action (such as reporting the results)
     ex = quote
         _check_testset($testsettype, $(QuoteNode(testsettype.args[1])))
-        ts = $(testsettype)($desc; $options...)
-        # this empty loop is here to force the block to be compiled,
-        # which is needed for backtrace scrubbing to work correctly.
-        while false; end
+        local ts = $(testsettype)($desc; $options...)
         push_testset(ts)
         # we reproduce the logic of guardseed, but this function
         # cannot be used as it changes slightly the semantic of @testset,
         # by wrapping the body in a function
         local RNG = default_rng()
-        oldrng = copy(RNG)
+        local oldrng = copy(RNG)
         try
             # RNG is re-seeded with its own seed to ease reproduce a failed test
             Random.seed!(RNG.seed)
@@ -1109,7 +1115,7 @@ function testset_beginend(args, tests, s
             err isa InterruptException && rethrow()
             # something in the test block threw an error. Count that as an
             # error in this test set
-            record(ts, Error(:nontest_error, :(), err, Base.catch_stack(), $(QuoteNode(source))))
+            record(ts, Error(:nontest_error, Expr(:tuple), err, Base.catch_stack(), $(QuoteNode(source))))
         finally
             copy!(RNG, oldrng)
         end
@@ -1182,11 +1188,11 @@ function testset_forloop(args, testloop,
             err isa InterruptException && rethrow()
             # Something in the test block threw an error. Count that as an
             # error in this test set
-            record(ts, Error(:nontest_error, :(), err, Base.catch_stack(), $(QuoteNode(source))))
+            record(ts, Error(:nontest_error, Expr(:tuple), err, Base.catch_stack(), $(QuoteNode(source))))
         end
     end
     quote
-        arr = Vector{Any}()
+        local arr = Vector{Any}()
         local first_iteration = true
         local ts
         local RNG = default_rng()
diff -pruN 1.3.1+dfsg-1/stdlib/Test/test/runtests.jl 1.4.0+dfsg-1/stdlib/Test/test/runtests.jl
--- 1.3.1+dfsg-1/stdlib/Test/test/runtests.jl	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/stdlib/Test/test/runtests.jl	2020-03-21 16:36:32.000000000 +0000
@@ -183,18 +183,18 @@ let fails = @testset NoThrowTestSet begi
     end
 
     let str = sprint(show, fails[11])
-        @test occursin("Expression: isapprox(1 / 2, 2 / 1, atol=1 / 1)", str)
-        @test occursin("Evaluated: isapprox(0.5, 2.0; atol=1.0)", str)
+        @test occursin("Expression: isapprox(1 / 2, 2 / 1, atol = 1 / 1)", str)
+        @test occursin("Evaluated: isapprox(0.5, 2.0; atol = 1.0)", str)
     end
 
     let str = sprint(show, fails[12])
-        @test occursin("Expression: isapprox(1 - 2, 2 - 1; atol=1 - 1)", str)
-        @test occursin("Evaluated: isapprox(-1, 1; atol=0)", str)
+        @test occursin("Expression: isapprox(1 - 2, 2 - 1; atol = 1 - 1)", str)
+        @test occursin("Evaluated: isapprox(-1, 1; atol = 0)", str)
     end
 
     let str = sprint(show, fails[13])
         @test occursin("Expression: isapprox(1, 2; k...)", str)
-        @test occursin("Evaluated: isapprox(1, 2; atol=0, nans=true)", str)
+        @test occursin("Evaluated: isapprox(1, 2; atol = 0, nans = true)", str)
     end
 
     let str = sprint(show, fails[14])
@@ -607,8 +607,6 @@ end
     end
     """)
     local msg = read(pipeline(ignorestatus(`$(Base.julia_cmd()) --startup-file=no --color=no $f`), stderr=devnull), String)
-    # NOTE: This test depends on the code generated by @testset getting compiled,
-    # to get good backtraces. If it fails, check the implementation of `testset_beginend`.
     @test !occursin("do_test(", msg)
     @test !occursin("include(", msg)
     @test occursin("at " * f * ":3", msg)
diff -pruN 1.3.1+dfsg-1/stdlib/UUIDs/src/UUIDs.jl 1.4.0+dfsg-1/stdlib/UUIDs/src/UUIDs.jl
--- 1.3.1+dfsg-1/stdlib/UUIDs/src/UUIDs.jl	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/stdlib/UUIDs/src/UUIDs.jl	2020-03-21 16:36:32.000000000 +0000
@@ -1,5 +1,9 @@
 # This file is a part of Julia. License is MIT: https://julialang.org/license
 
+"""
+This module provides universally unique identifiers (UUIDs),
+along with functions creating the different variants.
+"""
 module UUIDs
 
 using Random
diff -pruN 1.3.1+dfsg-1/sysimage.mk 1.4.0+dfsg-1/sysimage.mk
--- 1.3.1+dfsg-1/sysimage.mk	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/sysimage.mk	2020-03-21 16:36:32.000000000 +0000
@@ -6,6 +6,7 @@ include $(JULIAHOME)/Make.inc
 default: sysimg-$(JULIA_BUILD_MODE) # contains either "debug" or "release"
 all: sysimg-release sysimg-debug
 sysimg-ji: $(build_private_libdir)/sys.ji
+sysimg-bc: $(build_private_libdir)/sys-bc.a
 sysimg-release: $(build_private_libdir)/sys.$(SHLIB_EXT)
 sysimg-debug: $(build_private_libdir)/sys-debug.$(SHLIB_EXT)
 
@@ -64,7 +65,7 @@ $(build_private_libdir)/corecompiler.ji:
 
 $(build_private_libdir)/sys.ji: $(build_private_libdir)/corecompiler.ji $(JULIAHOME)/VERSION $(BASE_SRCS) $(STDLIB_SRCS)
 	@$(call PRINT_JULIA, cd $(JULIAHOME)/base && \
-	if ! $(call spawn,JULIA_BINDIR=$(call cygpath_w,$(build_bindir)) $(JULIA_EXECUTABLE)) -g1 -O0 -C "$(JULIA_CPU_TARGET)" --output-ji $(call cygpath_w,$@).tmp $(JULIA_SYSIMG_BUILD_FLAGS) \
+	if ! JULIA_BINDIR=$(call cygpath_w,$(build_bindir)) $(call spawn, $(JULIA_EXECUTABLE)) -g1 -O0 -C "$(JULIA_CPU_TARGET)" --output-ji $(call cygpath_w,$@).tmp $(JULIA_SYSIMG_BUILD_FLAGS) \
 			--startup-file=no --warn-overwrite=yes --sysimage $(call cygpath_w,$<) sysimg.jl $(RELBUILDROOT); then \
 		echo '*** This error might be fixed by running `make clean`. If the error persists$(COMMA) try `make cleanall`. ***'; \
 		false; \
@@ -74,7 +75,7 @@ $(build_private_libdir)/sys.ji: $(build_
 define sysimg_builder
 $$(build_private_libdir)/sys$1-o.a $$(build_private_libdir)/sys$1-bc.a : $$(build_private_libdir)/sys$1-%.a : $$(build_private_libdir)/sys.ji
 	@$$(call PRINT_JULIA, cd $$(JULIAHOME)/base && \
-	if ! $$(call spawn,JULIA_BINDIR=$(call cygpath_w,$(build_bindir)) $3) $2 -C "$$(JULIA_CPU_TARGET)" --output-$$* $$(call cygpath_w,$$@).tmp $$(JULIA_SYSIMG_BUILD_FLAGS) \
+	if ! JULIA_BINDIR=$$(call cygpath_w,$(build_bindir)) $$(call spawn, $3) $2 -C "$$(JULIA_CPU_TARGET)" --output-$$* $$(call cygpath_w,$$@).tmp $$(JULIA_SYSIMG_BUILD_FLAGS) \
 		--startup-file=no --warn-overwrite=yes --sysimage $$(call cygpath_w,$$<) $$(call cygpath_w,$$(JULIAHOME)/contrib/generate_precompile.jl) $(JULIA_PRECOMPILE); then \
 		echo '*** This error is usually fixed by running `make clean`. If the error persists$$(COMMA) try `make cleanall`. ***'; \
 		false; \
diff -pruN 1.3.1+dfsg-1/test/abstractarray.jl 1.4.0+dfsg-1/test/abstractarray.jl
--- 1.3.1+dfsg-1/test/abstractarray.jl	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/test/abstractarray.jl	2020-03-21 16:36:32.000000000 +0000
@@ -484,7 +484,7 @@ function test_primitives(::Type{T}, shap
     @test lastindex(B, 2) == lastindex(A, 2) == last(axes(B, 2))
 
     # first(a)
-    @test first(B) == B[firstindex(B)] == B[1] == A[1] # TODO: use B[begin] once parser transforms it
+    @test first(B) == B[firstindex(B)] == B[begin] == B[1] == A[1] == A[begin]
     @test firstindex(B) == firstindex(A) == first(LinearIndices(B))
     @test firstindex(B, 1) == firstindex(A, 1) == first(axes(B, 1))
     @test firstindex(B, 2) == firstindex(A, 2) == first(axes(B, 2))
@@ -995,3 +995,7 @@ end
         @test getindex(x) == getindex(x, CartesianIndex()) == 10
     end
 end
+
+@testset "vcat with mixed elements" begin
+    @test vcat(Nothing[], [missing], [1.0], [Int8(1)]) isa Vector{Union{Missing, Nothing, Float64}}
+end
diff -pruN 1.3.1+dfsg-1/test/ambiguous.jl 1.4.0+dfsg-1/test/ambiguous.jl
--- 1.3.1+dfsg-1/test/ambiguous.jl	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/test/ambiguous.jl	2020-03-21 16:36:32.000000000 +0000
@@ -67,6 +67,19 @@ let err = try
     @test lines[6] == "  ambig(::Integer, ::Integer)"
 end
 
+ambig_with_bounds(x, ::Int, ::T) where {T<:Integer,S} = 0
+ambig_with_bounds(::Int, x, ::T) where {T<:Integer,S} = 1
+let err = try
+              ambig_with_bounds(1, 2, 3)
+          catch _e_
+              _e_
+          end
+    io = IOBuffer()
+    Base.showerror(io, err)
+    lines = split(String(take!(io)), '\n')
+    @test lines[end] == "  ambig_with_bounds(::$Int, ::$Int, ::T) where T<:Integer"
+end
+
 ## Other ways of accessing functions
 # Test that non-ambiguous cases work
 let io = IOBuffer()
@@ -157,6 +170,16 @@ ambs = detect_ambiguities(Ambig5)
 # some ambiguities involving Union{} type parameters are expected, but not required
 @test !isempty(detect_ambiguities(Core, Base; imported=true, ambiguous_bottom=true))
 
+module AmbigStdlib
+using Test
+
+# List standard libraries.  Exclude modules such as Main.
+modules = [mod for (pkg, mod) in Base.loaded_modules if pkg.uuid !== nothing]
+
+# not using isempty so this prints more information when it fails
+@test detect_ambiguities(modules...; imported=true, recursive=true) == []
+end  # module
+
 amb_1(::Int8, ::Int) = 1
 amb_1(::Integer, x) = 2
 amb_1(x, ::Int) = 3
diff -pruN 1.3.1+dfsg-1/test/atexit.jl 1.4.0+dfsg-1/test/atexit.jl
--- 1.3.1+dfsg-1/test/atexit.jl	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/test/atexit.jl	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1,154 @@
+# This file is a part of Julia. License is MIT: https://julialang.org/license
+
+using Test
+
+@testset "atexit.jl" begin
+    function _atexit_tests_gen_cmd_eval(expr::String)
+        cmd_eval = ```
+        $(Base.julia_cmd()) -e $(expr)
+        ```
+        return cmd_eval
+    end
+    function _atexit_tests_gen_cmd_script(temp_dir::String, expr::String)
+        script, io = mktemp(temp_dir)
+        println(io, expr)
+        close(io)
+        cmd_script = ```
+        $(Base.julia_cmd()) $(script)
+        ```
+        return cmd_script
+    end
+    atexit_temp_dir = mktempdir()
+    atexit(() -> rm(atexit_temp_dir; force = true, recursive = true))
+    @testset "these should exit with exit code 0" begin
+        julia_expr_list = Dict(
+            # ++++++++++++++++++++++++++++++++++++++++++++++++++++++++
+            """
+            atexit(() -> exit(0))
+            exit(22)
+            """ => 0,
+            # ++++++++++++++++++++++++++++++++++++++++++++++++++++++++
+            )
+        for julia_expr in keys(julia_expr_list)
+            cmd_eval = _atexit_tests_gen_cmd_eval(julia_expr)
+            cmd_script = _atexit_tests_gen_cmd_script(atexit_temp_dir, julia_expr)
+            expected_exit_code = julia_expr_list[julia_expr]
+            @test success(cmd_eval)
+            @test success(cmd_script)
+            p_eval = run(cmd_eval; wait = false)
+            p_script = run(cmd_script; wait = false)
+            wait(p_eval)
+            wait(p_script)
+            @test p_eval.exitcode == expected_exit_code
+            @test p_script.exitcode == expected_exit_code
+        end
+    end
+    @testset "these should exit with exit code 1" begin
+        julia_expr_list = Dict(
+            # ++++++++++++++++++++++++++++++++++++++++++++++++++++++++
+            """
+            atexit(() -> exit(1))
+            exit(22)
+            """ => 1,
+            # ++++++++++++++++++++++++++++++++++++++++++++++++++++++++
+            """
+            atexit(() -> ("No error"))
+            atexit(() -> exit(1))
+            exit(22)
+            """ => 1,
+            # ++++++++++++++++++++++++++++++++++++++++++++++++++++++++
+            """
+            atexit(() -> exit(1))
+            atexit(() -> exit(1))
+            exit(22)
+            """ => 1,
+            # ++++++++++++++++++++++++++++++++++++++++++++++++++++++++
+            )
+        for julia_expr in keys(julia_expr_list)
+            cmd_eval = _atexit_tests_gen_cmd_eval(julia_expr)
+            cmd_script = _atexit_tests_gen_cmd_script(atexit_temp_dir, julia_expr)
+            expected_exit_code = julia_expr_list[julia_expr]
+            @test_throws ProcessFailedException run(cmd_eval)
+            @test_throws ProcessFailedException run(cmd_script)
+            p_eval = run(cmd_eval; wait = false)
+            p_script = run(cmd_script; wait = false)
+            wait(p_eval)
+            wait(p_script)
+            @test p_eval.exitcode == expected_exit_code
+            @test p_script.exitcode == expected_exit_code
+        end
+    end
+    @testset "test exit codes other than 0 or 1" begin
+        julia_expr_list = Dict(
+            # ++++++++++++++++++++++++++++++++++++++++++++++++++++++++
+            """
+            atexit(() -> exit(13))
+            exit(22)
+            """ => 13,
+            # ++++++++++++++++++++++++++++++++++++++++++++++++++++++++
+            """
+            atexit(() -> ("No error"))
+            atexit(() -> exit(5))
+            exit(22)
+            """ => 5,
+            # ++++++++++++++++++++++++++++++++++++++++++++++++++++++++
+            """
+            atexit(() -> exit(33))
+            atexit(() -> exit(33))
+            exit(22)
+            """ => 33,
+            # ++++++++++++++++++++++++++++++++++++++++++++++++++++++++
+            """
+            atexit(() -> exit(21))
+            atexit(() -> exit(21))
+            exit(22)
+            """ => 21,
+            # ++++++++++++++++++++++++++++++++++++++++++++++++++++++++
+            )
+        for julia_expr in keys(julia_expr_list)
+            cmd_eval = _atexit_tests_gen_cmd_eval(julia_expr)
+            cmd_script = _atexit_tests_gen_cmd_script(atexit_temp_dir, julia_expr)
+            expected_exit_code = julia_expr_list[julia_expr]
+            @test_throws(ProcessFailedException, run(cmd_eval))
+            @test_throws(ProcessFailedException, run(cmd_script))
+            p_eval = run(cmd_eval; wait = false)
+            p_script = run(cmd_script; wait = false)
+            wait(p_eval)
+            wait(p_script)
+            @test p_eval.exitcode == expected_exit_code
+            @test p_script.exitcode == expected_exit_code
+        end
+    end
+    @testset "test what happens if multiple places call exit(n)" begin
+        julia_expr_list = Dict(
+            # ++++++++++++++++++++++++++++++++++++++++++++++++++++++++
+            """
+            atexit(() -> exit(22))
+            atexit(() -> exit(11))
+            atexit(() -> exit(33))
+            """ => 22,
+            # ++++++++++++++++++++++++++++++++++++++++++++++++++++++++
+            """
+            atexit(() -> exit(4))
+            atexit(() -> exit(16))
+            atexit(() -> exit(7))
+            exit(22)
+            """ => 4,
+            # ++++++++++++++++++++++++++++++++++++++++++++++++++++++++
+            )
+        for julia_expr in keys(julia_expr_list)
+            cmd_eval = _atexit_tests_gen_cmd_eval(julia_expr)
+            cmd_script = _atexit_tests_gen_cmd_script(atexit_temp_dir, julia_expr)
+            expected_exit_code = julia_expr_list[julia_expr]
+            @test_throws(ProcessFailedException, run(cmd_eval))
+            @test_throws(ProcessFailedException, run(cmd_script))
+            p_eval = run(cmd_eval; wait = false)
+            p_script = run(cmd_script; wait = false)
+            wait(p_eval)
+            wait(p_script)
+            @test p_eval.exitcode == expected_exit_code
+            @test p_script.exitcode == expected_exit_code
+        end
+    end
+    rm(atexit_temp_dir; force = true, recursive = true)
+end
diff -pruN 1.3.1+dfsg-1/test/backtrace.jl 1.4.0+dfsg-1/test/backtrace.jl
--- 1.3.1+dfsg-1/test/backtrace.jl	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/test/backtrace.jl	2020-03-21 16:36:32.000000000 +0000
@@ -1,14 +1,18 @@
 # This file is a part of Julia. License is MIT: https://julialang.org/license
 
+import Base.StackTraces: lookup
+
 # Test location information for inlined code (ref issues #1334 #12544)
 module test_inline_bt
 using Test
+import ..lookup
 
 function get_bt_frames(functionname, bt)
     for i = 1:length(bt)
-        lkup = Base.StackTraces.lookup(bt[i])
-        lkup[end].func == functionname && (return lkup)
+        lkup = lookup(bt[i])
+        lkup[end].func == functionname && return lkup
     end
+    return StackTraces.StackFrame[]
 end
 
 # same-file inline
@@ -91,14 +95,14 @@ let
 end
 
 module BackTraceTesting
-
 using Test
+import ..lookup
 
 @inline bt2() = backtrace()
 @inline bt1() = bt2()
 bt() = bt1()
 
-lkup = map(StackTraces.lookup, bt())
+lkup = map(lookup, bt())
 hasbt = hasbt2 = false
 for sfs in lkup
     for sf in sfs
@@ -117,7 +121,7 @@ function btmacro()
     ret = @timed backtrace()
     ret[1]
 end
-lkup = map(StackTraces.lookup, btmacro())
+lkup = map(lookup, btmacro())
 hasme = hasbtmacro = false
 for sfs in lkup
     for sf in sfs
@@ -142,7 +146,7 @@ bt = eval(quote
         catch_backtrace()
     end
 end)
-lkup = map(StackTraces.lookup, bt)
+lkup = map(lookup, bt)
 hastoplevel = false
 for sfs in lkup
     for sf in sfs
@@ -170,7 +174,7 @@ let bt, found = false
     @testset begin
         bt = backtrace()
     end
-    for frame in map(StackTraces.lookup, bt)
+    for frame in map(lookup, bt)
         if frame[1].line == @__LINE__() - 3 && frame[1].file == Symbol(@__FILE__)
             found = true; break
         end
@@ -182,7 +186,7 @@ end
 let bt, found = false
     @info ""
     bt = backtrace()
-    for frame in map(StackTraces.lookup, bt)
+    for frame in map(lookup, bt)
         if frame[1].line == @__LINE__() - 2 && frame[1].file == Symbol(@__FILE__)
             found = true; break
         end
@@ -220,3 +224,37 @@ let trace = try
     @test trace[1].line == 2
 end
 
+# issue #29695 (see also test for #28442)
+let code = """
+    f29695(c) = g29695(c)
+    g29695(c) = c >= 1000 ? (return backtrace()) : f29695(c + 1)
+    bt = f29695(1)
+    meth_names = [ip.code.def.name for ip in bt
+                  if ip isa Base.InterpreterIP && ip.code isa Core.MethodInstance]
+    num_fs = sum(meth_names .== :f29695)
+    num_gs = sum(meth_names .== :g29695)
+    print(num_fs, ' ', num_gs)
+    """
+
+    @test read(`$(Base.julia_cmd()) --startup-file=no --compile=min -e $code`, String) == "1000 1000"
+end
+
+# Test that modules make it into InterpreterIP for top-level code
+let code = """
+    module A
+    foo() = error("Expected")
+    try
+        foo()
+    catch
+        global bt = catch_backtrace()
+    end
+    end
+
+    foreach(println, A.bt)
+    """
+
+    bt_str = read(`$(Base.julia_cmd()) --startup-file=no --compile=min -e $code`, String)
+    @test occursin("InterpreterIP in MethodInstance for foo", bt_str)
+    @test occursin("InterpreterIP in top-level CodeInfo for Main.A", bt_str)
+end
+
diff -pruN 1.3.1+dfsg-1/test/bigint.jl 1.4.0+dfsg-1/test/bigint.jl
--- 1.3.1+dfsg-1/test/bigint.jl	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/test/bigint.jl	1970-01-01 00:00:00.000000000 +0000
@@ -1,472 +0,0 @@
-# This file is a part of Julia. License is MIT: https://julialang.org/license
-
-using Random, Serialization
-
-a = parse(BigInt,"123456789012345678901234567890")
-b = parse(BigInt,"123456789012345678901234567891")
-c = parse(BigInt,"246913578024691357802469135780")
-d = parse(BigInt,"-246913578024691357802469135780")
-ee = typemax(Int64)
-@testset "basics" begin
-    @test BigInt <: Signed
-    @test big(1) isa Signed
-
-    let x = big(1)
-        @test signed(x) === x
-        @test convert(Signed, x) === x
-        @test Signed(x) === x
-        @test_throws MethodError convert(Unsigned, x) # could change in the future
-    end
-    @test a+BigInt(1) == b
-    @test typeof(a+1) == BigInt
-    @test a+1 == b
-    @test isequal(a+1, b)
-    @test b == a+1
-    @test !(b == a)
-    @test b > a
-    @test b >= a
-    @test !(b < a)
-    @test !(b <= a)
-
-    @test typeof(a * 2) == BigInt
-    @test a*2 == c
-    @test c-a == a
-    @test c == a + a
-    @test c+1 == a+b
-
-
-    @test typeof(d) == BigInt
-    @test d == -c
-
-    @test typeof(BigInt(ee)) == BigInt
-    @test BigInt(ee)+1 == parse(BigInt,"9223372036854775808")
-    @testset "printing" begin
-        #Multiple calls for sanity check, since we're doing direct memory manipulation
-        @test string(a) == "123456789012345678901234567890"
-        @test string(b) == "123456789012345678901234567891"
-        @test string(c) == "246913578024691357802469135780"
-        @test string(d) == "-246913578024691357802469135780"
-        @test string(a) == "123456789012345678901234567890"
-    end
-    @testset "constructors" begin
-        @test typeof(BigInt(typemax(Int8))) == BigInt
-        @test typeof(BigInt(typemax(Int16))) == BigInt
-        @test typeof(BigInt(typemax(Int32))) == BigInt
-        @test typeof(BigInt(typemax(Int64))) == BigInt
-        @test typeof(BigInt(typemax(Int128))) == BigInt
-
-        @test typeof(BigInt(true)) == BigInt
-        @test typeof(BigInt(typemax(UInt8))) == BigInt
-        @test typeof(BigInt(typemax(UInt16))) == BigInt
-        @test typeof(BigInt(typemax(UInt32))) == BigInt
-        @test typeof(BigInt(typemax(UInt64))) == BigInt
-        @test typeof(BigInt(typemax(UInt128))) == BigInt
-
-        @test typeof(BigInt(BigInt(1))) == BigInt
-
-        for x in (Int16(0), 1, 3//4, big(5//6), big(9))
-            @test big(typeof(x)) == typeof(big(x))
-            @test big(typeof(complex(x, x))) == typeof(big(complex(x, x)))
-        end
-    end
-end
-@testset "div, fld, mod, rem" begin
-    for i = -10:10, j = [-10:-1; 1:10]
-        @test div(BigInt(i), BigInt(j)) == div(i,j)
-        @test fld(BigInt(i), BigInt(j)) == fld(i,j)
-        @test mod(BigInt(i), BigInt(j)) == mod(i,j)
-        @test rem(BigInt(i), BigInt(j)) == rem(i,j)
-    end
-end
-
-@testset "Signed addition" begin
-    @test a+Int8(1) == b
-    @test a+Int16(1) == b
-    @test a+Int32(1) == b
-    @test a+Int64(1) == b
-    @test a+Int128(1) == b
-    @test Int8(1)+ a == b
-    @test Int16(1)+a == b
-    @test Int32(1)+a == b
-    @test Int64(1)+a == b
-    @test b+Int8(-1) == a
-    @test b+Int16(-1) == a
-    @test b+Int32(-1) == a
-    @test b+Int64(-1) == a
-    @test Int8(-1)+ b == a
-    @test Int16(-1)+b == a
-    @test Int32(-1)+b == a
-    @test Int64(-1)+b == a
-end
-@testset "Unsigned addition" begin
-    @test a+true == b
-    @test a+UInt8(1) == b
-    @test a+UInt16(1) == b
-    @test a+UInt32(1) == b
-    @test a+UInt64(1) == b
-    @test a+UInt128(1) == b
-    @test true+a == b
-    @test UInt8(1)+ a == b
-    @test UInt16(1)+a == b
-    @test UInt32(1)+a == b
-    @test UInt64(1)+a == b
-end
-@testset "Signed subtraction" begin
-    @test b-Int8(1) == a
-    @test b-Int16(1) == a
-    @test b-Int32(1) == a
-    @test b-Int64(1) == a
-    @test Int8(1)- b == -a
-    @test Int16(1)-b == -a
-    @test Int32(1)-b == -a
-    @test Int64(1)-b == -a
-    @test a-Int8(-1) == b
-    @test a-Int16(-1) == b
-    @test a-Int32(-1) == b
-    @test a-Int64(-1) == b
-    @test Int8(-1)- a == -b
-    @test Int16(-1)-a == -b
-    @test Int32(-1)-a == -b
-    @test Int64(-1)-a == -b
-end
-@testset "Unsigned subtraction" begin
-    @test b-true == a
-    @test b-UInt8(1) == a
-    @test b-UInt16(1) == a
-    @test b-UInt32(1) == a
-    @test b-UInt64(1) == a
-    @test true-b == -a
-    @test UInt8(1)- b == -a
-    @test UInt16(1)-b == -a
-    @test UInt32(1)-b == -a
-    @test UInt64(1)-b == -a
-end
-@testset "Signed multiplication" begin
-    @test a*Int8(1) == a
-    @test a*Int16(1) == a
-    @test a*Int32(1) == a
-    @test a*Int64(1) == a
-    @test Int8(1)* a == a
-    @test Int16(1)*a == a
-    @test Int32(1)*a == a
-    @test Int64(1)*a == a
-    @test a*Int8(-1) == -a
-    @test a*Int16(-1) == -a
-    @test a*Int32(-1) == -a
-    @test a*Int64(-1) == -a
-    @test Int8(-1)* a == -a
-    @test Int16(-1)*a == -a
-    @test Int32(-1)*a == -a
-    @test Int64(-1)*a == -a
-end
-@testset "Unsigned multiplication" begin
-    @test a*true == a
-    @test a*UInt8(1) == a
-    @test a*UInt16(1) == a
-    @test a*UInt32(1) == a
-    @test a*UInt64(1) == a
-    @test true*a == a
-    @test UInt8(1)* a == a
-    @test UInt16(1)*a == a
-    @test UInt32(1)*a == a
-    @test UInt64(1)*a == a
-end
-
-@testset "bitshifts" begin
-    @test BigInt(5) << 3 == 40
-    @test BigInt(5) >> 1 == 2
-    @test BigInt(-5) << 3 == -40
-    @test BigInt(-5) >> 1 == -3
-    @test BigInt(5) >> -3 == 40
-    @test BigInt(5) << -1 == 2
-    @test BigInt(-5) >> -3 == -40
-    @test BigInt(-5) << -1 == -3
-end
-@testset "boolean ops" begin
-    @test ~BigInt(123) == -124
-    @test BigInt(123) & BigInt(234) == 106
-    @test BigInt(123) | BigInt(234) == 251
-    @test BigInt(123) ⊻ BigInt(234) == 145
-
-    @test gcd(BigInt(48), BigInt(180)) == 12
-    @test lcm(BigInt(48), BigInt(180)) == 720
-end
-@testset "combinatorics" begin
-    @test factorial(BigInt(40)) == parse(BigInt,"815915283247897734345611269596115894272000000000")
-    @test binomial(BigInt(1), -1) == BigInt(0)
-    @test binomial(BigInt(1), 2)  == BigInt(0)
-    @test binomial(BigInt(-53), 42) == parse(BigInt,"959509335087854414441273718")
-    @test binomial(BigInt(113), BigInt(42)) == parse(BigInt,"18672199984318438125634054194360")
-end
-let a, b
-    a = rand(1:100, 10000)
-    b = map(BigInt, a)
-    @test sum(a) == sum(b)
-end
-
-@testset "Iterated arithmetic" begin
-    local a, b, c, d, f, g
-    a = parse(BigInt,"315135")
-    b = parse(BigInt,"12412")
-    c = parse(BigInt,"3426495623485904783478347")
-    d = parse(BigInt,"-1398984130")
-    f = parse(BigInt,"2413804710837418037418307081437315263635345357386985747464")
-    g = parse(BigInt,"-1")
-
-    @test +(a, b) == parse(BigInt,"327547")
-    @test +(a, b, c) == parse(BigInt,"3426495623485904783805894")
-    @test +(a, b, c, d) == parse(BigInt,"3426495623485903384821764")
-    @test +(a, b, c, d, f) == parse(BigInt,"2413804710837418037418307081437318690130968843290370569228")
-    @test +(a, b, c, d, f, g) == parse(BigInt,"2413804710837418037418307081437318690130968843290370569227")
-
-    @test *(a, b) == parse(BigInt,"3911455620")
-    @test *(a, b, c) == parse(BigInt,"13402585563389346256121263521460140")
-    @test *(a, b, c, d) == parse(BigInt,"-18750004504148804423388563022070650287578200")
-    @test *(a, b, c, d, f) == parse(BigInt,"-45258849200337190631492857400003938881995610529251881450243326128168934937055005474972396281351684800")
-    @test *(a, b, c, d, f, g) == parse(BigInt,"45258849200337190631492857400003938881995610529251881450243326128168934937055005474972396281351684800")
-
-    @test xor(a, b) == parse(BigInt,"327299")
-    @test xor(a, b, c) == parse(BigInt,"3426495623485904783798472")
-    @test xor(a, b, c, d) == parse(BigInt,"-3426495623485906178489610")
-    @test xor(a, b, c, d, f) == parse(BigInt,"-2413804710837418037418307081437316711364709261074607933698")
-    @test xor(a, b, c, d, f, g) == parse(BigInt,"2413804710837418037418307081437316711364709261074607933697")
-
-    @test (&)(a, b) == parse(BigInt,"124")
-    @test (&)(a, b, c) == parse(BigInt,"72")
-    @test (&)(a, b, c, d) == parse(BigInt,"8")
-    @test (&)(a, b, c, d, f) == parse(BigInt,"8")
-    @test (&)(a, b, c, d, f, g) == parse(BigInt,"8")
-
-    @test (|)(a, b) == parse(BigInt,"327423")
-    @test (|)(a, b, c) == parse(BigInt,"3426495623485904783802111")
-    @test (|)(a, b, c, d) == parse(BigInt,"-1396834561")
-    @test (|)(a, b, c, d, f) == parse(BigInt,"-1358954753")
-    @test (|)(a, b, c, d, f, g) == parse(BigInt,"-1")
-
-    @test trailing_ones(a) == 8
-    @test trailing_zeros(b) == 2
-    @test count_ones(a) == 14
-end
-
-# Large Fibonacci to exercise BigInt
-# from Bill Hart, https://groups.google.com/group/julia-dev/browse_frm/thread/798e2d1322daf633
-function mul(a::Vector{BigInt}, b::Vector{BigInt})
-   x = a[2]*b[2]
-   c = Vector{BigInt}(undef, 3)
-   c[1] = a[1]*b[1] + x
-   c[2] = a[1]*b[2] + a[2]*b[3]
-   c[3] = x + a[3]*b[3]
-   return c
-end
-
-function bigfib(n)
-    n == 0 && return BigInt(0)
-    n -= 1
-    r = [BigInt(1), BigInt(1), BigInt(0)]
-    s = [BigInt(1), BigInt(0), BigInt(1)]
-    while true
-       (n & 1) == 1 && (s = mul(s,r))
-       (n >>= 1) == 0 && return s[1]
-       r = mul(r,r)
-    end
-end
-@test [bigfib(n) for n=0:10] == [0,1,1,2,3,5,8,13,21,34,55]
-
-let s, n = bigfib(1000001)
-    @test ndigits(n) == 208988
-    @test mod(n,big(10)^15) == 359244926937501
-    @test div(n,big(10)^208973) == 316047687386689
-
-    s = string(n)
-    @test length(s) == 208988
-    @test endswith(s, "359244926937501")
-    @test startswith(s, "316047687386689")
-end
-
-# serialization (#5133)
-let n = parse(BigInt, "359334085968622831041960188598043661065388726959079837"),
-    b = IOBuffer()
-    serialize(b, n)
-    seek(b, 0)
-    @test deserialize(b) == n
-end
-
-@testset "issue #5873" begin
-    @test ndigits(big(90)) == 2
-    @test ndigits(big(99)) == 2
-    ndigits_mismatch(n) = ndigits(n) != ndigits(BigInt(n))
-    @test !any(ndigits_mismatch, 8:9)
-    @test !any(ndigits_mismatch, 64:99)
-    @test !any(ndigits_mismatch, 512:999)
-    @test !any(ndigits_mismatch, 8192:9999)
-end
-# The following should not crash (#16579)
-ndigits(big(rand(Int)), base=rand(63:typemax(Int)))
-ndigits(big(rand(Int)), base=big(2)^rand(2:999))
-
-for x in big.([-20:20; rand(Int)])
-    for _base in -1:1
-        @test_throws DomainError ndigits(x, base=_base)
-    end
-end
-
-@test Base.ndigits0zpb(big(0), big(rand(2:100))) == 0
-
-# digits with BigInt bases (#16844)
-@test digits(big(2)^256, base = big(2)^128) == [0, 0, 1]
-
-@testset "conversion from float" begin
-    @test BigInt(2.0) == BigInt(2.0f0) == BigInt(big(2.0)) == 2
-    @test_throws InexactError convert(BigInt, 2.1)
-    @test_throws InexactError convert(BigInt, big(2.1))
-end
-@testset "issue #13367" begin
-    @test trunc(BigInt,2.1) == 2
-    @test round(BigInt,2.1) == 2
-    @test floor(BigInt,2.1) == 2
-    @test ceil(BigInt,2.1) == 3
-
-    @test trunc(BigInt,2.1f0) == 2
-    @test round(BigInt,2.1f0) == 2
-    @test floor(BigInt,2.1f0) == 2
-    @test ceil(BigInt,2.1f0) == 3
-
-    @test_throws InexactError trunc(BigInt,Inf)
-    @test_throws InexactError round(BigInt,Inf)
-    @test_throws InexactError floor(BigInt,Inf)
-    @test_throws InexactError ceil(BigInt,Inf)
-
-    @test string(big(3), base = 2) == "11"
-    @test string(big(9), base = 8) == "11"
-    @test string(-big(9), base = 8) == "-11"
-    @test string(big(12), base = 16) == "c"
-end
-@testset "Issue #18849" begin
-    # bin, oct, dec, hex should not call sizeof on BigInts
-    # when padding is desired
-    padding = 4
-    low = big(4)
-    high = big(2^20)
-    @test string(low, pad = padding, base = 2) == "0100"
-    @test string(low, pad = padding, base = 8) == "0004"
-    @test string(low, pad = padding, base = 10) == "0004"
-    @test string(low, pad = padding, base = 16) == "0004"
-
-    @test string(high, pad = padding, base = 2) == "100000000000000000000"
-    @test string(high, pad = padding, base = 8) == "4000000"
-    @test string(high, pad = padding, base = 10) == "1048576"
-    @test string(high, pad = padding, base = 16) == "100000"
-
-    @test string(-low, pad = padding, base = 2) == "-0100" # handle negative numbers correctly
-    @test string(-low, pad = padding, base = 8) == "-0004"
-    @test string(-low, pad = padding, base = 10) == "-0004"
-    @test string(-low, pad = padding, base = 16) == "-0004"
-
-    @test string(-high, pad = padding, base = 2) == "-100000000000000000000"
-    @test string(-high, pad = padding, base = 8) == "-4000000"
-    @test string(-high, pad = padding, base = 10) == "-1048576"
-    @test string(-high, pad = padding, base = 16) == "-100000"
-end
-
-# respect 0-padding on big(0)
-for base in (2, 8, 10, 16)
-    local base
-    @test string(big(0), base=base, pad=0) == ""
-end
-@test string(big(0), base = rand(2:62), pad = 0) == ""
-
-@test isqrt(big(4)) == 2
-@test isqrt(big(5)) == 2
-
-@test big(5)^true == big(5)
-@test big(5)^false == one(BigInt)
-
-@testset "math ops returning BigFloat" begin
-    # operations that when applied to Int64 give Float64, should give BigFloat
-    @test typeof(exp(a)) == BigFloat
-    @test typeof(exp2(a)) == BigFloat
-    @test typeof(exp10(a)) == BigFloat
-    @test typeof(expm1(a)) == BigFloat
-    @test typeof(cosh(a)) == BigFloat
-    @test typeof(sinh(a)) == BigFloat
-    @test typeof(tanh(a)) == BigFloat
-    @test typeof(sech(a)) == BigFloat
-    @test typeof(csch(a)) == BigFloat
-    @test typeof(coth(a)) == BigFloat
-    @test typeof(cbrt(a)) == BigFloat
-    @test typeof(tan(a)) == BigFloat
-    @test typeof(cos(a)) == BigFloat
-    @test typeof(sin(a)) == BigFloat
-end
-
-# Issue #24298
-@test mod(BigInt(6), UInt(5)) == mod(6, 5)
-
-@testset "cmp has values in [-1, 0, 1], issue #28780" begin
-    # _rand produces values whose log2 is better distributed than rand
-    _rand(::Type{BigInt}, n=1000) = let x = big(2)^rand(1:rand(1:n))
-        rand(-x:x)
-    end
-    _rand(F::Type{<:AbstractFloat}) = F(_rand(BigInt, round(Int, log2(floatmax(F))))) + rand(F)
-    _rand(T) = rand(T)
-    for T in (Base.BitInteger_types..., BigInt, Float64, Float32, Float16)
-        @test cmp(big(2)^130, one(T)) === 1
-        @test cmp(-big(2)^130, one(T)) === -1
-        c = cmp(_rand(BigInt), _rand(T))
-        @test c ∈ (-1, 0, 1)
-        @test c isa Int
-        (T <: Integer && T !== BigInt) || continue
-        x = rand(T)
-        @test cmp(big(2)^130, x) === cmp(x, -big(2)^130) === 1
-        @test cmp(-big(2)^130, x) === cmp(x, big(2)^130) === -1
-        @test cmp(big(x), x) === cmp(x, big(x)) === 0
-    end
-    c = cmp(_rand(BigInt), _rand(BigInt))
-    @test c ∈ (-1, 0, 1)
-    @test c isa Int
-end
-
-@testset "generic conversion from Integer" begin
-    x = rand(Int128)
-    @test BigInt(x) % Int128 === x
-    y = rand(UInt128)
-    @test BigInt(y) % UInt128 === y
-end
-
-@testset "conversion from typemin(T)" begin
-    @test big(Int8(-128)) == big"-128"
-    @test big(Int16(-32768)) == big"-32768"
-    @test big(Int32(-2147483648)) == big"-2147483648"
-    @test big(Int64(-9223372036854775808)) == big"-9223372036854775808"
-    @test big(Int128(-170141183460469231731687303715884105728)) == big"-170141183460469231731687303715884105728"
-end
-
-@testset "conversion to Float" begin
-    x = big"2"^256 + big"2"^(256-53) + 1
-    @test Float64(x) == reinterpret(Float64, 0x4ff0000000000001)
-    @test Float64(-x) == -Float64(x)
-    x = (x >> 1) + 1
-    @test Float64(x) == reinterpret(Float64, 0x4fe0000000000001)
-    @test Float64(-x) == -Float64(x)
-
-    x = big"2"^64 + big"2"^(64-24) + 1
-    @test Float32(x) == reinterpret(Float32, 0x5f800001)
-    @test Float32(-x) == -Float32(x)
-    x = (x >> 1) + 1
-    @test Float32(x) == reinterpret(Float32, 0x5f000001)
-    @test Float32(-x) == -Float32(x)
-
-    x = big"2"^15 + big"2"^(15-11) + 1
-    @test Float16(x) == reinterpret(Float16, 0x7801)
-    @test Float16(-x) == -Float16(x)
-    x = (x >> 1) + 1
-    @test Float16(x) == reinterpret(Float16, 0x7401)
-    @test Float16(-x) == -Float16(x)
-
-    for T in (Float16, Float32, Float64)
-        n = exponent(floatmax(T))
-        @test T(big"2"^(n+1)) === T(Inf)
-        @test T(big"2"^(n+1) - big"2"^(n-precision(T))) === T(Inf)
-        @test T(big"2"^(n+1) - big"2"^(n-precision(T)) - 1) === floatmax(T)
-    end
-end
diff -pruN 1.3.1+dfsg-1/test/bitarray.jl 1.4.0+dfsg-1/test/bitarray.jl
--- 1.3.1+dfsg-1/test/bitarray.jl	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/test/bitarray.jl	2020-03-21 16:36:32.000000000 +0000
@@ -200,6 +200,12 @@ timesofar("utils")
         end
     end
 
+    @testset "constructor from NTuple" begin
+        for nt in ((true, false, false), NTuple{0,Bool}(), (false,), (true,))
+            @test BitVector(nt) == BitVector(collect(nt))
+        end
+    end
+
     @testset "one" begin
         @test Array(one(BitMatrix(undef, 2,2))) == Matrix(I, 2, 2)
         @test_throws DimensionMismatch one(BitMatrix(undef, 2,3))
diff -pruN 1.3.1+dfsg-1/test/broadcast.jl 1.4.0+dfsg-1/test/broadcast.jl
--- 1.3.1+dfsg-1/test/broadcast.jl	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/test/broadcast.jl	2020-03-21 16:36:32.000000000 +0000
@@ -854,3 +854,6 @@ end
 # treat Pair as scalar:
 @test replace.(split("The quick brown fox jumps over the lazy dog"), r"[aeiou]"i => "_") ==
       ["Th_", "q__ck", "br_wn", "f_x", "j_mps", "_v_r", "th_", "l_zy", "d_g"]
+
+# 28680
+@test 1 .+ 1 .+  (1, 2) == (3, 4)
diff -pruN 1.3.1+dfsg-1/test/ccall.jl 1.4.0+dfsg-1/test/ccall.jl
--- 1.3.1+dfsg-1/test/ccall.jl	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/test/ccall.jl	2020-03-21 16:36:32.000000000 +0000
@@ -6,6 +6,9 @@ using InteractiveUtils: code_llvm
 
 import Libdl
 
+# for cfunction_closure
+include("testenv.jl")
+
 const libccalltest = "libccalltest"
 
 const verbose = false
@@ -791,6 +794,8 @@ end
 ## cfunction roundtrip
 
 verbose && Libc.flush_cstdio()
+
+if cfunction_closure
 verbose && println("Testing cfunction closures: ")
 
 # helper Type for testing that constructors work
@@ -974,6 +979,12 @@ for (t, v) in ((Complex{Int32}, :ci32),
     end
 end
 
+else
+
+@test_broken "cfunction: no support for closures on this platform"
+
+end
+
 # issue 13031
 foo13031(x) = Cint(1)
 foo13031p = @cfunction(foo13031, Cint, (Ref{Tuple{}},))
diff -pruN 1.3.1+dfsg-1/test/char.jl 1.4.0+dfsg-1/test/char.jl
--- 1.3.1+dfsg-1/test/char.jl	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/test/char.jl	2020-03-21 16:36:32.000000000 +0000
@@ -290,3 +290,12 @@ end
 @testset "broadcasting of Char" begin
     @test identity.('a') == 'a'
 end
+
+@testset "code point format of U+ syntax (PR 33291)" begin
+    @test repr("text/plain", '\n') == "'\\n': ASCII/Unicode U+000A (category Cc: Other, control)"
+    @test repr("text/plain", '/') == "'/': ASCII/Unicode U+002F (category Po: Punctuation, other)"
+    @test repr("text/plain", '\u10e') == "'Ď': Unicode U+010E (category Lu: Letter, uppercase)"
+    @test repr("text/plain", '\u3a2c') == "'㨬': Unicode U+3A2C (category Lo: Letter, other)"
+    @test repr("text/plain", '\U001f428') == "'🐨': Unicode U+1F428 (category So: Symbol, other)"
+    @test repr("text/plain", '\U010f321') == "'\\U10f321': Unicode U+10F321 (category Co: Other, private use)"
+end
diff -pruN 1.3.1+dfsg-1/test/choosetests.jl 1.4.0+dfsg-1/test/choosetests.jl
--- 1.3.1+dfsg-1/test/choosetests.jl	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/test/choosetests.jl	2020-03-21 16:36:32.000000000 +0000
@@ -40,26 +40,27 @@ function choosetests(choices = [])
         "arrayops", "tuple", "reduce", "reducedim", "abstractarray",
         "intfuncs", "simdloop", "vecelement", "rational",
         "bitarray", "copy", "math", "fastmath", "functional", "iterators",
-        "operators", "path", "ccall", "parse", "loading", "bigint",
+        "operators", "path", "ccall", "parse", "loading", "gmp",
         "sorting", "spawn", "backtrace", "exceptions",
         "file", "read", "version", "namedtuple",
         "mpfr", "broadcast", "complex",
         "floatapprox", "stdlib", "reflection", "regex", "float16",
         "combinatorics", "sysinfo", "env", "rounding", "ranges", "mod2pi",
         "euler", "show", "client",
-        "errorshow", "sets", "goto", "llvmcall", "llvmcall2", "grisu",
+        "errorshow", "sets", "goto", "llvmcall", "llvmcall2", "ryu",
         "some", "meta", "stacktraces", "docs",
         "misc", "threads", "stress",
         "enums", "cmdlineargs", "int", "interpreter",
         "checked", "bitset", "floatfuncs", "precompile",
         "boundscheck", "error", "ambiguous", "cartesian", "osutils",
         "channels", "iostream", "secretbuffer", "specificity",
-        "reinterpretarray", "syntax", "logging", "missing", "asyncmap"
+        "reinterpretarray", "syntax", "logging", "missing", "asyncmap", "atexit"
     ]
 
     tests = []
     skip_tests = []
     exit_on_error = false
+    use_revise = false
     seed = rand(RandomDevice(), UInt128)
 
     for (i, t) in enumerate(choices)
@@ -68,6 +69,8 @@ function choosetests(choices = [])
             break
         elseif t == "--exit-on-error"
             exit_on_error = true
+        elseif t == "--revise"
+            use_revise = true
         elseif startswith(t, "--seed=")
             seed = parse(UInt128, t[8:end])
         else
@@ -183,5 +186,5 @@ function choosetests(choices = [])
     # Filter out tests from the test groups in the stdlibs
     filter!(!in(skip_tests), tests)
 
-    tests, net_on, exit_on_error, seed
+    tests, net_on, exit_on_error, use_revise, seed
 end
diff -pruN 1.3.1+dfsg-1/test/cmdlineargs.jl 1.4.0+dfsg-1/test/cmdlineargs.jl
--- 1.3.1+dfsg-1/test/cmdlineargs.jl	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/test/cmdlineargs.jl	2020-03-21 16:36:32.000000000 +0000
@@ -407,6 +407,9 @@ let exename = `$(Base.julia_cmd()) --sta
 
     # test the program name remains constant
     mktempdir() do dir
+        # dir can be case-incorrect sometimes
+        dir = realpath(dir)
+
         a = joinpath(dir, "a.jl")
         b = joinpath(dir, "b.jl")
         c = joinpath(dir, ".julia", "config", "startup.jl")
@@ -430,19 +433,19 @@ let exename = `$(Base.julia_cmd()) --sta
                 [a, a,
                  b, a]
             @test readsplit(`$exename -L $b -e 'exit(0)'`) ==
-                [realpath(b), ""]
+                [b, ""]
             @test readsplit(`$exename -L $b $a`) ==
-                [realpath(b), a,
+                [b, a,
                  a, a,
                  b, a]
             @test readsplit(`$exename --startup-file=yes -e 'exit(0)'`) ==
                 [c, ""]
             @test readsplit(`$exename --startup-file=yes -L $b -e 'exit(0)'`) ==
                 [c, "",
-                 realpath(b), ""]
+                 b, ""]
             @test readsplit(`$exename --startup-file=yes -L $b $a`) ==
                 [c, a,
-                 realpath(b), a,
+                 b, a,
                  a, a,
                  b, a]
         end
@@ -561,15 +564,12 @@ let exename = `$(Base.julia_cmd()) --sta
         "Bool(Base.JLOptions().use_sysimage_native_code)"`) == "false"
 end
 
-# backtrace contains type and line number info (esp. on windows #17179)
+# backtrace contains line number info (esp. on windows #17179)
 for precomp in ("yes", "no")
-    succ, out, bt = readchomperrors(`$(Base.julia_cmd()) --startup-file=no --sysimage-native-code=$precomp -E 'include("____nonexistent_file")'`)
+    succ, out, bt = readchomperrors(`$(Base.julia_cmd()) --startup-file=no --sysimage-native-code=$precomp -E 'sqrt(-2)'`)
     @test !succ
     @test out == ""
-    @test occursin("include_relative(::Module, ::String) at $(joinpath(".", "loading.jl"))", bt)
-    lno = match(r"at \.[\/\\]loading\.jl:(\d+)", bt)
-    @test length(lno.captures) == 1
-    @test parse(Int, lno.captures[1]) > 0
+    @test occursin(r"\.jl:(\d+)", bt)
 end
 
 # PR #23002
diff -pruN 1.3.1+dfsg-1/test/compiler/codegen.jl 1.4.0+dfsg-1/test/compiler/codegen.jl
--- 1.3.1+dfsg-1/test/compiler/codegen.jl	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/test/compiler/codegen.jl	2020-03-21 16:36:32.000000000 +0000
@@ -186,7 +186,7 @@ end
 if opt_level > 0
     @test !occursin("%gcframe", get_llvm(pointer_not_safepoint, Tuple{}))
     compare_large_struct_ir = get_llvm(compare_large_struct, Tuple{typeof(create_ref_struct())})
-    @test occursin("call i32 @memcmp", compare_large_struct_ir)
+    @test occursin("call i32 @memcmp(", compare_large_struct_ir) || occursin("call i32 @bcmp(", compare_large_struct_ir)
     @test !occursin("%gcframe", compare_large_struct_ir)
 
     @test occursin("jl_gc_pool_alloc", get_llvm(MutableStruct, Tuple{}))
@@ -392,6 +392,33 @@ end
 f_dict_hash_alloc(); g_dict_hash_alloc();
 @test (@allocated f_dict_hash_alloc()) == (@allocated g_dict_hash_alloc())
 
+# returning an argument shouldn't alloc a new box
+@noinline f33829(x) = (global called33829 = true; x)
+g33829() = @allocated Base.inferencebarrier(f33829)(1.1,)
+g33829() # warm up
+@test (@allocated g33829()) == 0
+@test called33829 # make sure there was a global side effect so it's hard for this call to simply be removed
+let src = get_llvm(f33829, Tuple{Float64}, true, true)
+    @test occursin(r"call [^(]*double @", src)
+    @test !occursin(r"call [^(]*\%jl_value_t", src)
+end
+
+let io = IOBuffer()
+    # Test for the f(args...) = g(args...) generic codegen optimization
+    code_llvm(io, Base.vect, Tuple{Vararg{Union{Float64, Int64}}})
+    @test !occursin("__apply", String(take!(io)))
+end
+
+function f1_30093(r)
+    while r[]>0
+        try
+        finally
+        end
+    end
+end
+
+@test f1_30093(Ref(0)) == nothing
+
 # issue 33590
 function f33590(b, x)
     y = b ? nothing : (x[1] + 1,)
@@ -399,3 +426,10 @@ function f33590(b, x)
 end
 @test f33590(true, (3,)) == (3,)
 @test f33590(false, (3,)) == (4,)
+
+# issue 29864
+const c29864 = VecElement{Union{Int,Nothing}}(2)
+@noinline f29864() = c29864
+@noinline g29864() = VecElement{Union{Int,Nothing}}(3)
+@test f29864().value === 2
+@test g29864().value === 3
diff -pruN 1.3.1+dfsg-1/test/compiler/inference.jl 1.4.0+dfsg-1/test/compiler/inference.jl
--- 1.3.1+dfsg-1/test/compiler/inference.jl	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/test/compiler/inference.jl	2020-03-21 16:36:32.000000000 +0000
@@ -1711,20 +1711,19 @@ g26826(x) = getfield26826(x, :a, :b)
 # If this test is broken (especially if inference is getting a correct, but loose result,
 # like a Union) then it's potentially an indication that the optimizer isn't hitting the
 # InferenceResult cache properly for varargs methods.
-typed_code = Core.Compiler.code_typed(f26826, (Float64,))[1].first
-found_well_typed_getfield_call = false
-let i
+let ct = Core.Compiler.code_typed(f26826, (Float64,))[1]
+    typed_code, retty = ct.first, ct.second
+    found_poorly_typed_getfield_call = false
     for i = 1:length(typed_code.code)
         stmt = typed_code.code[i]
         rhs = Meta.isexpr(stmt, :(=)) ? stmt.args[2] : stmt
-        if Meta.isexpr(rhs, :call) && rhs.args[1] == GlobalRef(Base, :getfield) && typed_code.ssavaluetypes[i] === Float64
-            global found_well_typed_getfield_call = true
+        if Meta.isexpr(rhs, :call) && rhs.args[1] == GlobalRef(Base, :getfield) && typed_code.ssavaluetypes[i] !== Float64
+            found_poorly_typed_getfield_call = true
         end
     end
+    @test !found_poorly_typed_getfield_call && retty === Float64
 end
 
-@test found_well_typed_getfield_call
-
 # 27059 fix fieldtype vararg and union handling
 
 f27059(::Type{T}) where T = i -> fieldtype(T, i)
@@ -2445,3 +2444,62 @@ f31974(n::Int) = f31974(1:n)
 
 f_overly_abstract_complex() = Complex(Ref{Number}(1)[])
 @test Base.return_types(f_overly_abstract_complex, Tuple{}) == [Complex]
+
+# Issue 26724
+const IntRange = AbstractUnitRange{<:Integer}
+const DenseIdx = Union{IntRange,Integer}
+@inline foo_26724(result) =
+    (result...,)
+@inline foo_26724(result, i::Integer, I::DenseIdx...) =
+    foo_26724(result, I...)
+@inline foo_26724(result, r::IntRange, I::DenseIdx...) =
+    foo_26724((result..., length(r)), I...)
+@test @inferred(foo_26724((), 1:4, 1:5, 1:6)) === (4, 5, 6)
+
+# Non uniformity in expresions with PartialTypeVar
+@test Core.Compiler.:⊑(Core.Compiler.PartialTypeVar(TypeVar(:N), true, true), TypeVar)
+let N = TypeVar(:N)
+    @test Core.Compiler.apply_type_nothrow([Core.Compiler.Const(NTuple),
+        Core.Compiler.PartialTypeVar(N, true, true),
+        Core.Compiler.Const(Any)], Type{Tuple{Vararg{Any,N}}})
+end
+
+# issue #33768
+function f33768()
+    Core._apply()
+end
+function g33768()
+    a = Any[iterate, tuple, (1,)]
+    Core._apply_iterate(a...)
+end
+function h33768()
+    Core._apply_iterate()
+end
+@test_throws ArgumentError f33768()
+@test Base.return_types(f33768, ()) == Any[Union{}]
+@test g33768() === (1,)
+@test Base.return_types(g33768, ()) == Any[Any]
+@test_throws ArgumentError h33768()
+@test Base.return_types(h33768, ()) == Any[Union{}]
+
+# constant prop of `Symbol("")`
+f_getf_computed_symbol(p) = getfield(p, Symbol("first"))
+@test Base.return_types(f_getf_computed_symbol, Tuple{Pair{Int8,String}}) == [Int8]
+
+# issue #33954
+struct X33954
+    x::Ptr{X33954}
+end
+f33954(x) = rand(Bool) ? f33954((x,)) : x
+@test Base.return_types(f33954, Tuple{X33954})[1] >: X33954
+
+# issue #34752
+struct a34752{T} end
+function a34752(c, d...)
+    length(d) > 1 || error()
+end
+function h34752()
+    g = Tuple[(42, Any[42][1], 42)][1]
+    a34752(g...)
+end
+@test h34752() === true
diff -pruN 1.3.1+dfsg-1/test/compiler/irpasses.jl 1.4.0+dfsg-1/test/compiler/irpasses.jl
--- 1.3.1+dfsg-1/test/compiler/irpasses.jl	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/test/compiler/irpasses.jl	2020-03-21 16:36:32.000000000 +0000
@@ -255,3 +255,43 @@ let m = Meta.@lower 1 + 1
     ret_2 = ir.stmts[ir.cfg.blocks[3].stmts[end]]
     @test isa(ret_2, Core.Compiler.ReturnNode) && ret_2.val == 2
 end
+
+# Issue #29213
+function f_29213()
+    while true
+        try
+            break
+        finally
+        end
+    end
+
+    while 1==1
+        try
+            ed = (_not_defined,)
+        finally
+            break
+        end
+    end
+
+    ed = string(ed)
+end
+
+@test_throws UndefVarError f_29213()
+
+function test_29253(K)
+    if true
+        try
+            error()
+        catch e
+        end
+    end
+    size(K,1)
+end
+let K = rand(2,2)
+    @test test_29253(K) == 2
+end
+
+# check getfield elim handling of GlobalRef
+const _some_coeffs = (1,[2],3,4)
+splat_from_globalref(x) = (x, _some_coeffs...,)
+@test splat_from_globalref(0) == (0, 1, [2], 3, 4)
diff -pruN 1.3.1+dfsg-1/test/complex.jl 1.4.0+dfsg-1/test/complex.jl
--- 1.3.1+dfsg-1/test/complex.jl	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/test/complex.jl	2020-03-21 16:36:32.000000000 +0000
@@ -14,6 +14,7 @@ end
 #show
 @test sprint(show, complex(1, 0), context=:compact => true) == "1+0im"
 @test sprint(show, complex(true, true)) == "Complex(true,true)"
+@test sprint(show, Complex{Int8}(0, typemin(Int8))) == "0 - 128im"
 
 @testset "unary operator on complex boolean" begin
     @test +Complex(true, true) === Complex(1, 1)
@@ -993,8 +994,8 @@ end
         join([
             "4-element Array{Complex{Float64},1}:",
             "     1.0 + 1.0e-10im",
-            " 2.0e-15 - 2.0e-5im ",
-            " 1.0e-15 + 2.0im    ",
+            " 2.0e-15 - 2.0e-5im",
+            " 1.0e-15 + 2.0im",
             "     1.0 + 2.0e-15im"], "\n")
 end
 
@@ -1148,3 +1149,6 @@ end
         @test isequal(ComplexF64(cscd(T(-1000, 100000))), ComplexF64(0.0, -0.0))
     end
 end
+
+# real(C) with C a Complex Unionall
+@test real(Complex{<:AbstractFloat}) == AbstractFloat
diff -pruN 1.3.1+dfsg-1/test/copy.jl 1.4.0+dfsg-1/test/copy.jl
--- 1.3.1+dfsg-1/test/copy.jl	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/test/copy.jl	2020-03-21 16:36:32.000000000 +0000
@@ -193,3 +193,13 @@ end
 let x = Bar17149()
     @test deepcopy(x) !== x
 end
+
+@testset "copying CodeInfo" begin
+    _testfunc() = nothing
+    ci,_ = code_typed(_testfunc, ())[1]
+    ci.edges = [_testfunc]
+
+    ci2 = copy(ci)
+    # Test that edges are not shared
+    @test ci2.edges !== ci.edges
+end
diff -pruN 1.3.1+dfsg-1/test/core.jl 1.4.0+dfsg-1/test/core.jl
--- 1.3.1+dfsg-1/test/core.jl	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/test/core.jl	2020-03-21 16:36:32.000000000 +0000
@@ -1085,8 +1085,8 @@ let
     @test_throws BoundsError(z, -1) getfield(z, -1)
     @test_throws BoundsError(z, 0) getfield(z, 0)
     @test_throws BoundsError(z, 3) getfield(z, 3)
-
-    strct = LoadError("yofile", 0, "bad")
+end
+let strct = LoadError("yofile", 0, "bad")
     @test nfields(strct) == 3 # sanity test
     @test_throws BoundsError(strct, 10) getfield(strct, 10)
     @test_throws ErrorException("setfield! immutable struct of type LoadError cannot be changed") setfield!(strct, 0, "")
@@ -1098,8 +1098,8 @@ let
     @test getfield(strct, 1) == "yofile"
     @test getfield(strct, 2) === 0
     @test getfield(strct, 3) == "bad"
-
-    mstrct = TestMutable("melm", 1, nothing)
+end
+let mstrct = TestMutable("melm", 1, nothing)
     @test Base.setproperty!(mstrct, :line, 8.0) === 8
     @test mstrct.line === 8
     @test_throws TypeError(:setfield!, "", Int, 8.0) setfield!(mstrct, :line, 8.0)
@@ -1112,6 +1112,14 @@ let
     @test_throws BoundsError(mstrct, 0) setfield!(mstrct, 0, "")
     @test_throws BoundsError(mstrct, 4) setfield!(mstrct, 4, "")
 end
+let strct = LoadError("yofile", 0, "bad")
+    @test_throws(ErrorException("setfield! immutable struct of type LoadError cannot be changed"),
+                 ccall(:jl_set_nth_field, Cvoid, (Any, Csize_t, Any), strct, 0, ""))
+end
+let mstrct = TestMutable("melm", 1, nothing)
+    @test_throws(BoundsError(mstrct, 4),
+                 ccall(:jl_set_nth_field, Cvoid, (Any, Csize_t, Any), mstrct, 3, ""))
+end
 
 # test getfield-overloading
 function Base.getproperty(mstrct::TestMutable, p::Symbol)
@@ -1447,7 +1455,7 @@ struct Foo2509; foo::Int; end
 # issue #2517
 struct Foo2517; end
 @test repr(Foo2517()) == "$(curmod_prefix)Foo2517()"
-@test repr(Vector{Foo2517}(undef, 1)) == "$(curmod_prefix)Foo2517[$(curmod_prefix)Foo2517()]"
+@test repr(Vector{Foo2517}(undef, 1)) == "[$(curmod_prefix)Foo2517()]"
 @test Foo2517() === Foo2517()
 
 # issue #1474
@@ -3614,10 +3622,19 @@ end
         return nothing
     end
 end
-@test_throws TypeError f1()
-@test_throws TypeError f2()
-@test_throws TypeError f3()
-@test_throws TypeError eval(Expr(:new, B, 1))
+@test_throws TypeError("new", A, 1) f1()
+@test_throws TypeError("new", A, 1) f2()
+@test_throws TypeError("new", A, 1) f3()
+@test_throws TypeError("new", A, 1) eval(Expr(:new, B, 1))
+
+# some tests for handling of malformed syntax--these cases should not be possible in normal code
+@test eval(Expr(:new, B, A())) == B(A())
+@test_throws ErrorException("invalid struct allocation") eval(Expr(:new, B))
+@test_throws ErrorException("invalid struct allocation") eval(Expr(:new, B, A(), A()))
+@test_throws TypeError("new", DataType, Complex) eval(Expr(:new, Complex))
+@test_throws TypeError("new", DataType, Complex.body) eval(Expr(:new, Complex.body))
+@test_throws TypeError("new", DataType, Complex) eval(Expr(:splatnew, Complex, ()))
+@test_throws TypeError("new", DataType, Complex.body) eval(Expr(:splatnew, Complex.body, ()))
 
 end
 
@@ -4116,82 +4133,90 @@ function f15180(x::T) where T
 end
 @test map(f15180(1), [1,2]) == [(Int,1),(Int,1)]
 
-let ary = Vector{Any}(undef, 10)
-    check_undef_and_fill(ary, rng) = for i in rng
-        @test !isassigned(ary, i)
-        ary[i] = (Float64(i), i) # some non-cached content
-        @test isassigned(ary, i)
-    end
-    # Check if the memory is initially zerod and fill it with value
-    # to check if these values are not reused later.
-    check_undef_and_fill(ary, 1:10)
-    # Check if the memory grown at the end are zerod
-    ccall(:jl_array_grow_end, Cvoid, (Any, Csize_t), ary, 10)
-    check_undef_and_fill(ary, 11:20)
-    # Make sure the content of the memory deleted at the end are not reused
-    ccall(:jl_array_del_end, Cvoid, (Any, Csize_t), ary, 5)
-    ccall(:jl_array_grow_end, Cvoid, (Any, Csize_t), ary, 5)
-    check_undef_and_fill(ary, 16:20)
-
-    # Now check grow/del_end
-    ary = Vector{Any}(undef, 1010)
-    check_undef_and_fill(ary, 1:1010)
-    # This del_beg should move the buffer
-    ccall(:jl_array_del_beg, Cvoid, (Any, Csize_t), ary, 1000)
-    ccall(:jl_array_grow_beg, Cvoid, (Any, Csize_t), ary, 1000)
-    check_undef_and_fill(ary, 1:1000)
-    ary = Vector{Any}(undef, 1010)
-    check_undef_and_fill(ary, 1:1010)
-    # This del_beg should not move the buffer
-    ccall(:jl_array_del_beg, Cvoid, (Any, Csize_t), ary, 10)
-    ccall(:jl_array_grow_beg, Cvoid, (Any, Csize_t), ary, 10)
-    check_undef_and_fill(ary, 1:10)
-
-    ary = Vector{Any}(undef, 1010)
-    check_undef_and_fill(ary, 1:1010)
-    ccall(:jl_array_grow_end, Cvoid, (Any, Csize_t), ary, 10)
-    check_undef_and_fill(ary, 1011:1020)
-    ccall(:jl_array_del_end, Cvoid, (Any, Csize_t), ary, 10)
-    ccall(:jl_array_grow_beg, Cvoid, (Any, Csize_t), ary, 10)
-    check_undef_and_fill(ary, 1:10)
-
-    # Make sure newly malloc'd buffers are filled with 0
-    # test this for a few different sizes since we need to make sure
-    # we are malloc'ing the buffer after the grow_end and malloc is not using
-    # mmap directly (which may return a zero'd new page).
-    for n in [50, 51, 100, 101, 200, 201, 300, 301]
-        ary = Vector{Any}(undef, n)
-        # Try to free the previous buffer that was filled with random content
-        # and to increase the chance of getting a non-zero'd buffer next time
-        GC.gc()
-        GC.gc()
-        GC.gc()
-        ccall(:jl_array_grow_beg, Cvoid, (Any, Csize_t), ary, 4)
-        ccall(:jl_array_del_beg, Cvoid, (Any, Csize_t), ary, 4)
-        ccall(:jl_array_grow_end, Cvoid, (Any, Csize_t), ary, n)
-        ccall(:jl_array_grow_beg, Cvoid, (Any, Csize_t), ary, 4)
-        check_undef_and_fill(ary, 1:(2n + 4))
-    end
+struct ValueWrapper
+    vpadding::NTuple{2,VecElement{UInt}}
+    value
+    ValueWrapper(value) = new((typemax(UInt), typemax(UInt)), value)
+end
+Base.convert(::Type{ValueWrapper}, x) = ValueWrapper(x)
+for T in (Any, ValueWrapper)
+    let ary = Vector{T}(undef, 10)
+        check_undef_and_fill(ary, rng) = for i in rng
+            @test !isassigned(ary, i)
+            ary[i] = (Float64(i), i) # some non-cached content
+            @test isassigned(ary, i)
+        end
+        # Check if the memory is initially zerod and fill it with value
+        # to check if these values are not reused later.
+        check_undef_and_fill(ary, 1:10)
+        # Check if the memory grown at the end are zerod
+        ccall(:jl_array_grow_end, Cvoid, (Any, Csize_t), ary, 10)
+        check_undef_and_fill(ary, 11:20)
+        # Make sure the content of the memory deleted at the end are not reused
+        ccall(:jl_array_del_end, Cvoid, (Any, Csize_t), ary, 5)
+        ccall(:jl_array_grow_end, Cvoid, (Any, Csize_t), ary, 5)
+        check_undef_and_fill(ary, 16:20)
+
+        # Now check grow/del_end
+        ary = Vector{T}(undef, 1010)
+        check_undef_and_fill(ary, 1:1010)
+        # This del_beg should move the buffer
+        ccall(:jl_array_del_beg, Cvoid, (Any, Csize_t), ary, 1000)
+        ccall(:jl_array_grow_beg, Cvoid, (Any, Csize_t), ary, 1000)
+        check_undef_and_fill(ary, 1:1000)
+        ary = Vector{T}(undef, 1010)
+        check_undef_and_fill(ary, 1:1010)
+        # This del_beg should not move the buffer
+        ccall(:jl_array_del_beg, Cvoid, (Any, Csize_t), ary, 10)
+        ccall(:jl_array_grow_beg, Cvoid, (Any, Csize_t), ary, 10)
+        check_undef_and_fill(ary, 1:10)
 
-    ary = Vector{Any}(undef, 100)
-    ccall(:jl_array_grow_end, Cvoid, (Any, Csize_t), ary, 10000)
-    ary[:] = 1:length(ary)
-    ccall(:jl_array_del_beg, Cvoid, (Any, Csize_t), ary, 10000)
-    # grow on the back until a buffer reallocation happens
-    cur_ptr = pointer(ary)
-    while cur_ptr == pointer(ary)
-        len = length(ary)
+        ary = Vector{T}(undef, 1010)
+        check_undef_and_fill(ary, 1:1010)
         ccall(:jl_array_grow_end, Cvoid, (Any, Csize_t), ary, 10)
-        for i in (len + 1):(len + 10)
-            @test !isassigned(ary, i)
+        check_undef_and_fill(ary, 1011:1020)
+        ccall(:jl_array_del_end, Cvoid, (Any, Csize_t), ary, 10)
+        ccall(:jl_array_grow_beg, Cvoid, (Any, Csize_t), ary, 10)
+        check_undef_and_fill(ary, 1:10)
+
+        # Make sure newly malloc'd buffers are filled with 0
+        # test this for a few different sizes since we need to make sure
+        # we are malloc'ing the buffer after the grow_end and malloc is not using
+        # mmap directly (which may return a zero'd new page).
+        for n in [50, 51, 100, 101, 200, 201, 300, 301]
+            ary = Vector{T}(undef, n)
+            # Try to free the previous buffer that was filled with random content
+            # and to increase the chance of getting a non-zero'd buffer next time
+            GC.gc()
+            GC.gc()
+            GC.gc()
+            ccall(:jl_array_grow_beg, Cvoid, (Any, Csize_t), ary, 4)
+            ccall(:jl_array_del_beg, Cvoid, (Any, Csize_t), ary, 4)
+            ccall(:jl_array_grow_end, Cvoid, (Any, Csize_t), ary, n)
+            ccall(:jl_array_grow_beg, Cvoid, (Any, Csize_t), ary, 4)
+            check_undef_and_fill(ary, 1:(2n + 4))
+        end
+
+        ary = Vector{T}(undef, 100)
+        ccall(:jl_array_grow_end, Cvoid, (Any, Csize_t), ary, 10000)
+        ary[:] = 1:length(ary)
+        ccall(:jl_array_del_beg, Cvoid, (Any, Csize_t), ary, 10000)
+        # grow on the back until a buffer reallocation happens
+        cur_ptr = pointer(ary)
+        while cur_ptr == pointer(ary)
+            len = length(ary)
+            ccall(:jl_array_grow_end, Cvoid, (Any, Csize_t), ary, 10)
+            for i in (len + 1):(len + 10)
+                @test !isassigned(ary, i)
+            end
         end
-    end
 
-    ary = Vector{Any}(undef, 100)
-    ary[:] = 1:length(ary)
-    ccall(:jl_array_grow_at, Cvoid, (Any, Csize_t, Csize_t), ary, 50, 10)
-    for i in 51:60
-        @test !isassigned(ary, i)
+        ary = Vector{T}(undef, 100)
+        ary[:] = 1:length(ary)
+        ccall(:jl_array_grow_at, Cvoid, (Any, Csize_t, Csize_t), ary, 50, 10)
+        for i in 51:60
+            @test !isassigned(ary, i)
+        end
     end
 end
 
@@ -4355,6 +4380,7 @@ function test_copy_alias(::Type{T}) wher
 end
 test_copy_alias(Int)
 test_copy_alias(Any)
+test_copy_alias(Union{Int,Nothing})
 
 # issue #15370
 @test isdefined(Core, :Box)
@@ -5019,13 +5045,15 @@ end
 # when calculating total allocation size.
 @noinline function f17255(n)
     GC.enable(false)
-    b0 = Base.gc_bytes()
+    b0 = Ref{Int64}(0)
+    b1 = Ref{Int64}(0)
+    Base.gc_bytes(b0)
     local a
     for i in 1:n
         a, t, allocd = @timed [Ref(1) for i in 1:1000]
         @test allocd > 0
-        b1 = Base.gc_bytes()
-        if b1 < b0
+        Base.gc_bytes(b1)
+        if b1[] < b0[]
             return false, a
         end
     end
@@ -5866,9 +5894,9 @@ let
     b3 = B23367[b][1] # copy b via array assignment
     addr(@nospecialize x) = ccall(:jl_value_ptr, Ptr{Cvoid}, (Any,), x)
     @test addr(b)  == addr(b)
-    @test addr(b)  == addr(b2)
-    @test addr(b)  == addr(b3)
-    @test addr(b2) == addr(b3)
+    # @test addr(b)  == addr(b2)
+    # @test addr(b)  == addr(b3)
+    # @test addr(b2) == addr(b3)
 
     @test b === b2 === b3 === b
     @test egal(b, b2) && egal(b2, b3) && egal(b3, b)
@@ -5877,7 +5905,7 @@ let
     @test b.x === Int8(91)
     @test b.z === Int8(23)
     @test b.y === A23367((Int8(1), Int8(2), Int8(3), Int8(4), Int8(5), Int8(6), Int8(7)))
-    @test sizeof(b) == sizeof(Int) * 3
+    @test sizeof(b) == 12
     @test A23367(Int8(1)).x === Int8(1)
     @test A23367(Int8(0)).x === Int8(0)
     @test A23367(Int16(1)).x === Int16(1)
@@ -5905,6 +5933,33 @@ for U in boxedunions
     end
 end
 
+struct UnionFieldInlineStruct
+    x::Int64
+    y::Union{Float64, Missing}
+end
+
+@test sizeof(Vector{UnionFieldInlineStruct}(undef, 2)) == sizeof(UnionFieldInlineStruct) * 2
+
+let x = UnionFieldInlineStruct(1, 3.14)
+    AInlineUnion = [x for i = 1:10]
+    @test sizeof(AInlineUnion) == sizeof(UnionFieldInlineStruct) * 10
+    BInlineUnion = Vector{UnionFieldInlineStruct}(undef, 10)
+    copyto!(BInlineUnion, AInlineUnion)
+    @test AInlineUnion == BInlineUnion
+    @test BInlineUnion[end] == x
+    CInlineUnion = vcat(AInlineUnion, BInlineUnion)
+    @test sizeof(CInlineUnion) == sizeof(UnionFieldInlineStruct) * 20
+    @test CInlineUnion[end] == x
+end
+
+# issue 33709
+struct A33709
+    a::Union{Nothing,A33709}
+end
+let a33709 = A33709(A33709(nothing))
+    @test isnothing(a33709.a.a)
+end
+
 # issue 31583
 a31583 = "a"
 f31583() = a31583 === "a"
@@ -7080,3 +7135,41 @@ function f32820(refs)
     x
 end
 @test f32820(Any[1,2]) == Any[1, 1]
+
+# Splatting with bad iterate
+struct SplatBadIterate; end
+Base.iterate(s::SplatBadIterate, args...) = ()
+@test_throws BoundsError (SplatBadIterate()...,)
+
+# issue #33954, layout with circular type parameters but not fields
+struct P33954{T}
+end
+struct A33954
+    x::P33954{A33954}
+end
+@test isbitstype(Tuple{A33954})
+struct Q33954{T}
+    x::Int
+end
+struct B33954
+    x::Q33954{B33954}
+end
+@test_broken isbitstype(Tuple{B33954})
+@test_broken isbitstype(B33954)
+
+# Issue #34206/34207
+function mre34206(a, n)
+    va = view(a, :)
+    b = ntuple(_ -> va, n)::Tuple{Vararg{typeof(va)}}
+    return b[1].offset1
+end
+@test mre34206([44], 1) == 0
+
+# Issue #34247
+function f34247(a)
+    GC.@preserve a try
+    catch
+    end
+    true
+end
+@test f34247("")
diff -pruN 1.3.1+dfsg-1/test/dict.jl 1.4.0+dfsg-1/test/dict.jl
--- 1.3.1+dfsg-1/test/dict.jl	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/test/dict.jl	2020-03-21 16:36:32.000000000 +0000
@@ -856,6 +856,7 @@ Dict(1 => rand(2,3), 'c' => "asdf") # ju
 
     wkd = WeakKeyDict(A=>1)
     @test delete!(wkd, A) == empty(wkd)
+    @test delete!(wkd, A) === wkd
 
     # issue #26939
     d26939 = WeakKeyDict()
diff -pruN 1.3.1+dfsg-1/test/docs.jl 1.4.0+dfsg-1/test/docs.jl
--- 1.3.1+dfsg-1/test/docs.jl	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/test/docs.jl	2020-03-21 16:36:32.000000000 +0000
@@ -41,6 +41,12 @@ macro macro_doctest() end
 
 @test (@doc @macro_doctest) !== nothing
 
+@test (@eval @doc $(Meta.parse("{a"))) isa Markdown.MD
+@test (@eval @doc $(Meta.parse("``"))) isa Markdown.MD
+@test (@eval @doc $(Meta.parse("``"))) == (@doc @cmd)
+@test (@eval @doc $(Meta.parse("123456789012345678901234567890"))) == (@doc @int128_str)
+@test (@eval @doc $(Meta.parse("1234567890123456789012345678901234567890"))) == (@doc @big_str)
+
 # test that random stuff interpolated into docstrings doesn't break search or other methods here
 @doc doc"""
 break me:
@@ -153,6 +159,18 @@ t(::Int, ::Any)
 "t-3"
 t{S <: Integer}(::S)
 
+# Docstrings to parametric methods after definition using where syntax (#32960):
+tw(x::T) where T = nothing
+tw(x::T, y::U) where {T, U <: Integer} = nothing
+tw(x::T, y::U, z::V) where T where U <: Integer where V <: AbstractFloat = nothing
+
+"tw-1"
+tw(x::T) where T
+"tw-2"
+tw(x::T, y::U) where {T, U <: Integer}
+"tw-3"
+tw(x::T, y::U, z::V) where T where U <: Integer where V <: AbstractFloat
+
 "FieldDocs"
 mutable struct FieldDocs
     "one"
@@ -193,6 +211,13 @@ function returntype(x::Int)::Int
     x
 end
 
+# @nospecialize (issue #34122)
+"`fnospecialize` for Numbers"
+fnospecialize(@nospecialize(x::Number)) = 1
+
+"`fnospecialize` for arrays"
+fnospecialize(@nospecialize(x::AbstractArray)) = 2
+
 end
 
 let md = meta(DocsTest)[@var(DocsTest)]
@@ -266,6 +291,14 @@ let rt = @var(DocsTest.returntype)
     @test md.order == [Tuple{Float64}, Tuple{Int}]
 end
 
+let fns = @var(DocsTest.fnospecialize)
+    md = meta(DocsTest)[fns]
+    d = md.docs[Tuple{Number}]
+    @test docstrings_equal(d, doc"`fnospecialize` for Numbers")
+    d = md.docs[Tuple{AbstractArray}]
+    @test docstrings_equal(d, doc"`fnospecialize` for arrays")
+end
+
 @test docstrings_equal(@doc(DocsTest.TA), doc"TA")
 
 @test docstrings_equal(@doc(DocsTest.@mac), doc"@mac()")
diff -pruN 1.3.1+dfsg-1/test/errorshow.jl 1.4.0+dfsg-1/test/errorshow.jl
--- 1.3.1+dfsg-1/test/errorshow.jl	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/test/errorshow.jl	2020-03-21 16:36:32.000000000 +0000
@@ -5,6 +5,50 @@ using Random, LinearAlgebra
 # For curmod_*
 include("testenv.jl")
 
+
+@testset "SystemError" begin
+    err = try; systemerror("reason", Cint(0)); false; catch ex; ex; end::SystemError
+    errs = sprint(Base.showerror, err)
+    @test startswith(errs, "SystemError: reason: ")
+
+    err = try; systemerror("reason", Cint(0), extrainfo="addend"); false; catch ex; ex; end::SystemError
+    errs = sprint(Base.showerror, err)
+    @test startswith(errs, "SystemError (with addend): reason: ")
+
+    err = try
+            Libc.errno(0xc0ffee)
+            systemerror("reason", true)
+            false
+        catch ex
+            ex
+        end::SystemError
+    errs = sprint(Base.showerror, err)
+    @test startswith(errs, "SystemError: reason: ")
+
+    err = try; Base.windowserror("reason", UInt32(0)); false; catch ex; ex; end::SystemError
+    errs = sprint(Base.showerror, err)
+    @test startswith(errs, Sys.iswindows() ? "SystemError: reason: " :
+        "SystemError (with Base.WindowsErrorInfo(0x00000000, nothing)): reason: ")
+
+    err = try; Base.windowserror("reason", UInt32(0); extrainfo="addend"); false; catch ex; ex; end::SystemError
+    errs = sprint(Base.showerror, err)
+    @test startswith(errs, Sys.iswindows() ? "SystemError (with addend): reason: " :
+        "SystemError (with Base.WindowsErrorInfo(0x00000000, \"addend\")): reason: ")
+
+    @static if Sys.iswindows()
+        err = try
+                ccall(:SetLastError, stdcall, Cvoid, (UInt32,), 0x00000000)
+                Base.windowserror("reason", true)
+                false
+            catch ex
+                ex
+            end::SystemError
+        errs = sprint(Base.showerror, err)
+        @test startswith(errs, "SystemError: reason: ")
+    end
+end
+
+
 cfile = " at $(@__FILE__):"
 c1line = @__LINE__() + 1
 method_c1(x::Float64, s::AbstractString...) = true
@@ -206,7 +250,7 @@ import ..@except_str
 global +
 +() = nothing
 err_str = @except_str 1 + 2 MethodError
-@test occursin("import Base.+", err_str)
+@test occursin("import Base.:+", err_str)
 
 err_str = @except_str Float64[](1) MethodError
 @test !occursin("import Base.Array", err_str)
@@ -578,3 +622,19 @@ let t1 = @async(error(1)),
     @test length(findall("Stacktrace:", s)) == 2
     @test occursin("[1] error(::Int", s)
 end
+
+module TestMethodShadow
+    struct Foo; x; end
+    +(a::Foo, b::Foo) = Foo(a.x + b.x)
+    ==(a::Foo, b::Foo) = Foo(a.x == b.x)
+    div(a::Foo, b::Foo) = Foo(div(a.x, b.x))
+end
+for (func,str) in ((TestMethodShadow.:+,":+"), (TestMethodShadow.:(==),":(==)"), (TestMethodShadow.:div,"div"))
+    ex = try
+        foo = TestMethodShadow.Foo(3)
+        func(foo,foo)
+    catch e
+       e
+    end::MethodError
+    @test occursin("You may have intended to import Base.$str", sprint(Base.showerror, ex))
+end
diff -pruN 1.3.1+dfsg-1/test/file.jl 1.4.0+dfsg-1/test/file.jl
--- 1.3.1+dfsg-1/test/file.jl	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/test/file.jl	2020-03-21 16:36:32.000000000 +0000
@@ -15,14 +15,14 @@ subdir = joinpath(dir, "adir")
 mkdir(subdir)
 subdir2 = joinpath(dir, "adir2")
 mkdir(subdir2)
-@test_throws SystemError mkdir(file)
+@test_throws Base.IOError mkdir(file)
 let err = nothing
     try
         mkdir(file)
     catch err
         io = IOBuffer()
         showerror(io, err)
-        @test startswith(String(take!(io)), "SystemError (with $file): mkdir:")
+        @test startswith(String(take!(io)), "IOError: mkdir: file already exists (EEXIST)")
     end
 end
 
@@ -48,6 +48,30 @@ if !Sys.iswindows()
     cd(pwd_)
 end
 
+using Random
+
+@testset "that temp names are actually unique" begin
+    temps = [tempname(cleanup=false) for _ = 1:100]
+    @test allunique(temps)
+    temps = map(1:100) do _
+        path, io = mktemp(cleanup=false)
+        close(io)
+        rm(path, force=true)
+        return path
+    end
+    @test allunique(temps)
+end
+
+@testset "tempname with parent" begin
+    t = tempname()
+    @test dirname(t) == tempdir()
+    mktempdir() do d
+        t = tempname(d)
+        @test dirname(t) == d
+    end
+    @test_throws ArgumentError tempname(randstring())
+end
+
 child_eval(code::String) = eval(Meta.parse(readchomp(`$(Base.julia_cmd()) -E $code`)))
 
 @testset "mktemp/dir basic cleanup" begin
@@ -67,6 +91,14 @@ child_eval(code::String) = eval(Meta.par
     # mktempdir with cleanup
     t = child_eval("t = mktempdir(); touch(joinpath(t, \"file.txt\")); t")
     @test !ispath(t)
+    # tempname without cleanup
+    t = child_eval("t = tempname(cleanup=false); touch(t); t")
+    @test isfile(t)
+    rm(t, force=true)
+    @test !ispath(t)
+    # tempname with cleanup
+    t = child_eval("t = tempname(); touch(t); t")
+    @test !ispath(t)
 end
 
 import Base.Filesystem: TEMP_CLEANUP_MIN, TEMP_CLEANUP_MAX, TEMP_CLEANUP
@@ -1257,6 +1289,20 @@ cd(dirwalk) do
 end
 rm(dirwalk, recursive=true)
 
+###################
+#     readdir     #
+###################
+@testset "readdir is sorted" begin
+    mktempdir() do dir
+        cd(dir) do
+            for k in 1:10
+                touch(randstring())
+            end
+            @test issorted(readdir())
+        end
+    end
+end
+
 ############
 # Clean up #
 ############
@@ -1384,3 +1430,48 @@ end
         @test sizeof(basename(tmpdir)) == 6
     end
 end
+
+@testset "readdir tests" begin
+    ≛(a, b) = sort(a) == sort(b)
+    mktempdir() do dir
+        d = cd(pwd, dir) # might resolve symlinks
+        @test isempty(readdir(d))
+        @test isempty(readdir(d, join=true))
+        cd(d) do
+            @test isempty(readdir())
+            @test isempty(readdir(join=true))
+        end
+        touch(joinpath(d, "file"))
+        mkdir(joinpath(d, "dir"))
+        names = ["dir", "file"]
+        paths = [joinpath(d, x) for x in names]
+        @test readdir(d) ≛ names
+        @test readdir(d, join=true) ≛ paths
+        cd(d) do
+            @test readdir() ≛ names
+            @test readdir(join=true) ≛ paths
+        end
+        t, b = splitdir(d)
+        cd(t) do
+            @test readdir(b) ≛ names
+            @test readdir(b, join=true) ≛ [joinpath(b, x) for x in names]
+        end
+    end
+    if !Sys.iswindows()
+        mktempdir() do dir
+            cd(dir) do
+                d = pwd() # might resolve symlinks
+                @test isdir(d)
+                @test Base.Filesystem.samefile(d, ".")
+                @test isempty(readdir())
+                @test isempty(readdir(d))
+                @test isempty(readdir(join=true))
+                rm(d, recursive=true)
+                @test !ispath(d)
+                @test isempty(readdir())
+                @test_throws SystemError readdir(d)
+                @test_throws Base.IOError readdir(join=true)
+            end
+        end
+    end
+end
diff -pruN 1.3.1+dfsg-1/test/gmp.jl 1.4.0+dfsg-1/test/gmp.jl
--- 1.3.1+dfsg-1/test/gmp.jl	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/test/gmp.jl	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1,472 @@
+# This file is a part of Julia. License is MIT: https://julialang.org/license
+
+using Random, Serialization
+
+a = parse(BigInt,"123456789012345678901234567890")
+b = parse(BigInt,"123456789012345678901234567891")
+c = parse(BigInt,"246913578024691357802469135780")
+d = parse(BigInt,"-246913578024691357802469135780")
+ee = typemax(Int64)
+@testset "basics" begin
+    @test BigInt <: Signed
+    @test big(1) isa Signed
+
+    let x = big(1)
+        @test signed(x) === x
+        @test convert(Signed, x) === x
+        @test Signed(x) === x
+        @test_throws MethodError convert(Unsigned, x) # could change in the future
+    end
+    @test a+BigInt(1) == b
+    @test typeof(a+1) == BigInt
+    @test a+1 == b
+    @test isequal(a+1, b)
+    @test b == a+1
+    @test !(b == a)
+    @test b > a
+    @test b >= a
+    @test !(b < a)
+    @test !(b <= a)
+
+    @test typeof(a * 2) == BigInt
+    @test a*2 == c
+    @test c-a == a
+    @test c == a + a
+    @test c+1 == a+b
+
+
+    @test typeof(d) == BigInt
+    @test d == -c
+
+    @test typeof(BigInt(ee)) == BigInt
+    @test BigInt(ee)+1 == parse(BigInt,"9223372036854775808")
+    @testset "printing" begin
+        #Multiple calls for sanity check, since we're doing direct memory manipulation
+        @test string(a) == "123456789012345678901234567890"
+        @test string(b) == "123456789012345678901234567891"
+        @test string(c) == "246913578024691357802469135780"
+        @test string(d) == "-246913578024691357802469135780"
+        @test string(a) == "123456789012345678901234567890"
+    end
+    @testset "constructors" begin
+        @test typeof(BigInt(typemax(Int8))) == BigInt
+        @test typeof(BigInt(typemax(Int16))) == BigInt
+        @test typeof(BigInt(typemax(Int32))) == BigInt
+        @test typeof(BigInt(typemax(Int64))) == BigInt
+        @test typeof(BigInt(typemax(Int128))) == BigInt
+
+        @test typeof(BigInt(true)) == BigInt
+        @test typeof(BigInt(typemax(UInt8))) == BigInt
+        @test typeof(BigInt(typemax(UInt16))) == BigInt
+        @test typeof(BigInt(typemax(UInt32))) == BigInt
+        @test typeof(BigInt(typemax(UInt64))) == BigInt
+        @test typeof(BigInt(typemax(UInt128))) == BigInt
+
+        @test typeof(BigInt(BigInt(1))) == BigInt
+
+        for x in (Int16(0), 1, 3//4, big(5//6), big(9))
+            @test big(typeof(x)) == typeof(big(x))
+            @test big(typeof(complex(x, x))) == typeof(big(complex(x, x)))
+        end
+    end
+end
+@testset "div, fld, mod, rem" begin
+    for i = -10:10, j = [-10:-1; 1:10]
+        @test div(BigInt(i), BigInt(j)) == div(i,j)
+        @test fld(BigInt(i), BigInt(j)) == fld(i,j)
+        @test mod(BigInt(i), BigInt(j)) == mod(i,j)
+        @test rem(BigInt(i), BigInt(j)) == rem(i,j)
+    end
+end
+
+@testset "Signed addition" begin
+    @test a+Int8(1) == b
+    @test a+Int16(1) == b
+    @test a+Int32(1) == b
+    @test a+Int64(1) == b
+    @test a+Int128(1) == b
+    @test Int8(1)+ a == b
+    @test Int16(1)+a == b
+    @test Int32(1)+a == b
+    @test Int64(1)+a == b
+    @test b+Int8(-1) == a
+    @test b+Int16(-1) == a
+    @test b+Int32(-1) == a
+    @test b+Int64(-1) == a
+    @test Int8(-1)+ b == a
+    @test Int16(-1)+b == a
+    @test Int32(-1)+b == a
+    @test Int64(-1)+b == a
+end
+@testset "Unsigned addition" begin
+    @test a+true == b
+    @test a+UInt8(1) == b
+    @test a+UInt16(1) == b
+    @test a+UInt32(1) == b
+    @test a+UInt64(1) == b
+    @test a+UInt128(1) == b
+    @test true+a == b
+    @test UInt8(1)+ a == b
+    @test UInt16(1)+a == b
+    @test UInt32(1)+a == b
+    @test UInt64(1)+a == b
+end
+@testset "Signed subtraction" begin
+    @test b-Int8(1) == a
+    @test b-Int16(1) == a
+    @test b-Int32(1) == a
+    @test b-Int64(1) == a
+    @test Int8(1)- b == -a
+    @test Int16(1)-b == -a
+    @test Int32(1)-b == -a
+    @test Int64(1)-b == -a
+    @test a-Int8(-1) == b
+    @test a-Int16(-1) == b
+    @test a-Int32(-1) == b
+    @test a-Int64(-1) == b
+    @test Int8(-1)- a == -b
+    @test Int16(-1)-a == -b
+    @test Int32(-1)-a == -b
+    @test Int64(-1)-a == -b
+end
+@testset "Unsigned subtraction" begin
+    @test b-true == a
+    @test b-UInt8(1) == a
+    @test b-UInt16(1) == a
+    @test b-UInt32(1) == a
+    @test b-UInt64(1) == a
+    @test true-b == -a
+    @test UInt8(1)- b == -a
+    @test UInt16(1)-b == -a
+    @test UInt32(1)-b == -a
+    @test UInt64(1)-b == -a
+end
+@testset "Signed multiplication" begin
+    @test a*Int8(1) == a
+    @test a*Int16(1) == a
+    @test a*Int32(1) == a
+    @test a*Int64(1) == a
+    @test Int8(1)* a == a
+    @test Int16(1)*a == a
+    @test Int32(1)*a == a
+    @test Int64(1)*a == a
+    @test a*Int8(-1) == -a
+    @test a*Int16(-1) == -a
+    @test a*Int32(-1) == -a
+    @test a*Int64(-1) == -a
+    @test Int8(-1)* a == -a
+    @test Int16(-1)*a == -a
+    @test Int32(-1)*a == -a
+    @test Int64(-1)*a == -a
+end
+@testset "Unsigned multiplication" begin
+    @test a*true == a
+    @test a*UInt8(1) == a
+    @test a*UInt16(1) == a
+    @test a*UInt32(1) == a
+    @test a*UInt64(1) == a
+    @test true*a == a
+    @test UInt8(1)* a == a
+    @test UInt16(1)*a == a
+    @test UInt32(1)*a == a
+    @test UInt64(1)*a == a
+end
+
+@testset "bitshifts" begin
+    @test BigInt(5) << 3 == 40
+    @test BigInt(5) >> 1 == 2
+    @test BigInt(-5) << 3 == -40
+    @test BigInt(-5) >> 1 == -3
+    @test BigInt(5) >> -3 == 40
+    @test BigInt(5) << -1 == 2
+    @test BigInt(-5) >> -3 == -40
+    @test BigInt(-5) << -1 == -3
+end
+@testset "boolean ops" begin
+    @test ~BigInt(123) == -124
+    @test BigInt(123) & BigInt(234) == 106
+    @test BigInt(123) | BigInt(234) == 251
+    @test BigInt(123) ⊻ BigInt(234) == 145
+
+    @test gcd(BigInt(48), BigInt(180)) == 12
+    @test lcm(BigInt(48), BigInt(180)) == 720
+end
+@testset "combinatorics" begin
+    @test factorial(BigInt(40)) == parse(BigInt,"815915283247897734345611269596115894272000000000")
+    @test binomial(BigInt(1), -1) == BigInt(0)
+    @test binomial(BigInt(1), 2)  == BigInt(0)
+    @test binomial(BigInt(-53), 42) == parse(BigInt,"959509335087854414441273718")
+    @test binomial(BigInt(113), BigInt(42)) == parse(BigInt,"18672199984318438125634054194360")
+end
+let a, b
+    a = rand(1:100, 10000)
+    b = map(BigInt, a)
+    @test sum(a) == sum(b)
+end
+
+@testset "Iterated arithmetic" begin
+    local a, b, c, d, f, g
+    a = parse(BigInt,"315135")
+    b = parse(BigInt,"12412")
+    c = parse(BigInt,"3426495623485904783478347")
+    d = parse(BigInt,"-1398984130")
+    f = parse(BigInt,"2413804710837418037418307081437315263635345357386985747464")
+    g = parse(BigInt,"-1")
+
+    @test +(a, b) == parse(BigInt,"327547")
+    @test +(a, b, c) == parse(BigInt,"3426495623485904783805894")
+    @test +(a, b, c, d) == parse(BigInt,"3426495623485903384821764")
+    @test +(a, b, c, d, f) == parse(BigInt,"2413804710837418037418307081437318690130968843290370569228")
+    @test +(a, b, c, d, f, g) == parse(BigInt,"2413804710837418037418307081437318690130968843290370569227")
+
+    @test *(a, b) == parse(BigInt,"3911455620")
+    @test *(a, b, c) == parse(BigInt,"13402585563389346256121263521460140")
+    @test *(a, b, c, d) == parse(BigInt,"-18750004504148804423388563022070650287578200")
+    @test *(a, b, c, d, f) == parse(BigInt,"-45258849200337190631492857400003938881995610529251881450243326128168934937055005474972396281351684800")
+    @test *(a, b, c, d, f, g) == parse(BigInt,"45258849200337190631492857400003938881995610529251881450243326128168934937055005474972396281351684800")
+
+    @test xor(a, b) == parse(BigInt,"327299")
+    @test xor(a, b, c) == parse(BigInt,"3426495623485904783798472")
+    @test xor(a, b, c, d) == parse(BigInt,"-3426495623485906178489610")
+    @test xor(a, b, c, d, f) == parse(BigInt,"-2413804710837418037418307081437316711364709261074607933698")
+    @test xor(a, b, c, d, f, g) == parse(BigInt,"2413804710837418037418307081437316711364709261074607933697")
+
+    @test (&)(a, b) == parse(BigInt,"124")
+    @test (&)(a, b, c) == parse(BigInt,"72")
+    @test (&)(a, b, c, d) == parse(BigInt,"8")
+    @test (&)(a, b, c, d, f) == parse(BigInt,"8")
+    @test (&)(a, b, c, d, f, g) == parse(BigInt,"8")
+
+    @test (|)(a, b) == parse(BigInt,"327423")
+    @test (|)(a, b, c) == parse(BigInt,"3426495623485904783802111")
+    @test (|)(a, b, c, d) == parse(BigInt,"-1396834561")
+    @test (|)(a, b, c, d, f) == parse(BigInt,"-1358954753")
+    @test (|)(a, b, c, d, f, g) == parse(BigInt,"-1")
+
+    @test trailing_ones(a) == 8
+    @test trailing_zeros(b) == 2
+    @test count_ones(a) == 14
+end
+
+# Large Fibonacci to exercise BigInt
+# from Bill Hart, https://groups.google.com/group/julia-dev/browse_frm/thread/798e2d1322daf633
+function mul(a::Vector{BigInt}, b::Vector{BigInt})
+   x = a[2]*b[2]
+   c = Vector{BigInt}(undef, 3)
+   c[1] = a[1]*b[1] + x
+   c[2] = a[1]*b[2] + a[2]*b[3]
+   c[3] = x + a[3]*b[3]
+   return c
+end
+
+function bigfib(n)
+    n == 0 && return BigInt(0)
+    n -= 1
+    r = [BigInt(1), BigInt(1), BigInt(0)]
+    s = [BigInt(1), BigInt(0), BigInt(1)]
+    while true
+       (n & 1) == 1 && (s = mul(s,r))
+       (n >>= 1) == 0 && return s[1]
+       r = mul(r,r)
+    end
+end
+@test [bigfib(n) for n=0:10] == [0,1,1,2,3,5,8,13,21,34,55]
+
+let s, n = bigfib(1000001)
+    @test ndigits(n) == 208988
+    @test mod(n,big(10)^15) == 359244926937501
+    @test div(n,big(10)^208973) == 316047687386689
+
+    s = string(n)
+    @test length(s) == 208988
+    @test endswith(s, "359244926937501")
+    @test startswith(s, "316047687386689")
+end
+
+# serialization (#5133)
+let n = parse(BigInt, "359334085968622831041960188598043661065388726959079837"),
+    b = IOBuffer()
+    serialize(b, n)
+    seek(b, 0)
+    @test deserialize(b) == n
+end
+
+@testset "issue #5873" begin
+    @test ndigits(big(90)) == 2
+    @test ndigits(big(99)) == 2
+    ndigits_mismatch(n) = ndigits(n) != ndigits(BigInt(n))
+    @test !any(ndigits_mismatch, 8:9)
+    @test !any(ndigits_mismatch, 64:99)
+    @test !any(ndigits_mismatch, 512:999)
+    @test !any(ndigits_mismatch, 8192:9999)
+end
+# The following should not crash (#16579)
+ndigits(big(rand(Int)), base=rand(63:typemax(Int)))
+ndigits(big(rand(Int)), base=big(2)^rand(2:999))
+
+for x in big.([-20:20; rand(Int)])
+    for _base in -1:1
+        @test_throws DomainError ndigits(x, base=_base)
+    end
+end
+
+@test Base.ndigits0zpb(big(0), big(rand(2:100))) == 0
+
+# digits with BigInt bases (#16844)
+@test digits(big(2)^256, base = big(2)^128) == [0, 0, 1]
+
+@testset "conversion from float" begin
+    @test BigInt(2.0) == BigInt(2.0f0) == BigInt(big(2.0)) == 2
+    @test_throws InexactError convert(BigInt, 2.1)
+    @test_throws InexactError convert(BigInt, big(2.1))
+end
+@testset "issue #13367" begin
+    @test trunc(BigInt,2.1) == 2
+    @test round(BigInt,2.1) == 2
+    @test floor(BigInt,2.1) == 2
+    @test ceil(BigInt,2.1) == 3
+
+    @test trunc(BigInt,2.1f0) == 2
+    @test round(BigInt,2.1f0) == 2
+    @test floor(BigInt,2.1f0) == 2
+    @test ceil(BigInt,2.1f0) == 3
+
+    @test_throws InexactError trunc(BigInt,Inf)
+    @test_throws InexactError round(BigInt,Inf)
+    @test_throws InexactError floor(BigInt,Inf)
+    @test_throws InexactError ceil(BigInt,Inf)
+
+    @test string(big(3), base = 2) == "11"
+    @test string(big(9), base = 8) == "11"
+    @test string(-big(9), base = 8) == "-11"
+    @test string(big(12), base = 16) == "c"
+end
+@testset "Issue #18849" begin
+    # bin, oct, dec, hex should not call sizeof on BigInts
+    # when padding is desired
+    padding = 4
+    low = big(4)
+    high = big(2^20)
+    @test string(low, pad = padding, base = 2) == "0100"
+    @test string(low, pad = padding, base = 8) == "0004"
+    @test string(low, pad = padding, base = 10) == "0004"
+    @test string(low, pad = padding, base = 16) == "0004"
+
+    @test string(high, pad = padding, base = 2) == "100000000000000000000"
+    @test string(high, pad = padding, base = 8) == "4000000"
+    @test string(high, pad = padding, base = 10) == "1048576"
+    @test string(high, pad = padding, base = 16) == "100000"
+
+    @test string(-low, pad = padding, base = 2) == "-0100" # handle negative numbers correctly
+    @test string(-low, pad = padding, base = 8) == "-0004"
+    @test string(-low, pad = padding, base = 10) == "-0004"
+    @test string(-low, pad = padding, base = 16) == "-0004"
+
+    @test string(-high, pad = padding, base = 2) == "-100000000000000000000"
+    @test string(-high, pad = padding, base = 8) == "-4000000"
+    @test string(-high, pad = padding, base = 10) == "-1048576"
+    @test string(-high, pad = padding, base = 16) == "-100000"
+end
+
+# respect 0-padding on big(0)
+for base in (2, 8, 10, 16)
+    local base
+    @test string(big(0), base=base, pad=0) == ""
+end
+@test string(big(0), base = rand(2:62), pad = 0) == ""
+
+@test isqrt(big(4)) == 2
+@test isqrt(big(5)) == 2
+
+@test big(5)^true == big(5)
+@test big(5)^false == one(BigInt)
+
+@testset "math ops returning BigFloat" begin
+    # operations that when applied to Int64 give Float64, should give BigFloat
+    @test typeof(exp(a)) == BigFloat
+    @test typeof(exp2(a)) == BigFloat
+    @test typeof(exp10(a)) == BigFloat
+    @test typeof(expm1(a)) == BigFloat
+    @test typeof(cosh(a)) == BigFloat
+    @test typeof(sinh(a)) == BigFloat
+    @test typeof(tanh(a)) == BigFloat
+    @test typeof(sech(a)) == BigFloat
+    @test typeof(csch(a)) == BigFloat
+    @test typeof(coth(a)) == BigFloat
+    @test typeof(cbrt(a)) == BigFloat
+    @test typeof(tan(a)) == BigFloat
+    @test typeof(cos(a)) == BigFloat
+    @test typeof(sin(a)) == BigFloat
+end
+
+# Issue #24298
+@test mod(BigInt(6), UInt(5)) == mod(6, 5)
+
+@testset "cmp has values in [-1, 0, 1], issue #28780" begin
+    # _rand produces values whose log2 is better distributed than rand
+    _rand(::Type{BigInt}, n=1000) = let x = big(2)^rand(1:rand(1:n))
+        rand(-x:x)
+    end
+    _rand(F::Type{<:AbstractFloat}) = F(_rand(BigInt, round(Int, log2(floatmax(F))))) + rand(F)
+    _rand(T) = rand(T)
+    for T in (Base.BitInteger_types..., BigInt, Float64, Float32, Float16)
+        @test cmp(big(2)^130, one(T)) === 1
+        @test cmp(-big(2)^130, one(T)) === -1
+        c = cmp(_rand(BigInt), _rand(T))
+        @test c ∈ (-1, 0, 1)
+        @test c isa Int
+        (T <: Integer && T !== BigInt) || continue
+        x = rand(T)
+        @test cmp(big(2)^130, x) === cmp(x, -big(2)^130) === 1
+        @test cmp(-big(2)^130, x) === cmp(x, big(2)^130) === -1
+        @test cmp(big(x), x) === cmp(x, big(x)) === 0
+    end
+    c = cmp(_rand(BigInt), _rand(BigInt))
+    @test c ∈ (-1, 0, 1)
+    @test c isa Int
+end
+
+@testset "generic conversion from Integer" begin
+    x = rand(Int128)
+    @test BigInt(x) % Int128 === x
+    y = rand(UInt128)
+    @test BigInt(y) % UInt128 === y
+end
+
+@testset "conversion from typemin(T)" begin
+    @test big(Int8(-128)) == big"-128"
+    @test big(Int16(-32768)) == big"-32768"
+    @test big(Int32(-2147483648)) == big"-2147483648"
+    @test big(Int64(-9223372036854775808)) == big"-9223372036854775808"
+    @test big(Int128(-170141183460469231731687303715884105728)) == big"-170141183460469231731687303715884105728"
+end
+
+@testset "conversion to Float" begin
+    x = big"2"^256 + big"2"^(256-53) + 1
+    @test Float64(x) == reinterpret(Float64, 0x4ff0000000000001)
+    @test Float64(-x) == -Float64(x)
+    x = (x >> 1) + 1
+    @test Float64(x) == reinterpret(Float64, 0x4fe0000000000001)
+    @test Float64(-x) == -Float64(x)
+
+    x = big"2"^64 + big"2"^(64-24) + 1
+    @test Float32(x) == reinterpret(Float32, 0x5f800001)
+    @test Float32(-x) == -Float32(x)
+    x = (x >> 1) + 1
+    @test Float32(x) == reinterpret(Float32, 0x5f000001)
+    @test Float32(-x) == -Float32(x)
+
+    x = big"2"^15 + big"2"^(15-11) + 1
+    @test Float16(x) == reinterpret(Float16, 0x7801)
+    @test Float16(-x) == -Float16(x)
+    x = (x >> 1) + 1
+    @test Float16(x) == reinterpret(Float16, 0x7401)
+    @test Float16(-x) == -Float16(x)
+
+    for T in (Float16, Float32, Float64)
+        n = exponent(floatmax(T))
+        @test T(big"2"^(n+1)) === T(Inf)
+        @test T(big"2"^(n+1) - big"2"^(n-precision(T))) === T(Inf)
+        @test T(big"2"^(n+1) - big"2"^(n-precision(T)) - 1) === floatmax(T)
+    end
+end
diff -pruN 1.3.1+dfsg-1/test/intfuncs.jl 1.4.0+dfsg-1/test/intfuncs.jl
--- 1.3.1+dfsg-1/test/intfuncs.jl	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/test/intfuncs.jl	2020-03-21 16:36:32.000000000 +0000
@@ -68,6 +68,17 @@ end
     @test gcdx(5, -12) == (1, 5, 2)
     @test gcdx(-25, -4) == (1, -1, 6)
 end
+@testset "gcd/lcm/gcdx for custom types" begin
+    struct MyRational <: Real
+        val::Rational{Int}
+    end
+    Base.promote_rule(::Type{MyRational}, T::Type{<:Real}) = promote_type(Rational{Int}, T)
+    (T::Type{<:Real})(x::MyRational) = T(x.val)
+
+    @test gcd(MyRational(2//3), 3) == gcd(2//3, 3) == gcd(Real[MyRational(2//3), 3])
+    @test lcm(MyRational(2//3), 3) == lcm(2//3, 3) == lcm(Real[MyRational(2//3), 3])
+    @test gcdx(MyRational(2//3), 3) == gcdx(2//3, 3)
+end
 @testset "invmod" begin
     @test invmod(6, 31) === 26
     @test invmod(-1, 3) === 2
diff -pruN 1.3.1+dfsg-1/test/int.jl 1.4.0+dfsg-1/test/int.jl
--- 1.3.1+dfsg-1/test/int.jl	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/test/int.jl	2020-03-21 16:36:32.000000000 +0000
@@ -305,3 +305,50 @@ let i = MyInt26779(1)
     @test_throws MethodError i << 1
     @test_throws MethodError i >>> 1
 end
+
+@testset "rounding division" begin
+    for x = -100:100
+        for y = 1:100
+            for rnd in (RoundNearest, RoundNearestTiesAway, RoundNearestTiesUp)
+                @test div(x,y,rnd) == round(x/y,rnd)
+                @test div(x,-y,rnd) == round(x/-y,rnd)
+            end
+        end
+    end
+    for (a, b, nearest, away, up) in (
+            (3, 2, 2, 2, 2),
+            (5, 3, 2, 2, 2),
+            (-3, 2, -2, -2, -1),
+            (5, 2, 2, 3, 3),
+            (-5, 2, -2, -3, -2),
+            (-5, 3, -2, -2, -2),
+            (5, -3, -2, -2, -2))
+        for sign in (+1, -1)
+            (a, b) = (a*sign, b*sign)
+            @test div(a, b, RoundNearest) == nearest
+            @test div(a, b, RoundNearestTiesAway) == away
+            @test div(a, b, RoundNearestTiesUp) == up
+        end
+    end
+
+    @test div(typemax(Int64), typemax(Int64)-1, RoundNearest) == 1
+    @test div(-typemax(Int64), typemax(Int64)-1, RoundNearest) == -1
+    @test div(typemax(Int64), 2, RoundNearest) == 4611686018427387904
+    @test div(-typemax(Int64), 2, RoundNearestTiesUp) == -4611686018427387903
+    @test div(typemax(Int)-2, typemax(Int), RoundNearest) == 1
+
+    # Exhaustively test (U)Int8 to catch any overflow-style issues
+    for r in (RoundNearest, RoundNearestTiesAway, RoundNearestTiesUp)
+        for T in (UInt8, Int8)
+            for x in typemin(T):typemax(T)
+                for y in typemin(T):typemax(T)
+                    if y == 0 || (T <: Signed && x == typemin(T) && y == -1)
+                        @test_throws DivideError div(x, y, r)
+                    else
+                        @test div(x, y, r) == T(div(widen(T)(x), widen(T)(y), r))
+                    end
+                end
+            end
+        end
+    end
+end
diff -pruN 1.3.1+dfsg-1/test/iterators.jl 1.4.0+dfsg-1/test/iterators.jl
--- 1.3.1+dfsg-1/test/iterators.jl	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/test/iterators.jl	2020-03-21 16:36:32.000000000 +0000
@@ -149,6 +149,29 @@ for xs in Any["abc", [1, 2, 3]]
     @test take(drop(take(xs, 3), 1), 1) === take(drop(xs, 1), 1)
 end
 
+# takewhile
+# --------
+@testset begin
+    @test collect(takewhile(<(4),1:10)) == [1,2,3]
+    @test collect(takewhile(<(4),Iterators.countfrom(1))) == [1,2,3]
+    @test collect(takewhile(<(4),5:10)) == []
+    @test collect(takewhile(_->true,5:10)) == 5:10
+    @test collect(takewhile(isodd,[1,1,2,3])) == [1,1]
+    @test collect(takewhile(<(2), takewhile(<(3), [1,1,2,3]))) == [1,1]
+end
+
+# dropwhile
+# --------
+@testset begin
+    @test collect(dropwhile(<(4), 1:10)) == 4:10
+    @test collect(dropwhile(<(4), 1:10)) isa Vector{Int}
+    @test isempty(dropwhile(<(4), []))
+    @test collect(dropwhile(_->false,1:3)) == 1:3
+    @test isempty(dropwhile(_->true, 1:3))
+    @test collect(dropwhile(isodd,[1,1,2,3])) == [2,3]
+    @test collect(dropwhile(iseven,dropwhile(isodd,[1,1,2,3]))) == [3]
+end
+
 # cycle
 # -----
 let i = 0
@@ -183,7 +206,6 @@ end
 @test Base.IteratorEltype(repeated(0, 5)) == Base.HasEltype()
 @test Base.IteratorSize(zip(repeated(0), repeated(0))) == Base.IsInfinite()
 
-
 # product
 # -------
 
@@ -411,6 +433,84 @@ for n in [5,6]
           [(1,1),(2,2),(3,3),(4,4),(5,5)]
 end
 
+function iterate_length(iter)
+    n=0
+    for i in iter
+        n += 1
+    end
+    return n
+end
+function simd_iterate_length(iter)
+    n=0
+    @simd for i in iter
+        n += 1
+    end
+    return n
+end
+function simd_trip_count(iter)
+    return sum(Base.SimdLoop.simd_inner_length(iter, i) for i in Base.SimdLoop.simd_outer_range(iter))
+end
+function iterate_elements(iter)
+    vals = Vector{eltype(iter)}(undef, length(iter))
+    i = 1
+    for v in iter
+        @inbounds vals[i] = v
+        i += 1
+    end
+    return vals
+end
+function simd_iterate_elements(iter)
+    vals = Vector{eltype(iter)}(undef, length(iter))
+    i = 1
+    @simd for v in iter
+        @inbounds vals[i] = v
+        i += 1
+    end
+    return vals
+end
+function index_elements(iter)
+    vals = Vector{eltype(iter)}(undef, length(iter))
+    i = 1
+    for j in eachindex(iter)
+        @inbounds vals[i] = iter[j]
+        i += 1
+    end
+    return vals
+end
+
+@testset "CartesianPartition optimizations" for dims in ((1,), (64,), (101,),
+                                                         (1,1), (8,8), (11, 13),
+                                                         (1,1,1), (8, 4, 2), (11, 13, 17)),
+                                                part in (1, 7, 8, 11, 63, 64, 65, 142, 143, 144)
+    P = partition(CartesianIndices(dims), part)
+    for I in P
+        @test length(I) == iterate_length(I) == simd_iterate_length(I) == simd_trip_count(I)
+        @test collect(I) == iterate_elements(I) == simd_iterate_elements(I) == index_elements(I)
+    end
+    @test all(Base.splat(==), zip(Iterators.flatten(map(collect, P)), CartesianIndices(dims)))
+end
+@testset "empty/invalid partitions" begin
+    @test_throws ArgumentError partition(1:10, 0)
+    @test_throws ArgumentError partition(1:10, -1)
+    @test_throws ArgumentError partition(1:0, 0)
+    @test_throws ArgumentError partition(1:0, -1)
+    @test isempty(partition(1:0, 1))
+    @test isempty(partition(CartesianIndices((0,1)), 1))
+end
+@testset "exact partition eltypes" for a in (Base.OneTo(24), 1:24, 1:1:24, LinRange(1,10,24), .1:.1:2.4, Vector(1:24),
+                                             CartesianIndices((4, 6)), Dict((1:24) .=> (1:24)))
+    P = partition(a, 2)
+    @test eltype(P) === typeof(first(P))
+    @test Iterators.IteratorEltype(P) == Iterators.HasEltype()
+    if a isa AbstractArray
+        P = partition(vec(a), 2)
+        @test eltype(P) === typeof(first(P))
+        P = partition(reshape(a, 6, 4), 2)
+        @test eltype(P) === typeof(first(P))
+        P = partition(reshape(a, 2, 3, 4), 2)
+        @test eltype(P) === typeof(first(P))
+    end
+end
 
 @test join(map(x->string(x...), partition("Hello World!", 5)), "|") ==
       "Hello| Worl|d!"
@@ -647,3 +747,52 @@ end
     @test length(collect(d)) == 2
     @test length(collect(d)) == 0
 end
+
+@testset "only" begin
+    @test only([3]) === 3
+    @test_throws ArgumentError only([])
+    @test_throws ArgumentError only([3, 2])
+
+    @test @inferred(only((3,))) === 3
+    @test_throws ArgumentError only(())
+    @test_throws ArgumentError only((3, 2))
+
+    @test only(Dict(1=>3)) === (1=>3)
+    @test_throws ArgumentError only(Dict{Int,Int}())
+    @test_throws ArgumentError only(Dict(1=>3, 2=>2))
+
+    @test only(Set([3])) === 3
+    @test_throws ArgumentError only(Set(Int[]))
+    @test_throws ArgumentError only(Set([3,2]))
+
+    @test @inferred(only((;a=1))) === 1
+    @test_throws ArgumentError only(NamedTuple())
+    @test_throws ArgumentError only((a=3, b=2.0))
+
+    @test @inferred(only(1)) === 1
+    @test @inferred(only('a')) === 'a'
+    @test @inferred(only(Ref([1, 2]))) == [1, 2]
+    @test_throws ArgumentError only(Pair(10, 20))
+
+    @test only(1 for ii in 1:1) === 1
+    @test only(1 for ii in 1:10 if ii < 2) === 1
+    @test_throws ArgumentError only(1 for ii in 1:10)
+    @test_throws ArgumentError only(1 for ii in 1:10 if ii > 2)
+    @test_throws ArgumentError only(1 for ii in 1:10 if ii > 200)
+end
+
+@testset "flatten empty tuple" begin
+    @test isempty(collect(Iterators.flatten(())))
+end
+
+@testset "Iterators.accumulate" begin
+    @test collect(Iterators.accumulate(+, [])) == []
+    @test collect(Iterators.accumulate(+, [1])) == [1]
+    @test collect(Iterators.accumulate(+, [1,2])) == [1,3]
+    @test collect(Iterators.accumulate(+, [1,2,3])) == [1,3,6]
+    @test collect(Iterators.accumulate(=>, [:a,:b,:c])) == [:a, :a => :b, (:a => :b) => :c]
+    @test length(Iterators.accumulate(+, [10,20,30])) == 3
+    @test size(Iterators.accumulate(max, rand(2,3))) == (2,3)
+    @test Base.IteratorSize(Iterators.accumulate(max, rand(2,3))) === Base.IteratorSize(rand(2,3))
+    @test Base.IteratorEltype(Iterators.accumulate(*, ())) isa Base.EltypeUnknown
+end
diff -pruN 1.3.1+dfsg-1/test/keywordargs.jl 1.4.0+dfsg-1/test/keywordargs.jl
--- 1.3.1+dfsg-1/test/keywordargs.jl	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/test/keywordargs.jl	2020-03-21 16:36:32.000000000 +0000
@@ -353,3 +353,11 @@ function g32074(i::Int32; args...)
     hook(i; args...)
 end
 @test isempty(g32074(Int32(1)))
+
+# issue #33026
+using InteractiveUtils
+@test (@which kwf1(1, tens=2)).line > 0
+
+no_kw_args(x::Int) = 0
+@test_throws MethodError no_kw_args(1, k=1)
+@test_throws MethodError no_kw_args("", k=1)
diff -pruN 1.3.1+dfsg-1/test/llvmpasses/fastmath.jl 1.4.0+dfsg-1/test/llvmpasses/fastmath.jl
--- 1.3.1+dfsg-1/test/llvmpasses/fastmath.jl	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/test/llvmpasses/fastmath.jl	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1,18 @@
+# This file is a part of Julia. License is MIT: https://julialang.org/license
+
+# RUN: julia --startup-file=no %s %t && llvm-link -S %t/* -o %t/module.ll
+# RUN: cat %t/module.ll | FileCheck %s
+
+## Notes:
+# This script uses the `emit` function (defined llvmpasses.jl) to emit either
+# optimized or unoptimized LLVM IR. Each function is emitted individually and
+# `llvm-link` is used to create a single module that can be passed to opt.
+# The order in which files are emitted and linked is important since `lit` will
+# process the test cases in order.
+
+include(joinpath("..", "testhelpers", "llvmpasses.jl"))
+
+import Base.FastMath
+
+# CHECK: call fast float @llvm.sqrt.f32(float %0)
+emit(FastMath.sqrt_fast, Float32)
diff -pruN 1.3.1+dfsg-1/test/llvmpasses/final-lower-gc.ll 1.4.0+dfsg-1/test/llvmpasses/final-lower-gc.ll
--- 1.3.1+dfsg-1/test/llvmpasses/final-lower-gc.ll	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/test/llvmpasses/final-lower-gc.ll	2020-03-21 16:36:32.000000000 +0000
@@ -24,15 +24,15 @@ top:
   %gcframe = call %jl_value_t addrspace(10)** @julia.new_gc_frame(i32 2)
 ; CHECK: %ptls = call %jl_value_t*** @julia.ptls_states()
   %ptls = call %jl_value_t*** @julia.ptls_states()
-; CHECK-NEXT: [[GCFRAME_SIZE_PTR:%.*]] = getelementptr %jl_value_t addrspace(10)*, %jl_value_t addrspace(10)** %gcframe, i32 0
-; CHECK-NEXT: [[GCFRAME_SIZE_PTR2:%.*]] = bitcast %jl_value_t addrspace(10)** [[GCFRAME_SIZE_PTR]] to i64*
-; CHECK-NEXT: store i64 4, i64* [[GCFRAME_SIZE_PTR2]], !tbaa !0
-; CHECK-NEXT: [[GCFRAME_SLOT:%.*]] = getelementptr %jl_value_t**, %jl_value_t*** %ptls, i32 0
-; CHECK-NEXT: [[PREV_GCFRAME_PTR:%.*]] = getelementptr %jl_value_t addrspace(10)*, %jl_value_t addrspace(10)** %gcframe, i32 1
-; CHECK-NEXT: [[PREV_GCFRAME_PTR2:%.*]] = bitcast %jl_value_t addrspace(10)** [[PREV_GCFRAME_PTR]] to %jl_value_t***
-; CHECK-NEXT: [[PREV_GCFRAME:%.*]] = load %jl_value_t**, %jl_value_t*** [[GCFRAME_SLOT]]
-; CHECK-NEXT: store %jl_value_t** [[PREV_GCFRAME]], %jl_value_t*** [[PREV_GCFRAME_PTR2]], !tbaa !0
-; CHECK-NEXT: [[GCFRAME_SLOT2:%.*]] = bitcast %jl_value_t*** [[GCFRAME_SLOT]] to %jl_value_t addrspace(10)***
+; CHECK-DAG: [[GCFRAME_SIZE_PTR:%.*]] = getelementptr %jl_value_t addrspace(10)*, %jl_value_t addrspace(10)** %gcframe, i32 0
+; CHECK-DAG: [[GCFRAME_SIZE_PTR2:%.*]] = bitcast %jl_value_t addrspace(10)** [[GCFRAME_SIZE_PTR]] to i64*
+; CHECK-DAG: store i64 8, i64* [[GCFRAME_SIZE_PTR2]], !tbaa !0
+; CHECK-DAG: [[GCFRAME_SLOT:%.*]] = getelementptr %jl_value_t**, %jl_value_t*** %ptls, i32 0
+; CHECK-DAG: [[PREV_GCFRAME_PTR:%.*]] = getelementptr %jl_value_t addrspace(10)*, %jl_value_t addrspace(10)** %gcframe, i32 1
+; CHECK-DAG: [[PREV_GCFRAME_PTR2:%.*]] = bitcast %jl_value_t addrspace(10)** [[PREV_GCFRAME_PTR]] to %jl_value_t***
+; CHECK-DAG: [[PREV_GCFRAME:%.*]] = load %jl_value_t**, %jl_value_t*** [[GCFRAME_SLOT]]
+; CHECK-DAG: store %jl_value_t** [[PREV_GCFRAME]], %jl_value_t*** [[PREV_GCFRAME_PTR2]], !tbaa !0
+; CHECK-DAG: [[GCFRAME_SLOT2:%.*]] = bitcast %jl_value_t*** [[GCFRAME_SLOT]] to %jl_value_t addrspace(10)***
 ; CHECK-NEXT: store %jl_value_t addrspace(10)** %gcframe, %jl_value_t addrspace(10)*** [[GCFRAME_SLOT2]]
   call void @julia.push_gc_frame(%jl_value_t addrspace(10)** %gcframe, i32 2)
   %aboxed = call %jl_value_t addrspace(10)* @jl_box_int64(i64 signext %a)
diff -pruN 1.3.1+dfsg-1/test/llvmpasses/fmf.jl 1.4.0+dfsg-1/test/llvmpasses/fmf.jl
--- 1.3.1+dfsg-1/test/llvmpasses/fmf.jl	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/test/llvmpasses/fmf.jl	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1,28 @@
+# This file is a part of Julia. License is MIT: https://julialang.org/license
+# REQUIRES: x86_64
+# RUN: julia --startup-file=no %s %t -O && llvm-link -S %t/* -o %t/module.ll
+# RUN: cat %t/module.ll | llc - -mtriple=x86_64-- -mattr=fma | FileCheck %s
+
+## Notes:
+# This script uses the `emit` function (defined llvmpasses.jl) to emit either
+# optimized or unoptimized LLVM IR. Each function is emitted individually and
+# `llvm-link` is used to create a single module that can be passed to opt.
+# The order in which files are emitted and linked is important since `lit` will
+# process the test cases in order.
+
+include(joinpath("..", "testhelpers", "llvmpasses.jl"))
+
+# CHECK-LABEL: julia_dotf_
+function dotf(a, b)
+    s = 0.0
+    @inbounds @simd for i ∈ eachindex(a)
+# CHECK:    vfmadd231pd
+# CHECK-NEXT:    vfmadd231pd
+# CHECK-NEXT:    vfmadd231pd
+# CHECK-NEXT:    vfmadd231pd
+        s += a[i] * b[i]
+    end
+    s
+end
+
+emit(dotf, Vector{Float64}, Vector{Float64})
diff -pruN 1.3.1+dfsg-1/test/llvmpasses/gcroots.ll 1.4.0+dfsg-1/test/llvmpasses/gcroots.ll
--- 1.3.1+dfsg-1/test/llvmpasses/gcroots.ll	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/test/llvmpasses/gcroots.ll	2020-03-21 16:36:32.000000000 +0000
@@ -112,6 +112,7 @@ define void @select_lift(i64 %a, i64 %b)
 define void @phi_lift(i64 %a, i64 %b) {
 top:
 ; CHECK-LABEL: @phi_lift
+; CHECK: %gclift = phi %jl_value_t addrspace(10)* [ %aboxed, %alabel ], [ %bboxed, %blabel ], [ %gclift, %common ]
     %ptls = call %jl_value_t*** @julia.ptls_states()
     %cmp = icmp eq i64 %a, %b
     br i1 %cmp, label %alabel, label %blabel
@@ -124,11 +125,12 @@ blabel:
     %bdecayed = addrspacecast %jl_value_t addrspace(10)* %bboxed to i64 addrspace(12)*
     br label %common
 common:
-    %phi = phi i64 addrspace(12)* [ %adecayed, %alabel ], [ %bdecayed, %blabel ]
+    %phi = phi i64 addrspace(12)* [ %adecayed, %alabel ], [ %bdecayed, %blabel ], [ %phi, %common ]
     call void @one_arg_decayed(i64 addrspace(12)* %phi)
-    ret void
+    br label %common
 }
 
+
 define void @phi_lift_union(i64 %a, i64 %b) {
 top:
 ; CHECK-LABEL: @phi_lift_union
@@ -140,15 +142,14 @@ alabel:
 ; CHECK: %aboxed = extractvalue { %jl_value_t addrspace(10)*, i8 } %u, 0
     %aboxed = extractvalue { %jl_value_t addrspace(10)*, i8 } %u, 0
     %adecayed = addrspacecast %jl_value_t addrspace(10)* %aboxed to i64 addrspace(12)*
-; CHECK: extractvalue { %jl_value_t addrspace(10)*, i8 } %u, 0
-; CHECK-NEXT: br label %common
+; CHECK: br label %common
     br label %common
 blabel:
     %bboxed = call %jl_value_t addrspace(10)* @jl_box_int64(i64 signext %b)
     %bdecayed = addrspacecast %jl_value_t addrspace(10)* %bboxed to i64 addrspace(12)*
     br label %common
 common:
-; CHECK: %gclift = phi %jl_value_t addrspace(10)* [ %{{.*}}, %alabel ], [ %bboxed, %blabel ]
+; CHECK: %gclift = phi %jl_value_t addrspace(10)* [ %aboxed, %alabel ], [ %bboxed, %blabel ]
     %phi = phi i64 addrspace(12)* [ %adecayed, %alabel ], [ %bdecayed, %blabel ]
     call void @one_arg_decayed(i64 addrspace(12)* %phi)
     ret void
@@ -182,6 +183,21 @@ define %jl_value_t addrspace(10)* @ret_u
     ret %jl_value_t addrspace(10)* %aboxed
 }
 
+define {%jl_value_t addrspace(10)*, i8} @ret_use_struct() {
+; CHECK-LABEL: @ret_use_struct
+; CHECK: %gcframe = alloca %jl_value_t addrspace(10)*, i32 3
+    %ptls = call %jl_value_t*** @julia.ptls_states()
+; CHECK: %aunion = call { %jl_value_t addrspace(10)*, i8 } @union_ret()
+    %aunion = call { %jl_value_t addrspace(10)*, i8 } @union_ret()
+; CHECK-DAG: [[GEP0:%.*]] = getelementptr %jl_value_t addrspace(10)*, %jl_value_t addrspace(10)** %gcframe, i32 [[GEPSLOT0:[0-9]+]]
+; CHECK-DAG: [[EXTRACT:%.*]] = extractvalue { %jl_value_t addrspace(10)*, i8 } %aunion, 0
+; CHECK-NEXT: store %jl_value_t addrspace(10)* [[EXTRACT]], %jl_value_t addrspace(10)** [[GEP0]]
+; CHECK-NEXT: call void @jl_safepoint()
+    call void @jl_safepoint()
+    ret {%jl_value_t addrspace(10)*, i8} %aunion
+}
+
+
 define i8 @nosafepoint(%jl_value_t addrspace(10)* dereferenceable(16)) {
 ; CHECK-LABEL: @nosafepoint
 ; CHECK-NOT: %gcframe
@@ -314,6 +330,19 @@ define %jl_value_t addrspace(10)* @vec_l
   ret %jl_value_t addrspace(10)* %v7
 }
 
+define %jl_value_t addrspace(10)* @vec_gep() {
+; CHECK-LABEL: @vec_gep
+; CHECK: %gcframe = alloca %jl_value_t addrspace(10)*, i32 3
+  %v4 = call %jl_value_t*** @julia.ptls_states()
+  %obj = call %jl_value_t addrspace(10) *@alloc()
+  %obj1 = bitcast %jl_value_t addrspace(10) * %obj to %jl_value_t addrspace(10)* addrspace(10)*
+  %v1 = getelementptr %jl_value_t addrspace(10)*, %jl_value_t addrspace(10)* addrspace(10)* %obj1, <2 x i32> < i32 0, i32 0 >
+  call void @jl_safepoint()
+  %obj2 = extractelement <2 x %jl_value_t addrspace(10)* addrspace(10)*> %v1, i32 0
+  %obj3 = bitcast %jl_value_t addrspace(10)* addrspace(10)* %obj2 to %jl_value_t addrspace(10)*
+  ret %jl_value_t addrspace(10)* %obj3
+}
+
 declare i1 @check_property(%jl_value_t addrspace(10)* %val)
 define void @loopyness(i1 %cond1, %jl_value_t addrspace(10) *%arg) {
 ; CHECK-LABEL: @loopyness
@@ -484,7 +513,7 @@ top:
     %ptls = call %jl_value_t*** @julia.ptls_states()
     %loaded = load <2 x %jl_value_t addrspace(10)*>, <2 x %jl_value_t addrspace(10)*> *%arg
     call void @jl_safepoint()
-    %select = select i1 %cond, <2 x %jl_value_t addrspace(10)*> zeroinitializer, <2 x %jl_value_t addrspace(10)*>  %loaded
+    %select = select i1 %cond, <2 x %jl_value_t addrspace(10)*> zeroinitializer, <2 x %jl_value_t addrspace(10)*> %loaded
     call void @jl_safepoint()
     %el1 = extractelement <2 x %jl_value_t addrspace(10)*> %select, i32 0
     %el2 = extractelement <2 x %jl_value_t addrspace(10)*> %select, i32 1
@@ -493,6 +522,76 @@ top:
     unreachable
 }
 
+define void @vecselect_lift(i1 %cond, <2 x %jl_value_t addrspace(10)*> *%arg) {
+; CHECK-LABEL: @vecselect_lift
+; CHECK: %gcframe = alloca %jl_value_t addrspace(10)*, i32 4
+    %ptls = call %jl_value_t*** @julia.ptls_states()
+    %loaded = load <2 x %jl_value_t addrspace(10)*>, <2 x %jl_value_t addrspace(10)*> *%arg
+    %decayed = addrspacecast <2 x %jl_value_t addrspace(10)*> %loaded to <2 x i64 addrspace(12)*>
+    call void @jl_safepoint()
+; CHECK: %gclift = select i1 %cond, %jl_value_t addrspace(10)* null, %jl_value_t addrspace(10)* %{{[0-9]+}}
+    %select = select i1 %cond, <2 x i64 addrspace(12)*> zeroinitializer, <2 x i64 addrspace(12)*> %decayed
+    call void @jl_safepoint()
+    %el1 = extractelement <2 x i64 addrspace(12)*> %select, i32 0
+    %el2 = extractelement <2 x i64 addrspace(12)*> %select, i32 1
+    call void @one_arg_decayed(i64 addrspace(12)* %el1)
+    call void @one_arg_decayed(i64 addrspace(12)* %el2)
+    unreachable
+}
+
+define void @vecvecselect_lift(<2 x i1> %cond, <2 x %jl_value_t addrspace(10)*> *%arg) {
+; CHECK-LABEL: @vecvecselect_lift
+; CHECK: %gcframe = alloca %jl_value_t addrspace(10)*, i32 4
+    %ptls = call %jl_value_t*** @julia.ptls_states()
+    %loaded = load <2 x %jl_value_t addrspace(10)*>, <2 x %jl_value_t addrspace(10)*> *%arg
+    %decayed = addrspacecast <2 x %jl_value_t addrspace(10)*> %loaded to <2 x i64 addrspace(12)*>
+    call void @jl_safepoint()
+; CHECK: %gclift = select i1 %{{[0-9]+}}, %jl_value_t addrspace(10)* null, %jl_value_t addrspace(10)* %{{[0-9]+}}
+    %select = select <2 x i1> %cond, <2 x i64 addrspace(12)*> zeroinitializer, <2 x i64 addrspace(12)*> %decayed
+    call void @jl_safepoint()
+    %el1 = extractelement <2 x i64 addrspace(12)*> %select, i32 0
+    %el2 = extractelement <2 x i64 addrspace(12)*> %select, i32 1
+    call void @one_arg_decayed(i64 addrspace(12)* %el1)
+    call void @one_arg_decayed(i64 addrspace(12)* %el2)
+    unreachable
+}
+
+define void @vecscalarselect_lift(<2 x i1> %cond, i64 %a) {
+; CHECK-LABEL: @vecscalarselect_lift
+; CHECK: %gcframe = alloca %jl_value_t addrspace(10)*, i32 4
+    %ptls = call %jl_value_t*** @julia.ptls_states()
+    %aboxed = call %jl_value_t addrspace(10)* @jl_box_int64(i64 signext %a)
+    %adecayed = addrspacecast %jl_value_t addrspace(10)* %aboxed to i64 addrspace(12)*
+    %avec = getelementptr i64, i64 addrspace(12)*  %adecayed, <2 x i32> zeroinitializer
+    call void @jl_safepoint()
+; CHECK: %gclift = select i1 %{{[0-9]+}}, %jl_value_t addrspace(10)* null, %jl_value_t addrspace(10)* %aboxed
+    %select = select <2 x i1> %cond, <2 x i64 addrspace(12)*> zeroinitializer, <2 x i64 addrspace(12)*> %avec
+    call void @jl_safepoint()
+    %el1 = extractelement <2 x i64 addrspace(12)*> %select, i32 0
+    %el2 = extractelement <2 x i64 addrspace(12)*> %select, i32 1
+    call void @one_arg_decayed(i64 addrspace(12)* %el1)
+    call void @one_arg_decayed(i64 addrspace(12)* %el2)
+    unreachable
+}
+
+define void @scalarvecselect_lift(i1 %cond, i64 %a) {
+; CHECK-LABEL: @scalarvecselect_lift
+; CHECK: %gcframe = alloca %jl_value_t addrspace(10)*, i32 4
+    %ptls = call %jl_value_t*** @julia.ptls_states()
+    %aboxed = call %jl_value_t addrspace(10)* @jl_box_int64(i64 signext %a)
+    %adecayed = addrspacecast %jl_value_t addrspace(10)* %aboxed to i64 addrspace(12)*
+    %avec = getelementptr i64, i64 addrspace(12)*  %adecayed, <2 x i32> zeroinitializer
+    call void @jl_safepoint()
+; CHECK: %gclift = select i1 %cond, %jl_value_t addrspace(10)* null, %jl_value_t addrspace(10)* %aboxed
+    %select = select i1 %cond, <2 x i64 addrspace(12)*> zeroinitializer, <2 x i64 addrspace(12)*> %avec
+    call void @jl_safepoint()
+    %el1 = extractelement <2 x i64 addrspace(12)*> %select, i32 0
+    %el2 = extractelement <2 x i64 addrspace(12)*> %select, i32 1
+    call void @one_arg_decayed(i64 addrspace(12)* %el1)
+    call void @one_arg_decayed(i64 addrspace(12)* %el2)
+    unreachable
+}
+
 define i8 @select_arrayptr(i1 %cond) {
 ; CHECK-LABEL: @select_arrayptr
 ; CHECK: %gcframe = alloca %jl_value_t addrspace(10)*, i32 4
@@ -519,6 +618,67 @@ top:
     ret i8 %add
 }
 
+define i8 @vector_arrayptrs() {
+; CHECK-LABEL: @vector_arrayptrs
+; CHECK: %gcframe = alloca %jl_value_t addrspace(10)*, i32 3
+; CHECK: [[GEP0:%.*]] = getelementptr %jl_value_t addrspace(10)*, %jl_value_t addrspace(10)** %gcframe, i32 2
+; CHECK: store %jl_value_t addrspace(10)* %obj1, %jl_value_t addrspace(10)** [[GEP0]]
+;
+top:
+   %ptls = call %jl_value_t*** @julia.ptls_states()
+   %obj1 = call %jl_value_t addrspace(10) *@alloc()
+   %decayed = addrspacecast %jl_value_t addrspace(10) *%obj1 to %jl_value_t addrspace(11) *
+   %arrayptrptr = bitcast %jl_value_t addrspace(11) *%decayed to <2 x i8 addrspace(13)*> addrspace(11)*
+   %arrayptrs = load <2 x i8 addrspace(13)*>, <2 x i8 addrspace(13)*> addrspace(11)* %arrayptrptr, align 16
+   %arrayptr = extractelement <2 x i8 addrspace(13)*> %arrayptrs, i32 0
+   call void @jl_safepoint()
+   %val = load i8, i8 addrspace(13)* %arrayptr
+   ret i8 %val
+}
+
+declare <2 x i8 addrspace(13)*> @llvm.masked.load.v2p13i8.p11v2p13i8 (<2 x i8 addrspace(13)*> addrspace(11)*, i32, <2 x i1>, <2 x i8 addrspace(13)*>)
+
+define i8 @masked_arrayptrs() {
+; CHECK-LABEL: @masked_arrayptrs
+; CHECK: %gcframe = alloca %jl_value_t addrspace(10)*, i32 3
+; CHECK: %arrayptrs = call <2 x i8 addrspace(13)*> @llvm.masked.load.v2p13i8.p11v2p13i8(<2 x i8 addrspace(13)*> addrspace(11)* %arrayptrptr, i32 16, <2 x i1> <i1 true, i1 false>, <2 x i8 addrspace(13)*> zeroinitializer)
+; CHECK: [[GEP0:%.*]] = getelementptr %jl_value_t addrspace(10)*, %jl_value_t addrspace(10)** %gcframe, i32 2
+; CHECK: store %jl_value_t addrspace(10)* %obj1, %jl_value_t addrspace(10)** [[GEP0]]
+;
+top:
+   %ptls = call %jl_value_t*** @julia.ptls_states()
+   %obj1 = call %jl_value_t addrspace(10) *@alloc()
+   %decayed = addrspacecast %jl_value_t addrspace(10) *%obj1 to %jl_value_t addrspace(11) *
+   %arrayptrptr = bitcast %jl_value_t addrspace(11) *%decayed to <2 x i8 addrspace(13)*> addrspace(11)*
+   %arrayptrs = call <2 x i8 addrspace(13)*> @llvm.masked.load.v2p13i8.p11v2p13i8(<2 x i8 addrspace(13)*> addrspace(11)* %arrayptrptr, i32 16, <2 x i1> <i1 true, i1 false>, <2 x i8 addrspace(13)*> undef)
+   %arrayptr = extractelement <2 x i8 addrspace(13)*> %arrayptrs, i32 0
+   call void @jl_safepoint()
+   %val = load i8, i8 addrspace(13)* %arrayptr
+   ret i8 %val
+}
+
+declare <2 x i8 addrspace(13)*> @llvm.masked.gather.v2p13i8.v2p11p13i8 (<2 x i8 addrspace(13)* addrspace(11)*>, i32, <2 x i1>, <2 x i8 addrspace(13)*>)
+
+define i8 @gather_arrayptrs() {
+; CHECK-LABEL: @gather_arrayptrs
+; CHECK: %gcframe = alloca %jl_value_t addrspace(10)*, i32 3
+; CHECK: %arrayptrs = call <2 x i8 addrspace(13)*> @llvm.masked.gather.v2p13i8.v2p11p13i8(<2 x i8 addrspace(13)* addrspace(11)*> %arrayptrptrs, i32 16, <2 x i1> <i1 true, i1 false>, <2 x i8 addrspace(13)*> zeroinitializer)
+; CHECK: [[GEP0:%.*]] = getelementptr %jl_value_t addrspace(10)*, %jl_value_t addrspace(10)** %gcframe, i32 2
+; CHECK: store %jl_value_t addrspace(10)* %obj1, %jl_value_t addrspace(10)** [[GEP0]]
+;
+top:
+   %ptls = call %jl_value_t*** @julia.ptls_states()
+   %obj1 = call %jl_value_t addrspace(10) *@alloc()
+   %decayed = addrspacecast %jl_value_t addrspace(10) *%obj1 to %jl_value_t addrspace(11)*
+   %arrayptrptr = bitcast %jl_value_t addrspace(11) *%decayed to i8 addrspace(13)* addrspace(11)*
+   %arrayptrptrs = insertelement <2 x i8 addrspace(13)* addrspace(11)*> zeroinitializer, i8 addrspace(13)* addrspace(11)* %arrayptrptr, i32 0
+   %arrayptrs = call <2 x i8 addrspace(13)*> @llvm.masked.gather.v2p13i8.v2p11p13i8(<2 x i8 addrspace(13)* addrspace(11)*> %arrayptrptrs, i32 16, <2 x i1> <i1 true, i1 false>, <2 x i8 addrspace(13)*> undef)
+   %arrayptr = extractelement <2 x i8 addrspace(13)*> %arrayptrs, i32 0
+   call void @jl_safepoint()
+   %val = load i8, i8 addrspace(13)* %arrayptr
+   ret i8 %val
+}
+
 !0 = !{!"jtbaa"}
 !1 = !{!"jtbaa_const", !0, i64 0}
 !2 = !{!1, !1, i64 0, i64 1}
diff -pruN 1.3.1+dfsg-1/test/llvmpasses/lit.cfg 1.4.0+dfsg-1/test/llvmpasses/lit.cfg
--- 1.3.1+dfsg-1/test/llvmpasses/lit.cfg	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/test/llvmpasses/lit.cfg	1970-01-01 00:00:00.000000000 +0000
@@ -1,18 +0,0 @@
-import os
-import sys
-import re
-import platform
-
-import lit.util
-import lit.formats
-
-config.name = 'Julia'
-config.suffixes = ['.ll','.jl']
-config.test_source_root = os.path.dirname(__file__)
-config.test_format = lit.formats.ShTest(True)
-config.substitutions.append(('%shlibext', '.dylib' if platform.system() == 'Darwin' else '.dll' if
-    platform.system() == 'Windows' else '.so'))
-
-path = os.path.pathsep.join((os.path.join(os.path.dirname(__file__),"../../usr/tools"), os.path.join(os.path.dirname(__file__),"../../usr/bin"), config.environment['PATH']))
-config.environment['PATH'] = path
-config.environment['HOME'] = "/tmp"
diff -pruN 1.3.1+dfsg-1/test/llvmpasses/lit.cfg.py 1.4.0+dfsg-1/test/llvmpasses/lit.cfg.py
--- 1.3.1+dfsg-1/test/llvmpasses/lit.cfg.py	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/test/llvmpasses/lit.cfg.py	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1,21 @@
+import os
+import sys
+import re
+import platform
+
+import lit.util
+import lit.formats
+
+config.name = 'Julia'
+config.suffixes = ['.ll','.jl']
+config.test_source_root = os.path.dirname(__file__)
+config.test_format = lit.formats.ShTest(True)
+config.substitutions.append(('%shlibext', '.dylib' if platform.system() == 'Darwin' else '.dll' if
+    platform.system() == 'Windows' else '.so'))
+
+path = os.path.pathsep.join((os.path.join(os.path.dirname(__file__),"../../usr/tools"), os.path.join(os.path.dirname(__file__),"../../usr/bin"), config.environment['PATH']))
+config.environment['PATH'] = path
+config.environment['HOME'] = "/tmp"
+
+if platform.machine() == "x86_64":
+    config.available_features.add('x86_64')
diff -pruN 1.3.1+dfsg-1/test/llvmpasses/llvmcall.jl 1.4.0+dfsg-1/test/llvmpasses/llvmcall.jl
--- 1.3.1+dfsg-1/test/llvmpasses/llvmcall.jl	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/test/llvmpasses/llvmcall.jl	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1,21 @@
+# This file is a part of Julia. License is MIT: https://julialang.org/license
+
+# RUN: julia --startup-file=no %s %t
+# RUN: cat %t/* | FileCheck %s
+
+include(joinpath("..", "testhelpers", "llvmpasses.jl"))
+
+@generated foo(x)=:(ccall("extern foo", llvmcall, $x, ($x,), x))
+bar(x) = ntuple(i -> VecElement{Float16}(x[i]), 2)
+
+# CHECK: call half @foo(half zeroext %{{[0-9]+}})
+emit(foo, Float16)
+
+# CHECK: call [2 x half] @foo([2 x half] %{{[0-9]+}})
+emit(foo, NTuple{2, Float16})
+
+# CHECK: call <2 x half> @foo(<2 x half> %{{[0-9]+}})
+emit(foo, NTuple{2, VecElement{Float16}})
+
+# CHECK: define <2 x i16> @julia_bar_{{[0-9]+}}([2 x i16]
+emit(bar, NTuple{2, Float16})
diff -pruN 1.3.1+dfsg-1/test/llvmpasses/loopinfo.jl 1.4.0+dfsg-1/test/llvmpasses/loopinfo.jl
--- 1.3.1+dfsg-1/test/llvmpasses/loopinfo.jl	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/test/llvmpasses/loopinfo.jl	2020-03-21 16:36:32.000000000 +0000
@@ -73,8 +73,8 @@ end
 
 # Example from a GPU kernel where we want to unroll the outer loop
 # and the inner loop is a boundschecked single iteration loop.
-# The `@show` is used to bloat the loop and `FINAL-COUNT-10:` seems
-# not to be working so we duplicate the checks.
+# The `@show` is used to bloat the loop and `X-COUNT-10:` seems
+# not to be working so we duplicate the checks. FIXME LLVM8
 # CHECK-LABEL: @julia_loop_unroll2
 # LOWER-LABEL: @julia_loop_unroll2
 # FINAL-LABEL: @julia_loop_unroll2
diff -pruN 1.3.1+dfsg-1/test/llvmpasses/Makefile 1.4.0+dfsg-1/test/llvmpasses/Makefile
--- 1.3.1+dfsg-1/test/llvmpasses/Makefile	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/test/llvmpasses/Makefile	2020-03-21 16:36:32.000000000 +0000
@@ -1,8 +1,14 @@
 SRCDIR := $(abspath $(dir $(lastword $(MAKEFILE_LIST))))
 JULIAHOME := $(abspath $(SRCDIR)/../..)
 include $(JULIAHOME)/Make.inc
-test:
+
+check: $(SRCDIR)
+
+TESTS = $(patsubst $(SRCDIR)/%,%,$(wildcard $(SRCDIR)/*.jl $(SRCDIR)/*.ll))
+
+$(SRCDIR) $(TESTS):
 	PATH=$(build_bindir):$(build_depsbindir):$$PATH \
 	LD_LIBRARY_PATH=${build_libdir}:$$LD_LIBRARY_PATH \
-	$(build_depsbindir)/lit/lit.py -v $(SRCDIR)
-.PHONY: test
+	$(build_depsbindir)/lit/lit.py -v $@
+
+.PHONY: $(TESTS) $(SRCDIR) check all
diff -pruN 1.3.1+dfsg-1/test/loading.jl 1.4.0+dfsg-1/test/loading.jl
--- 1.3.1+dfsg-1/test/loading.jl	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/test/loading.jl	2020-03-21 16:36:32.000000000 +0000
@@ -282,6 +282,12 @@ module NotPkgModule; end
         @test pathof(NotPkgModule) === nothing
     end
 
+    @testset "pkgdir" begin
+        @test pkgdir(Foo) == normpath(abspath(@__DIR__, "project/deps/Foo1"))
+        @test pkgdir(Foo.SubFoo) == normpath(abspath(@__DIR__, "project/deps/Foo1"))
+        @test pkgdir(NotPkgModule) === nothing
+    end
+
 end
 
 ## systematic generation of test environments ##
diff -pruN 1.3.1+dfsg-1/test/logging.jl 1.4.0+dfsg-1/test/logging.jl
--- 1.3.1+dfsg-1/test/logging.jl	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/test/logging.jl	2020-03-21 16:36:32.000000000 +0000
@@ -5,7 +5,7 @@ import Base.CoreLogging: BelowMinLevel,
     handle_message, shouldlog, min_enabled_level, catch_exceptions
 
 import Test: collect_test_logs, TestLogger
-using Base.Printf: @sprintf
+using Printf: @sprintf
 
 isdefined(Main, :MacroCalls) || @eval Main include("testhelpers/MacroCalls.jl")
 using Main.MacroCalls
@@ -178,20 +178,52 @@ end
         logger = TestLogger()
         with_logger(logger) do
             for (e, r) in (("", false),
-                           (",,,,", false),
-                           ("al", false),
-                           ("all", true),
-                           ("a,b,all,c", true),
-                           ("a,b,,c", false),
-                           ("Mainb", false),
-                           ("aMain", false),
-                           ("Main", true),
-                           ("a,b,Main,c", true),
-                           ("Base", true),
-                           ("a,b,Base,c", true),
-                           ("Filesystem", true),
-                           ("a,b,Filesystem,c", true),
-                           ("a,b,Base.Filesystem,c", false))
+                            (",,,,", false),
+                            ("al", false),
+                            ("all", true),
+                            ("a,b,all,c", true),
+                            ("a,b,,c", false),
+                            ("Mainb", false),
+                            ("aMain", false),
+                            ("Main", true),
+                            ("a,b,Main,c", true),
+                            ("Base", true),
+                            ("a,b,Base,c", true),
+                            ("Filesystem", true),
+                            ("a,b,Filesystem,c", true),
+                            ("a,b,Base.Filesystem,c", false),
+                            ("!al", true),
+                            ("all,!al", true),
+                            ("all,!al,!all", false),
+                            ("!all,Main", true),
+                            ("!all,!Main", false),
+                            ("!all,a,b,!Main,c", false),
+                            ("!all,Filesystem", true),
+                            ("!all,Base.Filesystem", false),
+                            ("a,b,all,!all,c", false),
+                            ("!Main", false),
+                            ("a,b,!Main,c", false),
+                            ("!Base", false),
+                            ("all,!Base", false),
+                            ("!all,Base", true),
+                            ("!all,!Base", false),
+                            ("a,b,!Base,c", false),
+                            ("all,a,b,!Base,c", false),
+                            ("!all,a,b,Base,c", true),
+                            ("!all,a,b,!Base,c", false),
+                            ("!Filesystem", false),
+                            ("all,!Filesystem", false),
+                            ("!all,Filesystem", true),
+                            ("!all,!Filesystem", false),
+                            ("a,b,!Filesystem,c", false),
+                            ("all,a,b,!Filesystem,c", false),
+                            ("!all,a,b,Filesystem,c", true),
+                            ("!all,a,b,!Filesystem,c", false),
+                            ("a,b,!Base.Filesystem,c", true),
+                            ("all,a,b,!Base.Filesystem,c", true),
+                            ("!all,a,b,Base.Filesystem,c", false),
+                            ("!all,a,b,!Base.Filesystem,c", false),
+                           )
                 ENV["JULIA_DEBUG"] = e
                 @test CoreLogging.env_override_minlevel(:Main, Base.Filesystem) === r
                 @test CoreLogging.current_logger_for_env(BelowMinLevel, :Main, Base.Filesystem) === (r ? logger : nothing)
@@ -352,4 +384,12 @@ end
     @test logs[1].id != logs[2].id
 end
 
+# Issue #34485
+@testset "`_group` must be a `Symbol`" begin
+    (record,), _ = collect_test_logs() do
+        @info "test"
+    end
+    @test record.group == :logging  # name of this file
+end
+
 end
diff -pruN 1.3.1+dfsg-1/test/Makefile 1.4.0+dfsg-1/test/Makefile
--- 1.3.1+dfsg-1/test/Makefile	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/test/Makefile	2020-03-21 16:36:32.000000000 +0000
@@ -25,6 +25,10 @@ $(TESTS):
 	@cd $(SRCDIR) && \
 	$(call PRINT_JULIA, $(call spawn,$(JULIA_EXECUTABLE)) --check-bounds=yes --startup-file=no ./runtests.jl $@)
 
+$(addprefix revise-, $(TESTS)): revise-% :
+	@cd $(SRCDIR) && \
+    $(call PRINT_JULIA, $(call spawn,$(JULIA_EXECUTABLE)) --check-bounds=yes --startup-file=no ./runtests.jl --revise $*)
+
 embedding:
 	@$(MAKE) -C $(SRCDIR)/$@ check $(EMBEDDING_ARGS)
 
@@ -35,4 +39,4 @@ clean:
 	@$(MAKE) -C embedding $@ $(EMBEDDING_ARGS)
 	@$(MAKE) -C gcext $@ $(GCEXT_ARGS)
 
-.PHONY: $(TESTS) embedding gcext clean
+.PHONY: $(TESTS) $(addprefix revise-, $(TESTS)) embedding gcext clean
diff -pruN 1.3.1+dfsg-1/test/math.jl 1.4.0+dfsg-1/test/math.jl
--- 1.3.1+dfsg-1/test/math.jl	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/test/math.jl	2020-03-21 16:36:32.000000000 +0000
@@ -487,17 +487,30 @@ end
 
 @testset "evalpoly" begin
     @test @evalpoly(2,3,4,5,6) == 3+2*(4+2*(5+2*6)) == @evalpoly(2+0im,3,4,5,6)
-    @test let evalcounts=0
-              @evalpoly(begin
-                            evalcounts += 1
-                            4
-                        end, 1,2,3,4,5)
-              evalcounts
-          end == 1
     a0 = 1
     a1 = 2
     c = 3
     @test @evalpoly(c, a0, a1) == 7
+    @test @evalpoly(1, 2) == 2
+end
+
+@testset "evalpoly real" begin
+    for x in -1.0:2.0, p1 in -3.0:3.0, p2 in -3.0:3.0, p3 in -3.0:3.0
+        evpm = @evalpoly(x, p1, p2, p3)
+        @test evalpoly(x, (p1, p2, p3)) == evpm
+        @test evalpoly(x, [p1, p2, p3]) == evpm
+    end
+end
+
+@testset "evalpoly complex" begin
+    for x in -1.0:2.0, y in -1.0:2.0, p1 in -3.0:3.0, p2 in -3.0:3.0, p3 in -3.0:3.0
+        z = x + im * y
+        evpm = @evalpoly(z, p1, p2, p3)
+        @test evalpoly(z, (p1, p2, p3)) == evpm
+        @test evalpoly(z, [p1, p2, p3]) == evpm
+    end
+    @test evalpoly(1+im, (2,)) == 2
+    @test evalpoly(1+im, [2,]) == 2
 end
 
 @testset "cis" begin
@@ -1017,10 +1030,15 @@ end
     end
 end
 
-isdefined(Main, :Furlongs) || @eval Main include("testhelpers/Furlongs.jl")
-using .Main.Furlongs
-@test hypot(Furlong(0), Furlong(0)) == Furlong(0.0)
-@test hypot(Furlong(3), Furlong(4)) == Furlong(5.0)
-@test hypot(Furlong(NaN), Furlong(Inf)) == Furlong(Inf)
-@test hypot(Furlong(Inf), Furlong(NaN)) == Furlong(Inf)
-@test hypot(Furlong(Inf), Furlong(Inf)) == Furlong(Inf)
+@testset "hypot" begin
+    @test hypot(0, 0) == 0.0
+    @test hypot(3, 4) == 5.0
+    @test hypot(NaN, Inf) == Inf
+    @test hypot(Inf, NaN) == Inf
+    @test hypot(Inf, Inf) == Inf
+
+    isdefined(Main, :Furlongs) || @eval Main include("testhelpers/Furlongs.jl")
+    using .Main.Furlongs
+    @test hypot(Furlong(0), Furlong(0)) == Furlong(0.0)
+    @test hypot(Furlong(3), Furlong(4)) == Furlong(5.0)
+end
diff -pruN 1.3.1+dfsg-1/test/misc.jl 1.4.0+dfsg-1/test/misc.jl
--- 1.3.1+dfsg-1/test/misc.jl	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/test/misc.jl	2020-03-21 16:36:32.000000000 +0000
@@ -438,6 +438,30 @@ let buf = IOBuffer()
     @test Base.prompt(IOBuffer("blah\n"), buf, "baz", default="foobar") == "blah"
 end
 
+# these tests are not in a test block so that they will compile separately
+@static if Sys.iswindows()
+    SetLastError(code) = ccall(:SetLastError, stdcall, Cvoid, (UInt32,), code)
+else
+    SetLastError(_) = nothing
+end
+@test Libc.errno(0xc0ffee) === nothing
+@test SetLastError(0xc0def00d) === nothing
+let finalized = false
+    function closefunc(_)
+        Libc.errno(0)
+        SetLastError(0)
+        finalized = true
+    end
+    @eval (finalizer($closefunc, zeros()); nothing)
+    GC.gc(); GC.gc(); GC.gc(); GC.gc()
+    @test finalized
+end
+@static if Sys.iswindows()
+    @test ccall(:GetLastError, stdcall, UInt32, ()) == 0xc0def00d
+    @test Libc.GetLastError() == 0xc0def00d
+end
+@test Libc.errno() == 0xc0ffee
+
 # Test that we can VirtualProtect jitted code to writable
 @noinline function WeVirtualProtectThisToRWX(x, y)
     return x + y
@@ -450,7 +474,7 @@ end
         err18083 = ccall(:VirtualProtect, stdcall, Cint,
             (Ptr{Cvoid}, Csize_t, UInt32, Ptr{UInt32}),
             addr, 4096, PAGE_EXECUTE_READWRITE, oldPerm)
-        err18083 == 0 && error(Libc.GetLastError())
+        err18083 == 0 && Base.windowserror(:VirtualProtect)
     end
 end
 
@@ -750,9 +774,34 @@ end
     @test sort([a, b]) == [b, a]
 end
 
+@testset "Libc.rand" begin
+    low, high = extrema(Libc.rand(Float64) for i=1:10^4)
+    # these fail with probability 2^(-10^4) ≈ 5e-3011
+    @test 0 ≤ low < 0.5
+    @test 0.5 < high < 1
+end
+
 # Pointer 0-arg constructor
 @test Ptr{Cvoid}() == C_NULL
 
+@testset "Pointer to unsigned/signed integer" begin
+    # assuming UInt and Ptr have the same size
+    @assert sizeof(UInt) == sizeof(Ptr{Nothing})
+    uint = UInt(0x12345678)
+    sint = signed(uint)
+    ptr = reinterpret(Ptr{Nothing}, uint)
+    @test unsigned(ptr) === uint
+    @test signed(ptr) === sint
+end
+
 # Finalizer with immutable should throw
 @test_throws ErrorException finalizer(x->nothing, 1)
 @test_throws ErrorException finalizer(C_NULL, 1)
+
+
+@testset "GC utilities" begin
+    GC.gc()
+    GC.gc(true); GC.gc(false)
+
+    GC.safepoint()
+end
diff -pruN 1.3.1+dfsg-1/test/missing.jl 1.4.0+dfsg-1/test/missing.jl
--- 1.3.1+dfsg-1/test/missing.jl	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/test/missing.jl	2020-03-21 16:36:32.000000000 +0000
@@ -221,7 +221,7 @@ end
 @testset "printing" begin
     @test sprint(show, missing) == "missing"
     @test sprint(show, missing, context=:compact => true) == "missing"
-    @test sprint(show, [missing]) == "$Missing[missing]"
+    @test sprint(show, [missing]) == "[missing]"
     @test sprint(show, [1 missing]) == "$(Union{Int, Missing})[1 missing]"
     b = IOBuffer()
     display(TextDisplay(b), [missing])
diff -pruN 1.3.1+dfsg-1/test/mpfr.jl 1.4.0+dfsg-1/test/mpfr.jl
--- 1.3.1+dfsg-1/test/mpfr.jl	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/test/mpfr.jl	2020-03-21 16:36:32.000000000 +0000
@@ -487,6 +487,9 @@ end
     x = BigFloat(12)
     @test precision(x) == old_precision
     @test_throws DomainError setprecision(1)
+    @test_throws DomainError BigFloat(1, precision = 0)
+    @test_throws DomainError BigFloat(big(1.1), precision = 0)
+    @test_throws DomainError BigFloat(2.5, precision = -900)
     # issue 15659
     @test (setprecision(53) do; big(1/3); end) < 1//3
 end
diff -pruN 1.3.1+dfsg-1/test/namedtuple.jl 1.4.0+dfsg-1/test/namedtuple.jl
--- 1.3.1+dfsg-1/test/namedtuple.jl	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/test/namedtuple.jl	2020-03-21 16:36:32.000000000 +0000
@@ -133,7 +133,7 @@ end
 @test Meta.lower(Main, Meta.parse("(; f(x))")) == Expr(:error, "invalid named tuple element \"f(x)\"")
 @test Meta.lower(Main, Meta.parse("(;1=0)")) == Expr(:error, "invalid named tuple field name \"1\"")
 
-@test Meta.parse("(;)") == quote end
+@test eval(Expr(:tuple, Expr(:parameters))) === NamedTuple()
 @test Meta.lower(Main, Meta.parse("(1,;2)")) == Expr(:error, "unexpected semicolon in tuple")
 
 # splatting
@@ -267,3 +267,11 @@ let n = NamedTuple{(:T,), Tuple{Type{Flo
     @test n isa NamedTuple{(:T,), Tuple{Type{Float64}}}
     @test n.T === Float64
 end
+
+# setindex
+let nt0 = NamedTuple(), nt1 = (a=33,), nt2 = (a=0, b=:v)
+    @test Base.setindex(nt0, 33, :a) == nt1
+    @test Base.setindex(Base.setindex(nt1, 0, :a), :v, :b) == nt2
+    @test Base.setindex(nt1, "value", :a) == (a="value",)
+    @test Base.setindex(nt1, "value", :a) isa NamedTuple{(:a,),<:Tuple{AbstractString}}
+end
diff -pruN 1.3.1+dfsg-1/test/numbers.jl 1.4.0+dfsg-1/test/numbers.jl
--- 1.3.1+dfsg-1/test/numbers.jl	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/test/numbers.jl	2020-03-21 16:36:32.000000000 +0000
@@ -415,11 +415,11 @@ end
     @test repr(-NaN) == "NaN"
     @test repr(Float64(pi)) == "3.141592653589793"
     # issue 6608
-    @test sprint(show, 666666.6, context=:compact => true) == "6.66667e5"
+    @test sprint(show, 666666.6, context=:compact => true) == "666667.0"
     @test sprint(show, 666666.049, context=:compact => true) == "666666.0"
     @test sprint(show, 666665.951, context=:compact => true) == "666666.0"
     @test sprint(show, 66.66666, context=:compact => true) == "66.6667"
-    @test sprint(show, -666666.6, context=:compact => true) == "-6.66667e5"
+    @test sprint(show, -666666.6, context=:compact => true) == "-666667.0"
     @test sprint(show, -666666.049, context=:compact => true) == "-666666.0"
     @test sprint(show, -666665.951, context=:compact => true) == "-666666.0"
     @test sprint(show, -66.66666, context=:compact => true) == "-66.6667"
diff -pruN 1.3.1+dfsg-1/test/offsetarray.jl 1.4.0+dfsg-1/test/offsetarray.jl
--- 1.3.1+dfsg-1/test/offsetarray.jl	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/test/offsetarray.jl	2020-03-21 16:36:32.000000000 +0000
@@ -116,6 +116,12 @@ end
 @test A[OffsetArray([true true;  false true], A.offsets)] == [1,3,4]
 @test_throws BoundsError A[[true true;  false true]]
 
+# begin, end
+a0 = rand(2,3,4,2)
+a = OffsetArray(a0, (-2,-3,4,5))
+@test a[begin,end,end,begin] == a0[begin,end,end,begin] ==
+      a0[1,3,4,1] == a0[end-1,begin+2,begin+3,end-1]
+
 # view
 S = view(A, :, 3)
 @test S == OffsetArray([1,2], (A.offsets[1],))
@@ -210,7 +216,7 @@ targets1 = ["0-dimensional $OAs_name.Off
             "1×1 $OAs_name.OffsetArray{Float64,2,Array{Float64,2}} with indices 2:2×3:3:\n 1.0",
             "1×1×1 $OAs_name.OffsetArray{Float64,3,Array{Float64,3}} with indices 2:2×3:3×4:4:\n[:, :, 4] =\n 1.0",
             "1×1×1×1 $OAs_name.OffsetArray{Float64,4,Array{Float64,4}} with indices 2:2×3:3×4:4×5:5:\n[:, :, 4, 5] =\n 1.0"]
-targets2 = ["(1.0, 1.0)",
+targets2 = ["(fill(1.0), fill(1.0))",
             "([1.0], [1.0])",
             "([1.0], [1.0])",
             "([1.0], [1.0])",
@@ -344,6 +350,7 @@ v2 = copy(v)
 @test push!(v2, 1) === v2
 @test v2[axes(v, 1)] == v
 @test v2[end] == 1
+@test v2[begin] == v[begin] == v[-2]
 v2 = copy(v)
 @test push!(v2, 2, 1) === v2
 @test v2[axes(v, 1)] == v
@@ -433,6 +440,14 @@ I = findall(!iszero, z)
 @test std(A_3_3, dims=2) == OffsetArray(reshape([3,3,3], (3,1)), A_3_3.offsets)
 @test sum(OffsetArray(fill(1,3000), -1000)) == 3000
 
+# https://github.com/JuliaArrays/OffsetArrays.jl/issues/92
+A92 = OffsetArray(reshape(1:27, 3, 3, 3), -2, -2, -2)
+B92 = view(A92, :, :, -1:0)
+@test axes(B92) == (-1:1, -1:1, 1:2)
+@test sum(B92, dims=(2,3)) == OffsetArray(reshape([51,57,63], Val(3)), -2, -2, 0)
+B92 = view(A92, :, :, Base.IdentityUnitRange(-1:0))
+@test sum(B92, dims=(2,3)) == OffsetArray(reshape([51,57,63], Val(3)), -2, -2, -2)
+
 @test norm(v) ≈ norm(parent(v))
 @test norm(A) ≈ norm(parent(A))
 @test dot(v, v) ≈ dot(v0, v0)
@@ -468,6 +483,19 @@ v = OffsetArray(rand(8), (-2,))
 @test sortslices(A, dims=2) == OffsetArray(sortslices(parent(A), dims=2), A.offsets)
 @test sort(A, dims=1) == OffsetArray(sort(parent(A), dims=1), A.offsets)
 @test sort(A, dims=2) == OffsetArray(sort(parent(A), dims=2), A.offsets)
+# Issue #33977
+soa = OffsetArray([2,2,3], -2)
+@test searchsorted(soa, 1) == -1:-2
+@test searchsortedfirst(soa, 1) == -1
+@test searchsortedlast(soa, 1) == -2
+@test first(sort!(soa; alg=QuickSort)) == 2
+@test first(sort!(soa; alg=MergeSort)) == 2
+soa = OffsetArray([2,2,3], typemax(Int)-4)
+@test searchsorted(soa, 1) == typemax(Int)-3:typemax(Int)-4
+@test searchsortedfirst(soa, 2) == typemax(Int) - 3
+@test searchsortedlast(soa, 2) == typemax(Int) - 2
+@test first(sort!(soa; alg=QuickSort)) == 2
+@test first(sort!(soa; alg=MergeSort)) == 2
 
 @test mapslices(sort, A, dims=1) == OffsetArray(mapslices(sort, parent(A), dims=1), A.offsets)
 @test mapslices(sort, A, dims=2) == OffsetArray(mapslices(sort, parent(A), dims=2), A.offsets)
@@ -546,15 +574,15 @@ end
     B = OffsetArray(reshape(1:24, 4, 3, 2), -5, 6, -7)
     for R in (fill(0, -4:-1), fill(0, -4:-1, 7:7), fill(0, -4:-1, 7:7, -6:-6))
         @test @inferred(maximum!(R, B)) == reshape(maximum(B, dims=(2,3)), axes(R)) == reshape(21:24, axes(R))
-        @test @allocated(maximum!(R, B)) <= 400
+        @test @allocated(maximum!(R, B)) <= 800
         @test @inferred(minimum!(R, B)) == reshape(minimum(B, dims=(2,3)), axes(R)) == reshape(1:4, axes(R))
-        @test @allocated(minimum!(R, B)) <= 400
+        @test @allocated(minimum!(R, B)) <= 800
     end
     for R in (fill(0, -4:-4, 7:9), fill(0, -4:-4, 7:9, -6:-6))
         @test @inferred(maximum!(R, B)) == reshape(maximum(B, dims=(1,3)), axes(R)) == reshape(16:4:24, axes(R))
-        @test @allocated(maximum!(R, B)) <= 400
+        @test @allocated(maximum!(R, B)) <= 800
         @test @inferred(minimum!(R, B)) == reshape(minimum(B, dims=(1,3)), axes(R)) == reshape(1:4:9, axes(R))
-        @test @allocated(minimum!(R, B)) <= 400
+        @test @allocated(minimum!(R, B)) <= 800
     end
     @test_throws DimensionMismatch maximum!(fill(0, -4:-1, 7:7, -6:-6, 1:1), B)
     @test_throws DimensionMismatch minimum!(fill(0, -4:-1, 7:7, -6:-6, 1:1), B)
diff -pruN 1.3.1+dfsg-1/test/operators.jl 1.4.0+dfsg-1/test/operators.jl
--- 1.3.1+dfsg-1/test/operators.jl	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/test/operators.jl	2020-03-21 16:36:32.000000000 +0000
@@ -105,9 +105,12 @@ Base.convert(::Type{T19714}, ::Int) = T1
 Base.promote_rule(::Type{T19714}, ::Type{Int}) = T19714
 @test T19714()/1 === 1/T19714() === T19714()
 
-# pr #17155
+# pr #17155 and #33568
 @testset "function composition" begin
     @test (uppercase∘(x->string(x,base=16)))(239487) == "3A77F"
+    @test ∘(x -> x-2, x -> x-3, x -> x+5)(7) == 7
+    fs = [x -> x[1:2], uppercase, lowercase]
+    @test ∘(fs...)("ABC") == "AB"
 end
 @testset "function negation" begin
     str = randstring(20)
@@ -197,7 +200,6 @@ end
     @test fy(x) == x / y
 end
 
-
 @testset "curried comparisons" begin
     eql5 = (==)(5)
     neq5 = (!=)(5)
diff -pruN 1.3.1+dfsg-1/test/parse.jl 1.4.0+dfsg-1/test/parse.jl
--- 1.3.1+dfsg-1/test/parse.jl	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/test/parse.jl	2020-03-21 16:36:32.000000000 +0000
@@ -352,3 +352,15 @@ end
         @test isequal(parse(Float64, s), sign(v))
     end
 end
+
+@testset "operator precedence correctness" begin
+    ops = map(Symbol, split("= => || && --> < <| |> : + * // << ^ :: ."))
+    for f in ops, g in ops
+        f == g && continue
+        pf = Base.operator_precedence(f)
+        pg = Base.operator_precedence(g)
+        @test pf != pg
+        expr = Meta.parse("x$(f)y$(g)z")
+        @test expr == Meta.parse(pf > pg ? "(x$(f)y)$(g)z" : "x$(f)(y$(g)z)")
+    end
+end
diff -pruN 1.3.1+dfsg-1/test/path.jl 1.4.0+dfsg-1/test/path.jl
--- 1.3.1+dfsg-1/test/path.jl	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/test/path.jl	2020-03-21 16:36:32.000000000 +0000
@@ -31,8 +31,14 @@
         @test isdirpath(S(".."))
     end
     @testset "joinpath" begin
+        @test joinpath(S("")) == ""
         @test joinpath(S("foo")) == "foo"
         @test joinpath(S("foo"), S("bar")) == "foo$(sep)bar"
+        @test joinpath(S("foo"), S("bar"), S("baz")) == "foo$(sep)bar$(sep)baz"
+        @test joinpath(S("foo"), S(""), S("baz")) == "foo$(sep)baz"
+        @test joinpath(S("foo"), S(""), S("")) == "foo$(sep)"
+        @test joinpath(S("foo"), S(""), S(""), S("bar")) == "foo$(sep)bar"
+
         @test joinpath(S("foo"), S(homedir())) == homedir()
         @test joinpath(S(abspath("foo")), S(homedir())) == homedir()
 
@@ -40,6 +46,18 @@
             @test joinpath(S("foo"),S("bar:baz")) == "bar:baz"
             @test joinpath(S("C:"),S("foo"),S("D:"),S("bar")) == "D:bar"
             @test joinpath(S("C:"),S("foo"),S("D:bar"),S("baz")) == "D:bar$(sep)baz"
+
+            # relative folders and case-insensitive drive letters
+            @test joinpath(S("C:\\a\\b"), S("c:c\\e")) == "C:\\a\\b\\c\\e"
+
+            # UNC paths
+            @test joinpath(S("\\\\server"), S("share")) == "\\\\server\\share"
+            @test joinpath(S("\\\\server"), S("share"), S("a")) == "\\\\server\\share\\a"
+            @test joinpath(S("\\\\server\\"), S("share"), S("a")) == "\\\\server\\share\\a"
+            @test joinpath(S("\\\\server"), S("share"), S("a"), S("b")) == "\\\\server\\share\\a\\b"
+            @test joinpath(S("\\\\server\\share"),S("a")) == "\\\\server\\share\\a"
+            @test joinpath(S("\\\\server\\share\\"), S("a")) == "\\\\server\\share\\a"
+
         elseif Sys.isunix()
             @test joinpath(S("foo"),S("bar:baz")) == "foo$(sep)bar:baz"
             @test joinpath(S("C:"),S("foo"),S("D:"),S("bar")) == "C:$(sep)foo$(sep)D:$(sep)bar"
@@ -86,42 +104,42 @@
     @test relpath(S(joinpath("foo","bar")), S("foo")) == "bar"
 
     @testset "splitpath" begin
-        @test splitpath(joinpath("a","b","c")) == ["a", "b", "c"]
+        @test splitpath(S(joinpath("a","b","c"))) == ["a", "b", "c"]
         @test splitpath("") == [""]
 
-        @test splitpath(joinpath("cats are", "gr8t")) == ["cats are", "gr8t"]
-        @test splitpath(joinpath("  ", " ")) == ["  ", " "]
+        @test splitpath(S(joinpath("cats are", "gr8t"))) == ["cats are", "gr8t"]
+        @test splitpath(S(joinpath("  ", " "))) == ["  ", " "]
 
         # Unix-style paths are understood by all systems.
-        @test splitpath("/a/b") == ["/", "a", "b"]
-        @test splitpath("/") == ["/"]
-        @test splitpath("a/") == ["a"]
-        @test splitpath("a/b/") == ["a", "b"]
-        @test splitpath("a.dir/b.txt") == ["a.dir", "b.txt"]
-        @test splitpath("///") == ["/"]
-        @test splitpath("///a///b///") == ["/", "a", "b"]
+        @test splitpath(S("/a/b")) == ["/", "a", "b"]
+        @test splitpath(S("/")) == ["/"]
+        @test splitpath(S("a/")) == ["a"]
+        @test splitpath(S("a/b/")) == ["a", "b"]
+        @test splitpath(S("a.dir/b.txt")) == ["a.dir", "b.txt"]
+        @test splitpath(S("///")) == ["/"]
+        @test splitpath(S("///a///b///")) == ["/", "a", "b"]
 
         if Sys.iswindows()
-            @test splitpath("C:\\\\a\\b\\c") == ["C:\\", "a", "b", "c"]
-            @test splitpath("C:\\\\") == ["C:\\"]
-            @test splitpath("J:\\") == ["J:\\"]
-            @test splitpath("C:") == ["C:"]
-            @test splitpath("C:a") == ["C:a"]
-            @test splitpath("C:a\\b") == ["C:a", "b"]
-
-            @test splitpath("a\\") == ["a"]
-            @test splitpath("a\\\\b\\\\") == ["a","b"]
-            @test splitpath("a.dir\\b.txt") == ["a.dir", "b.txt"]
-            @test splitpath("\\a\\b\\") == ["\\", "a","b"]
-            @test splitpath("\\\\a\\b") == ["\\\\a\\b"]  # This is actually a valid drive name in windows.
-
-            @test splitpath("/a/b\\c/d\\\\e") == ["/", "a", "b", "c", "d", "e"]
-            @test splitpath("/\\/\\") == ["/"]
-            @test splitpath("\\/\\a/\\//b") == ["\\","a","b"]
+            @test splitpath(S("C:\\\\a\\b\\c")) == ["C:\\", "a", "b", "c"]
+            @test splitpath(S("C:\\\\")) == ["C:\\"]
+            @test splitpath(S("J:\\")) == ["J:\\"]
+            @test splitpath(S("C:")) == ["C:"]
+            @test splitpath(S("C:a")) == ["C:a"]
+            @test splitpath(S("C:a\\b")) == ["C:a", "b"]
+
+            @test splitpath(S("a\\")) == ["a"]
+            @test splitpath(S("a\\\\b\\\\")) == ["a","b"]
+            @test splitpath(S("a.dir\\b.txt")) == ["a.dir", "b.txt"]
+            @test splitpath(S("\\a\\b\\")) == ["\\", "a","b"]
+            @test splitpath(S("\\\\a\\b")) == ["\\\\a\\b"]  # This is actually a valid drive name in windows.
+
+            @test splitpath(S("/a/b\\c/d\\\\e")) == ["/", "a", "b", "c", "d", "e"]
+            @test splitpath(S("/\\/\\")) == ["/"]
+            @test splitpath(S("\\/\\a/\\//b")) == ["\\","a","b"]
         end
     end
 
-    @testset "splitting" begin
+    @testset "splitdir, splitdrive" begin
         @test joinpath(splitdir(S(homedir()))...) == homedir()
         @test string(splitdrive(S(homedir()))...) == homedir()
         @test splitdrive("a\nb") == ("", "a\nb")
@@ -150,113 +168,115 @@
         @test_broken splitext(S(".foo...")) == (".foo", "...")
         @test splitext(S(".foo.bar")) == (".foo", ".bar")
     end
-end
 
-@testset "isabspath" begin
-    @test isabspath("~") == false
-    @test isabspath("/") == true # on windows, this is relatively absolute
-    @test isabspath("A:/") == Sys.iswindows()
-    @test isabspath("B:\\") == Sys.iswindows()
-    @test isabspath("./") == false
-    @test isabspath("C:") == false
-    @test isabspath("C:.") == false
-    @test isabspath("α:/") == false
-    @test isabspath(".:/") == false
-    #@test isabspath("_:/") == false # FIXME?
-    #@test isabspath("AB:/") == false # FIXME?
-    @test isabspath("\\\\") == Sys.iswindows()
-    if Sys.isunix()
-        @test isabspath(expanduser("~")) == true
-        @test startswith(expanduser("~"), homedir())
-    else
-        @test expanduser("~") == "~"
+    @testset "isabspath" begin
+        @test isabspath(S("~")) == false
+        @test isabspath(S("/")) == true # on windows, this is relatively absolute
+        @test isabspath(S("A:/")) == Sys.iswindows()
+        @test isabspath(S("B:\\")) == Sys.iswindows()
+        @test isabspath(S("./")) == false
+        @test isabspath(S("C:")) == false
+        @test isabspath(S("C:.")) == false
+        @test isabspath(S("α:/")) == false
+        @test isabspath(S(".:/")) == false
+        #@test isabspath(S("_:/")) == false # FIXME?
+        #@test isabspath(S("AB:/")) == false # FIXME?
+        @test isabspath(S("\\\\")) == Sys.iswindows()
+        if Sys.isunix()
+            @test isabspath(S(expanduser("~"))) == true
+            @test startswith(expanduser(S("~")), homedir())
+        else
+            @test expanduser(S("~")) == "~"
+        end
     end
-end
 
-@testset "relpath" begin
-    function test_relpath()
-        sep = Base.Filesystem.path_separator
-        filepaths = [
-            "$(sep)home$(sep)user$(sep).julia$(sep)Test1$(sep)docs$(sep)api$(sep)Test1.md",
-            "$(sep)home$(sep)user$(sep).julia$(sep)Test1$(sep)docs$(sep)api$(sep)lib$(sep)file1.md",
-            "$(sep)home$(sep)user$(sep).julia$(sep)测试2$(sep)docs$(sep)api$(sep)测试2.md",
-            "$(sep)home$(sep)user$(sep)dir_withendsep$(sep)",
-            "$(sep)home$(sep)dir2_withendsep$(sep)",
-            "$(sep)home$(sep)test.md",
-            "$(sep)home",
-            # Special cases
-            "$(sep)",
-            "$(sep)home$(sep)$(sep)$(sep)"
-        ]
-        startpaths = [
-            "$(sep)home$(sep)user$(sep).julia$(sep)Test1$(sep)docs$(sep)api$(sep)genindex.md",
-            "$(sep)multi_docs$(sep)genindex.md",
-            "$(sep)home$(sep)user$(sep)dir_withendsep$(sep)",
-            "$(sep)home$(sep)dir2_withendsep$(sep)",
-            "$(sep)home$(sep)test.md",
-            "$(sep)home",
-            # Special cases
-            "$(sep)",
-            "$(sep)home$(sep)$(sep)$(sep)"
-        ]
-        relpath_expected_results = [
-            "..$(sep)Test1.md",
-            "..$(sep)..$(sep)home$(sep)user$(sep).julia$(sep)Test1$(sep)docs$(sep)api$(sep)Test1.md",
-            "..$(sep).julia$(sep)Test1$(sep)docs$(sep)api$(sep)Test1.md",
-            "..$(sep)user$(sep).julia$(sep)Test1$(sep)docs$(sep)api$(sep)Test1.md",
-            "..$(sep)user$(sep).julia$(sep)Test1$(sep)docs$(sep)api$(sep)Test1.md",
-            "user$(sep).julia$(sep)Test1$(sep)docs$(sep)api$(sep)Test1.md",
-            "home$(sep)user$(sep).julia$(sep)Test1$(sep)docs$(sep)api$(sep)Test1.md",
-            "user$(sep).julia$(sep)Test1$(sep)docs$(sep)api$(sep)Test1.md",
-            "..$(sep)lib$(sep)file1.md",
-            "..$(sep)..$(sep)home$(sep)user$(sep).julia$(sep)Test1$(sep)docs$(sep)api$(sep)lib$(sep)file1.md",
-            "..$(sep).julia$(sep)Test1$(sep)docs$(sep)api$(sep)lib$(sep)file1.md",
-            "..$(sep)user$(sep).julia$(sep)Test1$(sep)docs$(sep)api$(sep)lib$(sep)file1.md",
-            "..$(sep)user$(sep).julia$(sep)Test1$(sep)docs$(sep)api$(sep)lib$(sep)file1.md",
-            "user$(sep).julia$(sep)Test1$(sep)docs$(sep)api$(sep)lib$(sep)file1.md",
-            "home$(sep)user$(sep).julia$(sep)Test1$(sep)docs$(sep)api$(sep)lib$(sep)file1.md",
-            "user$(sep).julia$(sep)Test1$(sep)docs$(sep)api$(sep)lib$(sep)file1.md",
-            "..$(sep)..$(sep)..$(sep)..$(sep)测试2$(sep)docs$(sep)api$(sep)测试2.md",
-            "..$(sep)..$(sep)home$(sep)user$(sep).julia$(sep)测试2$(sep)docs$(sep)api$(sep)测试2.md",
-            "..$(sep).julia$(sep)测试2$(sep)docs$(sep)api$(sep)测试2.md",
-            "..$(sep)user$(sep).julia$(sep)测试2$(sep)docs$(sep)api$(sep)测试2.md",
-            "..$(sep)user$(sep).julia$(sep)测试2$(sep)docs$(sep)api$(sep)测试2.md",
-            "user$(sep).julia$(sep)测试2$(sep)docs$(sep)api$(sep)测试2.md",
-            "home$(sep)user$(sep).julia$(sep)测试2$(sep)docs$(sep)api$(sep)测试2.md",
-            "user$(sep).julia$(sep)测试2$(sep)docs$(sep)api$(sep)测试2.md",
-            "..$(sep)..$(sep)..$(sep)..$(sep)..$(sep)dir_withendsep",
-            "..$(sep)..$(sep)home$(sep)user$(sep)dir_withendsep",".","..$(sep)user$(sep)dir_withendsep",
-            "..$(sep)user$(sep)dir_withendsep","user$(sep)dir_withendsep",
-            "home$(sep)user$(sep)dir_withendsep","user$(sep)dir_withendsep",
-            "..$(sep)..$(sep)..$(sep)..$(sep)..$(sep)..$(sep)dir2_withendsep",
-            "..$(sep)..$(sep)home$(sep)dir2_withendsep","..$(sep)..$(sep)dir2_withendsep",".",
-            "..$(sep)dir2_withendsep","dir2_withendsep","home$(sep)dir2_withendsep","dir2_withendsep",
-            "..$(sep)..$(sep)..$(sep)..$(sep)..$(sep)..$(sep)test.md","..$(sep)..$(sep)home$(sep)test.md",
-            "..$(sep)..$(sep)test.md","..$(sep)test.md",".","test.md","home$(sep)test.md","test.md",
-            "..$(sep)..$(sep)..$(sep)..$(sep)..$(sep)..","..$(sep)..$(sep)home","..$(sep)..",
-            "..","..",".","home",".","..$(sep)..$(sep)..$(sep)..$(sep)..$(sep)..$(sep)..","..$(sep)..",
-            "..$(sep)..$(sep)..","..$(sep)..","..$(sep)..","..",".","..",
-            "..$(sep)..$(sep)..$(sep)..$(sep)..$(sep)..","..$(sep)..$(sep)home","..$(sep)..",
-            "..","..",".","home","."
-        ]
-        idx = 0
-        for filep in filepaths
-            for startp in startpaths
-                res = relpath(filep, startp)
-                idx += 1
-                @test res == relpath_expected_results[idx]
+    @testset "relpath" begin
+        function test_relpath()
+            sep = Base.Filesystem.path_separator
+            filepaths = [
+                "$(sep)home$(sep)user$(sep).julia$(sep)Test1$(sep)docs$(sep)api$(sep)Test1.md",
+                "$(sep)home$(sep)user$(sep).julia$(sep)Test1$(sep)docs$(sep)api$(sep)lib$(sep)file1.md",
+                "$(sep)home$(sep)user$(sep).julia$(sep)测试2$(sep)docs$(sep)api$(sep)测试2.md",
+                "$(sep)home$(sep)user$(sep)dir_withendsep$(sep)",
+                "$(sep)home$(sep)dir2_withendsep$(sep)",
+                "$(sep)home$(sep)test.md",
+                "$(sep)home",
+                # Special cases
+                "$(sep)",
+                "$(sep)home$(sep)$(sep)$(sep)"
+            ]
+            startpaths = [
+                "$(sep)home$(sep)user$(sep).julia$(sep)Test1$(sep)docs$(sep)api$(sep)genindex.md",
+                "$(sep)multi_docs$(sep)genindex.md",
+                "$(sep)home$(sep)user$(sep)dir_withendsep$(sep)",
+                "$(sep)home$(sep)dir2_withendsep$(sep)",
+                "$(sep)home$(sep)test.md",
+                "$(sep)home",
+                # Special cases
+                "$(sep)",
+                "$(sep)home$(sep)$(sep)$(sep)"
+            ]
+            relpath_expected_results = [
+                "..$(sep)Test1.md",
+                "..$(sep)..$(sep)home$(sep)user$(sep).julia$(sep)Test1$(sep)docs$(sep)api$(sep)Test1.md",
+                "..$(sep).julia$(sep)Test1$(sep)docs$(sep)api$(sep)Test1.md",
+                "..$(sep)user$(sep).julia$(sep)Test1$(sep)docs$(sep)api$(sep)Test1.md",
+                "..$(sep)user$(sep).julia$(sep)Test1$(sep)docs$(sep)api$(sep)Test1.md",
+                "user$(sep).julia$(sep)Test1$(sep)docs$(sep)api$(sep)Test1.md",
+                "home$(sep)user$(sep).julia$(sep)Test1$(sep)docs$(sep)api$(sep)Test1.md",
+                "user$(sep).julia$(sep)Test1$(sep)docs$(sep)api$(sep)Test1.md",
+                "..$(sep)lib$(sep)file1.md",
+                "..$(sep)..$(sep)home$(sep)user$(sep).julia$(sep)Test1$(sep)docs$(sep)api$(sep)lib$(sep)file1.md",
+                "..$(sep).julia$(sep)Test1$(sep)docs$(sep)api$(sep)lib$(sep)file1.md",
+                "..$(sep)user$(sep).julia$(sep)Test1$(sep)docs$(sep)api$(sep)lib$(sep)file1.md",
+                "..$(sep)user$(sep).julia$(sep)Test1$(sep)docs$(sep)api$(sep)lib$(sep)file1.md",
+                "user$(sep).julia$(sep)Test1$(sep)docs$(sep)api$(sep)lib$(sep)file1.md",
+                "home$(sep)user$(sep).julia$(sep)Test1$(sep)docs$(sep)api$(sep)lib$(sep)file1.md",
+                "user$(sep).julia$(sep)Test1$(sep)docs$(sep)api$(sep)lib$(sep)file1.md",
+                "..$(sep)..$(sep)..$(sep)..$(sep)测试2$(sep)docs$(sep)api$(sep)测试2.md",
+                "..$(sep)..$(sep)home$(sep)user$(sep).julia$(sep)测试2$(sep)docs$(sep)api$(sep)测试2.md",
+                "..$(sep).julia$(sep)测试2$(sep)docs$(sep)api$(sep)测试2.md",
+                "..$(sep)user$(sep).julia$(sep)测试2$(sep)docs$(sep)api$(sep)测试2.md",
+                "..$(sep)user$(sep).julia$(sep)测试2$(sep)docs$(sep)api$(sep)测试2.md",
+                "user$(sep).julia$(sep)测试2$(sep)docs$(sep)api$(sep)测试2.md",
+                "home$(sep)user$(sep).julia$(sep)测试2$(sep)docs$(sep)api$(sep)测试2.md",
+                "user$(sep).julia$(sep)测试2$(sep)docs$(sep)api$(sep)测试2.md",
+                "..$(sep)..$(sep)..$(sep)..$(sep)..$(sep)dir_withendsep",
+                "..$(sep)..$(sep)home$(sep)user$(sep)dir_withendsep",".","..$(sep)user$(sep)dir_withendsep",
+                "..$(sep)user$(sep)dir_withendsep","user$(sep)dir_withendsep",
+                "home$(sep)user$(sep)dir_withendsep","user$(sep)dir_withendsep",
+                "..$(sep)..$(sep)..$(sep)..$(sep)..$(sep)..$(sep)dir2_withendsep",
+                "..$(sep)..$(sep)home$(sep)dir2_withendsep","..$(sep)..$(sep)dir2_withendsep",".",
+                "..$(sep)dir2_withendsep","dir2_withendsep","home$(sep)dir2_withendsep","dir2_withendsep",
+                "..$(sep)..$(sep)..$(sep)..$(sep)..$(sep)..$(sep)test.md","..$(sep)..$(sep)home$(sep)test.md",
+                "..$(sep)..$(sep)test.md","..$(sep)test.md",".","test.md","home$(sep)test.md","test.md",
+                "..$(sep)..$(sep)..$(sep)..$(sep)..$(sep)..","..$(sep)..$(sep)home","..$(sep)..",
+                "..","..",".","home",".","..$(sep)..$(sep)..$(sep)..$(sep)..$(sep)..$(sep)..","..$(sep)..",
+                "..$(sep)..$(sep)..","..$(sep)..","..$(sep)..","..",".","..",
+                "..$(sep)..$(sep)..$(sep)..$(sep)..$(sep)..","..$(sep)..$(sep)home","..$(sep)..",
+                "..","..",".","home","."
+            ]
+            idx = 0
+            for filep in filepaths
+                for startp in startpaths
+                    res = relpath(filep, startp)
+                    idx += 1
+                    @test res == relpath_expected_results[idx]
+                end
             end
+            # Additional cases
+            @test_throws ArgumentError relpath(S("$(sep)home$(sep)user$(sep)dir_withendsep$(sep)"), "")
+            @test_throws ArgumentError relpath(S(""), S("$(sep)home$(sep)user$(sep)dir_withendsep$(sep)"))
         end
-        # Additional cases
-        @test_throws ArgumentError relpath("$(sep)home$(sep)user$(sep)dir_withendsep$(sep)", "")
-        @test_throws ArgumentError relpath("", "$(sep)home$(sep)user$(sep)dir_withendsep$(sep)")
+        test_relpath()
+    end
+
+    @testset "type stability" begin
+        @test isa(joinpath(S("a"), S("b")), String)
+        @test isa(joinpath(S(abspath("a")), S("b")), String)
     end
-    test_relpath()
-end
-@testset "type stability" begin
-    @test isa(joinpath("a", "b"), String)
-    @test isa(joinpath(abspath("a"), "b"), String)
 end
+
 @testset "homedir" begin
     var = Sys.iswindows() ? "USERPROFILE" : "HOME"
     AVG_PATH = Base.Filesystem.AVG_PATH - 1 # null-termination character
diff -pruN 1.3.1+dfsg-1/test/precompile.jl 1.4.0+dfsg-1/test/precompile.jl
--- 1.3.1+dfsg-1/test/precompile.jl	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/test/precompile.jl	2020-03-21 16:36:32.000000000 +0000
@@ -87,7 +87,7 @@ try
               (::Task)(::UInt8, ::UInt16, ::UInt32) = 2
 
               # issue 16471 (capturing references to a kwfunc)
-              Test.@test_throws ErrorException Core.kwfunc(Base.nothing)
+              Test.@test !isdefined(Base.Nothing.name.mt, :kwsorter)
               Base.nothing(::UInt8, ::UInt16, ::UInt32; x = 52) = x
               const nothingkw = Core.kwfunc(Base.nothing)
 
@@ -144,11 +144,11 @@ try
                               missing, missing, missing,
                               missing, missing, 6]
 
-              let some_method = which(Base.include, (String,))
+              let some_method = which(Base.include, (Module, String,))
                     # global const some_method // FIXME: support for serializing a direct reference to an external Method not implemented
                   global const some_linfo =
                       ccall(:jl_specializations_get_linfo, Ref{Core.MethodInstance}, (Any, Any, Any, UInt),
-                          some_method, Tuple{typeof(Base.include), String}, Core.svec(), typemax(UInt))
+                          some_method, Tuple{typeof(Base.include), Module, String}, Core.svec(), typemax(UInt))
               end
 
               g() = override(1.0)
@@ -163,9 +163,17 @@ try
               _v31488 = Base.StringVector(2)
               resize!(_v31488, 0)
               const a31488 = fill(String(_v31488), 100)
+
+              const ptr1 = Ptr{UInt8}(1)
+              ptr2 = Ptr{UInt8}(1)
+              const ptr3 = Ptr{UInt8}(-1)
+              const layout1 = Ptr{Int8}[Ptr{Int8}(0), Ptr{Int8}(1), Ptr{Int8}(-1)]
+              const layout2 = Any[Ptr{Int8}(0), Ptr{Int16}(1), Ptr{Int32}(-1)]
+              const layout3 = collect(x.match for x in eachmatch(r"..", "abcdefghijk"))::Vector{SubString{String}}
           end
           """)
-    @test_throws ErrorException Core.kwfunc(Base.nothing) # make sure `nothing` didn't have a kwfunc (which would invalidate the attempted test)
+    # make sure `nothing` didn't have a kwfunc (which would invalidate the attempted test)
+    @test !isdefined(Base.Nothing.name.mt, :kwsorter)
 
     # Issue #12623
     @test __precompile__(false) === nothing
@@ -200,6 +208,14 @@ try
         @test Foo.x28998[end] == 6
 
         @test Foo.a31488 == fill("", 100)
+
+        @test Foo.ptr1 === Ptr{UInt8}(1)
+        @test Foo.ptr2 === Ptr{UInt8}(0)
+        @test Foo.ptr3 === Ptr{UInt8}(-1)
+        @test Foo.layout1::Vector{Ptr{Int8}} == Ptr{Int8}[Ptr{Int8}(0), Ptr{Int8}(0), Ptr{Int8}(-1)]
+        @test Foo.layout2 == Any[Ptr{Int8}(0), Ptr{Int16}(0), Ptr{Int32}(-1)]
+        @test typeof.(Foo.layout2) == [Ptr{Int8}, Ptr{Int16}, Ptr{Int32}]
+        @test Foo.layout3 == ["ab", "cd", "ef", "gh", "ij"]
     end
 
     cachedir = joinpath(dir, "compiled", "v$(VERSION.major).$(VERSION.minor)")
@@ -287,10 +303,10 @@ try
                 Val{3},
                 Val{nothing}},
             0:25)
-        some_method = which(Base.include, (String,))
+        some_method = which(Base.include, (Module, String,))
         some_linfo =
                 ccall(:jl_specializations_get_linfo, Ref{Core.MethodInstance}, (Any, Any, Any, UInt),
-                    some_method, Tuple{typeof(Base.include), String}, Core.svec(), typemax(UInt))
+                    some_method, Tuple{typeof(Base.include), Module, String}, Core.svec(), typemax(UInt))
         @test Foo.some_linfo::Core.MethodInstance === some_linfo
 
         ft = Base.datatype_fieldtypes
@@ -374,12 +390,12 @@ try
           end
           """)
     @test_warn "ERROR: LoadError: break me\nStacktrace:\n [1] error" try
-        Base.require(Main, :FooBar2)
-        error("\"LoadError: break me\" test failed")
-    catch exc
-        isa(exc, ErrorException) || rethrow()
-        occursin("ERROR: LoadError: break me", exc.msg) && rethrow()
-    end
+            Base.require(Main, :FooBar2)
+            error("the \"break me\" test failed")
+        catch exc
+            isa(exc, ErrorException) || rethrow()
+            occursin("ERROR: LoadError: break me", exc.msg) && rethrow()
+        end
 
     # Test transitive dependency for #21266
     FooBarT_file = joinpath(dir, "FooBarT.jl")
@@ -781,4 +797,27 @@ let
     end
 end
 
+# Issue #25971
+let
+    load_path = mktempdir()
+    load_cache_path = mktempdir()
+    try
+        pushfirst!(LOAD_PATH, load_path)
+        pushfirst!(DEPOT_PATH, load_cache_path)
+        sourcefile = joinpath(load_path, "Foo25971.jl")
+        write(sourcefile, "module Foo25971 end")
+        chmod(sourcefile, 0o666)
+        cachefile = Base.compilecache(Base.PkgId("Foo25971"))
+        @test filemode(sourcefile) == filemode(cachefile)
+        chmod(sourcefile, 0o600)
+        cachefile = Base.compilecache(Base.PkgId("Foo25971"))
+        @test filemode(sourcefile) == filemode(cachefile)
+    finally
+        rm(load_path, recursive=true)
+        rm(load_cache_path, recursive=true)
+        filter!((≠)(load_path), LOAD_PATH)
+        filter!((≠)(load_cache_path), DEPOT_PATH)
+    end
+end
+
 end # !withenv
diff -pruN 1.3.1+dfsg-1/test/project/deps/Foo1/src/Foo.jl 1.4.0+dfsg-1/test/project/deps/Foo1/src/Foo.jl
--- 1.3.1+dfsg-1/test/project/deps/Foo1/src/Foo.jl	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/test/project/deps/Foo1/src/Foo.jl	2020-03-21 16:36:32.000000000 +0000
@@ -1,6 +1,7 @@
 # This file is a part of Julia. License is MIT: https://julialang.org/license
 
 module Foo
+include("SubFoo.jl")
 import Bar, Baz, Qux
 this = "Foo1"
 which = "path"
diff -pruN 1.3.1+dfsg-1/test/project/deps/Foo1/src/SubFoo.jl 1.4.0+dfsg-1/test/project/deps/Foo1/src/SubFoo.jl
--- 1.3.1+dfsg-1/test/project/deps/Foo1/src/SubFoo.jl	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/test/project/deps/Foo1/src/SubFoo.jl	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1,5 @@
+# This file is a part of Julia. License is MIT: https://julialang.org/license
+
+module SubFoo
+thissub = "Foo1.SubFoo"
+end
diff -pruN 1.3.1+dfsg-1/test/ranges.jl 1.4.0+dfsg-1/test/ranges.jl
--- 1.3.1+dfsg-1/test/ranges.jl	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/test/ranges.jl	2020-03-21 16:36:32.000000000 +0000
@@ -572,24 +572,40 @@ end
     @test sum(0:0.000001:1) == 500000.5
     @test sum(0:0.1:10) == 505.
 end
-@testset "broadcasted operations with scalars" begin
-    @test broadcast(-, 1:3) === -1:-1:-3
-    @test broadcast(-, 1:3, 2) === -1:1
-    @test broadcast(-, 1:3, 0.25) === 1-0.25:3-0.25
-    @test broadcast(+, 1:3) === 1:3
-    @test broadcast(+, 1:3, 2) === 3:5
-    @test broadcast(+, 1:3, 0.25) === 1+0.25:3+0.25
-    @test broadcast(+, 1:2:6, 1) === 2:2:6
-    @test broadcast(+, 1:2:6, 0.3) === 1+0.3:2:5+0.3
-    @test broadcast(-, 1:2:6, 1) === 0:2:4
-    @test broadcast(-, 1:2:6, 0.3) === 1-0.3:2:5-0.3
-    @test broadcast(-, 2, 1:3) === 1:-1:-1
-end
-@testset "operations between ranges and arrays" begin
-    @test all(([1:5;] + (5:-1:1)) .== 6)
-    @test all(((5:-1:1) + [1:5;]) .== 6)
-    @test all(([1:5;] - (1:5)) .== 0)
-    @test all(((1:5) - [1:5;]) .== 0)
+@testset "broadcasted operations with scalars" for T in (Int, UInt, Int128)
+    @test broadcast(-, T(1):3, 2) === T(1)-2:1
+    @test broadcast(-, T(1):3, 0.25) === T(1)-0.25:3-0.25
+    @test broadcast(+, T(1):3) === T(1):3
+    @test broadcast(+, T(1):3, 2) === T(3):5
+    @test broadcast(+, T(1):3, 0.25) === T(1)+0.25:3+0.25
+    @test broadcast(+, T(1):2:6, 1) === T(2):2:6
+    @test broadcast(+, T(1):2:6, 0.3) === T(1)+0.3:2:5+0.3
+    @test broadcast(-, T(1):2:6, 1) === T(0):2:4
+    @test broadcast(-, T(1):2:6, 0.3) === T(1)-0.3:2:5-0.3
+    if T <: Unsigned
+        @test_broken broadcast(-, T(1):3) == -T(1):-1:-T(3)
+        @test_broken broadcast(-, 2, T(1):3) == T(1):-1:-T(1)
+    else
+        @test length(broadcast(-, T(1):3, 2)) === length(T(1)-2:T(3)-2)
+        @test broadcast(-, T(1):3) == -T(1):-1:-T(3)
+        @test broadcast(-, 2, T(1):3) == T(1):-1:-T(1)
+    end
+end
+@testset "operations between ranges and arrays" for T in (Int, UInt, Int128)
+    @test all(([T(1):5;] + (T(5):-1:1)) .=== T(6))
+    @test all(((T(5):-1:1) + [T(1):5;]) .=== T(6))
+    @test all(([T(1):5;] - (T(1):5)) .=== T(0))
+    @test all(((T(1):5) - [T(1):5;]) .=== T(0))
+end
+@testset "issue #32442: Broadcasting over views with non-`Int` indices" begin
+    a=rand(UInt32,20)
+    c=rand(UInt64,5)
+    @test reinterpret(UInt64,view(a,UInt64.(11:20))) .- c ==
+          reinterpret(UInt64,view(a,(11:20))) .- c ==
+          reinterpret(UInt64,view(a,(UInt64(11):UInt64(20)))) .- c ==
+          copy(reinterpret(UInt64,view(a,(UInt64(11):UInt64(20))))) .- c
+
+    @test view(a,(Int32(11):Int32(20))) .+ [1] == a[11:20] .+ 1
 end
 @testset "tricky floating-point ranges" begin
     for (start, step, stop, len) in ((1, 1, 3, 3), (0, 1, 3, 4),
@@ -1492,8 +1508,6 @@ end
 end
 
 @testset "allocation of TwicePrecision call" begin
-    0:286.493442:360
-    0:286:360
     @test @allocated(0:286.493442:360) == 0
     @test @allocated(0:286:360) == 0
 end
diff -pruN 1.3.1+dfsg-1/test/rational.jl 1.4.0+dfsg-1/test/rational.jl
--- 1.3.1+dfsg-1/test/rational.jl	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/test/rational.jl	2020-03-21 16:36:32.000000000 +0000
@@ -32,6 +32,10 @@ using Test
     @test_throws ArgumentError rationalize(Int, big(3.0), -1.)
     # issue 26823
     @test_throws InexactError rationalize(Int, NaN)
+    # issue 32569
+    @test_throws ArgumentError 1 // typemin(Int)
+    @test -2 // typemin(Int) == -1 // (typemin(Int) >> 1)
+    @test 2 // typemin(Int) == 1 // (typemin(Int) >> 1)
 
     for a = -5:5, b = -5:5
         if a == b == 0; continue; end
@@ -377,3 +381,25 @@ end
    @test -Rational(true) == -1//1
    @test -Rational(false) == 0//1
 end
+
+# issue #27039
+@testset "gcd, lcm, gcdx for Rational" begin
+    a = 6 // 35
+    b = 10 // 21
+    @test gcd(a, b) == 2//105
+    @test lcm(a, b) == 30//7
+    @test gcdx(a, b) == (2//105, -11, 4)
+
+    @test gcdx(1//0, 1//2) == (1//0, 1, 0)
+    @test gcdx(1//2, 1//0) == (1//0, 0, 1)
+    @test gcdx(1//0, 1//0) == (1//0, 1, 1)
+    @test gcdx(1//0, 0//1) == (1//0, 1, 0)
+
+    @test gcdx(1//3, 2) == (1//3, 1, 0)
+    @test lcm(1//3, 1) == 1//1
+    @test lcm(3//1, 1//0) == 3//1
+    @test lcm(0//1, 1//0) == 0//1
+
+    @test gcd([5, 2, 1//2]) == 1//2
+end
+
diff -pruN 1.3.1+dfsg-1/test/read.jl 1.4.0+dfsg-1/test/read.jl
--- 1.3.1+dfsg-1/test/read.jl	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/test/read.jl	2020-03-21 16:36:32.000000000 +0000
@@ -574,3 +574,25 @@ end
 
 # issue #26419
 @test Base.return_types(read, (String, Type{String})) == Any[String]
+
+@testset "read! to view" begin
+    x = rand(4, 4)
+    y = rand(10)
+    z = 1:10
+    v = [1.0, 2.0, 3.0, 4.0]
+    io = IOBuffer()
+    write(io, v)
+    flush(io)
+    seekstart(io)
+    read!(io, @view x[:, 3])
+    @test x[:, 3] == v
+    x = rand(3, 3)
+    seekstart(io)
+    read!(io, @view x[1:2, 2:3])
+    @test x[1:2, 2:3][:] == v[:]
+    seekstart(io)
+    read!(io, @view y[4:7])
+    @test y[4:7] == v
+    seekstart(io)
+    @test_throws ErrorException read!(io, @view z[4:6])
+end
diff -pruN 1.3.1+dfsg-1/test/reducedim.jl 1.4.0+dfsg-1/test/reducedim.jl
--- 1.3.1+dfsg-1/test/reducedim.jl	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/test/reducedim.jl	2020-03-21 16:36:32.000000000 +0000
@@ -398,3 +398,21 @@ end
     @test_throws DimensionMismatch maximum!(fill(0, 1, 1, 2, 1), B)
     @test_throws DimensionMismatch minimum!(fill(0, 1, 1, 2, 1), B)
 end
+
+# issue #26709
+@testset "dimensional reduce with custom non-bitstype types" begin
+    struct Variable
+        name::Symbol
+    end
+    struct AffExpr
+        vars::Vector{Variable}
+    end
+    Base.zero(::Union{Variable, Type{Variable}, AffExpr}) = AffExpr(Variable[])
+    Base.:+(v::Variable, w::Variable) = AffExpr([v, w])
+    Base.:+(aff::AffExpr, v::Variable) = AffExpr([aff.vars; v])
+    Base.:+(aff1::AffExpr, aff2::AffExpr) = AffExpr([aff1.vars; aff2.vars])
+    Base.:(==)(a::Variable, b::Variable) = a.name == b.name
+    Base.:(==)(a::AffExpr, b::AffExpr) = a.vars == b.vars
+
+    @test sum([Variable(:x), Variable(:y)], dims=1) == [AffExpr([Variable(:x), Variable(:y)])]
+end
diff -pruN 1.3.1+dfsg-1/test/reduce.jl 1.4.0+dfsg-1/test/reduce.jl
--- 1.3.1+dfsg-1/test/reduce.jl	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/test/reduce.jl	2020-03-21 16:36:32.000000000 +0000
@@ -30,6 +30,8 @@ using .Main.OffsetArrays
 
 @test Base.mapfoldr(abs2, -, 2:5) == -14
 @test Base.mapfoldr(abs2, -, 2:5; init=10) == -4
+@test @inferred(mapfoldr(x -> x + 1, (x, y) -> (x, y...), (1, 2.0, '3');
+                         init = ())) == (2, 3.0, '4')
 
 @test foldr((x, y) -> ('⟨' * x * '|' * y * '⟩'), "λ 🐨.α") == "⟨λ|⟨ |⟨🐨|⟨.|α⟩⟩⟩⟩" # issue #31780
 let x = rand(10)
@@ -533,3 +535,11 @@ x = [j^2 for j in i]
 i = Base.Slice(0:0)
 x = [j+7 for j in i]
 @test sum(x) == 7
+
+@testset "initial value handling with flatten" begin
+    @test mapfoldl(
+        x -> (x, x),
+        ((a, b), (c, d)) -> (min(a, c), max(b, d)),
+        Iterators.flatten((1:2, 3:4)),
+    ) == (1, 4)
+end
diff -pruN 1.3.1+dfsg-1/test/reflection.jl 1.4.0+dfsg-1/test/reflection.jl
--- 1.3.1+dfsg-1/test/reflection.jl	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/test/reflection.jl	2020-03-21 16:36:32.000000000 +0000
@@ -870,11 +870,12 @@ function _test_at_locals1(::Any, ::Any)
     @test @locals() == Dict{Symbol,Any}(:x=>1)
 end
 _test_at_locals1(1,1)
-function _test_at_locals2(a::Any, ::Any)
+function _test_at_locals2(a::Any, ::Any, c::T) where T
     x = 2
-    @test @locals() == Dict{Symbol,Any}(:x=>2,:a=>a)
+    @test @locals() == Dict{Symbol,Any}(:x=>2,:a=>a,:c=>c,:T=>typeof(c))
 end
-_test_at_locals2(1,1)
+_test_at_locals2(1,1,"")
+_test_at_locals2(1,1,0.5f0)
 
 @testset "issue #31687" begin
     import InteractiveUtils._dump_function
@@ -890,3 +891,34 @@ end
 
 @test nameof(Any) === :Any
 @test nameof(:) === :Colon
+@test nameof(Core.Intrinsics.mul_int) === :mul_int
+@test nameof(Core.Intrinsics.arraylen) === :arraylen
+
+module TestMod33403
+f(x) = 1
+f(x::Int) = 2
+g() = 3
+
+module Sub
+import ..TestMod33403: f
+f(x::Char) = 3
+end
+end
+
+@testset "methods with module" begin
+    using .TestMod33403: f, g
+    @test length(methods(f)) == 3
+    @test length(methods(f, (Int,))) == 1
+
+    @test length(methods(f, TestMod33403)) == 2
+    @test length(methods(f, [TestMod33403])) == 2
+    @test length(methods(f, (Int,), TestMod33403)) == 1
+    @test length(methods(f, (Int,), [TestMod33403])) == 1
+
+    @test length(methods(f, TestMod33403.Sub)) == 1
+    @test length(methods(f, [TestMod33403.Sub])) == 1
+    @test length(methods(f, (Char,), TestMod33403.Sub)) == 1
+    @test length(methods(f, (Int,), TestMod33403.Sub)) == 0
+
+    @test length(methods(g, ())) == 1
+end
diff -pruN 1.3.1+dfsg-1/test/runtests.jl 1.4.0+dfsg-1/test/runtests.jl
--- 1.3.1+dfsg-1/test/runtests.jl	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/test/runtests.jl	2020-03-21 16:36:32.000000000 +0000
@@ -2,15 +2,20 @@
 
 using Test
 using Distributed
+using Dates
 import REPL
-using Base.Printf: @sprintf
+using Printf: @sprintf
 
 include("choosetests.jl")
 include("testenv.jl")
 
-tests, net_on, exit_on_error, seed = choosetests(ARGS)
+tests, net_on, exit_on_error, use_revise, seed = choosetests(ARGS)
 tests = unique(tests)
 
+if use_revise
+    using Revise
+end
+
 const max_worker_rss = if haskey(ENV, "JULIA_TEST_MAXRSS_MB")
     parse(Int, ENV["JULIA_TEST_MAXRSS_MB"]) * 2^20
 else
@@ -70,26 +75,38 @@ cd(@__DIR__) do
 
     @everywhere include("testdefs.jl")
 
+    if use_revise
+        @everywhere begin
+            Revise.track(Core.Compiler)
+            Revise.track(Base)
+            Revise.revise()
+        end
+    end
+
     #pretty print the information about gc and mem usage
     testgroupheader = "Test"
     workerheader = "(Worker)"
-    name_align    = maximum([length(testgroupheader) + length(" ") + length(workerheader); map(x -> length(x) + 3 + ndigits(nworkers()), tests)])
-    elapsed_align = length("Time (s)")
-    gc_align      = length("GC (s)")
-    percent_align = length("GC %")
-    alloc_align   = length("Alloc (MB)")
-    rss_align     = length("RSS (MB)")
+    name_align    = maximum([textwidth(testgroupheader) + textwidth(" ") + textwidth(workerheader); map(x -> textwidth(x) + 3 + ndigits(nworkers()), tests)])
+    elapsed_align = textwidth("Time (s)")
+    gc_align      = textwidth("GC (s)")
+    percent_align = textwidth("GC %")
+    alloc_align   = textwidth("Alloc (MB)")
+    rss_align     = textwidth("RSS (MB)")
     printstyled(testgroupheader, color=:white)
-    printstyled(lpad(workerheader, name_align - length(testgroupheader) + 1), " | ", color=:white)
+    printstyled(lpad(workerheader, name_align - textwidth(testgroupheader) + 1), " | ", color=:white)
     printstyled("Time (s) | GC (s) | GC % | Alloc (MB) | RSS (MB)\n", color=:white)
-    results=[]
-    print_lock = ReentrantLock()
+    results = []
+    print_lock = stdout isa Base.LibuvStream ? stdout.lock : ReentrantLock()
+    if stderr isa Base.LibuvStream
+        stderr.lock = print_lock
+    end
 
     function print_testworker_stats(test, wrkr, resp)
+        @nospecialize resp
         lock(print_lock)
         try
             printstyled(test, color=:white)
-            printstyled(lpad("($wrkr)", name_align - length(test) + 1, " "), " | ", color=:white)
+            printstyled(lpad("($wrkr)", name_align - textwidth(test) + 1, " "), " | ", color=:white)
             time_str = @sprintf("%7.2f",resp[2])
             printstyled(lpad(time_str, elapsed_align, " "), " | ", color=:white)
             gc_str = @sprintf("%5.2f", resp[5].total_time / 10^9)
@@ -108,6 +125,29 @@ cd(@__DIR__) do
         end
     end
 
+    global print_testworker_started = (name, wrkr)->begin
+        lock(print_lock)
+        try
+            printstyled(name, color=:white)
+            printstyled(lpad("($wrkr)", name_align - textwidth(name) + 1, " "), " |",
+                " "^elapsed_align, "started at $(now())\n", color=:white)
+        finally
+            unlock(print_lock)
+        end
+    end
+
+    function print_testworker_errored(name, wrkr)
+        lock(print_lock)
+        try
+            printstyled(name, color=:red)
+            printstyled(lpad("($wrkr)", name_align - textwidth(name) + 1, " "), " |",
+                " "^elapsed_align, " failed at $(now())\n", color=:red)
+        finally
+            unlock(print_lock)
+        end
+    end
+
+
     all_tests = [tests; node1_tests]
 
     local stdin_monitor
@@ -115,6 +155,7 @@ cd(@__DIR__) do
     try
         # Monitor stdin and kill this task on ^C
         # but don't do this on Windows, because it may deadlock in the kernel
+        running_tests = Dict{String, DateTime}()
         if !Sys.iswindows() && isa(stdin, Base.TTY)
             t = current_task()
             stdin_monitor = @async begin
@@ -122,9 +163,16 @@ cd(@__DIR__) do
                 try
                     REPL.Terminals.raw!(term, true)
                     while true
-                        if read(term, Char) == '\x3'
+                        c = read(term, Char)
+                        if c == '\x3'
                             Base.throwto(t, InterruptException())
                             break
+                        elseif c == '?'
+                            println("Currently running: ")
+                            tests = sort(collect(running_tests), by=x->x[2])
+                            foreach(tests) do (test, date)
+                                println(test, " (running for ", round(now()-date, Minute), ")")
+                            end
                         end
                     end
                 catch e
@@ -140,31 +188,43 @@ cd(@__DIR__) do
                     push!(all_tasks, current_task())
                     while length(tests) > 0
                         test = popfirst!(tests)
+                        running_tests[test] = now()
                         local resp
                         wrkr = p
                         try
                             resp = remotecall_fetch(runtests, wrkr, test, test_path(test); seed=seed)
                         catch e
                             isa(e, InterruptException) && return
-                            resp = [e]
+                            resp = Any[e]
                         end
+                        delete!(running_tests, test)
                         push!(results, (test, resp))
                         if resp[1] isa Exception
+                            print_testworker_errored(test, wrkr)
                             if exit_on_error
                                 skipped = length(tests)
                                 empty!(tests)
-                            end
-                        elseif resp[end] > max_worker_rss
-                            if n > 1
+                            elseif n > 1
+                                # the worker encountered some failure, recycle it
+                                # so future tests get a fresh environment
                                 rmprocs(wrkr, waitfor=30)
                                 p = addprocs_with_testenv(1)[1]
                                 remotecall_fetch(include, p, "testdefs.jl")
-                            else # single process testing
-                                error("Halting tests. Memory limit reached : $resp > $max_worker_rss")
                             end
-                        end
-
-                        !isa(resp[1], Exception) && print_testworker_stats(test, wrkr, resp)
+                        else
+                            print_testworker_stats(test, wrkr, resp)
+                            if resp[end] > max_worker_rss
+                                # the worker has reached the max-rss limit, recycle it
+                                # so future tests start with a smaller working set
+                                if n > 1
+                                    rmprocs(wrkr, waitfor=30)
+                                    p = addprocs_with_testenv(1)[1]
+                                    remotecall_fetch(include, p, "testdefs.jl")
+                                else # single process testing
+                                    error("Halting tests. Memory limit reached : $resp > $max_worker_rss")
+                                end
+                            end
+                       end
                     end
                     if p != 1
                         # Free up memory =)
@@ -188,7 +248,7 @@ cd(@__DIR__) do
                 resp = eval(Expr(:call, () -> runtests(t, test_path(t), isolate, seed=seed))) # runtests is defined by the include above
                 print_testworker_stats(t, 1, resp)
             catch e
-                resp = [e]
+                resp = Any[e]
             end
             push!(results, (t, resp))
         end
@@ -237,63 +297,65 @@ cd(@__DIR__) do
     o_ts = Test.DefaultTestSet("Overall")
     Test.push_testset(o_ts)
     completed_tests = Set{String}()
-    for res in results
-        push!(completed_tests, res[1])
-        if isa(res[2][1], Test.DefaultTestSet)
-            Test.push_testset(res[2][1])
-            Test.record(o_ts, res[2][1])
+    for (testname, (resp,)) in results
+        push!(completed_tests, testname)
+        if isa(resp, Test.DefaultTestSet)
+            Test.push_testset(resp)
+            Test.record(o_ts, resp)
             Test.pop_testset()
-        elseif isa(res[2][1], Tuple{Int,Int})
-            fake = Test.DefaultTestSet(res[1])
-            for i in 1:res[2][1][1]
+        elseif isa(resp, Tuple{Int,Int})
+            fake = Test.DefaultTestSet(testname)
+            for i in 1:resp[1]
                 Test.record(fake, Test.Pass(:test, nothing, nothing, nothing))
             end
-            for i in 1:res[2][1][2]
+            for i in 1:resp[2]
                 Test.record(fake, Test.Broken(:test, nothing))
             end
             Test.push_testset(fake)
             Test.record(o_ts, fake)
             Test.pop_testset()
-        elseif isa(res[2][1], RemoteException) && isa(res[2][1].captured.ex, Test.TestSetException)
-            println("Worker $(res[2][1].pid) failed running test $(res[1]):")
-            Base.showerror(stdout,res[2][1].captured)
-            fake = Test.DefaultTestSet(res[1])
-            for i in 1:res[2][1].captured.ex.pass
+        elseif isa(resp, RemoteException) && isa(resp.captured.ex, Test.TestSetException)
+            println("Worker $(resp.pid) failed running test $(testname):")
+            Base.showerror(stdout, resp.captured)
+            println()
+            fake = Test.DefaultTestSet(testname)
+            for i in 1:resp.captured.ex.pass
                 Test.record(fake, Test.Pass(:test, nothing, nothing, nothing))
             end
-            for i in 1:res[2][1].captured.ex.broken
+            for i in 1:resp.captured.ex.broken
                 Test.record(fake, Test.Broken(:test, nothing))
             end
-            for t in res[2][1].captured.ex.errors_and_fails
+            for t in resp.captured.ex.errors_and_fails
                 Test.record(fake, t)
             end
             Test.push_testset(fake)
             Test.record(o_ts, fake)
             Test.pop_testset()
-        elseif isa(res[2][1], Exception)
+        else
+            if !isa(resp, Exception)
+                resp = ErrorException(string("Unknown result type : ", typeof(resp)))
+            end
             # If this test raised an exception that is not a remote testset exception,
             # i.e. not a RemoteException capturing a TestSetException that means
             # the test runner itself had some problem, so we may have hit a segfault,
             # deserialization errors or something similar.  Record this testset as Errored.
-            fake = Test.DefaultTestSet(res[1])
-            Test.record(fake, Test.Error(:test_error, res[1], res[2][1], [], LineNumberNode(1)))
+            fake = Test.DefaultTestSet(testname)
+            Test.record(fake, Test.Error(:test_error, testname, nothing, Any[(resp, [])], LineNumberNode(1)))
             Test.push_testset(fake)
             Test.record(o_ts, fake)
             Test.pop_testset()
-        else
-            error(string("Unknown result type : ", typeof(res)))
         end
     end
     for test in all_tests
         (test in completed_tests) && continue
         fake = Test.DefaultTestSet(test)
-        Test.record(fake, Test.Error(:test_interrupted, test, InterruptException(), [], LineNumberNode(1)))
+        Test.record(fake, Test.Error(:test_interrupted, test, nothing, [("skipped", [])], LineNumberNode(1)))
         Test.push_testset(fake)
         Test.record(o_ts, fake)
         Test.pop_testset()
     end
     println()
-    Test.print_test_results(o_ts,1)
+    Test.print_test_results(o_ts, 1)
     if !o_ts.anynonpass
         println("    \033[32;1mSUCCESS\033[0m")
     else
diff -pruN 1.3.1+dfsg-1/test/ryu.jl 1.4.0+dfsg-1/test/ryu.jl
--- 1.3.1+dfsg-1/test/ryu.jl	1970-01-01 00:00:00.000000000 +0000
+++ 1.4.0+dfsg-1/test/ryu.jl	2020-03-21 16:36:32.000000000 +0000
@@ -0,0 +1,770 @@
+# This file is a part of Julia. License is MIT: https://julialang.org/license
+
+using Base.Ryu
+
+const maxMantissa = (UInt64(1) << 53) - 1
+todouble(sign, exp, mant) = Core.bitcast(Float64, (UInt64(sign) << 63) | (UInt64(exp) << 52) | (UInt64(mant)))
+
+@testset "Ryu" begin
+
+@testset "Float64" begin
+
+@testset "Basic" begin
+    @test Ryu.writeshortest(0.0) == "0.0"
+    @test Ryu.writeshortest(-0.0) == "-0.0"
+    @test Ryu.writeshortest(1.0) == "1.0"
+    @test Ryu.writeshortest(-1.0) == "-1.0"
+    @test Ryu.writeshortest(NaN) == "NaN"
+    @test Ryu.writeshortest(Inf) == "Inf"
+    @test Ryu.writeshortest(-Inf) == "-Inf"
+end
+
+@testset "SwitchToSubnormal" begin
+    @test "2.2250738585072014e-308" == Ryu.writeshortest(2.2250738585072014e-308)
+end
+
+@testset "MinAndMax" begin
+    @test "1.7976931348623157e308" == Ryu.writeshortest(Core.bitcast(Float64, 0x7fefffffffffffff))
+    @test "5.0e-324" == Ryu.writeshortest(Core.bitcast(Float64, Int64(1)))
+end
+
+@testset "LotsOfTrailingZeros" begin
+    @test "2.9802322387695312e-8" == Ryu.writeshortest(2.98023223876953125e-8)
+end
+
+@testset "Regression" begin
+    @test "-2.109808898695963e16" == Ryu.writeshortest(-2.109808898695963e16)
+    @test "4.940656e-318" == Ryu.writeshortest(4.940656e-318)
+    @test "1.18575755e-316" == Ryu.writeshortest(1.18575755e-316)
+    @test "2.989102097996e-312" == Ryu.writeshortest(2.989102097996e-312)
+    @test "9.0608011534336e15" == Ryu.writeshortest(9.0608011534336e15)
+    @test "4.708356024711512e18" == Ryu.writeshortest(4.708356024711512e18)
+    @test "9.409340012568248e18" == Ryu.writeshortest(9.409340012568248e18)
+    @test "1.2345678" == Ryu.writeshortest(1.2345678)
+end
+
+@testset "LooksLikePow5" begin
+    # These numbers have a mantissa that is a multiple of the largest power of 5 that fits,
+    # and an exponent that causes the computation for q to result in 22, which is a corner
+    # case for Ryu.
+    @test "5.764607523034235e39" == Ryu.writeshortest(Core.bitcast(Float64, 0x4830F0CF064DD592))
+    @test "1.152921504606847e40" == Ryu.writeshortest(Core.bitcast(Float64, 0x4840F0CF064DD592))
+    @test "2.305843009213694e40" == Ryu.writeshortest(Core.bitcast(Float64, 0x4850F0CF064DD592))
+end
+
+@testset "OutputLength" begin
+    @test "1.0" == Ryu.writeshortest(1.0) # already tested in Basic
+    @test "1.2" == Ryu.writeshortest(1.2)
+    @test "1.23" == Ryu.writeshortest(1.23)
+    @test "1.234" == Ryu.writeshortest(1.234)
+    @test "1.2345" == Ryu.writeshortest(1.2345)
+    @test "1.23456" == Ryu.writeshortest(1.23456)
+    @test "1.234567" == Ryu.writeshortest(1.234567)
+    @test "1.2345678" == Ryu.writeshortest(1.2345678) # already tested in Regressi
+    @test "1.23456789" == Ryu.writeshortest(1.23456789)
+    @test "1.234567895" == Ryu.writeshortest(1.234567895) # 1.234567890 would be trimm
+    @test "1.2345678901" == Ryu.writeshortest(1.2345678901)
+    @test "1.23456789012" == Ryu.writeshortest(1.23456789012)
+    @test "1.234567890123" == Ryu.writeshortest(1.234567890123)
+    @test "1.2345678901234" == Ryu.writeshortest(1.2345678901234)
+    @test "1.23456789012345" == Ryu.writeshortest(1.23456789012345)
+    @test "1.234567890123456" == Ryu.writeshortest(1.234567890123456)
+    @test "1.2345678901234567" == Ryu.writeshortest(1.2345678901234567)
+
+  # Test 32-bit chunking
+    @test "4.294967294" == Ryu.writeshortest(4.294967294) # 2^32 -
+    @test "4.294967295" == Ryu.writeshortest(4.294967295) # 2^32 -
+    @test "4.294967296" == Ryu.writeshortest(4.294967296) # 2^
+    @test "4.294967297" == Ryu.writeshortest(4.294967297) # 2^32 +
+    @test "4.294967298" == Ryu.writeshortest(4.294967298) # 2^32 +
+end
+
+# Test min, max shift values in shiftright128
+@testset "MinMaxShift" begin
+    # 32-bit opt-size=0:  49 <= dist <= 50
+    # 32-bit opt-size=1:  30 <= dist <= 50
+    # 64-bit opt-size=0:  50 <= dist <= 50
+    # 64-bit opt-size=1:  30 <= dist <= 50
+    @test "1.7800590868057611e-307" == Ryu.writeshortest(todouble(false, 4, 0))
+    # 32-bit opt-size=0:  49 <= dist <= 49
+    # 32-bit opt-size=1:  28 <= dist <= 49
+    # 64-bit opt-size=0:  50 <= dist <= 50
+    # 64-bit opt-size=1:  28 <= dist <= 50
+    @test "2.8480945388892175e-306" == Ryu.writeshortest(todouble(false, 6, maxMantissa))
+    # 32-bit opt-size=0:  52 <= dist <= 53
+    # 32-bit opt-size=1:   2 <= dist <= 53
+    # 64-bit opt-size=0:  53 <= dist <= 53
+    # 64-bit opt-size=1:   2 <= dist <= 53
+    @test "2.446494580089078e-296" == Ryu.writeshortest(todouble(false, 41, 0))
+    # 32-bit opt-size=0:  52 <= dist <= 52
+    # 32-bit opt-size=1:   2 <= dist <= 52
+    # 64-bit opt-size=0:  53 <= dist <= 53
+    # 64-bit opt-size=1:   2 <= dist <= 53
+    @test "4.8929891601781557e-296" == Ryu.writeshortest(todouble(false, 40, maxMantissa))
+
+    # 32-bit opt-size=0:  57 <= dist <= 58
+    # 32-bit opt-size=1:  57 <= dist <= 58
+    # 64-bit opt-size=0:  58 <= dist <= 58
+    # 64-bit opt-size=1:  58 <= dist <= 58
+    @test "1.8014398509481984e16" == Ryu.writeshortest(todouble(false, 1077, 0))
+    # 32-bit opt-size=0:  57 <= dist <= 57
+    # 32-bit opt-size=1:  57 <= dist <= 57
+    # 64-bit opt-size=0:  58 <= dist <= 58
+    # 64-bit opt-size=1:  58 <= dist <= 58
+    @test "3.6028797018963964e16" == Ryu.writeshortest(todouble(false, 1076, maxMantissa))
+    # 32-bit opt-size=0:  51 <= dist <= 52
+    # 32-bit opt-size=1:  51 <= dist <= 59
+    # 64-bit opt-size=0:  52 <= dist <= 52
+    # 64-bit opt-size=1:  52 <= dist <= 59
+    @test "2.900835519859558e-216" == Ryu.writeshortest(todouble(false, 307, 0))
+    # 32-bit opt-size=0:  51 <= dist <= 51
+    # 32-bit opt-size=1:  51 <= dist <= 59
+    # 64-bit opt-size=0:  52 <= dist <= 52
+    # 64-bit opt-size=1:  52 <= dist <= 59
+    @test "5.801671039719115e-216" == Ryu.writeshortest(todouble(false, 306, maxMantissa))
+
+    # https:#github.com/ulfjack/ryu/commit/19e44d16d80236f5de25800f56d82606d1be00b9#commitcomment-30146483
+    # 32-bit opt-size=0:  49 <= dist <= 49
+    # 32-bit opt-size=1:  44 <= dist <= 49
+    # 64-bit opt-size=0:  50 <= dist <= 50
+    # 64-bit opt-size=1:  44 <= dist <= 50
+    @test "3.196104012172126e-27" == Ryu.writeshortest(todouble(false, 934, 0x000FA7161A4D6E0C))
+end
+
+@testset "SmallIntegers" begin
+    @test "9.007199254740991e15" == Ryu.writeshortest(9007199254740991.0)
+    @test "9.007199254740992e15" == Ryu.writeshortest(9007199254740992.0)
+
+    @test "1.0" == Ryu.writeshortest(1.0e+0)
+    @test "12.0" == Ryu.writeshortest(1.2e+1)
+    @test "123.0" == Ryu.writeshortest(1.23e+2)
+    @test "1234.0" == Ryu.writeshortest(1.234e+3)
+    @test "12345.0" == Ryu.writeshortest(1.2345e+4)
+    @test "123456.0" == Ryu.writeshortest(1.23456e+5)
+    @test "1.234567e6" == Ryu.writeshortest(1.234567e+6)
+    @test "1.2345678e7" == Ryu.writeshortest(1.2345678e+7)
+    @test "1.23456789e8" == Ryu.writeshortest(1.23456789e+8)
+    @test "1.23456789e9" == Ryu.writeshortest(1.23456789e+9)
+    @test "1.234567895e9" == Ryu.writeshortest(1.234567895e+9)
+    @test "1.2345678901e10" == Ryu.writeshortest(1.2345678901e+10)
+    @test "1.23456789012e11" == Ryu.writeshortest(1.23456789012e+11)
+    @test "1.234567890123e12" == Ryu.writeshortest(1.234567890123e+12)
+    @test "1.2345678901234e13" == Ryu.writeshortest(1.2345678901234e+13)
+    @test "1.23456789012345e14" == Ryu.writeshortest(1.23456789012345e+14)
+    @test "1.234567890123456e15" == Ryu.writeshortest(1.234567890123456e+15)
+
+  # 10^i
+    @test "1.0" == Ryu.writeshortest(1.0e+0)
+    @test "10.0" == Ryu.writeshortest(1.0e+1)
+    @test "100.0" == Ryu.writeshortest(1.0e+2)
+    @test "1000.0" == Ryu.writeshortest(1.0e+3)
+    @test "10000.0" == Ryu.writeshortest(1.0e+4)
+    @test "100000.0" == Ryu.writeshortest(1.0e+5)
+    @test "1.0e6" == Ryu.writeshortest(1.0e+6)
+    @test "1.0e7" == Ryu.writeshortest(1.0e+7)
+    @test "1.0e8" == Ryu.writeshortest(1.0e+8)
+    @test "1.0e9" == Ryu.writeshortest(1.0e+9)
+    @test "1.0e10" == Ryu.writeshortest(1.0e+10)
+    @test "1.0e11" == Ryu.writeshortest(1.0e+11)
+    @test "1.0e12" == Ryu.writeshortest(1.0e+12)
+    @test "1.0e13" == Ryu.writeshortest(1.0e+13)
+    @test "1.0e14" == Ryu.writeshortest(1.0e+14)
+    @test "1.0e15" == Ryu.writeshortest(1.0e+15)
+
+  # 10^15 + 10^i
+    @test "1.000000000000001e15" == Ryu.writeshortest(1.0e+15 + 1.0e+0)
+    @test "1.00000000000001e15" == Ryu.writeshortest(1.0e+15 + 1.0e+1)
+    @test "1.0000000000001e15" == Ryu.writeshortest(1.0e+15 + 1.0e+2)
+    @test "1.000000000001e15" == Ryu.writeshortest(1.0e+15 + 1.0e+3)
+    @test "1.00000000001e15" == Ryu.writeshortest(1.0e+15 + 1.0e+4)
+    @test "1.0000000001e15" == Ryu.writeshortest(1.0e+15 + 1.0e+5)
+    @test "1.000000001e15" == Ryu.writeshortest(1.0e+15 + 1.0e+6)
+    @test "1.00000001e15" == Ryu.writeshortest(1.0e+15 + 1.0e+7)
+    @test "1.0000001e15" == Ryu.writeshortest(1.0e+15 + 1.0e+8)
+    @test "1.000001e15" == Ryu.writeshortest(1.0e+15 + 1.0e+9)
+    @test "1.00001e15" == Ryu.writeshortest(1.0e+15 + 1.0e+10)
+    @test "1.0001e15" == Ryu.writeshortest(1.0e+15 + 1.0e+11)
+    @test "1.001e15" == Ryu.writeshortest(1.0e+15 + 1.0e+12)
+    @test "1.01e15" == Ryu.writeshortest(1.0e+15 + 1.0e+13)
+    @test "1.1e15" == Ryu.writeshortest(1.0e+15 + 1.0e+14)
+
+  # Largest power of 2 <= 10^(i+1)
+    @test "8.0" == Ryu.writeshortest(8.0)
+    @test "64.0" == Ryu.writeshortest(64.0)
+    @test "512.0" == Ryu.writeshortest(512.0)
+    @test "8192.0" == Ryu.writeshortest(8192.0)
+    @test "65536.0" == Ryu.writeshortest(65536.0)
+    @test "524288.0" == Ryu.writeshortest(524288.0)
+    @test "8.388608e6" == Ryu.writeshortest(8388608.0)
+    @test "6.7108864e7" == Ryu.writeshortest(67108864.0)
+    @test "5.36870912e8" == Ryu.writeshortest(536870912.0)
+    @test "8.589934592e9" == Ryu.writeshortest(8589934592.0)
+    @test "6.8719476736e10" == Ryu.writeshortest(68719476736.0)
+    @test "5.49755813888e11" == Ryu.writeshortest(549755813888.0)
+    @test "8.796093022208e12" == Ryu.writeshortest(8796093022208.0)
+    @test "7.0368744177664e13" == Ryu.writeshortest(70368744177664.0)
+    @test "5.62949953421312e14" == Ryu.writeshortest(562949953421312.0)
+    @test "9.007199254740992e15" == Ryu.writeshortest(9007199254740992.0)
+
+  # 1000 * (Largest power of 2 <= 10^(i+1))
+    @test "8000.0" == Ryu.writeshortest(8.0e+3)
+    @test "64000.0" == Ryu.writeshortest(64.0e+3)
+    @test "512000.0" == Ryu.writeshortest(512.0e+3)
+    @test "8.192e6" == Ryu.writeshortest(8192.0e+3)
+    @test "6.5536e7" == Ryu.writeshortest(65536.0e+3)
+    @test "5.24288e8" == Ryu.writeshortest(524288.0e+3)
+    @test "8.388608e9" == Ryu.writeshortest(8388608.0e+3)
+    @test "6.7108864e10" == Ryu.writeshortest(67108864.0e+3)
+    @test "5.36870912e11" == Ryu.writeshortest(536870912.0e+3)
+    @test "8.589934592e12" == Ryu.writeshortest(8589934592.0e+3)
+    @test "6.8719476736e13" == Ryu.writeshortest(68719476736.0e+3)
+    @test "5.49755813888e14" == Ryu.writeshortest(549755813888.0e+3)
+    @test "8.796093022208e15" == Ryu.writeshortest(8796093022208.0e+3)
+end
+
+end # Float64
+
+@testset "Float32" begin
+
+@testset "Basic" begin
+    @test "0.0" == Ryu.writeshortest(Float32(0.0))
+    @test "-0.0" == Ryu.writeshortest(Float32(-0.0))
+    @test "1.0" == Ryu.writeshortest(Float32(1.0))
+    @test "-1.0" == Ryu.writeshortest(Float32(-1.0))
+    @test "NaN" == Ryu.writeshortest(Float32(NaN))
+    @test "Inf" == Ryu.writeshortest(Float32(Inf))
+    @test "-Inf" == Ryu.writeshortest(Float32(-Inf))
+end
+
+@testset "SwitchToSubnormal" begin
+    @test "1.1754944e-38" == Ryu.writeshortest(1.1754944f-38)
+end
+
+@testset "MinAndMax" begin
+    @test "3.4028235e38" == Ryu.writeshortest(Core.bitcast(Float32, 0x7f7fffff))
+    @test "1.0e-45" == Ryu.writeshortest(Core.bitcast(Float32, Int32(1)))
+end
+
+# Check that we return the exact boundary if it is the shortest
+# representation, but only if the original floating point number is even.
+@testset "BoundaryRoundeven" begin
+    @test "3.355445e7" == Ryu.writeshortest(3.355445f7)
+    @test "9.0e9" == Ryu.writeshortest(8.999999f9)
+    @test "3.436672e10" == Ryu.writeshortest(3.4366717f10)
+end
+
+# If the exact value is exactly halfway between two shortest representations,
+# then we round to even. It seems like this only makes a difference if the
+# last two digits are ...2|5 or ...7|5, and we cut off the 5.
+@testset "exactValueRoundeven" begin
+    @test "305404.12" == Ryu.writeshortest(3.0540412f5)
+    @test "8099.0312" == Ryu.writeshortest(8.0990312f3)
+end
+
+@testset "LotsOfTrailingZeros" begin
+    # Pattern for the first test: 00111001100000000000000000000000
+    @test "0.00024414062" == Ryu.writeshortest(2.4414062f-4)
+    @test "0.0024414062" == Ryu.writeshortest(2.4414062f-3)
+    @test "0.0043945312" == Ryu.writeshortest(4.3945312f-3)
+    @test "0.0063476562" == Ryu.writeshortest(6.3476562f-3)
+end
+
+@testset "Regression" begin
+    @test "4.7223665e21" == Ryu.writeshortest(4.7223665f21)
+    @test "8.388608e6" == Ryu.writeshortest(8388608f0)
+    @test "1.6777216e7" == Ryu.writeshortest(1.6777216f7)
+    @test "3.3554436e7" == Ryu.writeshortest(3.3554436f7)
+    @test "6.7131496e7" == Ryu.writeshortest(6.7131496f7)
+    @test "1.9310392e-38" == Ryu.writeshortest(1.9310392f-38)
+    @test "-2.47e-43" == Ryu.writeshortest(-2.47f-43)
+    @test "1.993244e-38" == Ryu.writeshortest(1.993244f-38)
+    @test "4103.9004" == Ryu.writeshortest(4103.9003f0)
+    @test "5.3399997e9" == Ryu.writeshortest(5.3399997f9)
+    @test "6.0898e-39" == Ryu.writeshortest(6.0898f-39)
+    @test "0.0010310042" == Ryu.writeshortest(0.0010310042f0)
+    @test "2.882326e17" == Ryu.writeshortest(2.8823261f17)
+    @test "7.038531e-26" == Ryu.writeshortest(7.0385309f-26)
+    @test "9.223404e17" == Ryu.writeshortest(9.2234038f17)
+    @test "6.710887e7" == Ryu.writeshortest(6.7108872f7)
+    @test "1.0e-44" == Ryu.writeshortest(1.0f-44)
+    @test "2.816025e14" == Ryu.writeshortest(2.816025f14)
+    @test "9.223372e18" == Ryu.writeshortest(9.223372f18)
+    @test "1.5846086e29" == Ryu.writeshortest(1.5846085f29)
+    @test "1.1811161e19" == Ryu.writeshortest(1.1811161f19)
+    @test "5.368709e18" == Ryu.writeshortest(5.368709f18)
+    @test "4.6143166e18" == Ryu.writeshortest(4.6143165f18)
+    @test "0.007812537" == Ryu.writeshortest(0.007812537f0)
+    @test "1.0e-45" == Ryu.writeshortest(1.4f-45)
+    @test "1.18697725e20" == Ryu.writeshortest(1.18697724f20)
+    @test "1.00014165e-36" == Ryu.writeshortest(1.00014165f-36)
+    @test "200.0" == Ryu.writeshortest(200f0)
+    @test "3.3554432e7" == Ryu.writeshortest(3.3554432f7)
+end
+
+@testset "LooksLikePow5" begin
+    # These numbers have a mantissa that is the largest power of 5 that fits,
+    # and an exponent that causes the computation for q to result in 10, which is a corner
+    # case for Ryu.
+    @test "6.7108864e17" == Ryu.writeshortest(Core.bitcast(Float32, 0x5D1502F9))
+    @test "1.3421773e18" == Ryu.writeshortest(Core.bitcast(Float32, 0x5D9502F9))
+    @test "2.6843546e18" == Ryu.writeshortest(Core.bitcast(Float32, 0x5E1502F9))
+end
+
+@testset "OutputLength" begin
+    @test "1.0" == Ryu.writeshortest(Float32(1.0))
+    @test "1.2" == Ryu.writeshortest(Float32(1.2))
+    @test "1.23" == Ryu.writeshortest(Float32(1.23))
+    @test "1.234" == Ryu.writeshortest(Float32(1.234))
+    @test "1.2345" == Ryu.writeshortest(Float32(1.2345))
+    @test "1.23456" == Ryu.writeshortest(Float32(1.23456))
+    @test "1.234567" == Ryu.writeshortest(Float32(1.234567))
+    @test "1.2345678" == Ryu.writeshortest(Float32(1.2345678))
+    @test "1.23456735e-36" == Ryu.writeshortest(Float32(1.23456735e-36))
+end
+
+end # Float32
+
+@testset "Float16" begin
+
+@testset "Basic" begin
+    @test "0.0" == Ryu.writeshortest(Float16(0.0))
+    @test "-0.0" == Ryu.writeshortest(Float16(-0.0))
+    @test "1.0" == Ryu.writeshortest(Float16(1.0))
+    @test "-1.0" == Ryu.writeshortest(Float16(-1.0))
+    @test "NaN" == Ryu.writeshortest(Float16(NaN))
+    @test "Inf" == Ryu.writeshortest(Float16(Inf))
+    @test "-Inf" == Ryu.writeshortest(Float16(-Inf))
+end
+
+let x=floatmin(Float16)
+    while x <= floatmax(Float16)
+        @test parse(Float16, Ryu.writeshortest(x)) == x
+        x = nextfloat(x)
+    end
+end
+
+# function testfloats(T)
+#     x = floatmin(T)
+#     i = 0
+#     fails = 0
+#     success = 0
+#     while x < floatmax(T)
+#         test = parse(T, Ryu.writeshortest(x)) == x
+#         if !test
+
+#             fails += 1
+#         else
+#             success += 1
+#         end
+#         x = nextfloat(x)
+#         i += 1
+
+#     end
+#     return fails / (fails + success)
+# end
+
+end # Float16
+
+@testset "Ryu.writefixed" begin
+    @testset "Basic" begin
+        @test Ryu.writefixed(todouble(false, 1234, 99999), 0) ==
+            "3291009114715486435425664845573426149758869524108446525879746560"
+    end
+    @testset "Zero" begin
+        @test Ryu.writefixed(0.0, 4) == "0.0000"
+        @test Ryu.writefixed(0.0, 3) == "0.000"
+        @test Ryu.writefixed(0.0, 2) == "0.00"
+        @test Ryu.writefixed(0.0, 1) == "0.0"
+        @test Ryu.writefixed(0.0, 0) == "0"
+    end
+    @testset "MinMax" begin
+        @test Ryu.writefixed(todouble(false, 0, 1), 1074) ==
+            "0.0000000000000000000000000000000000000000000000000000000000000000000000000000000000000000" *
+            "000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000" *
+            "000000000000000000000000000000000000000000000000000000000000000000000000000000000000000000" *
+            "000000000000000000000000000000000000000000000000000000049406564584124654417656879286822137" *
+            "236505980261432476442558568250067550727020875186529983636163599237979656469544571773092665" *
+            "671035593979639877479601078187812630071319031140452784581716784898210368871863605699873072" *
+            "305000638740915356498438731247339727316961514003171538539807412623856559117102665855668676" *
+            "818703956031062493194527159149245532930545654440112748012970999954193198940908041656332452" *
+            "475714786901472678015935523861155013480352649347201937902681071074917033322268447533357208" *
+            "324319360923828934583680601060115061698097530783422773183292479049825247307763759272478746" *
+            "560847782037344696995336470179726777175851256605511991315048911014510378627381672509558373" *
+            "89733598993664809941164205702637090279242767544565229087538682506419718265533447265625"
+        @test Ryu.writefixed(todouble(false, 2046, 0xFFFFFFFFFFFFF), 0) ==
+            "179769313486231570814527423731704356798070567525844996598917476803157260780028538760589558" *
+            "632766878171540458953514382464234321326889464182768467546703537516986049910576551282076245" *
+            "490090389328944075868508455133942304583236903222948165808559332123348274797826204144723168" *
+            "738177180919299881250404026184124858368"
+    end
+    @testset "RoundToEven" begin
+        @test Ryu.writefixed(0.125, 3) == "0.125"
+        @test Ryu.writefixed(0.125, 2) == "0.12"
+        @test Ryu.writefixed(0.375, 3) == "0.375"
+        @test Ryu.writefixed(0.375, 2) == "0.38"
+    end
+    @testset "RoundToEvenInteger" begin
+        @test Ryu.writefixed(2.5, 1) == "2.5"
+        @test Ryu.writefixed(2.5, 0) == "2"
+        @test Ryu.writefixed(3.5, 1) == "3.5"
+        @test Ryu.writefixed(3.5, 0) == "4"
+    end
+    @testset "NonRoundToEvenScenarios" begin
+        @test Ryu.writefixed(0.748046875, 3) == "0.748"
+        @test Ryu.writefixed(0.748046875, 2) == "0.75"
+        @test Ryu.writefixed(0.748046875, 1) == "0.7"
+
+        @test Ryu.writefixed(0.2509765625, 3) == "0.251"
+        @test Ryu.writefixed(0.2509765625, 2) == "0.25"
+        @test Ryu.writefixed(0.2509765625, 1) == "0.3"
+
+        @test Ryu.writefixed(todouble(false, 1021, 1), 54) == "0.250000000000000055511151231257827021181583404541015625"
+        @test Ryu.writefixed(todouble(false, 1021, 1),  3) == "0.250"
+        @test Ryu.writefixed(todouble(false, 1021, 1),  2) == "0.25"
+        @test Ryu.writefixed(todouble(false, 1021, 1),  1) == "0.3"
+    end
+    @testset "VaryingPrecision" begin
+        @test Ryu.writefixed(1729.142857142857, 47) == "1729.14285714285711037518922239542007446289062500000"
+        @test Ryu.writefixed(1729.142857142857, 46) == "1729.1428571428571103751892223954200744628906250000"
+        @test Ryu.writefixed(1729.142857142857, 45) == "1729.142857142857110375189222395420074462890625000"
+        @test Ryu.writefixed(1729.142857142857, 44) == "1729.14285714285711037518922239542007446289062500"
+        @test Ryu.writefixed(1729.142857142857, 43) == "1729.1428571428571103751892223954200744628906250"
+        @test Ryu.writefixed(1729.142857142857, 42) == "1729.142857142857110375189222395420074462890625"
+        @test Ryu.writefixed(1729.142857142857, 41) == "1729.14285714285711037518922239542007446289062"
+        @test Ryu.writefixed(1729.142857142857, 40) == "1729.1428571428571103751892223954200744628906"
+        @test Ryu.writefixed(1729.142857142857, 39) == "1729.142857142857110375189222395420074462891"
+        @test Ryu.writefixed(1729.142857142857, 38) == "1729.14285714285711037518922239542007446289"
+        @test Ryu.writefixed(1729.142857142857, 37) == "1729.1428571428571103751892223954200744629"
+        @test Ryu.writefixed(1729.142857142857, 36) == "1729.142857142857110375189222395420074463"
+        @test Ryu.writefixed(1729.142857142857, 35) == "1729.14285714285711037518922239542007446"
+        @test Ryu.writefixed(1729.142857142857, 34) == "1729.1428571428571103751892223954200745"
+        @test Ryu.writefixed(1729.142857142857, 33) == "1729.142857142857110375189222395420074"
+        @test Ryu.writefixed(1729.142857142857, 32) == "1729.14285714285711037518922239542007"
+        @test Ryu.writefixed(1729.142857142857, 31) == "1729.1428571428571103751892223954201"
+        @test Ryu.writefixed(1729.142857142857, 30) == "1729.142857142857110375189222395420"
+        @test Ryu.writefixed(1729.142857142857, 29) == "1729.14285714285711037518922239542"
+        @test Ryu.writefixed(1729.142857142857, 28) == "1729.1428571428571103751892223954"
+        @test Ryu.writefixed(1729.142857142857, 27) == "1729.142857142857110375189222395"
+        @test Ryu.writefixed(1729.142857142857, 26) == "1729.14285714285711037518922240"
+        @test Ryu.writefixed(1729.142857142857, 25) == "1729.1428571428571103751892224"
+        @test Ryu.writefixed(1729.142857142857, 24) == "1729.142857142857110375189222"
+        @test Ryu.writefixed(1729.142857142857, 23) == "1729.14285714285711037518922"
+        @test Ryu.writefixed(1729.142857142857, 22) == "1729.1428571428571103751892"
+        @test Ryu.writefixed(1729.142857142857, 21) == "1729.142857142857110375189"
+        @test Ryu.writefixed(1729.142857142857, 20) == "1729.14285714285711037519"
+        @test Ryu.writefixed(1729.142857142857, 19) == "1729.1428571428571103752"
+        @test Ryu.writefixed(1729.142857142857, 18) == "1729.142857142857110375"
+        @test Ryu.writefixed(1729.142857142857, 17) == "1729.14285714285711038"
+        @test Ryu.writefixed(1729.142857142857, 16) == "1729.1428571428571104"
+        @test Ryu.writefixed(1729.142857142857, 15) == "1729.142857142857110"
+        @test Ryu.writefixed(1729.142857142857, 14) == "1729.14285714285711"
+        @test Ryu.writefixed(1729.142857142857, 13) == "1729.1428571428571"
+        @test Ryu.writefixed(1729.142857142857, 12) == "1729.142857142857"
+        @test Ryu.writefixed(1729.142857142857, 11) == "1729.14285714286"
+        @test Ryu.writefixed(1729.142857142857, 10) == "1729.1428571429"
+        @test Ryu.writefixed(1729.142857142857,  9) == "1729.142857143"
+        @test Ryu.writefixed(1729.142857142857,  8) == "1729.14285714"
+        @test Ryu.writefixed(1729.142857142857,  7) == "1729.1428571"
+        @test Ryu.writefixed(1729.142857142857,  6) == "1729.142857"
+        @test Ryu.writefixed(1729.142857142857,  5) == "1729.14286"
+        @test Ryu.writefixed(1729.142857142857,  4) == "1729.1429"
+        @test Ryu.writefixed(1729.142857142857,  3) == "1729.143"
+        @test Ryu.writefixed(1729.142857142857,  2) == "1729.14"
+        @test Ryu.writefixed(1729.142857142857,  1) == "1729.1"
+        @test Ryu.writefixed(1729.142857142857,  0) == "1729"
+    end
+
+    @testset "Carrying" begin
+        @test Ryu.writefixed(  0.0009, 4) == "0.0009"
+        @test Ryu.writefixed(  0.0009, 3) == "0.001"
+        @test Ryu.writefixed(  0.0029, 4) == "0.0029"
+        @test Ryu.writefixed(  0.0029, 3) == "0.003"
+        @test Ryu.writefixed(  0.0099, 4) == "0.0099"
+        @test Ryu.writefixed(  0.0099, 3) == "0.010"
+        @test Ryu.writefixed(  0.0299, 4) == "0.0299"
+        @test Ryu.writefixed(  0.0299, 3) == "0.030"
+        @test Ryu.writefixed(  0.0999, 4) == "0.0999"
+        @test Ryu.writefixed(  0.0999, 3) == "0.100"
+        @test Ryu.writefixed(  0.2999, 4) == "0.2999"
+        @test Ryu.writefixed(  0.2999, 3) == "0.300"
+        @test Ryu.writefixed(  0.9999, 4) == "0.9999"
+        @test Ryu.writefixed(  0.9999, 3) == "1.000"
+        @test Ryu.writefixed(  2.9999, 4) == "2.9999"
+        @test Ryu.writefixed(  2.9999, 3) == "3.000"
+        @test Ryu.writefixed(  9.9999, 4) == "9.9999"
+        @test Ryu.writefixed(  9.9999, 3) == "10.000"
+        @test Ryu.writefixed( 29.9999, 4) == "29.9999"
+        @test Ryu.writefixed( 29.9999, 3) == "30.000"
+        @test Ryu.writefixed( 99.9999, 4) == "99.9999"
+        @test Ryu.writefixed( 99.9999, 3) == "100.000"
+        @test Ryu.writefixed(299.9999, 4) == "299.9999"
+        @test Ryu.writefixed(299.9999, 3) == "300.000"
+
+        @test Ryu.writefixed(  0.09, 2) == "0.09"
+        @test Ryu.writefixed(  0.09, 1) == "0.1"
+        @test Ryu.writefixed(  0.29, 2) == "0.29"
+        @test Ryu.writefixed(  0.29, 1) == "0.3"
+        @test Ryu.writefixed(  0.99, 2) == "0.99"
+        @test Ryu.writefixed(  0.99, 1) == "1.0"
+        @test Ryu.writefixed(  2.99, 2) == "2.99"
+        @test Ryu.writefixed(  2.99, 1) == "3.0"
+        @test Ryu.writefixed(  9.99, 2) == "9.99"
+        @test Ryu.writefixed(  9.99, 1) == "10.0"
+        @test Ryu.writefixed( 29.99, 2) == "29.99"
+        @test Ryu.writefixed( 29.99, 1) == "30.0"
+        @test Ryu.writefixed( 99.99, 2) == "99.99"
+        @test Ryu.writefixed( 99.99, 1) == "100.0"
+        @test Ryu.writefixed(299.99, 2) == "299.99"
+        @test Ryu.writefixed(299.99, 1) == "300.0"
+
+        @test Ryu.writefixed(  0.9, 1) == "0.9"
+        @test Ryu.writefixed(  0.9, 0) == "1"
+        @test Ryu.writefixed(  2.9, 1) == "2.9"
+        @test Ryu.writefixed(  2.9, 0) == "3"
+        @test Ryu.writefixed(  9.9, 1) == "9.9"
+        @test Ryu.writefixed(  9.9, 0) == "10"
+        @test Ryu.writefixed( 29.9, 1) == "29.9"
+        @test Ryu.writefixed( 29.9, 0) == "30"
+        @test Ryu.writefixed( 99.9, 1) == "99.9"
+        @test Ryu.writefixed( 99.9, 0) == "100"
+        @test Ryu.writefixed(299.9, 1) == "299.9"
+        @test Ryu.writefixed(299.9, 0) == "300"
+    end
+
+    @testset "RoundingResultZero" begin
+        @test Ryu.writefixed(0.004, 3) == "0.004"
+        @test Ryu.writefixed(0.004, 2) == "0.00"
+        @test Ryu.writefixed(0.4, 1) == "0.4"
+        @test Ryu.writefixed(0.4, 0) == "0"
+        @test Ryu.writefixed(0.5, 1) == "0.5"
+        @test Ryu.writefixed(0.5, 0) == "0"
+    end
+
+    @testset "Regression" begin
+        @test Ryu.writefixed(7.018232e-82, 6) == "0.000000"
+    end
+
+end # fixed
+
+@testset "Ryu.writeexp" begin
+
+@testset "Basic" begin
+    @test Ryu.writeexp(todouble(false, 1234, 99999), 62) ==
+    "3.29100911471548643542566484557342614975886952410844652587974656e+63"
+end
+
+@testset "Zero" begin
+    @test Ryu.writeexp(0.0, 4) == "0.0000e+00"
+    @test Ryu.writeexp(0.0, 3) == "0.000e+00"
+    @test Ryu.writeexp(0.0, 2) == "0.00e+00"
+    @test Ryu.writeexp(0.0, 1) == "0.0e+00"
+    @test Ryu.writeexp(0.0, 0) == "0e+00"
+end
+
+@testset "MinMax" begin
+    @test Ryu.writeexp(todouble(false, 0, 1), 750) ==
+    "4.9406564584124654417656879286822137236505980261432476442558568250067550727020875186529983" *
+    "636163599237979656469544571773092665671035593979639877479601078187812630071319031140452784" *
+    "581716784898210368871863605699873072305000638740915356498438731247339727316961514003171538" *
+    "539807412623856559117102665855668676818703956031062493194527159149245532930545654440112748" *
+    "012970999954193198940908041656332452475714786901472678015935523861155013480352649347201937" *
+    "902681071074917033322268447533357208324319360923828934583680601060115061698097530783422773" *
+    "183292479049825247307763759272478746560847782037344696995336470179726777175851256605511991" *
+    "315048911014510378627381672509558373897335989936648099411642057026370902792427675445652290" *
+    "87538682506419718265533447265625e-324"
+
+    @test Ryu.writeexp(todouble(false, 2046, 0xFFFFFFFFFFFFF), 308) ==
+    "1.7976931348623157081452742373170435679807056752584499659891747680315726078002853876058955" *
+    "863276687817154045895351438246423432132688946418276846754670353751698604991057655128207624" *
+    "549009038932894407586850845513394230458323690322294816580855933212334827479782620414472316" *
+    "8738177180919299881250404026184124858368e+308"
+end
+
+@testset "RoundToEven" begin
+    @test Ryu.writeexp(0.125, 2) == "1.25e-01"
+    @test Ryu.writeexp(0.125, 1) == "1.2e-01"
+    @test Ryu.writeexp(0.375, 2) == "3.75e-01"
+    @test Ryu.writeexp(0.375, 1) == "3.8e-01"
+end
+
+@testset "RoundToEvenInteger" begin
+    @test Ryu.writeexp(2.5, 1) == "2.5e+00"
+    @test Ryu.writeexp(2.5, 0) == "2e+00"
+    @test Ryu.writeexp(3.5, 1) == "3.5e+00"
+    @test Ryu.writeexp(3.5, 0) == "4e+00"
+end
+
+@testset "NonRoundToEvenScenarios" begin
+    @test Ryu.writeexp(0.748046875, 2) == "7.48e-01"
+    @test Ryu.writeexp(0.748046875, 1) == "7.5e-01"
+    @test Ryu.writeexp(0.748046875, 0) == "7e-01"    # 0.75 would round to "8e-01", but this is smaller
+
+    @test Ryu.writeexp(0.2509765625, 2) == "2.51e-01"
+    @test Ryu.writeexp(0.2509765625, 1) == "2.5e-01"
+    @test Ryu.writeexp(0.2509765625, 0) == "3e-01"    # 0.25 would round to "2e-01", but this is larger
+
+    @test Ryu.writeexp(todouble(false, 1021, 1), 53) ==
+    "2.50000000000000055511151231257827021181583404541015625e-01"
+    @test Ryu.writeexp(todouble(false, 1021, 1),  2) ==
+    "2.50e-01"
+    @test Ryu.writeexp(todouble(false, 1021, 1),  1) ==
+    "2.5e-01"
+    @test Ryu.writeexp(todouble(false, 1021, 1),  0) ==
+    "3e-01"    # 0.25 would round to "2e-01", but this is larger (again)
+end
+
+@testset "VaryingPrecision" begin
+    @test Ryu.writeexp(1729.142857142857, 50) == "1.72914285714285711037518922239542007446289062500000e+03"
+    @test Ryu.writeexp(1729.142857142857, 49) == "1.7291428571428571103751892223954200744628906250000e+03"
+    @test Ryu.writeexp(1729.142857142857, 48) == "1.729142857142857110375189222395420074462890625000e+03"
+    @test Ryu.writeexp(1729.142857142857, 47) == "1.72914285714285711037518922239542007446289062500e+03"
+    @test Ryu.writeexp(1729.142857142857, 46) == "1.7291428571428571103751892223954200744628906250e+03"
+    @test Ryu.writeexp(1729.142857142857, 45) == "1.729142857142857110375189222395420074462890625e+03"
+    @test Ryu.writeexp(1729.142857142857, 44) == "1.72914285714285711037518922239542007446289062e+03"
+    @test Ryu.writeexp(1729.142857142857, 43) == "1.7291428571428571103751892223954200744628906e+03"
+    @test Ryu.writeexp(1729.142857142857, 42) == "1.729142857142857110375189222395420074462891e+03"
+    @test Ryu.writeexp(1729.142857142857, 41) == "1.72914285714285711037518922239542007446289e+03"
+    @test Ryu.writeexp(1729.142857142857, 40) == "1.7291428571428571103751892223954200744629e+03"
+    @test Ryu.writeexp(1729.142857142857, 39) == "1.729142857142857110375189222395420074463e+03"
+    @test Ryu.writeexp(1729.142857142857, 38) == "1.72914285714285711037518922239542007446e+03"
+    @test Ryu.writeexp(1729.142857142857, 37) == "1.7291428571428571103751892223954200745e+03"
+    @test Ryu.writeexp(1729.142857142857, 36) == "1.729142857142857110375189222395420074e+03"
+    @test Ryu.writeexp(1729.142857142857, 35) == "1.72914285714285711037518922239542007e+03"
+    @test Ryu.writeexp(1729.142857142857, 34) == "1.7291428571428571103751892223954201e+03"
+    @test Ryu.writeexp(1729.142857142857, 33) == "1.729142857142857110375189222395420e+03"
+    @test Ryu.writeexp(1729.142857142857, 32) == "1.72914285714285711037518922239542e+03"
+    @test Ryu.writeexp(1729.142857142857, 31) == "1.7291428571428571103751892223954e+03"
+    @test Ryu.writeexp(1729.142857142857, 30) == "1.729142857142857110375189222395e+03"
+    @test Ryu.writeexp(1729.142857142857, 29) == "1.72914285714285711037518922240e+03"
+    @test Ryu.writeexp(1729.142857142857, 28) == "1.7291428571428571103751892224e+03"
+    @test Ryu.writeexp(1729.142857142857, 27) == "1.729142857142857110375189222e+03"
+    @test Ryu.writeexp(1729.142857142857, 26) == "1.72914285714285711037518922e+03"
+    @test Ryu.writeexp(1729.142857142857, 25) == "1.7291428571428571103751892e+03"
+    @test Ryu.writeexp(1729.142857142857, 24) == "1.729142857142857110375189e+03"
+    @test Ryu.writeexp(1729.142857142857, 23) == "1.72914285714285711037519e+03"
+    @test Ryu.writeexp(1729.142857142857, 22) == "1.7291428571428571103752e+03"
+    @test Ryu.writeexp(1729.142857142857, 21) == "1.729142857142857110375e+03"
+    @test Ryu.writeexp(1729.142857142857, 20) == "1.72914285714285711038e+03"
+    @test Ryu.writeexp(1729.142857142857, 19) == "1.7291428571428571104e+03"
+    @test Ryu.writeexp(1729.142857142857, 18) == "1.729142857142857110e+03"
+    @test Ryu.writeexp(1729.142857142857, 17) == "1.72914285714285711e+03"
+    @test Ryu.writeexp(1729.142857142857, 16) == "1.7291428571428571e+03"
+    @test Ryu.writeexp(1729.142857142857, 15) == "1.729142857142857e+03"
+    @test Ryu.writeexp(1729.142857142857, 14) == "1.72914285714286e+03"
+    @test Ryu.writeexp(1729.142857142857, 13) == "1.7291428571429e+03"
+    @test Ryu.writeexp(1729.142857142857, 12) == "1.729142857143e+03"
+    @test Ryu.writeexp(1729.142857142857, 11) == "1.72914285714e+03"
+    @test Ryu.writeexp(1729.142857142857, 10) == "1.7291428571e+03"
+    @test Ryu.writeexp(1729.142857142857,  9) == "1.729142857e+03"
+    @test Ryu.writeexp(1729.142857142857,  8) == "1.72914286e+03"
+    @test Ryu.writeexp(1729.142857142857,  7) == "1.7291429e+03"
+    @test Ryu.writeexp(1729.142857142857,  6) == "1.729143e+03"
+    @test Ryu.writeexp(1729.142857142857,  5) == "1.72914e+03"
+    @test Ryu.writeexp(1729.142857142857,  4) == "1.7291e+03"
+    @test Ryu.writeexp(1729.142857142857,  3) == "1.729e+03"
+    @test Ryu.writeexp(1729.142857142857,  2) == "1.73e+03"
+    @test Ryu.writeexp(1729.142857142857,  1) == "1.7e+03"
+    @test Ryu.writeexp(1729.142857142857,  0) == "2e+03"
+end
+
+@testset "Carrying" begin
+    @test Ryu.writeexp(2.0009, 4) == "2.0009e+00"
+    @test Ryu.writeexp(2.0009, 3) == "2.001e+00"
+    @test Ryu.writeexp(2.0029, 4) == "2.0029e+00"
+    @test Ryu.writeexp(2.0029, 3) == "2.003e+00"
+    @test Ryu.writeexp(2.0099, 4) == "2.0099e+00"
+    @test Ryu.writeexp(2.0099, 3) == "2.010e+00"
+    @test Ryu.writeexp(2.0299, 4) == "2.0299e+00"
+    @test Ryu.writeexp(2.0299, 3) == "2.030e+00"
+    @test Ryu.writeexp(2.0999, 4) == "2.0999e+00"
+    @test Ryu.writeexp(2.0999, 3) == "2.100e+00"
+    @test Ryu.writeexp(2.2999, 4) == "2.2999e+00"
+    @test Ryu.writeexp(2.2999, 3) == "2.300e+00"
+    @test Ryu.writeexp(2.9999, 4) == "2.9999e+00"
+    @test Ryu.writeexp(2.9999, 3) == "3.000e+00"
+    @test Ryu.writeexp(9.9999, 4) == "9.9999e+00"
+    @test Ryu.writeexp(9.9999, 3) == "1.000e+01"
+
+    @test Ryu.writeexp(2.09, 2) == "2.09e+00"
+    @test Ryu.writeexp(2.09, 1) == "2.1e+00"
+    @test Ryu.writeexp(2.29, 2) == "2.29e+00"
+    @test Ryu.writeexp(2.29, 1) == "2.3e+00"
+    @test Ryu.writeexp(2.99, 2) == "2.99e+00"
+    @test Ryu.writeexp(2.99, 1) == "3.0e+00"
+    @test Ryu.writeexp(9.99, 2) == "9.99e+00"
+    @test Ryu.writeexp(9.99, 1) == "1.0e+01"
+
+    @test Ryu.writeexp(2.9, 1) == "2.9e+00"
+    @test Ryu.writeexp(2.9, 0) == "3e+00"
+    @test Ryu.writeexp(9.9, 1) == "9.9e+00"
+    @test Ryu.writeexp(9.9, 0) == "1e+01"
+end
+
+@testset "Exponents" begin
+    @test Ryu.writeexp(9.99e-100, 2) == "9.99e-100"
+    @test Ryu.writeexp(9.99e-99 , 2) == "9.99e-99"
+    @test Ryu.writeexp(9.99e-10 , 2) == "9.99e-10"
+    @test Ryu.writeexp(9.99e-09 , 2) == "9.99e-09"
+    @test Ryu.writeexp(9.99e-01 , 2) == "9.99e-01"
+    @test Ryu.writeexp(9.99e+00 , 2) == "9.99e+00"
+    @test Ryu.writeexp(9.99e+01 , 2) == "9.99e+01"
+    @test Ryu.writeexp(9.99e+09 , 2) == "9.99e+09"
+    @test Ryu.writeexp(9.99e+10 , 2) == "9.99e+10"
+    @test Ryu.writeexp(9.99e+99 , 2) == "9.99e+99"
+    @test Ryu.writeexp(9.99e+100, 2) == "9.99e+100"
+
+    @test Ryu.writeexp(9.99e-100, 1) == "1.0e-99"
+    @test Ryu.writeexp(9.99e-99 , 1) == "1.0e-98"
+    @test Ryu.writeexp(9.99e-10 , 1) == "1.0e-09"
+    @test Ryu.writeexp(9.99e-09 , 1) == "1.0e-08"
+    @test Ryu.writeexp(9.99e-01 , 1) == "1.0e+00"
+    @test Ryu.writeexp(9.99e+00 , 1) == "1.0e+01"
+    @test Ryu.writeexp(9.99e+01 , 1) == "1.0e+02"
+    @test Ryu.writeexp(9.99e+09 , 1) == "1.0e+10"
+    @test Ryu.writeexp(9.99e+10 , 1) == "1.0e+11"
+    @test Ryu.writeexp(9.99e+99 , 1) == "1.0e+100"
+    @test Ryu.writeexp(9.99e+100, 1) == "1.0e+101"
+end
+
+@testset "PrintDecimalPoint" begin
+  # These values exercise each codepath.
+    @test Ryu.writeexp(1e+54, 0) == "1e+54"
+    @test Ryu.writeexp(1e+54, 1) == "1.0e+54"
+    @test Ryu.writeexp(1e-63, 0) == "1e-63"
+    @test Ryu.writeexp(1e-63, 1) == "1.0e-63"
+    @test Ryu.writeexp(1e+83, 0) == "1e+83"
+    @test Ryu.writeexp(1e+83, 1) == "1.0e+83"
+end
+
+end # exp
+
+@testset "compact" begin
+
+    stringcompact(x) = sprint(show, x; context=:compact => true)
+
+    @test stringcompact(0.49999999) == "0.5"
+    @test stringcompact(0.459999999) == "0.46"
+    @test stringcompact(0.20058603493384108) == "0.200586"
+    @test stringcompact(0.9999999) == "1.0"
+    @test stringcompact(0.1999999) == "0.2"
+    @test stringcompact(123.4567) == "123.457"
+    @test stringcompact(0.001234567) == "0.00123457"
+    @test stringcompact(0.1234567) == "0.123457"
+    @test stringcompact(1234567.0) == "1.23457e6"
+    @test stringcompact(12345678910.0) == "1.23457e10"
+    @test stringcompact(12345678.0) == "1.23457e7"
+    @test stringcompact(0.10000049) == "0.1"
+    @test stringcompact(22.89825) == "22.8983"
+    @test stringcompact(0.646690981531646) == "0.646691"
+    @test stringcompact(6.938893903907228e-17) == "6.93889e-17"
+    @test stringcompact(1.015625) == "1.01562"
+    @test stringcompact(1.046875) == "1.04688"
+    @test stringcompact(0.025621074) == "0.0256211"
+
+    # subnormals
+    @test stringcompact(eps(0.0)) == "5.0e-324"
+    @test stringcompact(eps(0f0)) == "1.0f-45"
+    @test stringcompact(eps(Float16(0.0))) == "6.0e-8"
+end
+
+end # Ryu
diff -pruN 1.3.1+dfsg-1/test/sets.jl 1.4.0+dfsg-1/test/sets.jl
--- 1.3.1+dfsg-1/test/sets.jl	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/test/sets.jl	2020-03-21 16:36:32.000000000 +0000
@@ -347,6 +347,24 @@ end
     # symdiff must NOT uniquify
     @test symdiff([1, 2, 1]) == symdiff!([1, 2, 1]) == [2]
     @test symdiff([1, 2, 1], [2, 2]) == symdiff!([1, 2, 1], [2, 2]) == [2]
+
+    # Base.hasfastin
+    @test all(Base.hasfastin, Any[Dict(1=>2), Set(1), BitSet(1), 1:9, 1:2:9,
+                                  Dict, Set, BitSet, UnitRange, StepRange])
+    @test !any(Base.hasfastin, Any[[1, 2, 3], "123",
+                                   Array, String])
+
+    # tests for Dict
+    d1 = Dict(1=>nothing, 2=>nothing)
+    d2 = Dict(1=>nothing, 3=>nothing)
+    d3 = Dict(1=>nothing, 2=>nothing, 3=>nothing)
+    @test d3 == merge(d1, d2)
+    @test !issubset(d1, d2)
+    @test !issubset(d2, d1)
+    @test !issubset(d3, d1)
+    @test !issubset(d3, d2)
+    @test issubset(d1, d3)
+    @test issubset(d2, d3)
 end
 
 @testset "unique" begin
diff -pruN 1.3.1+dfsg-1/test/show.jl 1.4.0+dfsg-1/test/show.jl
--- 1.3.1+dfsg-1/test/show.jl	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/test/show.jl	2020-03-21 16:36:32.000000000 +0000
@@ -25,7 +25,7 @@ end
 @test replstr(Array{Any}(undef, 2)) == "2-element Array{Any,1}:\n #undef\n #undef"
 @test replstr(Array{Any}(undef, 2,2)) == "2×2 Array{Any,2}:\n #undef  #undef\n #undef  #undef"
 @test replstr(Array{Any}(undef, 2,2,2)) == "2×2×2 Array{Any,3}:\n[:, :, 1] =\n #undef  #undef\n #undef  #undef\n\n[:, :, 2] =\n #undef  #undef\n #undef  #undef"
-@test replstr([1f10]) == "1-element Array{Float32,1}:\n 1.0e10"
+@test replstr([1f10]) == "1-element Array{Float32,1}:\n 1.0f10"
 
 struct T5589
     names::Vector{String}
@@ -53,21 +53,78 @@ macro test_repr(x)
     # this is a macro instead of function so we can avoid getting useful backtraces :)
     return :(test_repr($(esc(x))))
 end
-function test_repr(x::String)
+macro weak_test_repr(x)
+    # this is a macro instead of function so we can avoid getting useful backtraces :)
+    return :(test_repr($(esc(x)), true))
+end
+function test_repr(x::String, remove_linenums::Bool = false)
     # Note: We can't just compare x1 and x2 because interpolated
     # strings get converted to string Exprs by the first show().
     # This could produce a few false positives, but until string
     # interpolation works we don't really have a choice.
+    #
+    # Rectification: comparing x1 and x2 seems to be working
     x1 = Meta.parse(x)
     x2 = eval(Meta.parse(repr(x1)))
     x3 = eval(Meta.parse(repr(x2)))
-    if x3 != x1
+    if !remove_linenums
+        if ! (x1 == x2 == x3)
+            error(string(
+                "\nrepr test (Rule 2) failed:",
+                "\noriginal: ", x,
+                "\n\npreparsed: ", x1, "\n", sprint(dump, x1),
+                "\n\nparsed: ", x2, "\n", sprint(dump, x2),
+                "\n\nreparsed: ", x3, "\n", sprint(dump, x3),
+                "\n\n"))
+        end
+        @test x1 == x2 == x3
+    end
+
+    x4 = Base.remove_linenums!(Meta.parse(x))
+    x5 = eval(Base.remove_linenums!(Meta.parse(repr(x4))))
+    x6 = eval(Base.remove_linenums!(Meta.parse(repr(x5))))
+    if ! (x4 == x5 == x6)
         error(string(
-            "repr test failed:",
+            "\nrepr test (Rule 2) without line numbers failed:",
             "\noriginal: ", x,
-            "\n\nparsed: ", x2, "\n", sprint(dump, x2),
-            "\n\nreparsed: ", x3, "\n", sprint(dump, x3)
-            ))
+            "\n\npreparsed: ", x4, "\n", sprint(dump, x4),
+            "\n\nparsed: ", x5, "\n", sprint(dump, x5),
+            "\n\nreparsed: ", x6, "\n", sprint(dump, x6),
+            "\n\n"))
+    end
+    @test x4 == x5 == x6
+
+    @test Base.remove_linenums!(x1) ==
+          Base.remove_linenums!(x2) ==
+          Base.remove_linenums!(x3) ==
+          x4 == x5 == x6
+
+    if isa(x1, Expr) && remove_linenums
+        if Base.remove_linenums!(Meta.parse(string(x1))) != x1
+            error(string(
+                "\nstring test (Rule 1) failed:",
+                "\noriginal: ", x,
+                "\n\npreparsed: ", x1, "\n", sprint(dump, x4),
+                "\n\nstring(preparsed): ", string(x1),
+                "\n\nBase.remove_linenums!(Meta.parse(string(preparsed))): ",
+                Base.remove_linenums!(Meta.parse(string(x1))), "\n",
+                sprint(dump, Base.remove_linenums!(Meta.parse(string(x1)))),
+                "\n\n"))
+        end
+        @test Base.remove_linenums!(Meta.parse(string(x1))) == x1
+    elseif isa(x1, Expr)
+        if Meta.parse(string(x1)) != x1
+            error(string(
+                "\nstring test (Rule 1) failed:",
+                "\noriginal: ", x,
+                "\n\npreparsed: ", x1, "\n", sprint(dump, x4),
+                "\n\nstring(preparsed): ", string(x1),
+                "\n\nMeta.parse(string(preparsed)): ",
+                Meta.parse(string(x1)), "\n",
+                sprint(dump, Meta.parse(string(x1))),
+                "\n\n"))
+        end
+        @test Meta.parse(string(x1)) == x1
     end
 end
 
@@ -143,9 +200,59 @@ end
 @test_repr "import A: a, x, y.z"
 @test_repr "import A.B.C: a, x, y.z"
 @test_repr "import ..A: a, x, y.z"
+@test_repr "import A.B, C.D"
+
+# keyword args (issue #34023 and #32775)
+@test_repr "f(a, b=c)"
+@test_repr "f(a, b! = c)"
+@test_repr "T{x=1}"
+@test_repr "[a=1]"
+@test_repr "a[x=1]"
+@test_repr "f(; a=1)"
+@test_repr "f(b=2; a=1)"
+@test_repr "@f(1, y=3)"
+@test_repr "n + (x=1)"
+@test_repr "(;x=1)"
+@test_repr "(x,;x=1)"
+@test_repr "(a=1,;x=1)"
+@test_repr "(a=1,b=2;x=1,y,:z=>2)"
+@test repr(:((a,;b))) == ":((a,; b))"
+@test repr(:((a=1,;x=2))) == ":((a = 1,; x = 2))"
+@test repr(:((a=1,3;x=2))) == ":((a = 1, 3; x = 2))"
+@test repr(:(g(a,; b))) == ":(g(a; b))"
+for ex in [Expr(:call, :f, Expr(:(=), :x, 1)),
+           Expr(:ref, :f, Expr(:(=), :x, 1)),
+           Expr(:vect, 1, 2, Expr(:kw, :x, 1)),
+           Expr(:kw, :a, :b),
+           Expr(:curly, :T, Expr(:kw, :x, 1)),
+           Expr(:call, :+, :n, Expr(:kw, :x, 1)),
+           :((a=1,; $(Expr(:(=), :x, 2)))),
+           :(($(Expr(:(=), :a, 1)),; x = 2)),
+           Expr(:tuple, Expr(:parameters))]
+    @test eval(Meta.parse(repr(ex))) == ex
+end
 
 @test repr(Expr(:using, :Foo)) == ":(\$(Expr(:using, :Foo)))"
 @test repr(Expr(:using, Expr(:(.), ))) == ":(\$(Expr(:using, :(\$(Expr(:.))))))"
+@test repr(Expr(:import, :Foo)) == ":(\$(Expr(:import, :Foo)))"
+@test repr(Expr(:import, Expr(:(.), ))) == ":(\$(Expr(:import, :(\$(Expr(:.))))))"
+
+@test repr(Expr(:using, Expr(:(.), :A))) == ":(using A)"
+@test repr(Expr(:using, Expr(:(.), :A),
+                        Expr(:(.), :B))) == ":(using A, B)"
+@test repr(Expr(:using, Expr(:(.), :A),
+                        Expr(:(.), :B, :C),
+                        Expr(:(.), :D))) == ":(using A, B.C, D)"
+@test repr(Expr(:using, Expr(:(.), :A, :B),
+                        Expr(:(.), :C, :D))) == ":(using A.B, C.D)"
+@test repr(Expr(:import, Expr(:(.), :A))) == ":(import A)"
+@test repr(Expr(:import, Expr(:(.), :A),
+                         Expr(:(.), :B))) == ":(import A, B)"
+@test repr(Expr(:import, Expr(:(.), :A),
+                         Expr(:(.), :B, :(C)),
+                         Expr(:(.), :D))) == ":(import A, B.C, D)"
+@test repr(Expr(:import, Expr(:(.), :A, :B),
+                         Expr(:(.), :C, :D))) == ":(import A.B, C.D)"
 
 # range syntax
 @test_repr "1:2"
@@ -163,7 +270,7 @@ end
 
 
 # control structures (shamelessly stolen from base/bitarray.jl)
-@test_repr """mutable struct BitArray{N} <: AbstractArray{Bool, N}
+@weak_test_repr """mutable struct BitArray{N} <: AbstractArray{Bool, N}
     # line meta
     chunks::Vector{UInt64}
     # line meta
@@ -210,7 +317,7 @@ end
     end
 end"""
 
-@test_repr """function copy_chunks(dest::Vector{UInt64}, pos_d::Integer, src::Vector{UInt64}, pos_s::Integer, numbits::Integer)
+@weak_test_repr """function copy_chunks(dest::Vector{UInt64}, pos_d::Integer, src::Vector{UInt64}, pos_s::Integer, numbits::Integer)
     # line meta
     if numbits == 0
         # line meta
@@ -289,13 +396,13 @@ end"""
     return
 end"""
 
-@test_repr """if a
+@weak_test_repr """if a
 # line meta
 b
 end
 """
 
-@test_repr """if a
+@weak_test_repr """if a
 # line meta
 b
 elseif c
@@ -304,7 +411,7 @@ d
 end
 """
 
-@test_repr """if a
+@weak_test_repr """if a
 # line meta
 b
 elseif c
@@ -316,7 +423,7 @@ e
 end
 """
 
-@test_repr """if a
+@weak_test_repr """if a
 # line meta
 b
 elseif c
@@ -328,7 +435,7 @@ f
 end
 """
 
-@test_repr """f(x, y) do z, w
+@weak_test_repr """f(x, y) do z, w
 # line meta
 a
 # line meta
@@ -336,7 +443,7 @@ b
 end
 """
 
-@test_repr """f(x, y) do z
+@weak_test_repr """f(x, y) do z
 # line meta
 a
 # line meta
@@ -351,6 +458,10 @@ end
 @test sprint(show, :+) == ":+"
 @test sprint(show, :end) == ":end"
 
+# make sure :var"'" prints correctly
+@test sprint(show, Symbol("'")) == "Symbol(\"'\")"
+@test_repr "var\"'\" = 5"
+
 # issue #32408: Printing of names which are invalid identifiers
 # Invalid identifiers which need `var` quoting:
 @test sprint(show, Expr(:call, :foo, Symbol("##")))   == ":(foo(var\"##\"))"
@@ -393,7 +504,7 @@ end
 
 @test_repr "[1 2 3; 4 5 6; 7 8 9]'"
 
-@test_repr "baremodule X
+@weak_test_repr "baremodule X
 # line meta
 # line meta
 import ...B.c
@@ -402,7 +513,7 @@ import D
 # line meta
 import B.C.D.E.F.g
 end"
-@test_repr "baremodule Y
+@weak_test_repr "baremodule Y
 # line meta
 # line meta
 export A, B, C
@@ -452,9 +563,6 @@ let a = Expr(:quote,Expr(:$,:x8d003))
     @test eval(eval(Meta.parse(repr(a)))) == 2
 end
 
-# issue #9865
-@test occursin(r"^Set\(\[.+….+\]\)$", replstr(Set(1:100)))
-
 # issue #11413
 @test string(:(*{1, 2})) == "*{1, 2}"
 @test string(:(*{1, x})) == "*{1, x}"
@@ -637,7 +745,6 @@ else
 end
 
 # Method location correction (Revise integration)
-methloc = Base.methodloc_callback[]
 dummyloc(m::Method) = :nofile, 123456789
 Base.methodloc_callback[] = dummyloc
 let repr = sprint(show, "text/plain", methods(Base.inbase))
@@ -646,18 +753,31 @@ end
 let repr = sprint(show, "text/html", methods(Base.inbase))
     @test occursin("nofile:123456789", repr)
 end
-Base.methodloc_callback[] = methloc
+Base.methodloc_callback[] = nothing
 
-# print_matrix should be able to handle small and large objects easily, test by
-# calling show. This also indirectly tests print_matrix_row, which
-# is used repeatedly by print_matrix.
-# This fits on screen:
-@test replstr(Matrix(1.0I, 10, 10)) == "10×10 Array{Float64,2}:\n 1.0  0.0  0.0  0.0  0.0  0.0  0.0  0.0  0.0  0.0\n 0.0  1.0  0.0  0.0  0.0  0.0  0.0  0.0  0.0  0.0\n 0.0  0.0  1.0  0.0  0.0  0.0  0.0  0.0  0.0  0.0\n 0.0  0.0  0.0  1.0  0.0  0.0  0.0  0.0  0.0  0.0\n 0.0  0.0  0.0  0.0  1.0  0.0  0.0  0.0  0.0  0.0\n 0.0  0.0  0.0  0.0  0.0  1.0  0.0  0.0  0.0  0.0\n 0.0  0.0  0.0  0.0  0.0  0.0  1.0  0.0  0.0  0.0\n 0.0  0.0  0.0  0.0  0.0  0.0  0.0  1.0  0.0  0.0\n 0.0  0.0  0.0  0.0  0.0  0.0  0.0  0.0  1.0  0.0\n 0.0  0.0  0.0  0.0  0.0  0.0  0.0  0.0  0.0  1.0"
-# an array too long vertically to fit on screen, and too long horizontally:
-@test replstr(Vector(1.:100.)) == "100-element Array{Float64,1}:\n   1.0\n   2.0\n   3.0\n   4.0\n   5.0\n   6.0\n   7.0\n   8.0\n   9.0\n  10.0\n   ⋮  \n  92.0\n  93.0\n  94.0\n  95.0\n  96.0\n  97.0\n  98.0\n  99.0\n 100.0"
-@test occursin(r"1×100 (LinearAlgebra\.)?Adjoint{Float64,Array{Float64,1}}:\n 1.0  2.0  3.0  4.0  5.0  6.0  7.0  …  95.0  96.0  97.0  98.0  99.0  100.0", replstr(Vector(1.:100.)'))
-# too big in both directions to fit on screen:
-@test replstr((1.:100.)*(1:100)') == "100×100 Array{Float64,2}:\n   1.0    2.0    3.0    4.0    5.0    6.0  …    97.0    98.0    99.0    100.0\n   2.0    4.0    6.0    8.0   10.0   12.0      194.0   196.0   198.0    200.0\n   3.0    6.0    9.0   12.0   15.0   18.0      291.0   294.0   297.0    300.0\n   4.0    8.0   12.0   16.0   20.0   24.0      388.0   392.0   396.0    400.0\n   5.0   10.0   15.0   20.0   25.0   30.0      485.0   490.0   495.0    500.0\n   6.0   12.0   18.0   24.0   30.0   36.0  …   582.0   588.0   594.0    600.0\n   7.0   14.0   21.0   28.0   35.0   42.0      679.0   686.0   693.0    700.0\n   8.0   16.0   24.0   32.0   40.0   48.0      776.0   784.0   792.0    800.0\n   9.0   18.0   27.0   36.0   45.0   54.0      873.0   882.0   891.0    900.0\n  10.0   20.0   30.0   40.0   50.0   60.0      970.0   980.0   990.0   1000.0\n   ⋮                                  ⋮    ⋱                                 \n  92.0  184.0  276.0  368.0  460.0  552.0     8924.0  9016.0  9108.0   9200.0\n  93.0  186.0  279.0  372.0  465.0  558.0     9021.0  9114.0  9207.0   9300.0\n  94.0  188.0  282.0  376.0  470.0  564.0     9118.0  9212.0  9306.0   9400.0\n  95.0  190.0  285.0  380.0  475.0  570.0     9215.0  9310.0  9405.0   9500.0\n  96.0  192.0  288.0  384.0  480.0  576.0  …  9312.0  9408.0  9504.0   9600.0\n  97.0  194.0  291.0  388.0  485.0  582.0     9409.0  9506.0  9603.0   9700.0\n  98.0  196.0  294.0  392.0  490.0  588.0     9506.0  9604.0  9702.0   9800.0\n  99.0  198.0  297.0  396.0  495.0  594.0     9603.0  9702.0  9801.0   9900.0\n 100.0  200.0  300.0  400.0  500.0  600.0     9700.0  9800.0  9900.0  10000.0"
+@testset "matrix printing" begin
+    # print_matrix should be able to handle small and large objects easily, test by
+    # calling show. This also indirectly tests print_matrix_row, which
+    # is used repeatedly by print_matrix.
+    # This fits on screen:
+                 @test replstr(Matrix(1.0I, 10, 10)) == "10×10 Array{Float64,2}:\n 1.0  0.0  0.0  0.0  0.0  0.0  0.0  0.0  0.0  0.0\n 0.0  1.0  0.0  0.0  0.0  0.0  0.0  0.0  0.0  0.0\n 0.0  0.0  1.0  0.0  0.0  0.0  0.0  0.0  0.0  0.0\n 0.0  0.0  0.0  1.0  0.0  0.0  0.0  0.0  0.0  0.0\n 0.0  0.0  0.0  0.0  1.0  0.0  0.0  0.0  0.0  0.0\n 0.0  0.0  0.0  0.0  0.0  1.0  0.0  0.0  0.0  0.0\n 0.0  0.0  0.0  0.0  0.0  0.0  1.0  0.0  0.0  0.0\n 0.0  0.0  0.0  0.0  0.0  0.0  0.0  1.0  0.0  0.0\n 0.0  0.0  0.0  0.0  0.0  0.0  0.0  0.0  1.0  0.0\n 0.0  0.0  0.0  0.0  0.0  0.0  0.0  0.0  0.0  1.0"
+    # an array too long vertically to fit on screen, and too long horizontally:
+    @test replstr(Vector(1.:100.)) == "100-element Array{Float64,1}:\n   1.0\n   2.0\n   3.0\n   4.0\n   5.0\n   6.0\n   7.0\n   8.0\n   9.0\n  10.0\n   ⋮\n  92.0\n  93.0\n  94.0\n  95.0\n  96.0\n  97.0\n  98.0\n  99.0\n 100.0"
+    @test occursin(r"1×100 (LinearAlgebra\.)?Adjoint{Float64,Array{Float64,1}}:\n 1.0  2.0  3.0  4.0  5.0  6.0  7.0  …  95.0  96.0  97.0  98.0  99.0  100.0", replstr(Vector(1.:100.)'))
+    # too big in both directions to fit on screen:
+    @test replstr((1.:100.)*(1:100)') == "100×100 Array{Float64,2}:\n   1.0    2.0    3.0    4.0    5.0    6.0  …    97.0    98.0    99.0    100.0\n   2.0    4.0    6.0    8.0   10.0   12.0      194.0   196.0   198.0    200.0\n   3.0    6.0    9.0   12.0   15.0   18.0      291.0   294.0   297.0    300.0\n   4.0    8.0   12.0   16.0   20.0   24.0      388.0   392.0   396.0    400.0\n   5.0   10.0   15.0   20.0   25.0   30.0      485.0   490.0   495.0    500.0\n   6.0   12.0   18.0   24.0   30.0   36.0  …   582.0   588.0   594.0    600.0\n   7.0   14.0   21.0   28.0   35.0   42.0      679.0   686.0   693.0    700.0\n   8.0   16.0   24.0   32.0   40.0   48.0      776.0   784.0   792.0    800.0\n   9.0   18.0   27.0   36.0   45.0   54.0      873.0   882.0   891.0    900.0\n  10.0   20.0   30.0   40.0   50.0   60.0      970.0   980.0   990.0   1000.0\n   ⋮                                  ⋮    ⋱                          \n  92.0  184.0  276.0  368.0  460.0  552.0     8924.0  9016.0  9108.0   9200.0\n  93.0  186.0  279.0  372.0  465.0  558.0     9021.0  9114.0  9207.0   9300.0\n  94.0  188.0  282.0  376.0  470.0  564.0     9118.0  9212.0  9306.0   9400.0\n  95.0  190.0  285.0  380.0  475.0  570.0     9215.0  9310.0  9405.0   9500.0\n  96.0  192.0  288.0  384.0  480.0  576.0  …  9312.0  9408.0  9504.0   9600.0\n  97.0  194.0  291.0  388.0  485.0  582.0     9409.0  9506.0  9603.0   9700.0\n  98.0  196.0  294.0  392.0  490.0  588.0     9506.0  9604.0  9702.0   9800.0\n  99.0  198.0  297.0  396.0  495.0  594.0     9603.0  9702.0  9801.0   9900.0\n 100.0  200.0  300.0  400.0  500.0  600.0     9700.0  9800.0  9900.0  10000.0"
+
+    # test that no spurious visual lines are added when one element spans multiple lines
+    v = fill!(Array{Any}(undef, 9), 0)
+    v[1] = "look I'm wide! --- " ^ 9
+    @test replstr(v) == "9-element Array{Any,1}:\n  \"look I'm wide! --- look I'm wide! --- look I'm wide! --- look I'm wide! --- look I'm wide! --- look I'm wide! --- look I'm wide! --- look I'm wide! --- look I'm wide! --- \"\n 0\n 0\n 0\n 0\n 0\n 0\n 0\n 0"
+    @test replstr([fill(0, 9) v]) == "9×2 Array{Any,2}:\n 0  …   \"look I'm wide! --- look I'm wide! --- look I'm wide! --- look I'm wide! --- look I'm wide! --- look I'm wide! --- look I'm wide! --- look I'm wide! --- look I'm wide! --- \"\n 0     0\n 0     0\n 0     0\n 0     0\n 0  …  0\n 0     0\n 0     0\n 0     0"
+    # test vertical/diagonal ellipsis
+    v = fill!(Array{Any}(undef, 50), 0)
+    v[1] = "look I'm wide! --- " ^ 9
+    @test replstr(v) == "50-element Array{Any,1}:\n  \"look I'm wide! --- look I'm wide! --- look I'm wide! --- look I'm wide! --- look I'm wide! --- look I'm wide! --- look I'm wide! --- look I'm wide! --- look I'm wide! --- \"\n 0\n 0\n 0\n 0\n 0\n 0\n 0\n 0\n 0\n ⋮\n 0\n 0\n 0\n 0\n 0\n 0\n 0\n 0\n 0"
+    @test replstr([fill(0, 50) v]) == "50×2 Array{Any,2}:\n 0  …   \"look I'm wide! --- look I'm wide! --- look I'm wide! --- look I'm wide! --- look I'm wide! --- look I'm wide! --- look I'm wide! --- look I'm wide! --- look I'm wide! --- \"\n 0     0\n 0     0\n 0     0\n 0     0\n 0  …  0\n 0     0\n 0     0\n 0     0\n 0     0\n ⋮  ⋱  \n 0     0\n 0     0\n 0     0\n 0     0\n 0  …  0\n 0     0\n 0     0\n 0     0\n 0     0"
+end
 
 # Issue 14121
 @test_repr "(A'x)'"
@@ -756,6 +876,21 @@ test_mt(show_f5, "show_f5(A::AbstractArr
 @test_repr "{a b c}"
 @test_repr "{a b; c d}"
 
+# typed vcat and hcat
+@test_repr "T[a]"
+@test_repr "T[a,b]"
+@test_repr "T[a;b;c]"
+@test_repr "T[a b]"
+@test_repr "T[a b;]"
+@test_repr "T[a b c]"
+@test_repr "T[a b; c d]"
+@test_repr repr(Expr(:quote, Expr(:typed_vcat, Expr(:$, :a), 1)))
+@test_repr repr(Expr(:quote, Expr(:typed_hcat, Expr(:$, :a), 1)))
+@test_repr "Expr(:quote, Expr(:typed_vcat, Expr(:\$, :a), 1))"
+@test_repr "Expr(:quote, Expr(:typed_hcat, Expr(:\$, :a), 1))"
+@test repr(Expr(:quote, Expr(:typed_vcat, Expr(:$, :a), 1))) == ":(:(\$a[1;]))"
+@test repr(Expr(:quote, Expr(:typed_hcat, Expr(:$, :a), 1))) == ":(:(\$a[1]))"
+
 # Printing of :(function f end)
 @test sprint(show, :(function f end)) == ":(function f end)"
 @test_repr "function g end"
@@ -765,17 +900,245 @@ test_mt(show_f5, "show_f5(A::AbstractArr
 @test_repr "macro m end"
 @test sprint(show, Expr(:macro, Expr(:call, :m, :ex), Expr(:block, :m))) ==
       ":(macro m(ex)\n      m\n  end)"
-@test_repr """macro identity(ex)
+@weak_test_repr """macro identity(ex)
     # line meta
     esc(ex)
 end"""
-@test_repr """macro m(a,b)
+@weak_test_repr """macro m(a,b)
     # line meta
     quote
         # line meta
         \$a + \$b
     end
 end"""
+@test repr(Meta.parse(
+"""macro m(a, b)
+    quote
+        \$a + \$b
+    end
+end""")) ==
+"""
+:(macro m(a, b)
+      #= none:2 =#
+      quote
+          #= none:3 =#
+          \$a + \$b
+      end
+  end)"""
+@test repr(Base.remove_linenums!(Meta.parse(
+"""macro m(a, b)
+    quote
+        \$a + \$b
+    end
+end"""))) ==
+"""
+:(macro m(a, b)
+      quote
+          \$a + \$b
+      end
+  end)"""
+@test repr(Meta.parse(
+"""macro m(a, b)
+    :(\$a + \$b)
+end""")) ==
+":(macro m(a, b)\n      #= none:2 =#\n      :(\$a + \$b)\n  end)"
+@test repr(Expr(:macro, Expr(:call, :m, :x), Expr(:quote, Expr(:call, :+, Expr(:($), :x), 1)))) ==
+":(macro m(x)\n      :(\$x + 1)\n  end)"
+
+# nested quotes and interpolations
+@test repr(Meta.parse(
+"""quote
+    quote
+        \$\$x
+    end
+end""")) ==
+"""
+:(quote
+      #= none:2 =#
+      quote
+          #= none:3 =#
+          \$\$x
+      end
+  end)"""
+@weak_test_repr """
+quote
+    #= none:2 =#
+    quote
+        #= none:3 =#
+        \$\$x
+    end
+end"""
+
+# fallback printing + nested quotes and unquotes
+@weak_test_repr repr(Expr(:block, LineNumberNode(0, :none),
+                     Expr(:exotic_head, Expr(:$, :x))))
+@test_repr repr(Expr(:exotic_head, Expr(:call, :+, 1, Expr(:quote, Expr(:$, Expr(:$, :y))))))
+@test_repr repr(Expr(:quote, Expr(:$, Expr(:exotic_head, Expr(:call, :+, 1, Expr(:$, :y))))))
+@test_repr repr(Expr(:$, Expr(:exotic_head, Expr(:call, :+, 1, Expr(:$, :y)))))
+@test_repr "Expr(:block, LineNumberNode(0, :none), Expr(:exotic_head, Expr(:\$, :x)))"
+@test_repr "Expr(:exotic_head, Expr(:call, :+, 1, \$y))"
+@test_repr "Expr(:exotic_head, Expr(:call, :+, 1, \$\$y))"
+@test_repr ":(Expr(:exotic_head, Expr(:call, :+, 1, \$y)))"
+@test_repr ":(:(Expr(:exotic_head, Expr(:call, :+, 1, \$\$y))))"
+@test repr(Expr(:block, LineNumberNode(0, :none),
+                Expr(:exotic_head, Expr(:$, :x)))) ==
+"""
+quote
+    #= none:0 =#
+    \$(Expr(:exotic_head, :(\$x)))
+end"""
+@test repr(Expr(:exotic_head, Expr(:call, :+, 1, :(Expr(:$, :y))))) ==
+    ":(\$(Expr(:exotic_head, :(1 + Expr(:\$, :y)))))"
+@test repr(Expr(:exotic_head, Expr(:call, :+, 1, Expr(:quote, Expr(:$, :y))))) ==
+    ":(\$(Expr(:exotic_head, :(1 + :(\$y)))))"
+@test repr(Expr(:quote, Expr(:exotic_head, Expr(:call, :+, 1, Expr(:$, :y))))) ==
+    ":(:(\$(Expr(:exotic_head, :(1 + \$y)))))"
+@test repr(Expr(:block, Expr(:(=), :y, 2),
+                        Expr(:quote, Expr(:exotic_head,
+                                          Expr(:call, :+, 1, Expr(:$, :y)))))) ==
+"""
+quote
+    y = 2
+    :(\$(Expr(:exotic_head, :(1 + \$y))))
+end"""
+@test repr(eval(Expr(:block, Expr(:(=), :y, 2),
+                        Expr(:quote, Expr(:exotic_head,
+                                          Expr(:call, :+, 1, Expr(:$, :y))))))) ==
+    ":(\$(Expr(:exotic_head, :(1 + 2))))"
+
+# nested quotes and blocks
+@test_repr "Expr(:quote, Expr(:block, :a, :b))"
+@weak_test_repr repr(Expr(:quote, Expr(:block, LineNumberNode(0, :none), :a, LineNumberNode(0, :none), :b)))
+@test repr(Expr(:quote, Expr(:block, :a, :b))) ==
+":(quote
+      a
+      b
+  end)"
+@test_repr "Expr(:quote, Expr(:block, :a))"
+@weak_test_repr repr(Expr(:quote, Expr(:block, LineNumberNode(0, :none), :a)))
+@test repr(Expr(:quote, Expr(:block, :a))) ==
+":(quote
+      a
+  end)"
+@test_repr "Expr(:quote, Expr(:block, :(a + b)))"
+@weak_test_repr repr(Expr(:quote, Expr(:block, LineNumberNode(0, :none), :(a + b))))
+@test repr(Expr(:quote, Expr(:block, :(a + b)))) ==
+":(quote
+      a + b
+  end)"
+
+# QuoteNode + quotes and unquotes
+@test_repr "QuoteNode(\$x)"
+@test_repr "QuoteNode(\$\$x)"
+@test_repr ":(QuoteNode(\$x))"
+@test_repr ":(:(QuoteNode(\$\$x)))"
+@test repr(QuoteNode(Expr(:$, :x))) == ":(\$(QuoteNode(:(\$(Expr(:\$, :x))))))"
+@test repr(QuoteNode(Expr(:quote, Expr(:$, :x)))) == ":(\$(QuoteNode(:(:(\$x)))))"
+@test repr(Expr(:quote, QuoteNode(Expr(:$, :x)))) == ":(:(\$(QuoteNode(:(\$(Expr(:\$, :x)))))))"
+
+# unquoting
+@test_repr "\$y"
+@test_repr "\$\$y"
+@weak_test_repr """
+begin
+    # line meta
+    \$y
+end"""
+@weak_test_repr """
+begin
+    # line meta
+    \$\$y
+end"""
+@test_repr ":(\$\$y)"
+@test_repr repr(Expr(:$, :y))
+
+# with reference to https://github.com/JuliaLang/julia/commit/9ef17207d5f99c7a0019cbbe0e58f77e7c4c1d21
+y856739 = 2
+x856739 = :y856739
+z856739 = [:a, :b]
+@test_repr repr(:(:(f($$x856739))))
+@test repr(:(:(f($$x856739)))) == ":(:(f(\$y856739)))"
+@test repr(eval(:(:(f($$x856739))))) == ":(f(2))"
+@test_repr repr(:(:(f($x856739))))
+@test repr(:(:(f($x856739)))) == ":(:(f(\$x856739)))"
+@test repr(eval(:(:(f($x856739))))) == ":(f(y856739))"
+@test_repr repr(:(:(f($(($z856739)...)))))
+@test repr(:(:(f($(($z856739)...))))) == ":(:(f(\$([:a, :b]...))))"
+@test repr(eval(:(:(f($(($z856739)...)))))) == ":(f(a, b))"
+
+# string interpolation, if this is what the comment in test_rep function
+# definition talk about
+@test repr(Expr(:string, "foo", :x, "bar")) == ":(\"foo\$(x)bar\")"
+@test Meta.parse(string(Expr(:string, "foo", :x, "bar"))) == Expr(:string, "foo", :x, "bar")
+@test repr(Meta.parse("\"foo\$(x)bar\"")) == ":(\"foo\$(x)bar\")"
+@test_repr "\"foo\$(x)bar\""
+
+# Printing of macrocall expressions with qualified macroname argument
+@test sprint(show, Expr(:macrocall,
+                   GlobalRef(Base, Symbol("@m")),
+                   LineNumberNode(0, :none), :a, :b)) ==
+    ":(#= none:0 =# Base.@m a b)"
+@test sprint(show, Expr(:macrocall,
+                   Expr(:(.), :Base, Expr(:quote, Symbol("@m"))),
+                   LineNumberNode(0, :none), :a, :b)) ==
+    ":(#= none:0 =# Base.@m a b)"
+@test sprint(show, Expr(:macrocall,
+                   Expr(:(.), Base, Expr(:quote, Symbol("@m"))),
+                   LineNumberNode(0, :none), :a, :b)) ==
+    ":(#= none:0 =# (Base).@m a b)"
+@test sprint(show, Expr(:macrocall,
+                   Expr(:(.), :Base, QuoteNode(Symbol("@m"))),
+                   LineNumberNode(0, :none), :a, :b)) ==
+    ":(#= none:0 =# Base.@m a b)"
+@test sprint(show, Expr(:macrocall,
+                   Expr(:(.), Base, QuoteNode(Symbol("@m"))),
+                   LineNumberNode(0, :none), :a, :b)) ==
+    ":(#= none:0 =# (Base).@m a b)"
+
+# issue #34080
+@test endswith(repr(:(a.b.@c x y)), "a.b.@c x y)")
+@test endswith(repr(:((1+2).@x a)), "(1 + 2).@x a)")
+@test repr(Expr(:(.),
+                Expr(:(.), :Base, QuoteNode(Symbol("Enums"))),
+                QuoteNode(Symbol("@enum")))) == ":(Base.Enums.var\"@enum\")"
+
+# Printing of special macro syntaxes
+# `a b c`
+@test sprint(show, Expr(:macrocall,
+                   GlobalRef(Core, Symbol("@cmd")),
+                   LineNumberNode(0, :none), "a b c")) == ":(`a b c`)"
+@test sprint(show, Expr(:macrocall,
+                        Expr(:(.), :Core, Expr(:quote, Symbol("@cmd"))),
+                        LineNumberNode(0, :none), "a b c")) == ":(#= none:0 =# Core.@cmd \"a b c\")"
+@test sprint(show, Expr(:macrocall,
+                        Expr(:(.), Core, Expr(:quote, Symbol("@cmd"))),
+                        LineNumberNode(0, :none), "a b c")) == ":(#= none:0 =# (Core).@cmd \"a b c\")"
+@test sprint(show, Expr(:macrocall,
+                        Expr(:(.), :Core, QuoteNode(Symbol("@cmd"))),
+                        LineNumberNode(0, :none), "a b c")) == ":(#= none:0 =# Core.@cmd \"a b c\")"
+@test sprint(show, Expr(:macrocall,
+                        Expr(:(.), Core, QuoteNode(Symbol("@cmd"))),
+                        LineNumberNode(0, :none), "a b c")) == ":(#= none:0 =# (Core).@cmd \"a b c\")"
+@test_repr "`a b c`"
+@test sprint(show, Meta.parse("`a b c`")) == ":(`a b c`)"
+# a"b" and a"b"c
+@test_repr "a\"b\""
+@test_repr "a\"b\"c"
+@test_repr "aa\"b\""
+@test_repr "a\"b\"cc"
+@test sprint(show, Meta.parse("a\"b\"")) == ":(a\"b\")"
+@test sprint(show, Meta.parse("a\"b\"c")) == ":(a\"b\"c)"
+@test sprint(show, Meta.parse("aa\"b\"")) == ":(aa\"b\")"
+@test sprint(show, Meta.parse("a\"b\"cc")) == ":(a\"b\"cc)"
+# 11111111111111111111, 0xfffffffffffffffff, 1111...many digits...
+@test sprint(show, Meta.parse("11111111111111111111")) == ":(11111111111111111111)"
+# @test_repr "Base.@int128_str \"11111111111111111111\""
+@test sprint(show, Meta.parse("Base.@int128_str \"11111111111111111111\"")) ==
+    ":(#= none:1 =# Base.@int128_str \"11111111111111111111\")"
+@test sprint(show, Meta.parse("11111111111111111111")) == ":(11111111111111111111)"
+@test sprint(show, Meta.parse("0xfffffffffffffffff")) == ":(0xfffffffffffffffff)"
+@test sprint(show, Meta.parse("11111111111111111111111111111111111111111111111111111111111111")) ==
+":(11111111111111111111111111111111111111111111111111111111111111)"
 
 # Issue #15765 printing of continue and break
 @test sprint(show, :(continue)) == ":(continue)"
@@ -787,8 +1150,8 @@ let x = [], y = [], z = Base.ImmutableDi
     push!(x, y)
     push!(y, x)
     push!(y, z)
-    @test replstr(x) == "1-element Array{Any,1}:\n Any[Any[Any[#= circular reference @-2 =#]], Base.ImmutableDict([Any[#= circular reference @-3 =#]] => [#= circular reference @-2 =#])]"
-    @test repr(z) == "Base.ImmutableDict([Any[Any[#= circular reference @-2 =#], Base.ImmutableDict(#= circular reference @-3 =#)]] => [Any[Any[#= circular reference @-2 =#]], Base.ImmutableDict(#= circular reference @-2 =#)])"
+    @test replstr(x) == "1-element Array{Any,1}:\n Any[Any[Any[#= circular reference @-2 =#]], Base.ImmutableDict{Array{Any,1},Array{Any,1}}([Any[#= circular reference @-3 =#]] => [#= circular reference @-2 =#])]"
+    @test repr(z) == "Base.ImmutableDict{Array{Any,1},Array{Any,1}}([Any[Any[#= circular reference @-2 =#], Base.ImmutableDict{Array{Any,1},Array{Any,1}}(#= circular reference @-3 =#)]] => [Any[Any[#= circular reference @-2 =#]], Base.ImmutableDict{Array{Any,1},Array{Any,1}}(#= circular reference @-2 =#)])"
     @test sprint(dump, x) == """
         Array{Any}((1,))
           1: Array{Any}((2,))
@@ -894,6 +1257,7 @@ let a = Vector{Any}(undef, 10000)
     repr = sprint(dump, a; context=(:limit => true), sizehint=0)
     @test repr == "Array{Any}((10000,))\n  1: #undef\n  2: String \"elemA\"\n  3: #undef\n  4: String \"elemB\"\n  5: #undef\n  ...\n  9996: #undef\n  9997: #undef\n  9998: #undef\n  9999: #undef\n  10000: #undef\n"
 end
+@test occursin("NamedTuple", sprint(dump, NamedTuple))
 
 # issue #17338
 @test repr(Core.svec(1, 2)) == "svec(1, 2)"
@@ -929,7 +1293,7 @@ test_repr("(+).:-")
 test_repr("(!).:~")
 test_repr("a.:(begin
         #= none:3 =#
-    end)")
+    end)", true)
 test_repr("a.:(=)")
 test_repr("a.:(:)")
 test_repr("(:).a")
@@ -953,6 +1317,7 @@ test_repr("(:).a")
 
 # don't use julia-specific `f` in Float32 printing (PR #18053)
 @test sprint(print, 1f-7) == "1.0e-7"
+@test string(1f-7) == "1.0e-7"
 
 let d = TextDisplay(IOBuffer())
     @test_throws MethodError display(d, "text/foobar", [3 1 4])
@@ -1058,7 +1423,7 @@ end
 
     # issue #28327
     d = Dict(Pair{Integer,Integer}(1,2)=>Pair{Integer,Integer}(1,2))
-    @test showstr(d) == "Dict((1 => 2) => (1 => 2))" # correct parenthesis
+    @test showstr(d) == "Dict{Pair{Integer,Integer},Pair{Integer,Integer}}((1 => 2) => (1 => 2))" # correct parenthesis
 
     # issue #29536
     d = Dict((+)=>1)
@@ -1069,15 +1434,20 @@ end
 end
 
 @testset "alignment for pairs" begin  # (#22899)
-    @test replstr([1=>22,33=>4]) == "2-element Array{Pair{$Int,$Int},1}:\n  1 => 22\n 33 => 4 "
+    @test replstr([1=>22,33=>4]) == "2-element Array{Pair{$Int,$Int},1}:\n  1 => 22\n 33 => 4"
     # first field may have "=>" in its representation
     @test replstr(Pair[(1=>2)=>3, 4=>5]) ==
         "2-element Array{Pair,1}:\n (1 => 2) => 3\n        4 => 5"
     @test replstr(Any[Dict(1=>2)=> (3=>4), 1=>2]) ==
-        "2-element Array{Any,1}:\n Dict(1 => 2) => (3 => 4)\n            1 => 2       "
+        "2-element Array{Any,1}:\n Dict(1 => 2) => (3 => 4)\n            1 => 2"
     # left-alignment when not using the "=>" symbol
     @test replstr(Any[Pair{Integer,Int64}(1, 2), Pair{Integer,Int64}(33, 4)]) ==
-        "2-element Array{Any,1}:\n Pair{Integer,Int64}(1, 2) \n Pair{Integer,Int64}(33, 4)"
+        "2-element Array{Any,1}:\n Pair{Integer,Int64}(1, 2)\n Pair{Integer,Int64}(33, 4)"
+end
+
+@testset "alignment for complex arrays" begin # (#34763)
+    @test replstr([ 1e-7 + 2.0e-11im, 2.0e-5 + 4e0im]) == "2-element Array{Complex{Float64},1}:\n 1.0e-7 + 2.0e-11im\n 2.0e-5 + 4.0im"
+    @test replstr([ 1f-7 + 2.0f-11im, 2.0f-5 + 4f0im]) == "2-element Array{Complex{Float32},1}:\n 1.0f-7 + 2.0f-11im\n 2.0f-5 + 4.0f0im"
 end
 
 @testset "display arrays non-compactly when size(⋅, 2) == 1" begin
@@ -1143,11 +1513,11 @@ end
     @test arrstr(zeros(4, 30), 4) == "4×30 Array{Float64,2}: …"
     @test arrstr(zeros(4, 3), 5)  == "4×3 Array{Float64,2}:\n ⋮      ⋱  "
     @test arrstr(zeros(4, 30), 5) == "4×30 Array{Float64,2}:\n ⋮      ⋱  "
-    @test arrstr(zeros(4, 3), 6)  == "4×3 Array{Float64,2}:\n 0.0  0.0  0.0\n ⋮            "
+    @test arrstr(zeros(4, 3), 6)  == "4×3 Array{Float64,2}:\n 0.0  0.0  0.0\n ⋮         "
     @test arrstr(zeros(4, 30), 6) ==
               string("4×30 Array{Float64,2}:\n",
                      " 0.0  0.0  0.0  0.0  0.0  0.0  0.0  0.0  …  0.0  0.0  0.0  0.0  0.0  0.0  0.0\n",
-                     " ⋮                        ⋮              ⋱            ⋮                      ")
+                     " ⋮                        ⋮              ⋱            ⋮                   ")
 end
 
 module UnexportedOperators
@@ -1262,9 +1632,9 @@ end
     @test replstr(view(A, [1], :)) == "1×1 view(::Array{Float64,2}, [1], :) with eltype Float64:\n 0.0"
 
     # issue #27680
-    @test replstr(Set([(1.0,1.0), (2.0,2.0), (3.0, 3.0)])) == (sizeof(Int) == 8 ?
-              "Set(Tuple{Float64,Float64}[(3.0, 3.0), (2.0, 2.0), (1.0, 1.0)])" :
-              "Set(Tuple{Float64,Float64}[(1.0, 1.0), (2.0, 2.0), (3.0, 3.0)])")
+    @test showstr(Set([(1.0,1.0), (2.0,2.0), (3.0, 3.0)])) == (sizeof(Int) == 8 ?
+              "Set([(3.0, 3.0), (2.0, 2.0), (1.0, 1.0)])" :
+              "Set([(1.0, 1.0), (2.0, 2.0), (3.0, 3.0)])")
 
     # issue #27747
     let t = (x = Integer[1, 2],)
@@ -1287,6 +1657,8 @@ end
     @test showstr(Pair{Integer,Integer}(1, 2), :typeinfo => Pair{Integer,Integer}) == "1 => 2"
     @test showstr([Pair{Integer,Integer}(1, 2)]) == "Pair{Integer,Integer}[1 => 2]"
     @test showstr(Dict{Integer,Integer}(1 => 2)) == "Dict{Integer,Integer}(1 => 2)"
+    @test showstr(Dict(true=>false)) == "Dict{Bool,Bool}(1 => 0)"
+    @test showstr(Dict((1 => 2) => (3 => 4))) == "Dict((1 => 2) => (3 => 4))"
 
     # issue #27979 (dislaying arrays of pairs containing arrays as first member)
     @test replstr([[1.0]=>1.0]) == "1-element Array{Pair{Array{Float64,1},Float64},1}:\n [1.0] => 1.0"
@@ -1348,13 +1720,15 @@ end
 end
 
 @testset "Intrinsic printing" begin
-    @test sprint(show, Core.Intrinsics.arraylen) == "arraylen"
+    @test sprint(show, Core.Intrinsics.arraylen) == "Core.Intrinsics.arraylen"
+    @test repr(Core.Intrinsics.arraylen) == "Core.Intrinsics.arraylen"
     let io = IOBuffer()
         show(io, MIME"text/plain"(), Core.Intrinsics.arraylen)
         str = String(take!(io))
         @test occursin("arraylen", str)
         @test occursin("(intrinsic function", str)
     end
+    @test string(Core.Intrinsics.add_int) == "add_int"
 end
 
 @testset "repr(mime, x)" begin
@@ -1541,6 +1915,21 @@ end
 Z = Array{Float64}(undef,0,0)
 @test eval(Meta.parse(repr(Z))) == Z
 
+@testset "show undef" begin
+    # issue  #33204 - Parseable `repr` for `undef`
+    @test eval(Meta.parse(repr(undef))) == undef == UndefInitializer()
+    @test showstr(undef) == "UndefInitializer()"
+    @test occursin(repr(undef), replstr(undef))
+    @test occursin("initializer with undefined values", replstr(undef))
+
+    vec_undefined = Vector(undef, 2)
+    vec_initialisers = fill(undef, 2)
+    @test showstr(vec_undefined) == "Any[#undef, #undef]"
+    @test showstr(vec_initialisers) == "[$undef, $undef]"
+    @test replstr(vec_undefined) == "2-element Array{Any,1}:\n #undef\n #undef"
+    @test replstr(vec_initialisers) == "2-element Array{UndefInitializer,1}:\n $undef\n $undef"
+end
+
 # issue #31065, do not print parentheses for nested dot expressions
 @test sprint(Base.show_unquoted, :(foo.x.x)) == "foo.x.x"
 
@@ -1553,3 +1942,60 @@ Z = Array{Float64}(undef,0,0)
     @test sdastr(2, 2) == "[2, 3]"
     @test sdastr(3, 3) == "[3, 4, 5]"
 end
+
+@testset "show Set" begin
+    s = Set{Int}(1:22)
+    str = showstr(s)
+    @test startswith(str, "Set([")
+    @test endswith(str, "])")
+    @test occursin("  …  ", str)
+
+    str = replstr(s)
+    @test startswith(str, "Set{$Int} with 22 elements:\n")
+    @test endswith(str, "\n  ⋮ ")
+    @test count(==('\n'), str) == 20
+
+    @test replstr(Set(['a'^100])) == "Set{String} with 1 element:\n  \"aaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaa…"
+end
+
+@testset "0-dimensional Array. Issue #31481" begin
+    for x in (zeros(Int32), collect('b'), fill(nothing), BitArray(0))
+        @test eval(Meta.parse(repr(x))) == x
+    end
+    @test showstr(zeros(Int32)) == "fill(0)"
+    @test showstr(collect('b')) == "fill('b')"
+    @test showstr(fill(nothing)) == "fill(nothing)"
+    @test showstr(BitArray(0)) == "BitArray(0)"
+
+    @test replstr(zeros(Int32)) == "0-dimensional Array{Int32,0}:\n0"
+    @test replstr(collect('b')) == "0-dimensional Array{Char,0}:\n'b'"
+    @test replstr(fill(nothing)) == "0-dimensional Array{Nothing,0}:\nnothing"
+    @test replstr(BitArray(0)) == "0-dimensional BitArray{0}:\n0"
+
+    # UndefInitializer
+    @test showstr(fill(undef)) == "fill($undef)"
+    @test replstr(fill(undef)) == "0-dimensional Array{UndefInitializer,0}:\n$undef"
+
+    # `#undef` values
+    @test showstr(Array{String, 0}(undef)) == "Array{String,0}($undef)"
+    @test replstr(Array{String, 0}(undef)) == "0-dimensional Array{String,0}:\n$(Base.undef_ref_str)"
+
+    # "undef" with isbits type
+    @test startswith(showstr(Array{Int32, 0}(undef)), "fill(")
+    @test startswith(replstr(Array{Int32, 0}(undef)), "0-dimensional Array{Int32,0}:\n")
+end
+
+# issue #31402, Print Symbol("true") as Symbol("true") instead of :true
+@test sprint(show, Symbol(true)) == "Symbol(\"true\")"
+@test sprint(show, Symbol("true")) == "Symbol(\"true\")"
+@test sprint(show, Symbol(false)) == "Symbol(\"false\")"
+@test sprint(show, Symbol("false")) == "Symbol(\"false\")"
+
+# begin/end indices
+@weak_test_repr "a[begin, end, (begin; end)]"
+@test repr(Base.remove_linenums!(:(a[begin, end, (begin; end)]))) == ":(a[begin, end, (begin;\n          end)])"
+@weak_test_repr "a[begin, end, let x=1; (x+1;); end]"
+@test repr(Base.remove_linenums!(:(a[begin, end, let x=1; (x+1;); end]))) ==
+        ":(a[begin, end, let x = 1\n          begin\n              x + 1\n          end\n      end])"
+@test_repr "a[(bla;)]"
+@weak_test_repr "a[x -> f(x)]"
diff -pruN 1.3.1+dfsg-1/test/sorting.jl 1.4.0+dfsg-1/test/sorting.jl
--- 1.3.1+dfsg-1/test/sorting.jl	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/test/sorting.jl	2020-03-21 16:36:32.000000000 +0000
@@ -2,38 +2,77 @@
 
 module SortingTests
 
-using Base.Order: Forward
+using Base.Order
 using Random
 using Test
 
-@test sort([2,3,1]) == [1,2,3]
-@test sort([2,3,1], rev=true) == [3,2,1]
-@test sort(['z':-1:'a';]) == ['a':'z';]
-@test sort(['a':'z';], rev=true) == ['z':-1:'a';]
-@test sortperm([2,3,1]) == [3,1,2]
-@test sortperm!([1,2,3], [2,3,1]) == [3,1,2]
-let s = view([1,2,3,4], 1:3),
-    r = sortperm!(s, [2,3,1])
-    @test r == [3,1,2]
-    @test r === s
-end
-@test_throws ArgumentError sortperm!(view([1,2,3,4], 1:4), [2,3,1])
-@test !issorted([2,3,1])
-@test issorted([1,2,3])
-@test reverse([2,3,1]) == [1,3,2]
-@test partialsort([3,6,30,1,9],3) == 6
-@test partialsort([3,6,30,1,9],3:4) == [6,9]
-@test partialsortperm([3,6,30,1,9], 3:4) == [2,5]
-@test partialsortperm!(Vector(1:5), [3,6,30,1,9], 3:4) == [2,5]
-let a=[1:10;]
-    for r in Any[2:4, 1:2, 10:10, 4:2, 2:1, 4:-1:2, 2:-1:1, 10:-1:10, 4:1:3, 1:2:8, 10:-3:1]
-        @test partialsort(a, r) == [r;]
-        @test partialsortperm(a, r) == [r;]
-        @test partialsort(a, r, rev=true) == (11 .- [r;])
-        @test partialsortperm(a, r, rev=true) == (11 .- [r;])
+@testset "Order" begin
+    @test Forward == ForwardOrdering()
+    @test ReverseOrdering(Forward) == ReverseOrdering() == Reverse
+end
+
+@testset "midpoint" begin
+    @test Base.Sort.midpoint(1, 3) === 2
+    @test Base.Sort.midpoint(2, 4) === 3
+    @test 2 <= Base.Sort.midpoint(1, 4) <= 3
+    @test Base.Sort.midpoint(-3, -1) === -2
+    @test Base.Sort.midpoint(-4, -2) === -3
+    @test -3 <= Base.Sort.midpoint(-4, -1) <= -2
+    @test Base.Sort.midpoint(-1, 1) ===  0
+    @test -1 <= Base.Sort.midpoint(-2, 1) <= 0
+    @test 0 <= Base.Sort.midpoint(-1, 2) <= 1
+    @test Base.Sort.midpoint(-2, 2) ===  0
+    @test Base.Sort.midpoint(typemax(Int)-2, typemax(Int)) === typemax(Int)-1
+    @test Base.Sort.midpoint(typemin(Int), typemin(Int)+2) === typemin(Int)+1
+    @test -1 <= Base.Sort.midpoint(typemin(Int), typemax(Int)) <= 0
+end
+
+@testset "sort" begin
+    @test sort([2,3,1]) == [1,2,3] == sort([2,3,1]; order=Forward)
+    @test sort([2,3,1], rev=true) == [3,2,1] == sort([2,3,1], order=Reverse)
+    @test sort(['z':-1:'a';]) == ['a':'z';]
+    @test sort(['a':'z';], rev=true) == ['z':-1:'a';]
+end
+
+@testset "sortperm" begin
+    @test sortperm([2,3,1]) == [3,1,2]
+    @test sortperm!([1,2,3], [2,3,1]) == [3,1,2]
+    let s = view([1,2,3,4], 1:3),
+        r = sortperm!(s, [2,3,1])
+        @test r == [3,1,2]
+        @test r === s
+    end
+    @test_throws ArgumentError sortperm!(view([1,2,3,4], 1:4), [2,3,1])
+end
+
+@testset "misc sorting" begin
+    @test !issorted([2,3,1])
+    @test issorted([1,2,3])
+    @test reverse([2,3,1]) == [1,3,2]
+    @test sum(randperm(6)) == 21
+end
+
+@testset "partialsort" begin
+    @test partialsort([3,6,30,1,9],3) == 6
+    @test partialsort([3,6,30,1,9],3:4) == [6,9]
+    @test partialsortperm([3,6,30,1,9], 3:4) == [2,5]
+    @test partialsortperm!(Vector(1:5), [3,6,30,1,9], 3:4) == [2,5]
+    let a=[1:10;]
+        for r in Any[2:4, 1:2, 10:10, 4:2, 2:1, 4:-1:2, 2:-1:1, 10:-1:10, 4:1:3, 1:2:8, 10:-3:1, UInt(2):UInt(5)]
+            @test partialsort(a, r) == [r;]
+            @test partialsortperm(a, r) == [r;]
+            @test partialsort(a, r, rev=true) == (11 .- [r;])
+            @test partialsortperm(a, r, rev=true) == (11 .- [r;])
+        end
+        for i in (2, UInt(2), Int128(1), big(10))
+            @test partialsort(a, i) == i
+            @test partialsortperm(a, i) == i
+            @test partialsort(a, i, rev=true) == (11 - i)
+            @test partialsortperm(a, i, rev=true) == (11 - i)
+        end
     end
+    @test_throws ArgumentError partialsortperm!([1,2], [2,3,1], 1:2)
 end
-@test sum(randperm(6)) == 21
 
 @testset "searchsorted" begin
     numTypes = [ Int8,  Int16,  Int32,  Int64,  Int128,
@@ -398,4 +437,32 @@ end
     end
 end
 
+@testset "sorting of views with strange axes" for T in (Int, UInt, Int128, UInt128, BigInt)
+    a = [8,6,7,5,3,0,9]
+    b = @view a[T(2):T(5)]
+    @test issorted(sort!(b))
+    @test b == [3,5,6,7]
+    @test a == [8,3,5,6,7,0,9]
+
+    a = [8,6,7,5,3,0,9]
+    b = @view a[T(2):T(5)]
+    c = sort(b)
+    @test issorted(c)
+    @test c == [3,5,6,7]
+    @test a == [8,6,7,5,3,0,9]
+
+    a = [8,6,7,NaN,5,3,0,9]
+    b = @view a[T(2):T(5)]
+    @test issorted(sort!(b))
+    @test isequal(b, [5,6,7,NaN])
+    @test isequal(a, [8,5,6,7,NaN,3,0,9])
+
+    a = [8,6,7,NaN,5,3,0,9]
+    b = @view a[T(2):T(5)]
+    c = sort(b)
+    @test issorted(c)
+    @test isequal(c, [5,6,7,NaN])
+    @test isequal(a, [8,6,7,NaN,5,3,0,9])
+end
+
 end
diff -pruN 1.3.1+dfsg-1/test/spawn.jl 1.4.0+dfsg-1/test/spawn.jl
--- 1.3.1+dfsg-1/test/spawn.jl	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/test/spawn.jl	2020-03-21 16:36:32.000000000 +0000
@@ -675,3 +675,88 @@ end
 if Sys.iswindows()
     rm(busybox, force=true)
 end
+
+
+# shell escaping on Windows
+@testset "shell_escape_winsomely" begin
+    # Note  argument A can be parsed both as A or "A".
+    # We do not test that the parsing satisfies either of these conditions.
+    # In other words, tests may fail even for valid parsing.
+    # This is done to avoid overly verbose tests.
+
+    # input :
+    # output: ""
+    @test Base.shell_escape_winsomely("") == "\"\""
+
+    @test Base.shell_escape_winsomely("A") == "A"
+
+    @test Base.shell_escape_winsomely(`A`) == "A"
+
+    # input : hello world
+    # output: "hello world"
+    @test Base.shell_escape_winsomely("hello world") == "\"hello world\""
+
+    # input : hello  world
+    # output: "hello  world"
+    @test Base.shell_escape_winsomely("hello\tworld") == "\"hello\tworld\""
+
+    # input : hello"world
+    # output: "hello\"world" (also valid) hello\"world
+    @test Base.shell_escape_winsomely("hello\"world") == "\"hello\\\"world\""
+
+    # input : hello""world
+    # output: "hello\"\"world" (also valid) hello\"\"world
+    @test Base.shell_escape_winsomely("hello\"\"world") == "\"hello\\\"\\\"world\""
+
+    # input : hello\world
+    # output: hello\world
+    @test Base.shell_escape_winsomely("hello\\world") == "hello\\world"
+
+    # input : hello\\world
+    # output: hello\\world
+    @test Base.shell_escape_winsomely("hello\\\\world") == "hello\\\\world"
+
+    # input : hello\"world
+    # output: "hello\"world" (also valid) hello\"world
+    @test Base.shell_escape_winsomely("hello\\\"world") == "\"hello\\\\\\\"world\""
+
+    # input : hello\\"world
+    # output: "hello\\\\\"world" (also valid) hello\\\\\"world
+    @test Base.shell_escape_winsomely("hello\\\\\"world")  == "\"hello\\\\\\\\\\\"world\""
+
+    # input : hello world\
+    # output: "hello world\\"
+    @test Base.shell_escape_winsomely("hello world\\") == "\"hello world\\\\\""
+
+    # input : A\B
+    # output: A\B"
+    @test Base.shell_escape_winsomely("A\\B") == "A\\B"
+
+    # input : [A\, B]
+    # output: "A\ B"
+    @test Base.shell_escape_winsomely("A\\", "B") == "A\\ B"
+
+    # input : A"B
+    # output: "A\"B"
+    @test Base.shell_escape_winsomely("A\"B") ==  "\"A\\\"B\""
+
+    # input : [A B\, C]
+    # output: "A B\\" C
+    @test Base.shell_escape_winsomely("A B\\", "C") == "\"A B\\\\\" C"
+
+    # input : [A "B, C]
+    # output: "A \"B" C
+    @test Base.shell_escape_winsomely("A \"B", "C") == "\"A \\\"B\" C"
+
+    # input : [A B\, C]
+    # output: "A B\\" C
+    @test Base.shell_escape_winsomely("A B\\", "C") == "\"A B\\\\\" C"
+
+    # input :[A\ B\, C]
+    # output: "A\ B\\" C
+    @test Base.shell_escape_winsomely("A\\ B\\", "C") == "\"A\\ B\\\\\" C"
+
+    # input : [A\ B\, C, D K]
+    # output: "A\ B\\" C "D K"
+    @test Base.shell_escape_winsomely("A\\ B\\", "C", "D K") == "\"A\\ B\\\\\" C \"D K\""
+end
diff -pruN 1.3.1+dfsg-1/test/stacktraces.jl 1.4.0+dfsg-1/test/stacktraces.jl
--- 1.3.1+dfsg-1/test/stacktraces.jl	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/test/stacktraces.jl	2020-03-21 16:36:32.000000000 +0000
@@ -48,7 +48,7 @@ let (default, with_c, without_c) = (stac
     @test isempty(filter(frame -> frame.from_c, without_c))
 end
 
-@test StackTraces.lookup(C_NULL) == [StackTraces.UNKNOWN]
+@test StackTraces.lookup(C_NULL) == [StackTraces.UNKNOWN] == StackTraces.lookup(C_NULL + 1) == StackTraces.lookup(C_NULL - 1)
 
 let ct = current_task()
     # After a task switch, there should be nothing in catch_backtrace
@@ -118,7 +118,7 @@ let li = typeof(fieldtype).name.mt.cache
 end
 
 let ctestptr = cglobal((:ctest, "libccalltest")),
-    ctest = StackTraces.lookup(ctestptr + 1)
+    ctest = StackTraces.lookup(ctestptr)
 
     @test length(ctest) == 1
     @test ctest[1].func === :ctest
@@ -168,3 +168,26 @@ end
 @test bt[2].line == 42
 @test bt[2].file === :foo
 end
+
+@noinline f33065(x; b=1.0, a="") = error()
+@noinline f33065(x, y; b=1.0, a="", c...) = error()
+let bt
+    try
+        f33065(0.0f0)
+    catch
+        bt = stacktrace(catch_backtrace())
+    end
+    @test any(s->startswith(string(s), "f33065(::Float32; b::Float64, a::String)"), bt)
+    try
+        f33065(0.0f0, b=:x)
+    catch
+        bt = stacktrace(catch_backtrace())
+    end
+    @test any(s->startswith(string(s), "f33065(::Float32; b::Symbol, a::String)"), bt)
+    try
+        f33065(0.0f0, 0.0f0, z=0)
+    catch
+        bt = stacktrace(catch_backtrace())
+    end
+    @test any(s->startswith(string(s), "f33065(::Float32, ::Float32; b::Float64, a::String, c::"), bt)
+end
diff -pruN 1.3.1+dfsg-1/test/staged.jl 1.4.0+dfsg-1/test/staged.jl
--- 1.3.1+dfsg-1/test/staged.jl	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/test/staged.jl	2020-03-21 16:36:32.000000000 +0000
@@ -1,6 +1,5 @@
 # This file is a part of Julia. License is MIT: https://julialang.org/license
 
-using Base.Printf: @sprintf
 using Random
 
 @generated function staged_t1(a,b)
@@ -32,7 +31,7 @@ stagediobuf = IOBuffer()
     :(nothing)
 end
 
-const intstr = @sprintf("%s", Int)
+const intstr = string(Int)
 splat2(1)
 @test String(take!(stagediobuf)) == "($intstr,)"
 splat2(1, 3)
@@ -292,3 +291,9 @@ end
 end
 
 @test_throws ErrorException("syntax: local variable name \"x\" conflicts with an argument") f30284(1)
+
+# issue #33243
+@generated function f33243()
+    :(global x33243 = 2)
+end
+@test_throws ErrorException f33243()
diff -pruN 1.3.1+dfsg-1/test/strings/basic.jl 1.4.0+dfsg-1/test/strings/basic.jl
--- 1.3.1+dfsg-1/test/strings/basic.jl	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/test/strings/basic.jl	2020-03-21 16:36:32.000000000 +0000
@@ -20,6 +20,11 @@ using Random
     @test s == "ab"
 
     @test isempty(string())
+    @test !isempty("abc")
+    @test !isempty("∀∃")
+    @test !isempty(GenericString("∀∃"))
+    @test isempty(GenericString(""))
+    @test !isempty(GenericString("abc"))
     @test eltype(GenericString) == Char
     @test firstindex("abc") == 1
     @test cmp("ab","abc") == -1
@@ -324,7 +329,12 @@ end
                  eltype(Base.EachStringIndex{String}) ==
                  eltype(Base.EachStringIndex{GenericString}) ==
                  eltype(eachindex("foobar")) == eltype(eachindex(gstr))
-    @test map(uppercase, "foó") == "FOÓ"
+    for T in (GenericString, String)
+        @test map(uppercase, T("foó")) == "FOÓ"
+        @test map(x -> 'ó', T("")) == ""
+        @test map(x -> 'ó', T("x")) == "ó"
+        @test map(x -> 'ó', T("xxx")) == "óóó"
+    end
     @test nextind("fóobar", 0, 3) == 4
 
     @test Symbol(gstr) == Symbol("12")
diff -pruN 1.3.1+dfsg-1/test/subtype.jl 1.4.0+dfsg-1/test/subtype.jl
--- 1.3.1+dfsg-1/test/subtype.jl	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/test/subtype.jl	2020-03-21 16:36:32.000000000 +0000
@@ -1683,5 +1683,21 @@ c32703(::Type{<:Str{C}}, str::Str{C}) wh
 @test  issub(Tuple{Type{Any}, NTuple{4,Union{Int,Nothing}}},
              Tuple{Type{V}, Tuple{Vararg{V, N} where N}} where V)
 
+# issue #26065
+t26065 = Ref{Tuple{T,Ref{Union{Ref{Tuple{Ref{Union{Ref{Ref{Tuple{Ref{Tuple{Union{Tuple{Ref{Ref{T}},T}, T},T}},T}}}, T}},T}}, Ref{T}, T}}}} where T
+s26065 = Ref{Tuple{T,Ref{Union{Ref{Tuple{Ref{Union{Ref{Ref{Tuple{Ref{Tuple{Union{Tuple{Ref{Ref{T}},T}, T},T}},T}}}, T}},T}}, Ref{T}, T}}}} where T
+@test t26065 <: s26065
+
+# issue #33894
+@testintersect(Tuple{Tuple{Vararg{Any,T}},:N} where T,
+               Tuple{Tuple{Vararg{Any,T}},T} where T,
+               Union{})
+@testintersect(Tuple{Int,Vararg{Any,T}} where T,
+               Tuple{T,Vararg{Any,T}} where T,
+               Union{})
+@testintersect(Tuple{:N,Vararg{Any,T}} where T,
+               Tuple{T,Vararg{Any,T}} where T,
+               Union{})
+
 @test !issub(Tuple{Type{T}, T} where T<:Tuple{String, Union{Base.Regex, AbstractChar, AbstractString}, String, Union{Base.Regex, AbstractChar, AbstractString}, String, Union{Base.Regex, AbstractChar, AbstractString}, String, Union{Base.Regex, AbstractChar, AbstractString}, String, Union{Base.Regex, AbstractChar, AbstractString}, String, Union{Base.Regex, AbstractChar, AbstractString}, String, Union{Base.Regex, AbstractChar, AbstractString}, String, Union{Base.Regex, AbstractChar, AbstractString}, String, Union{Base.Regex, AbstractChar, AbstractString}, String, Union{Base.Regex, AbstractChar, AbstractString}, String, Union{Base.Regex, AbstractChar, AbstractString}, String, Union{Base.Regex, AbstractChar, AbstractString}, String, Union{Base.Regex, AbstractChar, AbstractString}},
              Tuple{Type{Tuple{Vararg{V, N} where N}}, Tuple{Vararg{V, N} where N}} where V)
diff -pruN 1.3.1+dfsg-1/test/syntax.jl 1.4.0+dfsg-1/test/syntax.jl
--- 1.3.1+dfsg-1/test/syntax.jl	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/test/syntax.jl	2020-03-21 16:36:32.000000000 +0000
@@ -171,7 +171,7 @@ macro test999_str(args...); args; end
 
 # blocks vs. tuples
 @test Meta.parse("()") == Expr(:tuple)
-@test Meta.parse("(;)") == Expr(:block)
+@test_skip Meta.parse("(;)") == Expr(:tuple, Expr(:parameters))
 @test Meta.parse("(;;;;)") == Expr(:block)
 @test_throws ParseError Meta.parse("(,)")
 @test_throws ParseError Meta.parse("(;,)")
@@ -1322,14 +1322,23 @@ end
 @test Meta.parse("-(x)^2")     == Expr(:call, :-, Expr(:call, :^, :x, 2))
 @test Meta.parse("-(a=1)^2")   == Expr(:call, :-, Expr(:call, :^, Expr(:(=), :a, 1), 2))
 @test Meta.parse("-(x;y)^2")   == Expr(:call, :-, Expr(:call, :^, Expr(:block, :x, LineNumberNode(1,:none), :y), 2))
-@test Meta.parse("-(;)^2")     == Expr(:call, :-, Expr(:call, :^, Expr(:block), 2))
+@test_skip Meta.parse("-(;)^2")     == Expr(:call, :-, Expr(:call, :^, Expr(:tuple, Expr(:parameters)), 2))
 @test Meta.parse("-(;;;;)^2")  == Expr(:call, :-, Expr(:call, :^, Expr(:block), 2))
 @test Meta.parse("-(x;;;)^2")  == Expr(:call, :-, Expr(:call, :^, Expr(:block, :x), 2))
 @test Meta.parse("+((1,2))")   == Expr(:call, :+, Expr(:tuple, 1, 2))
 
-@test_throws ParseError("space before \"(\" not allowed in \"+ (\"") Meta.parse("1 -+ (a=1, b=2)")
+@test_throws ParseError("space before \"(\" not allowed in \"+ (\" at none:1") Meta.parse("1 -+ (a=1, b=2)")
 # issue #29781
-@test_throws ParseError("space before \"(\" not allowed in \"sin. (\"") Meta.parse("sin. (1)")
+@test_throws ParseError("space before \"(\" not allowed in \"sin. (\" at none:1") Meta.parse("sin. (1)")
+# Parser errors for disallowed space contain line numbers
+@test_throws ParseError("space before \"[\" not allowed in \"f() [\" at none:2") Meta.parse("\nf() [i]")
+@test_throws ParseError("space before \"(\" not allowed in \"f() (\" at none:2") Meta.parse("\nf() (i)")
+@test_throws ParseError("space before \".\" not allowed in \"f() .\" at none:2") Meta.parse("\nf() .i")
+@test_throws ParseError("space before \"{\" not allowed in \"f() {\" at none:2") Meta.parse("\nf() {i}")
+@test_throws ParseError("space before \"m\" not allowed in \"@ m\" at none:2") Meta.parse("\n@ m")
+@test_throws ParseError("space before \".\" not allowed in \"a .\" at none:2") Meta.parse("\nusing a .b")
+@test_throws ParseError("space before \".\" not allowed in \"a .\" at none:2") Meta.parse("\nusing a .b")
+@test_throws ParseError("space before \"(\" not allowed in \"+ (\" at none:2") Meta.parse("\n+ (x, y)")
 
 @test Meta.parse("1 -+(a=1, b=2)") == Expr(:call, :-, 1,
                                            Expr(:call, :+, Expr(:kw, :a, 1), Expr(:kw, :b, 2)))
@@ -1380,7 +1389,7 @@ end
 # Module name cannot be a reserved word.
 @test_throws ParseError Meta.parse("module module end")
 
-@test Meta.lower(@__MODULE__, :(global true)) == Expr(:error, "invalid identifier name \"true\"")
+@test Meta.lower(@__MODULE__, :(global true)) == Expr(:error, "invalid syntax in \"global\" declaration")
 @test Meta.lower(@__MODULE__, :(let ccall end)) == Expr(:error, "invalid identifier name \"ccall\"")
 @test Meta.lower(@__MODULE__, :(cglobal = 0)) == Expr(:error, "invalid assignment location \"cglobal\"")
 
@@ -1845,8 +1854,7 @@ end
 @testset "closure conversion in testsets" begin
     p = (2, 3, 4)
     @test p == (2, 3, 4)
-    identity(p)
-    allocs = @allocated identity(p)
+    allocs = (() -> @allocated identity(p))()
     @test allocs == 0
 end
 
@@ -1912,7 +1920,9 @@ end
 @test Meta.parse(":a..:b") == Expr(:call, :(..), QuoteNode(:a), QuoteNode(:b))
 
 # Non-standard identifiers (PR #32408)
-@test Meta.parse("var\"#\"") == Symbol("#")
+@test Meta.parse("var\"#\"") === Symbol("#")
+@test Meta.parse("var\"true\"") === Symbol("true")
+@test Meta.parse("var\"false\"") === Symbol("false")
 @test_throws ParseError Meta.parse("var\"#\"x") # Reject string macro-like suffix
 @test_throws ParseError Meta.parse("var \"#\"")
 @test_throws ParseError Meta.parse("var\"for\" i = 1:10; end")
@@ -1928,6 +1938,10 @@ end
 # Stream positioning after parsing var
 @test Meta.parse("var'", 1, greedy=false) == (:var, 4)
 
+# quoted names in import (#33158)
+@test Meta.parse("import Base.:+") == :(import Base.+)
+@test Meta.parse("import Base.Foo.:(==).bar") == :(import Base.Foo.==.bar)
+
 # issue #33135
 function f33135(x::T) where {C1, T}
     let C1 = 1, C2 = 2
@@ -1939,6 +1953,16 @@ end
 # issue #33227
 @test Meta.isexpr(Meta.lower(Main, :((@label a; @goto a))), :thunk)
 
+# issue #33250
+@test Meta.lower(Main, :(f(b=b...))) == Expr(:error, "\"...\" expression cannot be used as keyword argument value")
+@test Meta.lower(Main, :(f(;a=a,b=b...))) == Expr(:error, "\"...\" expression cannot be used as keyword argument value")
+@test Meta.lower(Main, :((a=a,b=b...))) == Expr(:error, "\"...\" expression cannot be used as named tuple field value")
+@test Meta.lower(Main, :(f(;a...,b...)=0)) == Expr(:error, "invalid \"...\" on non-final keyword argument")
+@test Meta.lower(Main, :(f(;a...,b=0)=0)) == Expr(:error, "invalid \"...\" on non-final keyword argument")
+
+# issue #31547
+@test Meta.lower(Main, :(a := 1)) == Expr(:error, "unsupported assignment operator \":=\"")
+
 # issue #33841
 let a(; b) = b
     @test a(b=3) == 3
@@ -1947,3 +1971,11 @@ end
 # issue #33987
 f33987(args::(Vararg{Any, N} where N); kwargs...) = args
 @test f33987(1,2,3) === (1,2,3)
+
+@test @eval let
+    (z,)->begin
+        $(Expr(:inbounds, true))
+        $(Expr(:inbounds, :pop))
+    end
+    pop = 1
+end == 1
diff -pruN 1.3.1+dfsg-1/test/testdefs.jl 1.4.0+dfsg-1/test/testdefs.jl
--- 1.3.1+dfsg-1/test/testdefs.jl	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/test/testdefs.jl	2020-03-21 16:36:32.000000000 +0000
@@ -15,7 +15,9 @@ function runtests(name, path, isolate=tr
             m = Main
         end
         @eval(m, using Test, Random)
-        println("running testset ", name, "...")
+        let id = myid()
+            wait(@spawnat 1 print_testworker_started(name, id))
+        end
         ex = quote
             @timed @testset $"$name" begin
                 # Random.seed!(nothing) will fail
diff -pruN 1.3.1+dfsg-1/test/testenv.jl 1.4.0+dfsg-1/test/testenv.jl
--- 1.3.1+dfsg-1/test/testenv.jl	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/test/testenv.jl	2020-03-21 16:36:32.000000000 +0000
@@ -32,4 +32,8 @@ if !@isdefined(testenv_defined)
     const curmod_name = fullname(curmod)
     const curmod_str = curmod === Main ? "Main" : join(curmod_name, ".")
     const curmod_prefix = "$(["$m." for m in curmod_name]...)"
+
+    # platforms that support cfunction with closures
+    # (requires LLVM back-end support for trampoline intrinsics)
+    const cfunction_closure = Sys.ARCH === :x86_64 || Sys.ARCH === :i686
 end
diff -pruN 1.3.1+dfsg-1/test/testhelpers/Furlongs.jl 1.4.0+dfsg-1/test/testhelpers/Furlongs.jl
--- 1.3.1+dfsg-1/test/testhelpers/Furlongs.jl	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/test/testhelpers/Furlongs.jl	2020-03-21 16:36:32.000000000 +0000
@@ -45,8 +45,8 @@ for f in (:real,:imag,:complex,:+,:-)
     @eval Base.$f(x::Furlong{p}) where {p} = Furlong{p}($f(x.val))
 end
 
-import Base: +, -, ==, !=, <, <=, isless, isequal, *, /, //, div, rem, mod, ^, hypot
-for op in (:+, :-, :hypot)
+import Base: +, -, ==, !=, <, <=, isless, isequal, *, /, //, div, rem, mod, ^
+for op in (:+, :-)
     @eval function $op(x::Furlong{p}, y::Furlong{p}) where {p}
         v = $op(x.val, y.val)
         Furlong{p}(v)
diff -pruN 1.3.1+dfsg-1/test/threads_exec.jl 1.4.0+dfsg-1/test/threads_exec.jl
--- 1.3.1+dfsg-1/test/threads_exec.jl	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/test/threads_exec.jl	2020-03-21 16:36:32.000000000 +0000
@@ -4,6 +4,9 @@ using Test
 using Base.Threads
 using Base.Threads: SpinLock
 
+# for cfunction_closure
+include("testenv.jl")
+
 # threading constructs
 
 let a = zeros(Int, 2 * nthreads())
@@ -27,26 +30,30 @@ end
 # parallel loop with parallel atomic addition
 function threaded_loop(a, r, x)
     @threads for i in r
-        a[i] = 1 + atomic_add!(x, 1)
+        j = i - firstindex(r) + 1
+        a[j] = 1 + atomic_add!(x, 1)
     end
 end
 
 function test_threaded_loop_and_atomic_add()
-    x = Atomic()
-    a = zeros(Int,10000)
-    threaded_loop(a,1:10000,x)
-    found = zeros(Bool,10000)
-    was_inorder = true
-    for i=1:length(a)
-        was_inorder &= a[i]==i
-        found[a[i]] = true
-    end
-    @test x[] == 10000
-    # Next test checks that all loop iterations ran,
-    # and were unique (via pigeon-hole principle).
-    @test !(false in found)
-    if was_inorder && nthreads() > 1
-        println(stderr, "Warning: threaded loop executed in order")
+    for r in [1:10000, collect(1:10000), Base.IdentityUnitRange(-500:500), (1,2,3,4,5,6,7,8,9,10)]
+        n = length(r)
+        x = Atomic()
+        a = zeros(Int, n)
+        threaded_loop(a,r,x)
+        found = zeros(Bool,n)
+        was_inorder = true
+        for i=1:length(a)
+            was_inorder &= a[i]==i
+            found[a[i]] = true
+        end
+        @test x[] == n
+        # Next test checks that all loop iterations ran,
+        # and were unique (via pigeon-hole principle).
+        @test !(false in found)
+        if was_inorder && nthreads() > 1
+            println(stderr, "Warning: threaded loop executed in order")
+        end
     end
 end
 
@@ -435,16 +442,7 @@ end
 function test_thread_cfunction()
     # ensure a runtime call to `get_trampoline` will be created
     # TODO: get_trampoline is not thread-safe (as this test shows)
-    function complex_cfunction(a)
-        s = zero(eltype(a))
-        @inbounds @simd for i in a
-            s += muladd(a[i], a[i], -2)
-        end
-        return s
-    end
-    fs = [ let a = zeros(10)
-            () -> complex_cfunction(a)
-        end for i in 1:1000 ]
+    fs = [ Core.Box() for i in 1:1000 ]
     @noinline cf(f) = @cfunction $f Float64 ()
     cfs = Vector{Base.CFunction}(undef, length(fs))
     cf1 = cf(fs[1])
@@ -465,10 +463,12 @@ function test_thread_cfunction()
     end
     @test sum(ok) == 10000
 end
-if nthreads() == 1
-    test_thread_cfunction()
-else
-    @test_broken "cfunction trampoline code not thread-safe"
+if cfunction_closure
+    if nthreads() == 1
+        test_thread_cfunction()
+    else
+        @test_broken "cfunction trampoline code not thread-safe"
+    end
 end
 
 # Compare the two ways of checking if threading is enabled.
@@ -701,3 +701,96 @@ let a = zeros(nthreads())
     _atthreads_with_error(a, false)
     @test a == [1:nthreads();]
 end
+
+try
+    @macroexpand @threads(for i = 1:10, j = 1:10; end)
+catch ex
+    @test ex isa LoadError
+    @test ex.error isa ArgumentError
+end
+
+@testset "@spawn interpolation" begin
+    # Issue #30896: evaluating arguments immediately
+    begin
+        outs = zeros(5)
+        # Use interpolation to fill outs with the values of `i`
+        @sync begin
+            local i = 1
+            while i <= 5
+                Threads.@spawn setindex!(outs, $i, $i)
+                i += 1
+            end
+        end
+        @test outs == 1:5
+    end
+
+    # Test macro parsing for interpolating into Args
+    @test fetch(Threads.@spawn 2+$2) == 4
+    @test fetch(Threads.@spawn Int($(2.0))) == 2
+    a = 2
+    @test fetch(Threads.@spawn *($a,$a)) == a^2
+    # Test macro parsing for interpolating into kwargs
+    @test fetch(Threads.@spawn sort($([3 2; 1 0]), dims=2)) == [2 3; 0 1]
+    @test fetch(Threads.@spawn sort([3 $2; 1 $0]; dims=$2)) == [2 3; 0 1]
+
+    # Test macro parsing supports multiple levels of interpolation
+    @testset "spawn macro multiple levels of interpolation" begin
+        # Use `ch` to synchronize within the tests to run after the local variables are
+        # updated, showcasing the problem and the solution.
+        ch = Channel()   # (This synchronization fixes test failure reported in #34141.)
+
+        @test fetch(Threads.@spawn "$($a)") == "$a"
+        let a = 1
+            # Interpolate the current value of `a` vs the value of `a` in the closure
+            t = Threads.@spawn (take!(ch); :(+($$a, $a, a)))
+            a = 2  # update `a` after spawning, before `t` runs
+            put!(ch, nothing)  # now run t
+            @test fetch(t) == Expr(:call, :+, 1, 2, :a)
+        end
+
+        # Test the difference between different levels of interpolation
+        # Without interpolation, each spawned task sees the last value of `i` (6);
+        # with interpolation, each spawned task has the value of `i` at time of `@spawn`.
+        let
+            oneinterp  = Vector{Any}(undef, 5)
+            twointerps = Vector{Any}(undef, 5)
+            @sync begin
+               local i = 1
+               while i <= 5
+                   Threads.@spawn (take!(ch); setindex!(oneinterp, :($i), $i))
+                   Threads.@spawn (take!(ch); setindex!(twointerps, :($($i)), $i))
+                   i += 1
+               end
+               for _ in 1:10; put!(ch, nothing); end # Now run all the tasks.
+            end
+            # The first definition _didn't_ interpolate i
+            @test oneinterp == fill(6, 5)
+            # The second definition _did_ interpolate i
+            @test twointerps == 1:5
+        end
+    end
+end
+
+@testset "@async interpolation" begin
+    # Args
+    @test fetch(@async 2+$2) == 4
+    @test fetch(@async Int($(2.0))) == 2
+    a = 2
+    @test fetch(@async *($a,$a)) == a^2
+    # kwargs
+    @test fetch(@async sort($([3 2; 1 0]), dims=2)) == [2 3; 0 1]
+    @test fetch(@async sort([3 $2; 1 $0]; dims=$2)) == [2 3; 0 1]
+
+    # Supports multiple levels of interpolation
+    @test fetch(@async :($a)) == a
+    @test fetch(@async :($($a))) == a
+    @test fetch(@async "$($a)") == "$a"
+end
+
+# Issue #34138
+@testset "spawn interpolation: macrocalls" begin
+    x = [reshape(1:4, 2, 2);]
+    @test fetch(Threads.@spawn @. $exp(x)) == @. $exp(x)
+    x = 2
+    @test @eval(fetch(@async 2+$x)) == 4
+end
diff -pruN 1.3.1+dfsg-1/test/threads.jl 1.4.0+dfsg-1/test/threads.jl
--- 1.3.1+dfsg-1/test/threads.jl	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/test/threads.jl	2020-03-21 16:36:32.000000000 +0000
@@ -13,3 +13,127 @@ let p, cmd = `$(Base.julia_cmd()) --depw
         error("threads test failed with nthreads == $other_nthreads")
     end
 end
+
+# issue #34415 - make sure external affinity settings work
+if Sys.islinux() && Sys.CPU_THREADS > 1 && Sys.which("taskset") !== nothing
+    run_with_affinity(spec) = readchomp(`taskset -c $spec $(Base.julia_cmd()) -e "run(\`taskset -p \$(getpid())\`)"`)
+    @test endswith(run_with_affinity("1"), "2")
+    @test endswith(run_with_affinity("0,1"), "3")
+end
+
+# issue #34769
+function idle_callback(handle)
+    idle = @Base.handle_as handle UvTestIdle
+    if idle.active
+        idle.count += 1
+        if idle.count == 1
+            # We want to hit the case where we're allowing
+            # the thread to go to sleep, which only happens
+            # after some default amount of time (DEFAULT_THREAD_SLEEP_THRESHOLD)
+            # so spend that amount of time here.
+            Libc.systemsleep(0.004)
+        elseif idle.count >= 10
+            lock(idle.cond)
+            try
+                notify(idle.cond, true)
+            finally
+                unlock(idle.cond)
+            end
+            idle.active = false
+        end
+    end
+    nothing
+end
+
+mutable struct UvTestIdle
+    handle::Ptr{Cvoid}
+    cond::Base.ThreadSynchronizer
+    isopen::Bool
+    active::Bool
+    count::Int
+
+    function UvTestIdle()
+        this = new(Libc.malloc(Base._sizeof_uv_idle), Base.ThreadSynchronizer(), true, false, 0)
+        Base.iolock_begin()
+        Base.associate_julia_struct(this.handle, this)
+        err = ccall(:uv_idle_init, Cint, (Ptr{Cvoid}, Ptr{Cvoid}),
+            Base.eventloop(), this.handle)
+        if err != 0
+            Libc.free(this.handle)
+            this.handle = C_NULL
+            throw(_UVError("uv_idle_init", err))
+        end
+        err = ccall(:uv_idle_start, Cint, (Ptr{Cvoid}, Ptr{Cvoid}),
+            this.handle, @cfunction(idle_callback, Cvoid, (Ptr{Cvoid},)))
+        if err != 0
+            Libc.free(this.handle)
+            this.handle = C_NULL
+            throw(_UVError("uv_idle_start", err))
+        end
+        finalizer(Base.uvfinalize, this)
+        Base.iolock_end()
+        return this
+    end
+end
+Base.unsafe_convert(::Type{Ptr{Cvoid}}, idle::UvTestIdle) = idle.handle
+
+function Base.uvfinalize(t::UvTestIdle)
+    Base.iolock_begin()
+    Base.lock(t.cond)
+    try
+        if t.handle != C_NULL
+            Base.disassociate_julia_struct(t.handle) # not going to call the usual close hooks
+            if t.isopen
+                t.isopen = false
+                ccall(:jl_close_uv, Cvoid, (Ptr{Cvoid},), t)
+            end
+            t.handle = C_NULL
+            notify(t.cond, false)
+        end
+    finally
+        unlock(t.cond)
+    end
+    Base.iolock_end()
+    nothing
+end
+
+function Base.wait(idle::UvTestIdle)
+    Base.iolock_begin()
+    Base.preserve_handle(idle)
+    Base.lock(idle.cond)
+    try
+        idle.active = true
+        wait(idle.cond)
+    finally
+        Base.unlock(idle.cond)
+        Base.unpreserve_handle(idle)
+        Base.iolock_end()
+    end
+end
+
+# Spawn another process as a watchdog. If this test fails, it'll unrecoverably
+# hang in the event loop. Another process needs to kill it
+cmd = """
+    @async (Base.wait_readnb(stdin, 1); exit())
+    sleep(100)
+    isopen(stdin) || exit()
+    println(stderr, "ERROR: Killing threads test due to watchdog expiry")
+    ccall(:uv_kill, Cint, (Cint, Cint), $(getpid()), Base.SIGTERM)
+"""
+proc = open(pipeline(`$(Base.julia_cmd()) -e $cmd`; stderr=stderr); write=true)
+
+let idle=UvTestIdle()
+    wait(idle)
+end
+
+using Base.Threads
+@threads for i = 1:1
+    let idle=UvTestIdle()
+        wait(idle)
+    end
+end
+
+@test process_running(proc)
+
+# We don't need the watchdog anymore
+close(proc.in)
diff -pruN 1.3.1+dfsg-1/test/tuple.jl 1.4.0+dfsg-1/test/tuple.jl
--- 1.3.1+dfsg-1/test/tuple.jl	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/test/tuple.jl	2020-03-21 16:36:32.000000000 +0000
@@ -89,6 +89,13 @@ end
 
     # issue #28915
     @test convert(Union{Tuple{}, Tuple{Int}}, (1,)) === (1,)
+
+    @testset "one-element containers" begin
+        r = Ref(3)
+        @test (3,) === @inferred Tuple(r)
+        z = Array{Float64,0}(undef); z[] = 3.0
+        @test (3.0,) === @inferred Tuple(z)
+    end
 end
 
 @testset "size" begin
@@ -247,6 +254,16 @@ end
     @test_throws ArgumentError mapfoldl(abs, =>, ())
 end
 
+@testset "filter" begin
+    @test filter(isodd, (1,2,3)) == (1, 3)
+    @test filter(isequal(2), (true, 2.0, 3)) === (2.0,)
+    @test filter(i -> true, ()) == ()
+    @test filter(identity, (true,)) === (true,)
+    longtuple = ntuple(identity, 20)
+    @test filter(iseven, longtuple) == ntuple(i->2i, 10)
+    @test filter(x -> x<2, (longtuple..., 1.5)) === (1, 1.5)
+end
+
 @testset "comparison and hash" begin
     @test isequal((), ())
     @test isequal((1,2,3), (1,2,3))
diff -pruN 1.3.1+dfsg-1/test/vecelement.jl 1.4.0+dfsg-1/test/vecelement.jl
--- 1.3.1+dfsg-1/test/vecelement.jl	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/test/vecelement.jl	2020-03-21 16:36:32.000000000 +0000
@@ -3,7 +3,7 @@
 make_value(::Type{T}, i::Integer) where {T<:Integer} = 3*i%T
 make_value(::Type{T},i::Integer) where {T<:AbstractFloat} = T(3*i)
 
-Vec{N,T} = NTuple{N,Base.VecElement{T}}
+const Vec{N,T} = NTuple{N,Base.VecElement{T}}
 
 # Crash report for #15244 motivated this test.
 @generated function thrice_iota(::Type{Vec{N,T}}) where {N,T}
@@ -73,6 +73,13 @@ end
 
 @test isa(VecElement((1,2)), VecElement{Tuple{Int,Int}})
 
+# test for alignment agreement (#32414)
+@noinline function bar32414(a)
+    v = ntuple(w -> VecElement(Float64(10w)), Val(8))
+    return a, (v, (a, (1e6, 1e9)))
+end
+@test bar32414(-35.0) === (-35.0, ((VecElement(10.0), VecElement(20.0), VecElement(30.0), VecElement(40.0), VecElement(50.0), VecElement(60.0), VecElement(70.0), VecElement(80.0)), (-35.0, (1.0e6, 1.0e9))))
+
 # The following test mimic SIMD.jl
 const _llvmtypes = Dict{DataType, String}(
     Float64 => "double",
@@ -105,14 +112,8 @@ end
 # Test various SIMD Vectors with known good sizes
 for T in (Float64, Float32, Int64, Int32)
     for N in 1:36
-        # For some vectortypes Julia emits llvm arrays instead of vectors
-        if N %  7 == 0 || N % 11 == 0 || N % 13 == 0 || N % 15 == 0 ||
-           N % 19 == 0 || N % 23 == 0 || N % 25 == 0 || N % 27 == 0 ||
-           N % 29 == 0 || N % 31 == 0
-            continue
-        end
-        a = ntuple(i->VecElement(T(i)), N)
-        result = ntuple(i-> VecElement(T(i+i)), N)
+        a = ntuple(i -> VecElement(T(i)), N)
+        result = ntuple(i -> VecElement(T(i+i)), N)
         b = vecadd(a, a)
         @test b == result
         b = f20961([a], [a])
diff -pruN 1.3.1+dfsg-1/VERSION 1.4.0+dfsg-1/VERSION
--- 1.3.1+dfsg-1/VERSION	2019-12-30 21:36:22.000000000 +0000
+++ 1.4.0+dfsg-1/VERSION	2020-03-21 16:36:32.000000000 +0000
@@ -1 +1 @@
-1.3.1
+1.4.0
